//#region src/utils.ts
function stdout() {
	return console._stdout || process.stdout || void 0;
}
function stderr() {
	return console._stderr || process.stderr || void 0;
}

//#endregion
export { stderr, stdout };