//#region src-js/package/config.ts
/**
* Define an Oxlint configuration with type inference.
*
* @param config - Oxlint configuration
* @returns Config unchanged
*/
function defineConfig(config) {
	return config;
}
//#endregion
export { defineConfig };
