export declare const readdirOrError: (path: string) => Promise<import("node:fs").Dirent<string>[] | Error>;
export declare const readdirOrErrorSync: (path: string) => import("node:fs").Dirent<string>[] | Error;
//# sourceMappingURL=readdir-or-error.d.ts.map