export declare const fixEPERM: (fn: (path: string) => Promise<unknown>) => (path: string) => Promise<void>;
export declare const fixEPERMSync: (fn: (path: string) => unknown) => (path: string) => void;
//# sourceMappingURL=fix-eperm.d.ts.map