import { a as sortTailwindClasses, n as formatEmbeddedDoc, r as formatFile, t as formatEmbeddedCode } from "./apis-rMlkuPw1.js";
export { formatEmbeddedCode, formatEmbeddedDoc, formatFile, sortTailwindClasses };
