//#region src/entry/utils.d.ts
type Handler = Function;
declare function getHandler(filename: string, name: string): Promise<Handler | null>;
declare function throwInNextTick(error: Error): void;

//#endregion
export { getHandler, throwInNextTick };