import { a as setCurrentWorkspace, i as destroyWorkspace, n as currentWorkspace, o as workspaces, r as currentWorkspaceUri, t as createWorkspace } from "./workspace2.js";
export { createWorkspace, currentWorkspace, currentWorkspaceUri, destroyWorkspace, setCurrentWorkspace, workspaces };
