//#region src-js/utils/globals.ts
/**
* Properties of global objects exported as variables.
*
* TSDown will replace e.g. `Object.keys` with import of `ObjectKeys` from this file.
*
* If you use any globals in code in `src-js` directory, you should add them to this file.
*
* See TSDown config file for more details.
*/
const { prototype: ObjectPrototype, hasOwn: ObjectHasOwn, keys: ObjectKeys, values: ObjectValues, freeze: ObjectFreeze, preventExtensions: ObjectPreventExtensions, defineProperty: ObjectDefineProperty, defineProperties: ObjectDefineProperties, create: ObjectCreate, assign: ObjectAssign, getPrototypeOf: ObjectGetPrototypeOf, setPrototypeOf: ObjectSetPrototypeOf, entries: ObjectEntries } = Object, { prototype: ArrayPrototype, isArray: ArrayIsArray, from: ArrayFrom } = Array, { min: MathMin, max: MathMax, floor: MathFloor } = Math, { parse: JSONParse, stringify: JSONStringify } = JSON, { ownKeys: ReflectOwnKeys } = Reflect, { iterator: SymbolIterator } = Symbol, { fromCodePoint: StringFromCodePoint } = String, { now: DateNow } = Date;
//#endregion
export { ObjectValues as _, JSONStringify as a, ObjectAssign as c, ObjectEntries as d, ObjectFreeze as f, ObjectPrototype as g, ObjectPreventExtensions as h, JSONParse as i, ObjectCreate as l, ObjectKeys as m, ArrayIsArray as n, MathMax as o, ObjectHasOwn as p, DateNow as r, MathMin as s, ArrayFrom as t, ObjectDefineProperty as u, StringFromCodePoint as v, SymbolIterator as y };
