import { a as __toESM, i as __require, t as __commonJSMin } from "./chunk-DSjvVL_1-CHQFAj82.js";
import { createRequire } from "node:module";
//#region ../../node_modules/.pnpm/prettier-plugin-tailwindcss@0.0.0-insiders.3997fbd_prettier@3.8.2/node_modules/prettier-plugin-tailwindcss/dist/jiti-Bb1dT6Cw.mjs
var require_jiti = /* @__PURE__ */ __commonJSMin(((exports, module) => {
	(() => {
		var e = { "./node_modules/.pnpm/mlly@1.8.0/node_modules/mlly/dist lazy recursive": function(e) {
			function webpackEmptyAsyncContext(e) {
				return Promise.resolve().then(function() {
					var t = /* @__PURE__ */ new Error("Cannot find module '" + e + "'");
					throw t.code = "MODULE_NOT_FOUND", t;
				});
			}
			webpackEmptyAsyncContext.keys = () => [], webpackEmptyAsyncContext.resolve = webpackEmptyAsyncContext, webpackEmptyAsyncContext.id = "./node_modules/.pnpm/mlly@1.8.0/node_modules/mlly/dist lazy recursive", e.exports = webpackEmptyAsyncContext;
		} }, t = {};
		function __webpack_require__(i) {
			var s = t[i];
			if (void 0 !== s) return s.exports;
			var r = t[i] = { exports: {} };
			return e[i](r, r.exports, __webpack_require__), r.exports;
		}
		__webpack_require__.n = (e) => {
			var t = e && e.__esModule ? () => e.default : () => e;
			return __webpack_require__.d(t, { a: t }), t;
		}, __webpack_require__.d = (e, t) => {
			for (var i in t) __webpack_require__.o(t, i) && !__webpack_require__.o(e, i) && Object.defineProperty(e, i, {
				enumerable: !0,
				get: t[i]
			});
		}, __webpack_require__.o = (e, t) => Object.prototype.hasOwnProperty.call(e, t);
		var i = {};
		(() => {
			"use strict";
			var _globalThis$process6, _globalThis$process7, _globalThis$process8, _globalThis$process9, _globalThis$process10, _globalThis$process11, _globalThis$navigator, _Lt$WriteStream, _Lt$WriteStream$hasCo;
			__webpack_require__.d(i, { default: () => createJiti });
			const e = __require("node:os");
			var t = [
				509,
				0,
				227,
				0,
				150,
				4,
				294,
				9,
				1368,
				2,
				2,
				1,
				6,
				3,
				41,
				2,
				5,
				0,
				166,
				1,
				574,
				3,
				9,
				9,
				7,
				9,
				32,
				4,
				318,
				1,
				80,
				3,
				71,
				10,
				50,
				3,
				123,
				2,
				54,
				14,
				32,
				10,
				3,
				1,
				11,
				3,
				46,
				10,
				8,
				0,
				46,
				9,
				7,
				2,
				37,
				13,
				2,
				9,
				6,
				1,
				45,
				0,
				13,
				2,
				49,
				13,
				9,
				3,
				2,
				11,
				83,
				11,
				7,
				0,
				3,
				0,
				158,
				11,
				6,
				9,
				7,
				3,
				56,
				1,
				2,
				6,
				3,
				1,
				3,
				2,
				10,
				0,
				11,
				1,
				3,
				6,
				4,
				4,
				68,
				8,
				2,
				0,
				3,
				0,
				2,
				3,
				2,
				4,
				2,
				0,
				15,
				1,
				83,
				17,
				10,
				9,
				5,
				0,
				82,
				19,
				13,
				9,
				214,
				6,
				3,
				8,
				28,
				1,
				83,
				16,
				16,
				9,
				82,
				12,
				9,
				9,
				7,
				19,
				58,
				14,
				5,
				9,
				243,
				14,
				166,
				9,
				71,
				5,
				2,
				1,
				3,
				3,
				2,
				0,
				2,
				1,
				13,
				9,
				120,
				6,
				3,
				6,
				4,
				0,
				29,
				9,
				41,
				6,
				2,
				3,
				9,
				0,
				10,
				10,
				47,
				15,
				343,
				9,
				54,
				7,
				2,
				7,
				17,
				9,
				57,
				21,
				2,
				13,
				123,
				5,
				4,
				0,
				2,
				1,
				2,
				6,
				2,
				0,
				9,
				9,
				49,
				4,
				2,
				1,
				2,
				4,
				9,
				9,
				330,
				3,
				10,
				1,
				2,
				0,
				49,
				6,
				4,
				4,
				14,
				10,
				5350,
				0,
				7,
				14,
				11465,
				27,
				2343,
				9,
				87,
				9,
				39,
				4,
				60,
				6,
				26,
				9,
				535,
				9,
				470,
				0,
				2,
				54,
				8,
				3,
				82,
				0,
				12,
				1,
				19628,
				1,
				4178,
				9,
				519,
				45,
				3,
				22,
				543,
				4,
				4,
				5,
				9,
				7,
				3,
				6,
				31,
				3,
				149,
				2,
				1418,
				49,
				513,
				54,
				5,
				49,
				9,
				0,
				15,
				0,
				23,
				4,
				2,
				14,
				1361,
				6,
				2,
				16,
				3,
				6,
				2,
				1,
				2,
				4,
				101,
				0,
				161,
				6,
				10,
				9,
				357,
				0,
				62,
				13,
				499,
				13,
				245,
				1,
				2,
				9,
				726,
				6,
				110,
				6,
				6,
				9,
				4759,
				9,
				787719,
				239
			], s = [
				0,
				11,
				2,
				25,
				2,
				18,
				2,
				1,
				2,
				14,
				3,
				13,
				35,
				122,
				70,
				52,
				268,
				28,
				4,
				48,
				48,
				31,
				14,
				29,
				6,
				37,
				11,
				29,
				3,
				35,
				5,
				7,
				2,
				4,
				43,
				157,
				19,
				35,
				5,
				35,
				5,
				39,
				9,
				51,
				13,
				10,
				2,
				14,
				2,
				6,
				2,
				1,
				2,
				10,
				2,
				14,
				2,
				6,
				2,
				1,
				4,
				51,
				13,
				310,
				10,
				21,
				11,
				7,
				25,
				5,
				2,
				41,
				2,
				8,
				70,
				5,
				3,
				0,
				2,
				43,
				2,
				1,
				4,
				0,
				3,
				22,
				11,
				22,
				10,
				30,
				66,
				18,
				2,
				1,
				11,
				21,
				11,
				25,
				71,
				55,
				7,
				1,
				65,
				0,
				16,
				3,
				2,
				2,
				2,
				28,
				43,
				28,
				4,
				28,
				36,
				7,
				2,
				27,
				28,
				53,
				11,
				21,
				11,
				18,
				14,
				17,
				111,
				72,
				56,
				50,
				14,
				50,
				14,
				35,
				39,
				27,
				10,
				22,
				251,
				41,
				7,
				1,
				17,
				2,
				60,
				28,
				11,
				0,
				9,
				21,
				43,
				17,
				47,
				20,
				28,
				22,
				13,
				52,
				58,
				1,
				3,
				0,
				14,
				44,
				33,
				24,
				27,
				35,
				30,
				0,
				3,
				0,
				9,
				34,
				4,
				0,
				13,
				47,
				15,
				3,
				22,
				0,
				2,
				0,
				36,
				17,
				2,
				24,
				20,
				1,
				64,
				6,
				2,
				0,
				2,
				3,
				2,
				14,
				2,
				9,
				8,
				46,
				39,
				7,
				3,
				1,
				3,
				21,
				2,
				6,
				2,
				1,
				2,
				4,
				4,
				0,
				19,
				0,
				13,
				4,
				31,
				9,
				2,
				0,
				3,
				0,
				2,
				37,
				2,
				0,
				26,
				0,
				2,
				0,
				45,
				52,
				19,
				3,
				21,
				2,
				31,
				47,
				21,
				1,
				2,
				0,
				185,
				46,
				42,
				3,
				37,
				47,
				21,
				0,
				60,
				42,
				14,
				0,
				72,
				26,
				38,
				6,
				186,
				43,
				117,
				63,
				32,
				7,
				3,
				0,
				3,
				7,
				2,
				1,
				2,
				23,
				16,
				0,
				2,
				0,
				95,
				7,
				3,
				38,
				17,
				0,
				2,
				0,
				29,
				0,
				11,
				39,
				8,
				0,
				22,
				0,
				12,
				45,
				20,
				0,
				19,
				72,
				200,
				32,
				32,
				8,
				2,
				36,
				18,
				0,
				50,
				29,
				113,
				6,
				2,
				1,
				2,
				37,
				22,
				0,
				26,
				5,
				2,
				1,
				2,
				31,
				15,
				0,
				328,
				18,
				16,
				0,
				2,
				12,
				2,
				33,
				125,
				0,
				80,
				921,
				103,
				110,
				18,
				195,
				2637,
				96,
				16,
				1071,
				18,
				5,
				26,
				3994,
				6,
				582,
				6842,
				29,
				1763,
				568,
				8,
				30,
				18,
				78,
				18,
				29,
				19,
				47,
				17,
				3,
				32,
				20,
				6,
				18,
				433,
				44,
				212,
				63,
				129,
				74,
				6,
				0,
				67,
				12,
				65,
				1,
				2,
				0,
				29,
				6135,
				9,
				1237,
				42,
				9,
				8936,
				3,
				2,
				6,
				2,
				1,
				2,
				290,
				16,
				0,
				30,
				2,
				3,
				0,
				15,
				3,
				9,
				395,
				2309,
				106,
				6,
				12,
				4,
				8,
				8,
				9,
				5991,
				84,
				2,
				70,
				2,
				1,
				3,
				0,
				3,
				1,
				3,
				3,
				2,
				11,
				2,
				0,
				2,
				6,
				2,
				64,
				2,
				3,
				3,
				7,
				2,
				6,
				2,
				27,
				2,
				3,
				2,
				4,
				2,
				0,
				4,
				6,
				2,
				339,
				3,
				24,
				2,
				24,
				2,
				30,
				2,
				24,
				2,
				30,
				2,
				24,
				2,
				30,
				2,
				24,
				2,
				30,
				2,
				24,
				2,
				7,
				1845,
				30,
				7,
				5,
				262,
				61,
				147,
				44,
				11,
				6,
				17,
				0,
				322,
				29,
				19,
				43,
				485,
				27,
				229,
				29,
				3,
				0,
				496,
				6,
				2,
				3,
				2,
				1,
				2,
				14,
				2,
				196,
				60,
				67,
				8,
				0,
				1205,
				3,
				2,
				26,
				2,
				1,
				2,
				0,
				3,
				0,
				2,
				9,
				2,
				3,
				2,
				0,
				2,
				0,
				7,
				0,
				5,
				0,
				2,
				0,
				2,
				0,
				2,
				2,
				2,
				1,
				2,
				0,
				3,
				0,
				2,
				0,
				2,
				0,
				2,
				0,
				2,
				0,
				2,
				1,
				2,
				0,
				3,
				3,
				2,
				6,
				2,
				3,
				2,
				3,
				2,
				0,
				2,
				9,
				2,
				16,
				6,
				2,
				2,
				4,
				2,
				16,
				4421,
				42719,
				33,
				4153,
				7,
				221,
				3,
				5761,
				15,
				7472,
				16,
				621,
				2467,
				541,
				1507,
				4938,
				6,
				4191
			], r = "ªµºÀ-ÖØ-öø-ˁˆ-ˑˠ-ˤˬˮͰ-ʹͶͷͺ-ͽͿΆΈ-ΊΌΎ-ΡΣ-ϵϷ-ҁҊ-ԯԱ-Ֆՙՠ-ֈא-תׯ-ײؠ-يٮٯٱ-ۓەۥۦۮۯۺ-ۼۿܐܒ-ܯݍ-ޥޱߊ-ߪߴߵߺࠀ-ࠕࠚࠤࠨࡀ-ࡘࡠ-ࡪࡰ-ࢇࢉ-ࢎࢠ-ࣉऄ-हऽॐक़-ॡॱ-ঀঅ-ঌএঐও-নপ-রলশ-হঽৎড়ঢ়য়-ৡৰৱৼਅ-ਊਏਐਓ-ਨਪ-ਰਲਲ਼ਵਸ਼ਸਹਖ਼-ੜਫ਼ੲ-ੴઅ-ઍએ-ઑઓ-નપ-રલળવ-હઽૐૠૡૹଅ-ଌଏଐଓ-ନପ-ରଲଳଵ-ହଽଡ଼ଢ଼ୟ-ୡୱஃஅ-ஊஎ-ஐஒ-கஙசஜஞடணதந-பம-ஹௐఅ-ఌఎ-ఐఒ-నప-హఽౘ-ౚౝౠౡಀಅ-ಌಎ-ಐಒ-ನಪ-ಳವ-ಹಽೝೞೠೡೱೲഄ-ഌഎ-ഐഒ-ഺഽൎൔ-ൖൟ-ൡൺ-ൿඅ-ඖක-නඳ-රලව-ෆก-ะาำเ-ๆກຂຄຆ-ຊຌ-ຣລວ-ະາຳຽເ-ໄໆໜ-ໟༀཀ-ཇཉ-ཬྈ-ྌက-ဪဿၐ-ၕၚ-ၝၡၥၦၮ-ၰၵ-ႁႎႠ-ჅჇჍა-ჺჼ-ቈቊ-ቍቐ-ቖቘቚ-ቝበ-ኈኊ-ኍነ-ኰኲ-ኵኸ-ኾዀዂ-ዅወ-ዖዘ-ጐጒ-ጕጘ-ፚᎀ-ᎏᎠ-Ᏽᏸ-ᏽᐁ-ᙬᙯ-ᙿᚁ-ᚚᚠ-ᛪᛮ-ᛸᜀ-ᜑᜟ-ᜱᝀ-ᝑᝠ-ᝬᝮ-ᝰក-ឳៗៜᠠ-ᡸᢀ-ᢨᢪᢰ-ᣵᤀ-ᤞᥐ-ᥭᥰ-ᥴᦀ-ᦫᦰ-ᧉᨀ-ᨖᨠ-ᩔᪧᬅ-ᬳᭅ-ᭌᮃ-ᮠᮮᮯᮺ-ᯥᰀ-ᰣᱍ-ᱏᱚ-ᱽᲀ-ᲊᲐ-ᲺᲽ-Ჿᳩ-ᳬᳮ-ᳳᳵᳶᳺᴀ-ᶿḀ-ἕἘ-Ἕἠ-ὅὈ-Ὅὐ-ὗὙὛὝὟ-ώᾀ-ᾴᾶ-ᾼιῂ-ῄῆ-ῌῐ-ΐῖ-Ίῠ-Ῥῲ-ῴῶ-ῼⁱⁿₐ-ₜℂℇℊ-ℓℕ℘-ℝℤΩℨK-ℹℼ-ℿⅅ-ⅉⅎⅠ-ↈⰀ-ⳤⳫ-ⳮⳲⳳⴀ-ⴥⴧⴭⴰ-ⵧⵯⶀ-ⶖⶠ-ⶦⶨ-ⶮⶰ-ⶶⶸ-ⶾⷀ-ⷆⷈ-ⷎⷐ-ⷖⷘ-ⷞ々-〇〡-〩〱-〵〸-〼ぁ-ゖ゛-ゟァ-ヺー-ヿㄅ-ㄯㄱ-ㆎㆠ-ㆿㇰ-ㇿ㐀-䶿一-ꒌꓐ-ꓽꔀ-ꘌꘐ-ꘟꘪꘫꙀ-ꙮꙿ-ꚝꚠ-ꛯꜗ-ꜟꜢ-ꞈꞋ-ꟍꟐꟑꟓꟕ-Ƛꟲ-ꠁꠃ-ꠅꠇ-ꠊꠌ-ꠢꡀ-ꡳꢂ-ꢳꣲ-ꣷꣻꣽꣾꤊ-ꤥꤰ-ꥆꥠ-ꥼꦄ-ꦲꧏꧠ-ꧤꧦ-ꧯꧺ-ꧾꨀ-ꨨꩀ-ꩂꩄ-ꩋꩠ-ꩶꩺꩾ-ꪯꪱꪵꪶꪹ-ꪽꫀꫂꫛ-ꫝꫠ-ꫪꫲ-ꫴꬁ-ꬆꬉ-ꬎꬑ-ꬖꬠ-ꬦꬨ-ꬮꬰ-ꭚꭜ-ꭩꭰ-ꯢ가-힣ힰ-ퟆퟋ-ퟻ豈-舘並-龎ﬀ-ﬆﬓ-ﬗיִײַ-ﬨשׁ-זּטּ-לּמּנּסּףּפּצּ-ﮱﯓ-ﴽﵐ-ﶏﶒ-ﷇﷰ-ﷻﹰ-ﹴﹶ-ﻼＡ-Ｚａ-ｚｦ-ﾾￂ-ￇￊ-ￏￒ-ￗￚ-ￜ", n = {
				3: "abstract boolean byte char class double enum export extends final float goto implements import int interface long native package private protected public short static super synchronized throws transient volatile",
				5: "class enum extends super const export import",
				6: "enum",
				strict: "implements interface let package private protected public static yield",
				strictBind: "eval arguments"
			}, a = "break case catch continue debugger default do else finally for function if return switch throw try var while with null true false instanceof typeof void delete new in this", o = {
				5: a,
				"5module": a + " export import",
				6: a + " const class extends export import super"
			}, h = /^in(stanceof)?$/, c = new RegExp("[" + r + "]"), p = new RegExp("[" + r + "‌‍·̀-ͯ·҃-֑҇-ׇֽֿׁׂׅׄؐ-ًؚ-٩ٰۖ-ۜ۟-۪ۤۧۨ-ۭ۰-۹ܑܰ-݊ަ-ް߀-߉߫-߽߳ࠖ-࠙ࠛ-ࠣࠥ-ࠧࠩ-࡙࠭-࡛ࢗ-࢟࣊-ࣣ࣡-ःऺ-़ा-ॏ॑-ॗॢॣ०-९ঁ-ঃ়া-ৄেৈো-্ৗৢৣ০-৯৾ਁ-ਃ਼ਾ-ੂੇੈੋ-੍ੑ੦-ੱੵઁ-ઃ઼ા-ૅે-ૉો-્ૢૣ૦-૯ૺ-૿ଁ-ଃ଼ା-ୄେୈୋ-୍୕-ୗୢୣ୦-୯ஂா-ூெ-ைொ-்ௗ௦-௯ఀ-ఄ఼ా-ౄె-ైొ-్ౕౖౢౣ౦-౯ಁ-ಃ಼ಾ-ೄೆ-ೈೊ-್ೕೖೢೣ೦-೯ೳഀ-ഃ഻഼ാ-ൄെ-ൈൊ-്ൗൢൣ൦-൯ඁ-ඃ්ා-ුූෘ-ෟ෦-෯ෲෳัิ-ฺ็-๎๐-๙ັິ-ຼ່-໎໐-໙༘༙༠-༩༹༵༷༾༿ཱ-྄྆྇ྍ-ྗྙ-ྼ࿆ါ-ှ၀-၉ၖ-ၙၞ-ၠၢ-ၤၧ-ၭၱ-ၴႂ-ႍႏ-ႝ፝-፟፩-፱ᜒ-᜕ᜲ-᜴ᝒᝓᝲᝳ឴-៓៝០-៩᠋-᠍᠏-᠙ᢩᤠ-ᤫᤰ-᤻᥆-᥏᧐-᧚ᨗ-ᨛᩕ-ᩞ᩠-᩿᩼-᪉᪐-᪙᪰-᪽ᪿ-ᫎᬀ-ᬄ᬴-᭄᭐-᭙᭫-᭳ᮀ-ᮂᮡ-ᮭ᮰-᮹᯦-᯳ᰤ-᰷᱀-᱉᱐-᱙᳐-᳔᳒-᳨᳭᳴᳷-᳹᷀-᷿‌‍‿⁀⁔⃐-⃥⃜⃡-⃰⳯-⵿⳱ⷠ-〪ⷿ-゙゚〯・꘠-꘩꙯ꙴ-꙽ꚞꚟ꛰꛱ꠂ꠆ꠋꠣ-ꠧ꠬ꢀꢁꢴ-ꣅ꣐-꣙꣠-꣱ꣿ-꤉ꤦ-꤭ꥇ-꥓ꦀ-ꦃ꦳-꧀꧐-꧙ꧥ꧰-꧹ꨩ-ꨶꩃꩌꩍ꩐-꩙ꩻ-ꩽꪰꪲ-ꪴꪷꪸꪾ꪿꫁ꫫ-ꫯꫵ꫶ꯣ-ꯪ꯬꯭꯰-꯹ﬞ︀-️︠-︯︳︴﹍-﹏０-９＿･]");
			function isInAstralSet(e, t) {
				for (var i = 65536, s = 0; s < t.length; s += 2) {
					if ((i += t[s]) > e) return !1;
					if ((i += t[s + 1]) >= e) return !0;
				}
				return !1;
			}
			function isIdentifierStart(e, t) {
				return e < 65 ? 36 === e : e < 91 || (e < 97 ? 95 === e : e < 123 || (e <= 65535 ? e >= 170 && c.test(String.fromCharCode(e)) : !1 !== t && isInAstralSet(e, s)));
			}
			function isIdentifierChar(e, i) {
				return e < 48 ? 36 === e : e < 58 || !(e < 65) && (e < 91 || (e < 97 ? 95 === e : e < 123 || (e <= 65535 ? e >= 170 && p.test(String.fromCharCode(e)) : !1 !== i && (isInAstralSet(e, s) || isInAstralSet(e, t)))));
			}
			var acorn_TokenType = function(e, t) {
				void 0 === t && (t = {}), this.label = e, this.keyword = t.keyword, this.beforeExpr = !!t.beforeExpr, this.startsExpr = !!t.startsExpr, this.isLoop = !!t.isLoop, this.isAssign = !!t.isAssign, this.prefix = !!t.prefix, this.postfix = !!t.postfix, this.binop = t.binop || null, this.updateContext = null;
			};
			function binop(e, t) {
				return new acorn_TokenType(e, {
					beforeExpr: !0,
					binop: t
				});
			}
			var l = { beforeExpr: !0 }, u = { startsExpr: !0 }, d = {};
			function kw(e, t) {
				return void 0 === t && (t = {}), t.keyword = e, d[e] = new acorn_TokenType(e, t);
			}
			var f = {
				num: new acorn_TokenType("num", u),
				regexp: new acorn_TokenType("regexp", u),
				string: new acorn_TokenType("string", u),
				name: new acorn_TokenType("name", u),
				privateId: new acorn_TokenType("privateId", u),
				eof: new acorn_TokenType("eof"),
				bracketL: new acorn_TokenType("[", {
					beforeExpr: !0,
					startsExpr: !0
				}),
				bracketR: new acorn_TokenType("]"),
				braceL: new acorn_TokenType("{", {
					beforeExpr: !0,
					startsExpr: !0
				}),
				braceR: new acorn_TokenType("}"),
				parenL: new acorn_TokenType("(", {
					beforeExpr: !0,
					startsExpr: !0
				}),
				parenR: new acorn_TokenType(")"),
				comma: new acorn_TokenType(",", l),
				semi: new acorn_TokenType(";", l),
				colon: new acorn_TokenType(":", l),
				dot: new acorn_TokenType("."),
				question: new acorn_TokenType("?", l),
				questionDot: new acorn_TokenType("?."),
				arrow: new acorn_TokenType("=>", l),
				template: new acorn_TokenType("template"),
				invalidTemplate: new acorn_TokenType("invalidTemplate"),
				ellipsis: new acorn_TokenType("...", l),
				backQuote: new acorn_TokenType("`", u),
				dollarBraceL: new acorn_TokenType("${", {
					beforeExpr: !0,
					startsExpr: !0
				}),
				eq: new acorn_TokenType("=", {
					beforeExpr: !0,
					isAssign: !0
				}),
				assign: new acorn_TokenType("_=", {
					beforeExpr: !0,
					isAssign: !0
				}),
				incDec: new acorn_TokenType("++/--", {
					prefix: !0,
					postfix: !0,
					startsExpr: !0
				}),
				prefix: new acorn_TokenType("!/~", {
					beforeExpr: !0,
					prefix: !0,
					startsExpr: !0
				}),
				logicalOR: binop("||", 1),
				logicalAND: binop("&&", 2),
				bitwiseOR: binop("|", 3),
				bitwiseXOR: binop("^", 4),
				bitwiseAND: binop("&", 5),
				equality: binop("==/!=/===/!==", 6),
				relational: binop("</>/<=/>=", 7),
				bitShift: binop("<</>>/>>>", 8),
				plusMin: new acorn_TokenType("+/-", {
					beforeExpr: !0,
					binop: 9,
					prefix: !0,
					startsExpr: !0
				}),
				modulo: binop("%", 10),
				star: binop("*", 10),
				slash: binop("/", 10),
				starstar: new acorn_TokenType("**", { beforeExpr: !0 }),
				coalesce: binop("??", 1),
				_break: kw("break"),
				_case: kw("case", l),
				_catch: kw("catch"),
				_continue: kw("continue"),
				_debugger: kw("debugger"),
				_default: kw("default", l),
				_do: kw("do", {
					isLoop: !0,
					beforeExpr: !0
				}),
				_else: kw("else", l),
				_finally: kw("finally"),
				_for: kw("for", { isLoop: !0 }),
				_function: kw("function", u),
				_if: kw("if"),
				_return: kw("return", l),
				_switch: kw("switch"),
				_throw: kw("throw", l),
				_try: kw("try"),
				_var: kw("var"),
				_const: kw("const"),
				_while: kw("while", { isLoop: !0 }),
				_with: kw("with"),
				_new: kw("new", {
					beforeExpr: !0,
					startsExpr: !0
				}),
				_this: kw("this", u),
				_super: kw("super", u),
				_class: kw("class", u),
				_extends: kw("extends", l),
				_export: kw("export"),
				_import: kw("import", u),
				_null: kw("null", u),
				_true: kw("true", u),
				_false: kw("false", u),
				_in: kw("in", {
					beforeExpr: !0,
					binop: 7
				}),
				_instanceof: kw("instanceof", {
					beforeExpr: !0,
					binop: 7
				}),
				_typeof: kw("typeof", {
					beforeExpr: !0,
					prefix: !0,
					startsExpr: !0
				}),
				_void: kw("void", {
					beforeExpr: !0,
					prefix: !0,
					startsExpr: !0
				}),
				_delete: kw("delete", {
					beforeExpr: !0,
					prefix: !0,
					startsExpr: !0
				})
			}, m = /\r\n?|\n|\u2028|\u2029/, g = new RegExp(m.source, "g");
			function isNewLine(e) {
				return 10 === e || 13 === e || 8232 === e || 8233 === e;
			}
			function nextLineBreak(e, t, i) {
				void 0 === i && (i = e.length);
				for (var s = t; s < i; s++) {
					var r = e.charCodeAt(s);
					if (isNewLine(r)) return s < i - 1 && 13 === r && 10 === e.charCodeAt(s + 1) ? s + 2 : s + 1;
				}
				return -1;
			}
			var x = /[\u1680\u2000-\u200a\u202f\u205f\u3000\ufeff]/, v = /(?:\s|\/\/.*|\/\*[^]*?\*\/)*/g, y = Object.prototype, _ = y.hasOwnProperty, E = y.toString, b = Object.hasOwn || function(e, t) {
				return _.call(e, t);
			}, S = Array.isArray || function(e) {
				return "[object Array]" === E.call(e);
			}, k = Object.create(null);
			function wordsRegexp(e) {
				return k[e] || (k[e] = new RegExp("^(?:" + e.replace(/ /g, "|") + ")$"));
			}
			function codePointToString(e) {
				return e <= 65535 ? String.fromCharCode(e) : (e -= 65536, String.fromCharCode(55296 + (e >> 10), 56320 + (1023 & e)));
			}
			var w = /(?:[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])/, acorn_Position = function(e, t) {
				this.line = e, this.column = t;
			};
			acorn_Position.prototype.offset = function(e) {
				return new acorn_Position(this.line, this.column + e);
			};
			var acorn_SourceLocation = function(e, t, i) {
				this.start = t, this.end = i, null !== e.sourceFile && (this.source = e.sourceFile);
			};
			function getLineInfo(e, t) {
				for (var i = 1, s = 0;;) {
					var r = nextLineBreak(e, s, t);
					if (r < 0) return new acorn_Position(i, t - s);
					++i, s = r;
				}
			}
			var I = {
				ecmaVersion: null,
				sourceType: "script",
				onInsertedSemicolon: null,
				onTrailingComma: null,
				allowReserved: null,
				allowReturnOutsideFunction: !1,
				allowImportExportEverywhere: !1,
				allowAwaitOutsideFunction: null,
				allowSuperOutsideMethod: null,
				allowHashBang: !1,
				checkPrivateFields: !0,
				locations: !1,
				onToken: null,
				onComment: null,
				ranges: !1,
				program: null,
				sourceFile: null,
				directSourceFile: null,
				preserveParens: !1
			}, C = !1;
			function getOptions(e) {
				var t = {};
				for (var i in I) t[i] = e && b(e, i) ? e[i] : I[i];
				if ("latest" === t.ecmaVersion ? t.ecmaVersion = 1e8 : null == t.ecmaVersion ? (!C && "object" == typeof console && console.warn && (C = !0, console.warn("Since Acorn 8.0.0, options.ecmaVersion is required.\nDefaulting to 2020, but this will stop working in the future.")), t.ecmaVersion = 11) : t.ecmaVersion >= 2015 && (t.ecmaVersion -= 2009), t.allowReserved ?? (t.allowReserved = t.ecmaVersion < 5), e && null != e.allowHashBang || (t.allowHashBang = t.ecmaVersion >= 14), S(t.onToken)) {
					var s = t.onToken;
					t.onToken = function(e) {
						return s.push(e);
					};
				}
				return S(t.onComment) && (t.onComment = function(e, t) {
					return function(i, s, r, n, a, o) {
						var h = {
							type: i ? "Block" : "Line",
							value: s,
							start: r,
							end: n
						};
						e.locations && (h.loc = new acorn_SourceLocation(this, a, o)), e.ranges && (h.range = [r, n]), t.push(h);
					};
				}(t, t.onComment)), t;
			}
			var R = 256, P = 259;
			function functionFlags(e, t) {
				return 2 | (e ? 4 : 0) | (t ? 8 : 0);
			}
			var acorn_Parser = function(e, t, i) {
				this.options = e = getOptions(e), this.sourceFile = e.sourceFile, this.keywords = wordsRegexp(o[e.ecmaVersion >= 6 ? 6 : "module" === e.sourceType ? "5module" : 5]);
				var s = "";
				!0 !== e.allowReserved && (s = n[e.ecmaVersion >= 6 ? 6 : 5 === e.ecmaVersion ? 5 : 3], "module" === e.sourceType && (s += " await")), this.reservedWords = wordsRegexp(s);
				var r = (s ? s + " " : "") + n.strict;
				this.reservedWordsStrict = wordsRegexp(r), this.reservedWordsStrictBind = wordsRegexp(r + " " + n.strictBind), this.input = String(t), this.containsEsc = !1, i ? (this.pos = i, this.lineStart = this.input.lastIndexOf("\n", i - 1) + 1, this.curLine = this.input.slice(0, this.lineStart).split(m).length) : (this.pos = this.lineStart = 0, this.curLine = 1), this.type = f.eof, this.value = null, this.start = this.end = this.pos, this.startLoc = this.endLoc = this.curPosition(), this.lastTokEndLoc = this.lastTokStartLoc = null, this.lastTokStart = this.lastTokEnd = this.pos, this.context = this.initialContext(), this.exprAllowed = !0, this.inModule = "module" === e.sourceType, this.strict = this.inModule || this.strictDirective(this.pos), this.potentialArrowAt = -1, this.potentialArrowInForAwait = !1, this.yieldPos = this.awaitPos = this.awaitIdentPos = 0, this.labels = [], this.undefinedExports = Object.create(null), 0 === this.pos && e.allowHashBang && "#!" === this.input.slice(0, 2) && this.skipLineComment(2), this.scopeStack = [], this.enterScope(1), this.regexpState = null, this.privateNameStack = [];
			}, T = {
				inFunction: { configurable: !0 },
				inGenerator: { configurable: !0 },
				inAsync: { configurable: !0 },
				canAwait: { configurable: !0 },
				allowSuper: { configurable: !0 },
				allowDirectSuper: { configurable: !0 },
				treatFunctionsAsVar: { configurable: !0 },
				allowNewDotTarget: { configurable: !0 },
				inClassStaticBlock: { configurable: !0 }
			};
			acorn_Parser.prototype.parse = function() {
				var e = this.options.program || this.startNode();
				return this.nextToken(), this.parseTopLevel(e);
			}, T.inFunction.get = function() {
				return (2 & this.currentVarScope().flags) > 0;
			}, T.inGenerator.get = function() {
				return (8 & this.currentVarScope().flags) > 0;
			}, T.inAsync.get = function() {
				return (4 & this.currentVarScope().flags) > 0;
			}, T.canAwait.get = function() {
				for (var e = this.scopeStack.length - 1; e >= 0; e--) {
					var t = this.scopeStack[e].flags;
					if (768 & t) return !1;
					if (2 & t) return (4 & t) > 0;
				}
				return this.inModule && this.options.ecmaVersion >= 13 || this.options.allowAwaitOutsideFunction;
			}, T.allowSuper.get = function() {
				return (64 & this.currentThisScope().flags) > 0 || this.options.allowSuperOutsideMethod;
			}, T.allowDirectSuper.get = function() {
				return (128 & this.currentThisScope().flags) > 0;
			}, T.treatFunctionsAsVar.get = function() {
				return this.treatFunctionsAsVarInScope(this.currentScope());
			}, T.allowNewDotTarget.get = function() {
				for (var e = this.scopeStack.length - 1; e >= 0; e--) {
					var t = this.scopeStack[e].flags;
					if (768 & t || 2 & t && !(16 & t)) return !0;
				}
				return !1;
			}, T.inClassStaticBlock.get = function() {
				return (this.currentVarScope().flags & R) > 0;
			}, acorn_Parser.extend = function() {
				for (var e = [], t = arguments.length; t--;) e[t] = arguments[t];
				for (var i = this, s = 0; s < e.length; s++) i = e[s](i);
				return i;
			}, acorn_Parser.parse = function(e, t) {
				return new this(t, e).parse();
			}, acorn_Parser.parseExpressionAt = function(e, t, i) {
				var s = new this(i, e, t);
				return s.nextToken(), s.parseExpression();
			}, acorn_Parser.tokenizer = function(e, t) {
				return new this(t, e);
			}, Object.defineProperties(acorn_Parser.prototype, T);
			var A = acorn_Parser.prototype, N = /^(?:'((?:\\[^]|[^'\\])*?)'|"((?:\\[^]|[^"\\])*?)")/;
			A.strictDirective = function(e) {
				if (this.options.ecmaVersion < 5) return !1;
				for (;;) {
					v.lastIndex = e, e += v.exec(this.input)[0].length;
					var t = N.exec(this.input.slice(e));
					if (!t) return !1;
					if ("use strict" === (t[1] || t[2])) {
						v.lastIndex = e + t[0].length;
						var i = v.exec(this.input), s = i.index + i[0].length, r = this.input.charAt(s);
						return ";" === r || "}" === r || m.test(i[0]) && !(/[(`.[+\-/*%<>=,?^&]/.test(r) || "!" === r && "=" === this.input.charAt(s + 1));
					}
					e += t[0].length, v.lastIndex = e, e += v.exec(this.input)[0].length, ";" === this.input[e] && e++;
				}
			}, A.eat = function(e) {
				return this.type === e && (this.next(), !0);
			}, A.isContextual = function(e) {
				return this.type === f.name && this.value === e && !this.containsEsc;
			}, A.eatContextual = function(e) {
				return !!this.isContextual(e) && (this.next(), !0);
			}, A.expectContextual = function(e) {
				this.eatContextual(e) || this.unexpected();
			}, A.canInsertSemicolon = function() {
				return this.type === f.eof || this.type === f.braceR || m.test(this.input.slice(this.lastTokEnd, this.start));
			}, A.insertSemicolon = function() {
				if (this.canInsertSemicolon()) return this.options.onInsertedSemicolon && this.options.onInsertedSemicolon(this.lastTokEnd, this.lastTokEndLoc), !0;
			}, A.semicolon = function() {
				this.eat(f.semi) || this.insertSemicolon() || this.unexpected();
			}, A.afterTrailingComma = function(e, t) {
				if (this.type === e) return this.options.onTrailingComma && this.options.onTrailingComma(this.lastTokStart, this.lastTokStartLoc), t || this.next(), !0;
			}, A.expect = function(e) {
				this.eat(e) || this.unexpected();
			}, A.unexpected = function(e) {
				this.raise(null != e ? e : this.start, "Unexpected token");
			};
			var acorn_DestructuringErrors = function() {
				this.shorthandAssign = this.trailingComma = this.parenthesizedAssign = this.parenthesizedBind = this.doubleProto = -1;
			};
			A.checkPatternErrors = function(e, t) {
				if (e) {
					e.trailingComma > -1 && this.raiseRecoverable(e.trailingComma, "Comma is not permitted after the rest element");
					var i = t ? e.parenthesizedAssign : e.parenthesizedBind;
					i > -1 && this.raiseRecoverable(i, t ? "Assigning to rvalue" : "Parenthesized pattern");
				}
			}, A.checkExpressionErrors = function(e, t) {
				if (!e) return !1;
				var i = e.shorthandAssign, s = e.doubleProto;
				if (!t) return i >= 0 || s >= 0;
				i >= 0 && this.raise(i, "Shorthand property assignments are valid only in destructuring patterns"), s >= 0 && this.raiseRecoverable(s, "Redefinition of __proto__ property");
			}, A.checkYieldAwaitInDefaultParams = function() {
				this.yieldPos && (!this.awaitPos || this.yieldPos < this.awaitPos) && this.raise(this.yieldPos, "Yield expression cannot be a default value"), this.awaitPos && this.raise(this.awaitPos, "Await expression cannot be a default value");
			}, A.isSimpleAssignTarget = function(e) {
				return "ParenthesizedExpression" === e.type ? this.isSimpleAssignTarget(e.expression) : "Identifier" === e.type || "MemberExpression" === e.type;
			};
			var L = acorn_Parser.prototype;
			L.parseTopLevel = function(e) {
				var t = Object.create(null);
				for (e.body || (e.body = []); this.type !== f.eof;) {
					var i = this.parseStatement(null, !0, t);
					e.body.push(i);
				}
				if (this.inModule) for (var s = 0, r = Object.keys(this.undefinedExports); s < r.length; s += 1) {
					var n = r[s];
					this.raiseRecoverable(this.undefinedExports[n].start, "Export '" + n + "' is not defined");
				}
				return this.adaptDirectivePrologue(e.body), this.next(), e.sourceType = this.options.sourceType, this.finishNode(e, "Program");
			};
			var O = { kind: "loop" }, D = { kind: "switch" };
			L.isLet = function(e) {
				if (this.options.ecmaVersion < 6 || !this.isContextual("let")) return !1;
				v.lastIndex = this.pos;
				var t = v.exec(this.input), i = this.pos + t[0].length, s = this.input.charCodeAt(i);
				if (91 === s || 92 === s) return !0;
				if (e) return !1;
				if (123 === s || s > 55295 && s < 56320) return !0;
				if (isIdentifierStart(s, !0)) {
					for (var r = i + 1; isIdentifierChar(s = this.input.charCodeAt(r), !0);) ++r;
					if (92 === s || s > 55295 && s < 56320) return !0;
					var n = this.input.slice(i, r);
					if (!h.test(n)) return !0;
				}
				return !1;
			}, L.isAsyncFunction = function() {
				if (this.options.ecmaVersion < 8 || !this.isContextual("async")) return !1;
				v.lastIndex = this.pos;
				var e, t = v.exec(this.input), i = this.pos + t[0].length;
				return !(m.test(this.input.slice(this.pos, i)) || "function" !== this.input.slice(i, i + 8) || i + 8 !== this.input.length && (isIdentifierChar(e = this.input.charCodeAt(i + 8)) || e > 55295 && e < 56320));
			}, L.isUsingKeyword = function(e, t) {
				if (this.options.ecmaVersion < 17 || !this.isContextual(e ? "await" : "using")) return !1;
				v.lastIndex = this.pos;
				var i = v.exec(this.input), s = this.pos + i[0].length;
				if (m.test(this.input.slice(this.pos, s))) return !1;
				if (e) {
					var r, n = s + 5;
					if ("using" !== this.input.slice(s, n) || n === this.input.length || isIdentifierChar(r = this.input.charCodeAt(n)) || r > 55295 && r < 56320) return !1;
					v.lastIndex = n;
					var a = v.exec(this.input);
					if (a && m.test(this.input.slice(n, n + a[0].length))) return !1;
				}
				if (t) {
					var o, h = s + 2;
					if (!("of" !== this.input.slice(s, h) || h !== this.input.length && (isIdentifierChar(o = this.input.charCodeAt(h)) || o > 55295 && o < 56320))) return !1;
				}
				var c = this.input.charCodeAt(s);
				return isIdentifierStart(c, !0) || 92 === c;
			}, L.isAwaitUsing = function(e) {
				return this.isUsingKeyword(!0, e);
			}, L.isUsing = function(e) {
				return this.isUsingKeyword(!1, e);
			}, L.parseStatement = function(e, t, i) {
				var s, r = this.type, n = this.startNode();
				switch (this.isLet(e) && (r = f._var, s = "let"), r) {
					case f._break:
					case f._continue: return this.parseBreakContinueStatement(n, r.keyword);
					case f._debugger: return this.parseDebuggerStatement(n);
					case f._do: return this.parseDoStatement(n);
					case f._for: return this.parseForStatement(n);
					case f._function: return e && (this.strict || "if" !== e && "label" !== e) && this.options.ecmaVersion >= 6 && this.unexpected(), this.parseFunctionStatement(n, !1, !e);
					case f._class: return e && this.unexpected(), this.parseClass(n, !0);
					case f._if: return this.parseIfStatement(n);
					case f._return: return this.parseReturnStatement(n);
					case f._switch: return this.parseSwitchStatement(n);
					case f._throw: return this.parseThrowStatement(n);
					case f._try: return this.parseTryStatement(n);
					case f._const:
					case f._var: return s = s || this.value, e && "var" !== s && this.unexpected(), this.parseVarStatement(n, s);
					case f._while: return this.parseWhileStatement(n);
					case f._with: return this.parseWithStatement(n);
					case f.braceL: return this.parseBlock(!0, n);
					case f.semi: return this.parseEmptyStatement(n);
					case f._export:
					case f._import:
						if (this.options.ecmaVersion > 10 && r === f._import) {
							v.lastIndex = this.pos;
							var a = v.exec(this.input), o = this.pos + a[0].length, h = this.input.charCodeAt(o);
							if (40 === h || 46 === h) return this.parseExpressionStatement(n, this.parseExpression());
						}
						return this.options.allowImportExportEverywhere || (t || this.raise(this.start, "'import' and 'export' may only appear at the top level"), this.inModule || this.raise(this.start, "'import' and 'export' may appear only with 'sourceType: module'")), r === f._import ? this.parseImport(n) : this.parseExport(n, i);
					default:
						if (this.isAsyncFunction()) return e && this.unexpected(), this.next(), this.parseFunctionStatement(n, !0, !e);
						var c = this.isAwaitUsing(!1) ? "await using" : this.isUsing(!1) ? "using" : null;
						if (c) return t && "script" === this.options.sourceType && this.raise(this.start, "Using declaration cannot appear in the top level when source type is `script`"), "await using" === c && (this.canAwait || this.raise(this.start, "Await using cannot appear outside of async function"), this.next()), this.next(), this.parseVar(n, !1, c), this.semicolon(), this.finishNode(n, "VariableDeclaration");
						var p = this.value, l = this.parseExpression();
						return r === f.name && "Identifier" === l.type && this.eat(f.colon) ? this.parseLabeledStatement(n, p, l, e) : this.parseExpressionStatement(n, l);
				}
			}, L.parseBreakContinueStatement = function(e, t) {
				var i = "break" === t;
				this.next(), this.eat(f.semi) || this.insertSemicolon() ? e.label = null : this.type !== f.name ? this.unexpected() : (e.label = this.parseIdent(), this.semicolon());
				for (var s = 0; s < this.labels.length; ++s) {
					var r = this.labels[s];
					if (null == e.label || r.name === e.label.name) {
						if (null != r.kind && (i || "loop" === r.kind)) break;
						if (e.label && i) break;
					}
				}
				return s === this.labels.length && this.raise(e.start, "Unsyntactic " + t), this.finishNode(e, i ? "BreakStatement" : "ContinueStatement");
			}, L.parseDebuggerStatement = function(e) {
				return this.next(), this.semicolon(), this.finishNode(e, "DebuggerStatement");
			}, L.parseDoStatement = function(e) {
				return this.next(), this.labels.push(O), e.body = this.parseStatement("do"), this.labels.pop(), this.expect(f._while), e.test = this.parseParenExpression(), this.options.ecmaVersion >= 6 ? this.eat(f.semi) : this.semicolon(), this.finishNode(e, "DoWhileStatement");
			}, L.parseForStatement = function(e) {
				this.next();
				var t = this.options.ecmaVersion >= 9 && this.canAwait && this.eatContextual("await") ? this.lastTokStart : -1;
				if (this.labels.push(O), this.enterScope(0), this.expect(f.parenL), this.type === f.semi) return t > -1 && this.unexpected(t), this.parseFor(e, null);
				var i = this.isLet();
				if (this.type === f._var || this.type === f._const || i) {
					var s = this.startNode(), r = i ? "let" : this.value;
					return this.next(), this.parseVar(s, !0, r), this.finishNode(s, "VariableDeclaration"), this.parseForAfterInit(e, s, t);
				}
				var n = this.isContextual("let"), a = !1, o = this.isUsing(!0) ? "using" : this.isAwaitUsing(!0) ? "await using" : null;
				if (o) {
					var h = this.startNode();
					return this.next(), "await using" === o && this.next(), this.parseVar(h, !0, o), this.finishNode(h, "VariableDeclaration"), this.parseForAfterInit(e, h, t);
				}
				var c = this.containsEsc, p = new acorn_DestructuringErrors(), l = this.start, u = t > -1 ? this.parseExprSubscripts(p, "await") : this.parseExpression(!0, p);
				return this.type === f._in || (a = this.options.ecmaVersion >= 6 && this.isContextual("of")) ? (t > -1 ? (this.type === f._in && this.unexpected(t), e.await = !0) : a && this.options.ecmaVersion >= 8 && (u.start !== l || c || "Identifier" !== u.type || "async" !== u.name ? this.options.ecmaVersion >= 9 && (e.await = !1) : this.unexpected()), n && a && this.raise(u.start, "The left-hand side of a for-of loop may not start with 'let'."), this.toAssignable(u, !1, p), this.checkLValPattern(u), this.parseForIn(e, u)) : (this.checkExpressionErrors(p, !0), t > -1 && this.unexpected(t), this.parseFor(e, u));
			}, L.parseForAfterInit = function(e, t, i) {
				return (this.type === f._in || this.options.ecmaVersion >= 6 && this.isContextual("of")) && 1 === t.declarations.length ? (this.options.ecmaVersion >= 9 && (this.type === f._in ? i > -1 && this.unexpected(i) : e.await = i > -1), this.parseForIn(e, t)) : (i > -1 && this.unexpected(i), this.parseFor(e, t));
			}, L.parseFunctionStatement = function(e, t, i) {
				return this.next(), this.parseFunction(e, U | (i ? 0 : M), !1, t);
			}, L.parseIfStatement = function(e) {
				return this.next(), e.test = this.parseParenExpression(), e.consequent = this.parseStatement("if"), e.alternate = this.eat(f._else) ? this.parseStatement("if") : null, this.finishNode(e, "IfStatement");
			}, L.parseReturnStatement = function(e) {
				return this.inFunction || this.options.allowReturnOutsideFunction || this.raise(this.start, "'return' outside of function"), this.next(), this.eat(f.semi) || this.insertSemicolon() ? e.argument = null : (e.argument = this.parseExpression(), this.semicolon()), this.finishNode(e, "ReturnStatement");
			}, L.parseSwitchStatement = function(e) {
				var t;
				this.next(), e.discriminant = this.parseParenExpression(), e.cases = [], this.expect(f.braceL), this.labels.push(D), this.enterScope(0);
				for (var i = !1; this.type !== f.braceR;) if (this.type === f._case || this.type === f._default) {
					var s = this.type === f._case;
					t && this.finishNode(t, "SwitchCase"), e.cases.push(t = this.startNode()), t.consequent = [], this.next(), s ? t.test = this.parseExpression() : (i && this.raiseRecoverable(this.lastTokStart, "Multiple default clauses"), i = !0, t.test = null), this.expect(f.colon);
				} else t || this.unexpected(), t.consequent.push(this.parseStatement(null));
				return this.exitScope(), t && this.finishNode(t, "SwitchCase"), this.next(), this.labels.pop(), this.finishNode(e, "SwitchStatement");
			}, L.parseThrowStatement = function(e) {
				return this.next(), m.test(this.input.slice(this.lastTokEnd, this.start)) && this.raise(this.lastTokEnd, "Illegal newline after throw"), e.argument = this.parseExpression(), this.semicolon(), this.finishNode(e, "ThrowStatement");
			};
			var V = [];
			L.parseCatchClauseParam = function() {
				var e = this.parseBindingAtom(), t = "Identifier" === e.type;
				return this.enterScope(t ? 32 : 0), this.checkLValPattern(e, t ? 4 : 2), this.expect(f.parenR), e;
			}, L.parseTryStatement = function(e) {
				if (this.next(), e.block = this.parseBlock(), e.handler = null, this.type === f._catch) {
					var t = this.startNode();
					this.next(), this.eat(f.parenL) ? t.param = this.parseCatchClauseParam() : (this.options.ecmaVersion < 10 && this.unexpected(), t.param = null, this.enterScope(0)), t.body = this.parseBlock(!1), this.exitScope(), e.handler = this.finishNode(t, "CatchClause");
				}
				return e.finalizer = this.eat(f._finally) ? this.parseBlock() : null, e.handler || e.finalizer || this.raise(e.start, "Missing catch or finally clause"), this.finishNode(e, "TryStatement");
			}, L.parseVarStatement = function(e, t, i) {
				return this.next(), this.parseVar(e, !1, t, i), this.semicolon(), this.finishNode(e, "VariableDeclaration");
			}, L.parseWhileStatement = function(e) {
				return this.next(), e.test = this.parseParenExpression(), this.labels.push(O), e.body = this.parseStatement("while"), this.labels.pop(), this.finishNode(e, "WhileStatement");
			}, L.parseWithStatement = function(e) {
				return this.strict && this.raise(this.start, "'with' in strict mode"), this.next(), e.object = this.parseParenExpression(), e.body = this.parseStatement("with"), this.finishNode(e, "WithStatement");
			}, L.parseEmptyStatement = function(e) {
				return this.next(), this.finishNode(e, "EmptyStatement");
			}, L.parseLabeledStatement = function(e, t, i, s) {
				for (var r = 0, n = this.labels; r < n.length; r += 1) n[r].name === t && this.raise(i.start, "Label '" + t + "' is already declared");
				for (var a = this.type.isLoop ? "loop" : this.type === f._switch ? "switch" : null, o = this.labels.length - 1; o >= 0; o--) {
					var h = this.labels[o];
					if (h.statementStart !== e.start) break;
					h.statementStart = this.start, h.kind = a;
				}
				return this.labels.push({
					name: t,
					kind: a,
					statementStart: this.start
				}), e.body = this.parseStatement(s ? -1 === s.indexOf("label") ? s + "label" : s : "label"), this.labels.pop(), e.label = i, this.finishNode(e, "LabeledStatement");
			}, L.parseExpressionStatement = function(e, t) {
				return e.expression = t, this.semicolon(), this.finishNode(e, "ExpressionStatement");
			}, L.parseBlock = function(e, t, i) {
				for (void 0 === e && (e = !0), void 0 === t && (t = this.startNode()), t.body = [], this.expect(f.braceL), e && this.enterScope(0); this.type !== f.braceR;) {
					var s = this.parseStatement(null);
					t.body.push(s);
				}
				return i && (this.strict = !1), this.next(), e && this.exitScope(), this.finishNode(t, "BlockStatement");
			}, L.parseFor = function(e, t) {
				return e.init = t, this.expect(f.semi), e.test = this.type === f.semi ? null : this.parseExpression(), this.expect(f.semi), e.update = this.type === f.parenR ? null : this.parseExpression(), this.expect(f.parenR), e.body = this.parseStatement("for"), this.exitScope(), this.labels.pop(), this.finishNode(e, "ForStatement");
			}, L.parseForIn = function(e, t) {
				var i = this.type === f._in;
				return this.next(), "VariableDeclaration" === t.type && null != t.declarations[0].init && (!i || this.options.ecmaVersion < 8 || this.strict || "var" !== t.kind || "Identifier" !== t.declarations[0].id.type) && this.raise(t.start, (i ? "for-in" : "for-of") + " loop variable declaration may not have an initializer"), e.left = t, e.right = i ? this.parseExpression() : this.parseMaybeAssign(), this.expect(f.parenR), e.body = this.parseStatement("for"), this.exitScope(), this.labels.pop(), this.finishNode(e, i ? "ForInStatement" : "ForOfStatement");
			}, L.parseVar = function(e, t, i, s) {
				for (e.declarations = [], e.kind = i;;) {
					var r = this.startNode();
					if (this.parseVarId(r, i), this.eat(f.eq) ? r.init = this.parseMaybeAssign(t) : s || "const" !== i || this.type === f._in || this.options.ecmaVersion >= 6 && this.isContextual("of") ? s || "using" !== i && "await using" !== i || !(this.options.ecmaVersion >= 17) || this.type === f._in || this.isContextual("of") ? s || "Identifier" === r.id.type || t && (this.type === f._in || this.isContextual("of")) ? r.init = null : this.raise(this.lastTokEnd, "Complex binding patterns require an initialization value") : this.raise(this.lastTokEnd, "Missing initializer in " + i + " declaration") : this.unexpected(), e.declarations.push(this.finishNode(r, "VariableDeclarator")), !this.eat(f.comma)) break;
				}
				return e;
			}, L.parseVarId = function(e, t) {
				e.id = "using" === t || "await using" === t ? this.parseIdent() : this.parseBindingAtom(), this.checkLValPattern(e.id, "var" === t ? 1 : 2, !1);
			};
			var U = 1, M = 2;
			function isPrivateNameConflicted(e, t) {
				var i = t.key.name, s = e[i], r = "true";
				return "MethodDefinition" !== t.type || "get" !== t.kind && "set" !== t.kind || (r = (t.static ? "s" : "i") + t.kind), "iget" === s && "iset" === r || "iset" === s && "iget" === r || "sget" === s && "sset" === r || "sset" === s && "sget" === r ? (e[i] = "true", !1) : !!s || (e[i] = r, !1);
			}
			function checkKeyName(e, t) {
				var i = e.computed, s = e.key;
				return !i && ("Identifier" === s.type && s.name === t || "Literal" === s.type && s.value === t);
			}
			L.parseFunction = function(e, t, i, s, r) {
				this.initFunction(e), (this.options.ecmaVersion >= 9 || this.options.ecmaVersion >= 6 && !s) && (this.type === f.star && t & M && this.unexpected(), e.generator = this.eat(f.star)), this.options.ecmaVersion >= 8 && (e.async = !!s), t & U && (e.id = 4 & t && this.type !== f.name ? null : this.parseIdent(), !e.id || t & M || this.checkLValSimple(e.id, this.strict || e.generator || e.async ? this.treatFunctionsAsVar ? 1 : 2 : 3));
				var n = this.yieldPos, a = this.awaitPos, o = this.awaitIdentPos;
				return this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, this.enterScope(functionFlags(e.async, e.generator)), t & U || (e.id = this.type === f.name ? this.parseIdent() : null), this.parseFunctionParams(e), this.parseFunctionBody(e, i, !1, r), this.yieldPos = n, this.awaitPos = a, this.awaitIdentPos = o, this.finishNode(e, t & U ? "FunctionDeclaration" : "FunctionExpression");
			}, L.parseFunctionParams = function(e) {
				this.expect(f.parenL), e.params = this.parseBindingList(f.parenR, !1, this.options.ecmaVersion >= 8), this.checkYieldAwaitInDefaultParams();
			}, L.parseClass = function(e, t) {
				this.next();
				var i = this.strict;
				this.strict = !0, this.parseClassId(e, t), this.parseClassSuper(e);
				var s = this.enterClassBody(), r = this.startNode(), n = !1;
				for (r.body = [], this.expect(f.braceL); this.type !== f.braceR;) {
					var a = this.parseClassElement(null !== e.superClass);
					a && (r.body.push(a), "MethodDefinition" === a.type && "constructor" === a.kind ? (n && this.raiseRecoverable(a.start, "Duplicate constructor in the same class"), n = !0) : a.key && "PrivateIdentifier" === a.key.type && isPrivateNameConflicted(s, a) && this.raiseRecoverable(a.key.start, "Identifier '#" + a.key.name + "' has already been declared"));
				}
				return this.strict = i, this.next(), e.body = this.finishNode(r, "ClassBody"), this.exitClassBody(), this.finishNode(e, t ? "ClassDeclaration" : "ClassExpression");
			}, L.parseClassElement = function(e) {
				if (this.eat(f.semi)) return null;
				var t = this.options.ecmaVersion, i = this.startNode(), s = "", r = !1, n = !1, a = "method", o = !1;
				if (this.eatContextual("static")) {
					if (t >= 13 && this.eat(f.braceL)) return this.parseClassStaticBlock(i), i;
					this.isClassElementNameStart() || this.type === f.star ? o = !0 : s = "static";
				}
				if (i.static = o, !s && t >= 8 && this.eatContextual("async") && (!this.isClassElementNameStart() && this.type !== f.star || this.canInsertSemicolon() ? s = "async" : n = !0), !s && (t >= 9 || !n) && this.eat(f.star) && (r = !0), !s && !n && !r) {
					var h = this.value;
					(this.eatContextual("get") || this.eatContextual("set")) && (this.isClassElementNameStart() ? a = h : s = h);
				}
				if (s ? (i.computed = !1, i.key = this.startNodeAt(this.lastTokStart, this.lastTokStartLoc), i.key.name = s, this.finishNode(i.key, "Identifier")) : this.parseClassElementName(i), t < 13 || this.type === f.parenL || "method" !== a || r || n) {
					var c = !i.static && checkKeyName(i, "constructor"), p = c && e;
					c && "method" !== a && this.raise(i.key.start, "Constructor can't have get/set modifier"), i.kind = c ? "constructor" : a, this.parseClassMethod(i, r, n, p);
				} else this.parseClassField(i);
				return i;
			}, L.isClassElementNameStart = function() {
				return this.type === f.name || this.type === f.privateId || this.type === f.num || this.type === f.string || this.type === f.bracketL || this.type.keyword;
			}, L.parseClassElementName = function(e) {
				this.type === f.privateId ? ("constructor" === this.value && this.raise(this.start, "Classes can't have an element named '#constructor'"), e.computed = !1, e.key = this.parsePrivateIdent()) : this.parsePropertyName(e);
			}, L.parseClassMethod = function(e, t, i, s) {
				var r = e.key;
				"constructor" === e.kind ? (t && this.raise(r.start, "Constructor can't be a generator"), i && this.raise(r.start, "Constructor can't be an async method")) : e.static && checkKeyName(e, "prototype") && this.raise(r.start, "Classes may not have a static property named prototype");
				var n = e.value = this.parseMethod(t, i, s);
				return "get" === e.kind && 0 !== n.params.length && this.raiseRecoverable(n.start, "getter should have no params"), "set" === e.kind && 1 !== n.params.length && this.raiseRecoverable(n.start, "setter should have exactly one param"), "set" === e.kind && "RestElement" === n.params[0].type && this.raiseRecoverable(n.params[0].start, "Setter cannot use rest params"), this.finishNode(e, "MethodDefinition");
			}, L.parseClassField = function(e) {
				return checkKeyName(e, "constructor") ? this.raise(e.key.start, "Classes can't have a field named 'constructor'") : e.static && checkKeyName(e, "prototype") && this.raise(e.key.start, "Classes can't have a static field named 'prototype'"), this.eat(f.eq) ? (this.enterScope(576), e.value = this.parseMaybeAssign(), this.exitScope()) : e.value = null, this.semicolon(), this.finishNode(e, "PropertyDefinition");
			}, L.parseClassStaticBlock = function(e) {
				e.body = [];
				var t = this.labels;
				for (this.labels = [], this.enterScope(320); this.type !== f.braceR;) {
					var i = this.parseStatement(null);
					e.body.push(i);
				}
				return this.next(), this.exitScope(), this.labels = t, this.finishNode(e, "StaticBlock");
			}, L.parseClassId = function(e, t) {
				this.type === f.name ? (e.id = this.parseIdent(), t && this.checkLValSimple(e.id, 2, !1)) : (!0 === t && this.unexpected(), e.id = null);
			}, L.parseClassSuper = function(e) {
				e.superClass = this.eat(f._extends) ? this.parseExprSubscripts(null, !1) : null;
			}, L.enterClassBody = function() {
				var e = {
					declared: Object.create(null),
					used: []
				};
				return this.privateNameStack.push(e), e.declared;
			}, L.exitClassBody = function() {
				var e = this.privateNameStack.pop(), t = e.declared, i = e.used;
				if (this.options.checkPrivateFields) for (var s = this.privateNameStack.length, r = 0 === s ? null : this.privateNameStack[s - 1], n = 0; n < i.length; ++n) {
					var a = i[n];
					b(t, a.name) || (r ? r.used.push(a) : this.raiseRecoverable(a.start, "Private field '#" + a.name + "' must be declared in an enclosing class"));
				}
			}, L.parseExportAllDeclaration = function(e, t) {
				return this.options.ecmaVersion >= 11 && (this.eatContextual("as") ? (e.exported = this.parseModuleExportName(), this.checkExport(t, e.exported, this.lastTokStart)) : e.exported = null), this.expectContextual("from"), this.type !== f.string && this.unexpected(), e.source = this.parseExprAtom(), this.options.ecmaVersion >= 16 && (e.attributes = this.parseWithClause()), this.semicolon(), this.finishNode(e, "ExportAllDeclaration");
			}, L.parseExport = function(e, t) {
				if (this.next(), this.eat(f.star)) return this.parseExportAllDeclaration(e, t);
				if (this.eat(f._default)) return this.checkExport(t, "default", this.lastTokStart), e.declaration = this.parseExportDefaultDeclaration(), this.finishNode(e, "ExportDefaultDeclaration");
				if (this.shouldParseExportStatement()) e.declaration = this.parseExportDeclaration(e), "VariableDeclaration" === e.declaration.type ? this.checkVariableExport(t, e.declaration.declarations) : this.checkExport(t, e.declaration.id, e.declaration.id.start), e.specifiers = [], e.source = null, this.options.ecmaVersion >= 16 && (e.attributes = []);
				else {
					if (e.declaration = null, e.specifiers = this.parseExportSpecifiers(t), this.eatContextual("from")) this.type !== f.string && this.unexpected(), e.source = this.parseExprAtom(), this.options.ecmaVersion >= 16 && (e.attributes = this.parseWithClause());
					else {
						for (var i = 0, s = e.specifiers; i < s.length; i += 1) {
							var r = s[i];
							this.checkUnreserved(r.local), this.checkLocalExport(r.local), "Literal" === r.local.type && this.raise(r.local.start, "A string literal cannot be used as an exported binding without `from`.");
						}
						e.source = null, this.options.ecmaVersion >= 16 && (e.attributes = []);
					}
					this.semicolon();
				}
				return this.finishNode(e, "ExportNamedDeclaration");
			}, L.parseExportDeclaration = function(e) {
				return this.parseStatement(null);
			}, L.parseExportDefaultDeclaration = function() {
				var e;
				if (this.type === f._function || (e = this.isAsyncFunction())) {
					var t = this.startNode();
					return this.next(), e && this.next(), this.parseFunction(t, 4 | U, !1, e);
				}
				if (this.type === f._class) {
					var i = this.startNode();
					return this.parseClass(i, "nullableID");
				}
				var s = this.parseMaybeAssign();
				return this.semicolon(), s;
			}, L.checkExport = function(e, t, i) {
				e && ("string" != typeof t && (t = "Identifier" === t.type ? t.name : t.value), b(e, t) && this.raiseRecoverable(i, "Duplicate export '" + t + "'"), e[t] = !0);
			}, L.checkPatternExport = function(e, t) {
				var i = t.type;
				if ("Identifier" === i) this.checkExport(e, t, t.start);
				else if ("ObjectPattern" === i) for (var s = 0, r = t.properties; s < r.length; s += 1) {
					var n = r[s];
					this.checkPatternExport(e, n);
				}
				else if ("ArrayPattern" === i) for (var a = 0, o = t.elements; a < o.length; a += 1) {
					var h = o[a];
					h && this.checkPatternExport(e, h);
				}
				else "Property" === i ? this.checkPatternExport(e, t.value) : "AssignmentPattern" === i ? this.checkPatternExport(e, t.left) : "RestElement" === i && this.checkPatternExport(e, t.argument);
			}, L.checkVariableExport = function(e, t) {
				if (e) for (var i = 0, s = t; i < s.length; i += 1) {
					var r = s[i];
					this.checkPatternExport(e, r.id);
				}
			}, L.shouldParseExportStatement = function() {
				return "var" === this.type.keyword || "const" === this.type.keyword || "class" === this.type.keyword || "function" === this.type.keyword || this.isLet() || this.isAsyncFunction();
			}, L.parseExportSpecifier = function(e) {
				var t = this.startNode();
				return t.local = this.parseModuleExportName(), t.exported = this.eatContextual("as") ? this.parseModuleExportName() : t.local, this.checkExport(e, t.exported, t.exported.start), this.finishNode(t, "ExportSpecifier");
			}, L.parseExportSpecifiers = function(e) {
				var t = [], i = !0;
				for (this.expect(f.braceL); !this.eat(f.braceR);) {
					if (i) i = !1;
					else if (this.expect(f.comma), this.afterTrailingComma(f.braceR)) break;
					t.push(this.parseExportSpecifier(e));
				}
				return t;
			}, L.parseImport = function(e) {
				return this.next(), this.type === f.string ? (e.specifiers = V, e.source = this.parseExprAtom()) : (e.specifiers = this.parseImportSpecifiers(), this.expectContextual("from"), e.source = this.type === f.string ? this.parseExprAtom() : this.unexpected()), this.options.ecmaVersion >= 16 && (e.attributes = this.parseWithClause()), this.semicolon(), this.finishNode(e, "ImportDeclaration");
			}, L.parseImportSpecifier = function() {
				var e = this.startNode();
				return e.imported = this.parseModuleExportName(), this.eatContextual("as") ? e.local = this.parseIdent() : (this.checkUnreserved(e.imported), e.local = e.imported), this.checkLValSimple(e.local, 2), this.finishNode(e, "ImportSpecifier");
			}, L.parseImportDefaultSpecifier = function() {
				var e = this.startNode();
				return e.local = this.parseIdent(), this.checkLValSimple(e.local, 2), this.finishNode(e, "ImportDefaultSpecifier");
			}, L.parseImportNamespaceSpecifier = function() {
				var e = this.startNode();
				return this.next(), this.expectContextual("as"), e.local = this.parseIdent(), this.checkLValSimple(e.local, 2), this.finishNode(e, "ImportNamespaceSpecifier");
			}, L.parseImportSpecifiers = function() {
				var e = [], t = !0;
				if (this.type === f.name && (e.push(this.parseImportDefaultSpecifier()), !this.eat(f.comma))) return e;
				if (this.type === f.star) return e.push(this.parseImportNamespaceSpecifier()), e;
				for (this.expect(f.braceL); !this.eat(f.braceR);) {
					if (t) t = !1;
					else if (this.expect(f.comma), this.afterTrailingComma(f.braceR)) break;
					e.push(this.parseImportSpecifier());
				}
				return e;
			}, L.parseWithClause = function() {
				var e = [];
				if (!this.eat(f._with)) return e;
				this.expect(f.braceL);
				for (var t = {}, i = !0; !this.eat(f.braceR);) {
					if (i) i = !1;
					else if (this.expect(f.comma), this.afterTrailingComma(f.braceR)) break;
					var s = this.parseImportAttribute(), r = "Identifier" === s.key.type ? s.key.name : s.key.value;
					b(t, r) && this.raiseRecoverable(s.key.start, "Duplicate attribute key '" + r + "'"), t[r] = !0, e.push(s);
				}
				return e;
			}, L.parseImportAttribute = function() {
				var e = this.startNode();
				return e.key = this.type === f.string ? this.parseExprAtom() : this.parseIdent("never" !== this.options.allowReserved), this.expect(f.colon), this.type !== f.string && this.unexpected(), e.value = this.parseExprAtom(), this.finishNode(e, "ImportAttribute");
			}, L.parseModuleExportName = function() {
				if (this.options.ecmaVersion >= 13 && this.type === f.string) {
					var e = this.parseLiteral(this.value);
					return w.test(e.value) && this.raise(e.start, "An export name cannot include a lone surrogate."), e;
				}
				return this.parseIdent(!0);
			}, L.adaptDirectivePrologue = function(e) {
				for (var t = 0; t < e.length && this.isDirectiveCandidate(e[t]); ++t) e[t].directive = e[t].expression.raw.slice(1, -1);
			}, L.isDirectiveCandidate = function(e) {
				return this.options.ecmaVersion >= 5 && "ExpressionStatement" === e.type && "Literal" === e.expression.type && "string" == typeof e.expression.value && ("\"" === this.input[e.start] || "'" === this.input[e.start]);
			};
			var j = acorn_Parser.prototype;
			j.toAssignable = function(e, t, i) {
				if (this.options.ecmaVersion >= 6 && e) switch (e.type) {
					case "Identifier":
						this.inAsync && "await" === e.name && this.raise(e.start, "Cannot use 'await' as identifier inside an async function");
						break;
					case "ObjectPattern":
					case "ArrayPattern":
					case "AssignmentPattern":
					case "RestElement": break;
					case "ObjectExpression":
						e.type = "ObjectPattern", i && this.checkPatternErrors(i, !0);
						for (var s = 0, r = e.properties; s < r.length; s += 1) {
							var n = r[s];
							this.toAssignable(n, t), "RestElement" !== n.type || "ArrayPattern" !== n.argument.type && "ObjectPattern" !== n.argument.type || this.raise(n.argument.start, "Unexpected token");
						}
						break;
					case "Property":
						"init" !== e.kind && this.raise(e.key.start, "Object pattern can't contain getter or setter"), this.toAssignable(e.value, t);
						break;
					case "ArrayExpression":
						e.type = "ArrayPattern", i && this.checkPatternErrors(i, !0), this.toAssignableList(e.elements, t);
						break;
					case "SpreadElement":
						e.type = "RestElement", this.toAssignable(e.argument, t), "AssignmentPattern" === e.argument.type && this.raise(e.argument.start, "Rest elements cannot have a default value");
						break;
					case "AssignmentExpression":
						"=" !== e.operator && this.raise(e.left.end, "Only '=' operator can be used for specifying default value."), e.type = "AssignmentPattern", delete e.operator, this.toAssignable(e.left, t);
						break;
					case "ParenthesizedExpression":
						this.toAssignable(e.expression, t, i);
						break;
					case "ChainExpression":
						this.raiseRecoverable(e.start, "Optional chaining cannot appear in left-hand side");
						break;
					case "MemberExpression": if (!t) break;
					default: this.raise(e.start, "Assigning to rvalue");
				}
				else i && this.checkPatternErrors(i, !0);
				return e;
			}, j.toAssignableList = function(e, t) {
				for (var i = e.length, s = 0; s < i; s++) {
					var r = e[s];
					r && this.toAssignable(r, t);
				}
				if (i) {
					var n = e[i - 1];
					6 === this.options.ecmaVersion && t && n && "RestElement" === n.type && "Identifier" !== n.argument.type && this.unexpected(n.argument.start);
				}
				return e;
			}, j.parseSpread = function(e) {
				var t = this.startNode();
				return this.next(), t.argument = this.parseMaybeAssign(!1, e), this.finishNode(t, "SpreadElement");
			}, j.parseRestBinding = function() {
				var e = this.startNode();
				return this.next(), 6 === this.options.ecmaVersion && this.type !== f.name && this.unexpected(), e.argument = this.parseBindingAtom(), this.finishNode(e, "RestElement");
			}, j.parseBindingAtom = function() {
				if (this.options.ecmaVersion >= 6) switch (this.type) {
					case f.bracketL:
						var e = this.startNode();
						return this.next(), e.elements = this.parseBindingList(f.bracketR, !0, !0), this.finishNode(e, "ArrayPattern");
					case f.braceL: return this.parseObj(!0);
				}
				return this.parseIdent();
			}, j.parseBindingList = function(e, t, i, s) {
				for (var r = [], n = !0; !this.eat(e);) if (n ? n = !1 : this.expect(f.comma), t && this.type === f.comma) r.push(null);
				else {
					if (i && this.afterTrailingComma(e)) break;
					if (this.type === f.ellipsis) {
						var a = this.parseRestBinding();
						this.parseBindingListItem(a), r.push(a), this.type === f.comma && this.raiseRecoverable(this.start, "Comma is not permitted after the rest element"), this.expect(e);
						break;
					}
					r.push(this.parseAssignableListItem(s));
				}
				return r;
			}, j.parseAssignableListItem = function(e) {
				var t = this.parseMaybeDefault(this.start, this.startLoc);
				return this.parseBindingListItem(t), t;
			}, j.parseBindingListItem = function(e) {
				return e;
			}, j.parseMaybeDefault = function(e, t, i) {
				if (i = i || this.parseBindingAtom(), this.options.ecmaVersion < 6 || !this.eat(f.eq)) return i;
				var s = this.startNodeAt(e, t);
				return s.left = i, s.right = this.parseMaybeAssign(), this.finishNode(s, "AssignmentPattern");
			}, j.checkLValSimple = function(e, t, i) {
				void 0 === t && (t = 0);
				var s = 0 !== t;
				switch (e.type) {
					case "Identifier":
						this.strict && this.reservedWordsStrictBind.test(e.name) && this.raiseRecoverable(e.start, (s ? "Binding " : "Assigning to ") + e.name + " in strict mode"), s && (2 === t && "let" === e.name && this.raiseRecoverable(e.start, "let is disallowed as a lexically bound name"), i && (b(i, e.name) && this.raiseRecoverable(e.start, "Argument name clash"), i[e.name] = !0), 5 !== t && this.declareName(e.name, t, e.start));
						break;
					case "ChainExpression":
						this.raiseRecoverable(e.start, "Optional chaining cannot appear in left-hand side");
						break;
					case "MemberExpression":
						s && this.raiseRecoverable(e.start, "Binding member expression");
						break;
					case "ParenthesizedExpression": return s && this.raiseRecoverable(e.start, "Binding parenthesized expression"), this.checkLValSimple(e.expression, t, i);
					default: this.raise(e.start, (s ? "Binding" : "Assigning to") + " rvalue");
				}
			}, j.checkLValPattern = function(e, t, i) {
				switch (void 0 === t && (t = 0), e.type) {
					case "ObjectPattern":
						for (var s = 0, r = e.properties; s < r.length; s += 1) {
							var n = r[s];
							this.checkLValInnerPattern(n, t, i);
						}
						break;
					case "ArrayPattern":
						for (var a = 0, o = e.elements; a < o.length; a += 1) {
							var h = o[a];
							h && this.checkLValInnerPattern(h, t, i);
						}
						break;
					default: this.checkLValSimple(e, t, i);
				}
			}, j.checkLValInnerPattern = function(e, t, i) {
				switch (void 0 === t && (t = 0), e.type) {
					case "Property":
						this.checkLValInnerPattern(e.value, t, i);
						break;
					case "AssignmentPattern":
						this.checkLValPattern(e.left, t, i);
						break;
					case "RestElement":
						this.checkLValPattern(e.argument, t, i);
						break;
					default: this.checkLValPattern(e, t, i);
				}
			};
			var acorn_TokContext = function(e, t, i, s, r) {
				this.token = e, this.isExpr = !!t, this.preserveSpace = !!i, this.override = s, this.generator = !!r;
			}, F = {
				b_stat: new acorn_TokContext("{", !1),
				b_expr: new acorn_TokContext("{", !0),
				b_tmpl: new acorn_TokContext("${", !1),
				p_stat: new acorn_TokContext("(", !1),
				p_expr: new acorn_TokContext("(", !0),
				q_tmpl: new acorn_TokContext("`", !0, !0, function(e) {
					return e.tryReadTemplateToken();
				}),
				f_stat: new acorn_TokContext("function", !1),
				f_expr: new acorn_TokContext("function", !0),
				f_expr_gen: new acorn_TokContext("function", !0, !1, null, !0),
				f_gen: new acorn_TokContext("function", !1, !1, null, !0)
			}, B = acorn_Parser.prototype;
			B.initialContext = function() {
				return [F.b_stat];
			}, B.curContext = function() {
				return this.context[this.context.length - 1];
			}, B.braceIsBlock = function(e) {
				var t = this.curContext();
				return t === F.f_expr || t === F.f_stat || (e !== f.colon || t !== F.b_stat && t !== F.b_expr ? e === f._return || e === f.name && this.exprAllowed ? m.test(this.input.slice(this.lastTokEnd, this.start)) : e === f._else || e === f.semi || e === f.eof || e === f.parenR || e === f.arrow || (e === f.braceL ? t === F.b_stat : e !== f._var && e !== f._const && e !== f.name && !this.exprAllowed) : !t.isExpr);
			}, B.inGeneratorContext = function() {
				for (var e = this.context.length - 1; e >= 1; e--) {
					var t = this.context[e];
					if ("function" === t.token) return t.generator;
				}
				return !1;
			}, B.updateContext = function(e) {
				var t, i = this.type;
				i.keyword && e === f.dot ? this.exprAllowed = !1 : (t = i.updateContext) ? t.call(this, e) : this.exprAllowed = i.beforeExpr;
			}, B.overrideContext = function(e) {
				this.curContext() !== e && (this.context[this.context.length - 1] = e);
			}, f.parenR.updateContext = f.braceR.updateContext = function() {
				if (1 !== this.context.length) {
					var e = this.context.pop();
					e === F.b_stat && "function" === this.curContext().token && (e = this.context.pop()), this.exprAllowed = !e.isExpr;
				} else this.exprAllowed = !0;
			}, f.braceL.updateContext = function(e) {
				this.context.push(this.braceIsBlock(e) ? F.b_stat : F.b_expr), this.exprAllowed = !0;
			}, f.dollarBraceL.updateContext = function() {
				this.context.push(F.b_tmpl), this.exprAllowed = !0;
			}, f.parenL.updateContext = function(e) {
				var t = e === f._if || e === f._for || e === f._with || e === f._while;
				this.context.push(t ? F.p_stat : F.p_expr), this.exprAllowed = !0;
			}, f.incDec.updateContext = function() {}, f._function.updateContext = f._class.updateContext = function(e) {
				!e.beforeExpr || e === f._else || e === f.semi && this.curContext() !== F.p_stat || e === f._return && m.test(this.input.slice(this.lastTokEnd, this.start)) || (e === f.colon || e === f.braceL) && this.curContext() === F.b_stat ? this.context.push(F.f_stat) : this.context.push(F.f_expr), this.exprAllowed = !1;
			}, f.colon.updateContext = function() {
				"function" === this.curContext().token && this.context.pop(), this.exprAllowed = !0;
			}, f.backQuote.updateContext = function() {
				this.curContext() === F.q_tmpl ? this.context.pop() : this.context.push(F.q_tmpl), this.exprAllowed = !1;
			}, f.star.updateContext = function(e) {
				if (e === f._function) {
					var t = this.context.length - 1;
					this.context[t] === F.f_expr ? this.context[t] = F.f_expr_gen : this.context[t] = F.f_gen;
				}
				this.exprAllowed = !0;
			}, f.name.updateContext = function(e) {
				var t = !1;
				this.options.ecmaVersion >= 6 && e !== f.dot && ("of" === this.value && !this.exprAllowed || "yield" === this.value && this.inGeneratorContext()) && (t = !0), this.exprAllowed = t;
			};
			var $ = acorn_Parser.prototype;
			function isLocalVariableAccess(e) {
				return "Identifier" === e.type || "ParenthesizedExpression" === e.type && isLocalVariableAccess(e.expression);
			}
			function isPrivateFieldAccess(e) {
				return "MemberExpression" === e.type && "PrivateIdentifier" === e.property.type || "ChainExpression" === e.type && isPrivateFieldAccess(e.expression) || "ParenthesizedExpression" === e.type && isPrivateFieldAccess(e.expression);
			}
			$.checkPropClash = function(e, t, i) {
				if (!(this.options.ecmaVersion >= 9 && "SpreadElement" === e.type || this.options.ecmaVersion >= 6 && (e.computed || e.method || e.shorthand))) {
					var s, r = e.key;
					switch (r.type) {
						case "Identifier":
							s = r.name;
							break;
						case "Literal":
							s = String(r.value);
							break;
						default: return;
					}
					var n = e.kind;
					if (this.options.ecmaVersion >= 6) "__proto__" === s && "init" === n && (t.proto && (i ? i.doubleProto < 0 && (i.doubleProto = r.start) : this.raiseRecoverable(r.start, "Redefinition of __proto__ property")), t.proto = !0);
					else {
						var a = t[s = "$" + s];
						if (a) ("init" === n ? this.strict && a.init || a.get || a.set : a.init || a[n]) && this.raiseRecoverable(r.start, "Redefinition of property");
						else a = t[s] = {
							init: !1,
							get: !1,
							set: !1
						};
						a[n] = !0;
					}
				}
			}, $.parseExpression = function(e, t) {
				var i = this.start, s = this.startLoc, r = this.parseMaybeAssign(e, t);
				if (this.type === f.comma) {
					var n = this.startNodeAt(i, s);
					for (n.expressions = [r]; this.eat(f.comma);) n.expressions.push(this.parseMaybeAssign(e, t));
					return this.finishNode(n, "SequenceExpression");
				}
				return r;
			}, $.parseMaybeAssign = function(e, t, i) {
				if (this.isContextual("yield")) {
					if (this.inGenerator) return this.parseYield(e);
					this.exprAllowed = !1;
				}
				var s = !1, r = -1, n = -1, a = -1;
				t ? (r = t.parenthesizedAssign, n = t.trailingComma, a = t.doubleProto, t.parenthesizedAssign = t.trailingComma = -1) : (t = new acorn_DestructuringErrors(), s = !0);
				var o = this.start, h = this.startLoc;
				this.type !== f.parenL && this.type !== f.name || (this.potentialArrowAt = this.start, this.potentialArrowInForAwait = "await" === e);
				var c = this.parseMaybeConditional(e, t);
				if (i && (c = i.call(this, c, o, h)), this.type.isAssign) {
					var p = this.startNodeAt(o, h);
					return p.operator = this.value, this.type === f.eq && (c = this.toAssignable(c, !1, t)), s || (t.parenthesizedAssign = t.trailingComma = t.doubleProto = -1), t.shorthandAssign >= c.start && (t.shorthandAssign = -1), this.type === f.eq ? this.checkLValPattern(c) : this.checkLValSimple(c), p.left = c, this.next(), p.right = this.parseMaybeAssign(e), a > -1 && (t.doubleProto = a), this.finishNode(p, "AssignmentExpression");
				}
				return s && this.checkExpressionErrors(t, !0), r > -1 && (t.parenthesizedAssign = r), n > -1 && (t.trailingComma = n), c;
			}, $.parseMaybeConditional = function(e, t) {
				var i = this.start, s = this.startLoc, r = this.parseExprOps(e, t);
				if (this.checkExpressionErrors(t)) return r;
				if (this.eat(f.question)) {
					var n = this.startNodeAt(i, s);
					return n.test = r, n.consequent = this.parseMaybeAssign(), this.expect(f.colon), n.alternate = this.parseMaybeAssign(e), this.finishNode(n, "ConditionalExpression");
				}
				return r;
			}, $.parseExprOps = function(e, t) {
				var i = this.start, s = this.startLoc, r = this.parseMaybeUnary(t, !1, !1, e);
				return this.checkExpressionErrors(t) || r.start === i && "ArrowFunctionExpression" === r.type ? r : this.parseExprOp(r, i, s, -1, e);
			}, $.parseExprOp = function(e, t, i, s, r) {
				var n = this.type.binop;
				if (null != n && (!r || this.type !== f._in) && n > s) {
					var a = this.type === f.logicalOR || this.type === f.logicalAND, o = this.type === f.coalesce;
					o && (n = f.logicalAND.binop);
					var h = this.value;
					this.next();
					var c = this.start, p = this.startLoc, l = this.parseExprOp(this.parseMaybeUnary(null, !1, !1, r), c, p, n, r), u = this.buildBinary(t, i, e, l, h, a || o);
					return (a && this.type === f.coalesce || o && (this.type === f.logicalOR || this.type === f.logicalAND)) && this.raiseRecoverable(this.start, "Logical expressions and coalesce expressions cannot be mixed. Wrap either by parentheses"), this.parseExprOp(u, t, i, s, r);
				}
				return e;
			}, $.buildBinary = function(e, t, i, s, r, n) {
				"PrivateIdentifier" === s.type && this.raise(s.start, "Private identifier can only be left side of binary expression");
				var a = this.startNodeAt(e, t);
				return a.left = i, a.operator = r, a.right = s, this.finishNode(a, n ? "LogicalExpression" : "BinaryExpression");
			}, $.parseMaybeUnary = function(e, t, i, s) {
				var r, n = this.start, a = this.startLoc;
				if (this.isContextual("await") && this.canAwait) r = this.parseAwait(s), t = !0;
				else if (this.type.prefix) {
					var o = this.startNode(), h = this.type === f.incDec;
					o.operator = this.value, o.prefix = !0, this.next(), o.argument = this.parseMaybeUnary(null, !0, h, s), this.checkExpressionErrors(e, !0), h ? this.checkLValSimple(o.argument) : this.strict && "delete" === o.operator && isLocalVariableAccess(o.argument) ? this.raiseRecoverable(o.start, "Deleting local variable in strict mode") : "delete" === o.operator && isPrivateFieldAccess(o.argument) ? this.raiseRecoverable(o.start, "Private fields can not be deleted") : t = !0, r = this.finishNode(o, h ? "UpdateExpression" : "UnaryExpression");
				} else if (t || this.type !== f.privateId) {
					if (r = this.parseExprSubscripts(e, s), this.checkExpressionErrors(e)) return r;
					for (; this.type.postfix && !this.canInsertSemicolon();) {
						var c = this.startNodeAt(n, a);
						c.operator = this.value, c.prefix = !1, c.argument = r, this.checkLValSimple(r), this.next(), r = this.finishNode(c, "UpdateExpression");
					}
				} else (s || 0 === this.privateNameStack.length) && this.options.checkPrivateFields && this.unexpected(), r = this.parsePrivateIdent(), this.type !== f._in && this.unexpected();
				return i || !this.eat(f.starstar) ? r : t ? void this.unexpected(this.lastTokStart) : this.buildBinary(n, a, r, this.parseMaybeUnary(null, !1, !1, s), "**", !1);
			}, $.parseExprSubscripts = function(e, t) {
				var i = this.start, s = this.startLoc, r = this.parseExprAtom(e, t);
				if ("ArrowFunctionExpression" === r.type && ")" !== this.input.slice(this.lastTokStart, this.lastTokEnd)) return r;
				var n = this.parseSubscripts(r, i, s, !1, t);
				return e && "MemberExpression" === n.type && (e.parenthesizedAssign >= n.start && (e.parenthesizedAssign = -1), e.parenthesizedBind >= n.start && (e.parenthesizedBind = -1), e.trailingComma >= n.start && (e.trailingComma = -1)), n;
			}, $.parseSubscripts = function(e, t, i, s, r) {
				for (var n = this.options.ecmaVersion >= 8 && "Identifier" === e.type && "async" === e.name && this.lastTokEnd === e.end && !this.canInsertSemicolon() && e.end - e.start === 5 && this.potentialArrowAt === e.start, a = !1;;) {
					var o = this.parseSubscript(e, t, i, s, n, a, r);
					if (o.optional && (a = !0), o === e || "ArrowFunctionExpression" === o.type) {
						if (a) {
							var h = this.startNodeAt(t, i);
							h.expression = o, o = this.finishNode(h, "ChainExpression");
						}
						return o;
					}
					e = o;
				}
			}, $.shouldParseAsyncArrow = function() {
				return !this.canInsertSemicolon() && this.eat(f.arrow);
			}, $.parseSubscriptAsyncArrow = function(e, t, i, s) {
				return this.parseArrowExpression(this.startNodeAt(e, t), i, !0, s);
			}, $.parseSubscript = function(e, t, i, s, r, n, a) {
				var o = this.options.ecmaVersion >= 11, h = o && this.eat(f.questionDot);
				s && h && this.raise(this.lastTokStart, "Optional chaining cannot appear in the callee of new expressions");
				var c = this.eat(f.bracketL);
				if (c || h && this.type !== f.parenL && this.type !== f.backQuote || this.eat(f.dot)) {
					var p = this.startNodeAt(t, i);
					p.object = e, c ? (p.property = this.parseExpression(), this.expect(f.bracketR)) : this.type === f.privateId && "Super" !== e.type ? p.property = this.parsePrivateIdent() : p.property = this.parseIdent("never" !== this.options.allowReserved), p.computed = !!c, o && (p.optional = h), e = this.finishNode(p, "MemberExpression");
				} else if (!s && this.eat(f.parenL)) {
					var l = new acorn_DestructuringErrors(), u = this.yieldPos, d = this.awaitPos, m = this.awaitIdentPos;
					this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0;
					var g = this.parseExprList(f.parenR, this.options.ecmaVersion >= 8, !1, l);
					if (r && !h && this.shouldParseAsyncArrow()) return this.checkPatternErrors(l, !1), this.checkYieldAwaitInDefaultParams(), this.awaitIdentPos > 0 && this.raise(this.awaitIdentPos, "Cannot use 'await' as identifier inside an async function"), this.yieldPos = u, this.awaitPos = d, this.awaitIdentPos = m, this.parseSubscriptAsyncArrow(t, i, g, a);
					this.checkExpressionErrors(l, !0), this.yieldPos = u || this.yieldPos, this.awaitPos = d || this.awaitPos, this.awaitIdentPos = m || this.awaitIdentPos;
					var x = this.startNodeAt(t, i);
					x.callee = e, x.arguments = g, o && (x.optional = h), e = this.finishNode(x, "CallExpression");
				} else if (this.type === f.backQuote) {
					(h || n) && this.raise(this.start, "Optional chaining cannot appear in the tag of tagged template expressions");
					var v = this.startNodeAt(t, i);
					v.tag = e, v.quasi = this.parseTemplate({ isTagged: !0 }), e = this.finishNode(v, "TaggedTemplateExpression");
				}
				return e;
			}, $.parseExprAtom = function(e, t, i) {
				this.type === f.slash && this.readRegexp();
				var s, r = this.potentialArrowAt === this.start;
				switch (this.type) {
					case f._super: return this.allowSuper || this.raise(this.start, "'super' keyword outside a method"), s = this.startNode(), this.next(), this.type !== f.parenL || this.allowDirectSuper || this.raise(s.start, "super() call outside constructor of a subclass"), this.type !== f.dot && this.type !== f.bracketL && this.type !== f.parenL && this.unexpected(), this.finishNode(s, "Super");
					case f._this: return s = this.startNode(), this.next(), this.finishNode(s, "ThisExpression");
					case f.name:
						var n = this.start, a = this.startLoc, o = this.containsEsc, h = this.parseIdent(!1);
						if (this.options.ecmaVersion >= 8 && !o && "async" === h.name && !this.canInsertSemicolon() && this.eat(f._function)) return this.overrideContext(F.f_expr), this.parseFunction(this.startNodeAt(n, a), 0, !1, !0, t);
						if (r && !this.canInsertSemicolon()) {
							if (this.eat(f.arrow)) return this.parseArrowExpression(this.startNodeAt(n, a), [h], !1, t);
							if (this.options.ecmaVersion >= 8 && "async" === h.name && this.type === f.name && !o && (!this.potentialArrowInForAwait || "of" !== this.value || this.containsEsc)) return h = this.parseIdent(!1), !this.canInsertSemicolon() && this.eat(f.arrow) || this.unexpected(), this.parseArrowExpression(this.startNodeAt(n, a), [h], !0, t);
						}
						return h;
					case f.regexp:
						var c = this.value;
						return (s = this.parseLiteral(c.value)).regex = {
							pattern: c.pattern,
							flags: c.flags
						}, s;
					case f.num:
					case f.string: return this.parseLiteral(this.value);
					case f._null:
					case f._true:
					case f._false: return (s = this.startNode()).value = this.type === f._null ? null : this.type === f._true, s.raw = this.type.keyword, this.next(), this.finishNode(s, "Literal");
					case f.parenL:
						var p = this.start, l = this.parseParenAndDistinguishExpression(r, t);
						return e && (e.parenthesizedAssign < 0 && !this.isSimpleAssignTarget(l) && (e.parenthesizedAssign = p), e.parenthesizedBind < 0 && (e.parenthesizedBind = p)), l;
					case f.bracketL: return s = this.startNode(), this.next(), s.elements = this.parseExprList(f.bracketR, !0, !0, e), this.finishNode(s, "ArrayExpression");
					case f.braceL: return this.overrideContext(F.b_expr), this.parseObj(!1, e);
					case f._function: return s = this.startNode(), this.next(), this.parseFunction(s, 0);
					case f._class: return this.parseClass(this.startNode(), !1);
					case f._new: return this.parseNew();
					case f.backQuote: return this.parseTemplate();
					case f._import: return this.options.ecmaVersion >= 11 ? this.parseExprImport(i) : this.unexpected();
					default: return this.parseExprAtomDefault();
				}
			}, $.parseExprAtomDefault = function() {
				this.unexpected();
			}, $.parseExprImport = function(e) {
				var t = this.startNode();
				if (this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword import"), this.next(), this.type === f.parenL && !e) return this.parseDynamicImport(t);
				if (this.type === f.dot) {
					var i = this.startNodeAt(t.start, t.loc && t.loc.start);
					return i.name = "import", t.meta = this.finishNode(i, "Identifier"), this.parseImportMeta(t);
				}
				this.unexpected();
			}, $.parseDynamicImport = function(e) {
				if (this.next(), e.source = this.parseMaybeAssign(), this.options.ecmaVersion >= 16) this.eat(f.parenR) ? e.options = null : (this.expect(f.comma), this.afterTrailingComma(f.parenR) ? e.options = null : (e.options = this.parseMaybeAssign(), this.eat(f.parenR) || (this.expect(f.comma), this.afterTrailingComma(f.parenR) || this.unexpected())));
				else if (!this.eat(f.parenR)) {
					var t = this.start;
					this.eat(f.comma) && this.eat(f.parenR) ? this.raiseRecoverable(t, "Trailing comma is not allowed in import()") : this.unexpected(t);
				}
				return this.finishNode(e, "ImportExpression");
			}, $.parseImportMeta = function(e) {
				this.next();
				var t = this.containsEsc;
				return e.property = this.parseIdent(!0), "meta" !== e.property.name && this.raiseRecoverable(e.property.start, "The only valid meta property for import is 'import.meta'"), t && this.raiseRecoverable(e.start, "'import.meta' must not contain escaped characters"), "module" === this.options.sourceType || this.options.allowImportExportEverywhere || this.raiseRecoverable(e.start, "Cannot use 'import.meta' outside a module"), this.finishNode(e, "MetaProperty");
			}, $.parseLiteral = function(e) {
				var t = this.startNode();
				return t.value = e, t.raw = this.input.slice(this.start, this.end), 110 === t.raw.charCodeAt(t.raw.length - 1) && (t.bigint = null != t.value ? t.value.toString() : t.raw.slice(0, -1).replace(/_/g, "")), this.next(), this.finishNode(t, "Literal");
			}, $.parseParenExpression = function() {
				this.expect(f.parenL);
				var e = this.parseExpression();
				return this.expect(f.parenR), e;
			}, $.shouldParseArrow = function(e) {
				return !this.canInsertSemicolon();
			}, $.parseParenAndDistinguishExpression = function(e, t) {
				var i, s = this.start, r = this.startLoc, n = this.options.ecmaVersion >= 8;
				if (this.options.ecmaVersion >= 6) {
					this.next();
					var a, o = this.start, h = this.startLoc, c = [], p = !0, l = !1, u = new acorn_DestructuringErrors(), d = this.yieldPos, m = this.awaitPos;
					for (this.yieldPos = 0, this.awaitPos = 0; this.type !== f.parenR;) {
						if (p ? p = !1 : this.expect(f.comma), n && this.afterTrailingComma(f.parenR, !0)) {
							l = !0;
							break;
						}
						if (this.type === f.ellipsis) {
							a = this.start, c.push(this.parseParenItem(this.parseRestBinding())), this.type === f.comma && this.raiseRecoverable(this.start, "Comma is not permitted after the rest element");
							break;
						}
						c.push(this.parseMaybeAssign(!1, u, this.parseParenItem));
					}
					var g = this.lastTokEnd, x = this.lastTokEndLoc;
					if (this.expect(f.parenR), e && this.shouldParseArrow(c) && this.eat(f.arrow)) return this.checkPatternErrors(u, !1), this.checkYieldAwaitInDefaultParams(), this.yieldPos = d, this.awaitPos = m, this.parseParenArrowList(s, r, c, t);
					c.length && !l || this.unexpected(this.lastTokStart), a && this.unexpected(a), this.checkExpressionErrors(u, !0), this.yieldPos = d || this.yieldPos, this.awaitPos = m || this.awaitPos, c.length > 1 ? ((i = this.startNodeAt(o, h)).expressions = c, this.finishNodeAt(i, "SequenceExpression", g, x)) : i = c[0];
				} else i = this.parseParenExpression();
				if (this.options.preserveParens) {
					var v = this.startNodeAt(s, r);
					return v.expression = i, this.finishNode(v, "ParenthesizedExpression");
				}
				return i;
			}, $.parseParenItem = function(e) {
				return e;
			}, $.parseParenArrowList = function(e, t, i, s) {
				return this.parseArrowExpression(this.startNodeAt(e, t), i, !1, s);
			};
			var q = [];
			$.parseNew = function() {
				this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword new");
				var e = this.startNode();
				if (this.next(), this.options.ecmaVersion >= 6 && this.type === f.dot) {
					var t = this.startNodeAt(e.start, e.loc && e.loc.start);
					t.name = "new", e.meta = this.finishNode(t, "Identifier"), this.next();
					var i = this.containsEsc;
					return e.property = this.parseIdent(!0), "target" !== e.property.name && this.raiseRecoverable(e.property.start, "The only valid meta property for new is 'new.target'"), i && this.raiseRecoverable(e.start, "'new.target' must not contain escaped characters"), this.allowNewDotTarget || this.raiseRecoverable(e.start, "'new.target' can only be used in functions and class static block"), this.finishNode(e, "MetaProperty");
				}
				var s = this.start, r = this.startLoc;
				return e.callee = this.parseSubscripts(this.parseExprAtom(null, !1, !0), s, r, !0, !1), this.eat(f.parenL) ? e.arguments = this.parseExprList(f.parenR, this.options.ecmaVersion >= 8, !1) : e.arguments = q, this.finishNode(e, "NewExpression");
			}, $.parseTemplateElement = function(e) {
				var t = e.isTagged, i = this.startNode();
				return this.type === f.invalidTemplate ? (t || this.raiseRecoverable(this.start, "Bad escape sequence in untagged template literal"), i.value = {
					raw: this.value.replace(/\r\n?/g, "\n"),
					cooked: null
				}) : i.value = {
					raw: this.input.slice(this.start, this.end).replace(/\r\n?/g, "\n"),
					cooked: this.value
				}, this.next(), i.tail = this.type === f.backQuote, this.finishNode(i, "TemplateElement");
			}, $.parseTemplate = function(e) {
				void 0 === e && (e = {});
				var t = e.isTagged;
				void 0 === t && (t = !1);
				var i = this.startNode();
				this.next(), i.expressions = [];
				var s = this.parseTemplateElement({ isTagged: t });
				for (i.quasis = [s]; !s.tail;) this.type === f.eof && this.raise(this.pos, "Unterminated template literal"), this.expect(f.dollarBraceL), i.expressions.push(this.parseExpression()), this.expect(f.braceR), i.quasis.push(s = this.parseTemplateElement({ isTagged: t }));
				return this.next(), this.finishNode(i, "TemplateLiteral");
			}, $.isAsyncProp = function(e) {
				return !e.computed && "Identifier" === e.key.type && "async" === e.key.name && (this.type === f.name || this.type === f.num || this.type === f.string || this.type === f.bracketL || this.type.keyword || this.options.ecmaVersion >= 9 && this.type === f.star) && !m.test(this.input.slice(this.lastTokEnd, this.start));
			}, $.parseObj = function(e, t) {
				var i = this.startNode(), s = !0, r = {};
				for (i.properties = [], this.next(); !this.eat(f.braceR);) {
					if (s) s = !1;
					else if (this.expect(f.comma), this.options.ecmaVersion >= 5 && this.afterTrailingComma(f.braceR)) break;
					var n = this.parseProperty(e, t);
					e || this.checkPropClash(n, r, t), i.properties.push(n);
				}
				return this.finishNode(i, e ? "ObjectPattern" : "ObjectExpression");
			}, $.parseProperty = function(e, t) {
				var i, s, r, n, a = this.startNode();
				if (this.options.ecmaVersion >= 9 && this.eat(f.ellipsis)) return e ? (a.argument = this.parseIdent(!1), this.type === f.comma && this.raiseRecoverable(this.start, "Comma is not permitted after the rest element"), this.finishNode(a, "RestElement")) : (a.argument = this.parseMaybeAssign(!1, t), this.type === f.comma && t && t.trailingComma < 0 && (t.trailingComma = this.start), this.finishNode(a, "SpreadElement"));
				this.options.ecmaVersion >= 6 && (a.method = !1, a.shorthand = !1, (e || t) && (r = this.start, n = this.startLoc), e || (i = this.eat(f.star)));
				var o = this.containsEsc;
				return this.parsePropertyName(a), !e && !o && this.options.ecmaVersion >= 8 && !i && this.isAsyncProp(a) ? (s = !0, i = this.options.ecmaVersion >= 9 && this.eat(f.star), this.parsePropertyName(a)) : s = !1, this.parsePropertyValue(a, e, i, s, r, n, t, o), this.finishNode(a, "Property");
			}, $.parseGetterSetter = function(e) {
				var t = e.key.name;
				this.parsePropertyName(e), e.value = this.parseMethod(!1), e.kind = t;
				var i = "get" === e.kind ? 0 : 1;
				if (e.value.params.length !== i) {
					var s = e.value.start;
					"get" === e.kind ? this.raiseRecoverable(s, "getter should have no params") : this.raiseRecoverable(s, "setter should have exactly one param");
				} else "set" === e.kind && "RestElement" === e.value.params[0].type && this.raiseRecoverable(e.value.params[0].start, "Setter cannot use rest params");
			}, $.parsePropertyValue = function(e, t, i, s, r, n, a, o) {
				(i || s) && this.type === f.colon && this.unexpected(), this.eat(f.colon) ? (e.value = t ? this.parseMaybeDefault(this.start, this.startLoc) : this.parseMaybeAssign(!1, a), e.kind = "init") : this.options.ecmaVersion >= 6 && this.type === f.parenL ? (t && this.unexpected(), e.method = !0, e.value = this.parseMethod(i, s), e.kind = "init") : t || o || !(this.options.ecmaVersion >= 5) || e.computed || "Identifier" !== e.key.type || "get" !== e.key.name && "set" !== e.key.name || this.type === f.comma || this.type === f.braceR || this.type === f.eq ? this.options.ecmaVersion >= 6 && !e.computed && "Identifier" === e.key.type ? ((i || s) && this.unexpected(), this.checkUnreserved(e.key), "await" !== e.key.name || this.awaitIdentPos || (this.awaitIdentPos = r), t ? e.value = this.parseMaybeDefault(r, n, this.copyNode(e.key)) : this.type === f.eq && a ? (a.shorthandAssign < 0 && (a.shorthandAssign = this.start), e.value = this.parseMaybeDefault(r, n, this.copyNode(e.key))) : e.value = this.copyNode(e.key), e.kind = "init", e.shorthand = !0) : this.unexpected() : ((i || s) && this.unexpected(), this.parseGetterSetter(e));
			}, $.parsePropertyName = function(e) {
				if (this.options.ecmaVersion >= 6) {
					if (this.eat(f.bracketL)) return e.computed = !0, e.key = this.parseMaybeAssign(), this.expect(f.bracketR), e.key;
					e.computed = !1;
				}
				return e.key = this.type === f.num || this.type === f.string ? this.parseExprAtom() : this.parseIdent("never" !== this.options.allowReserved);
			}, $.initFunction = function(e) {
				e.id = null, this.options.ecmaVersion >= 6 && (e.generator = e.expression = !1), this.options.ecmaVersion >= 8 && (e.async = !1);
			}, $.parseMethod = function(e, t, i) {
				var s = this.startNode(), r = this.yieldPos, n = this.awaitPos, a = this.awaitIdentPos;
				return this.initFunction(s), this.options.ecmaVersion >= 6 && (s.generator = e), this.options.ecmaVersion >= 8 && (s.async = !!t), this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, this.enterScope(64 | functionFlags(t, s.generator) | (i ? 128 : 0)), this.expect(f.parenL), s.params = this.parseBindingList(f.parenR, !1, this.options.ecmaVersion >= 8), this.checkYieldAwaitInDefaultParams(), this.parseFunctionBody(s, !1, !0, !1), this.yieldPos = r, this.awaitPos = n, this.awaitIdentPos = a, this.finishNode(s, "FunctionExpression");
			}, $.parseArrowExpression = function(e, t, i, s) {
				var r = this.yieldPos, n = this.awaitPos, a = this.awaitIdentPos;
				return this.enterScope(16 | functionFlags(i, !1)), this.initFunction(e), this.options.ecmaVersion >= 8 && (e.async = !!i), this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, e.params = this.toAssignableList(t, !0), this.parseFunctionBody(e, !0, !1, s), this.yieldPos = r, this.awaitPos = n, this.awaitIdentPos = a, this.finishNode(e, "ArrowFunctionExpression");
			}, $.parseFunctionBody = function(e, t, i, s) {
				var r = t && this.type !== f.braceL, n = this.strict, a = !1;
				if (r) e.body = this.parseMaybeAssign(s), e.expression = !0, this.checkParams(e, !1);
				else {
					var o = this.options.ecmaVersion >= 7 && !this.isSimpleParamList(e.params);
					n && !o || (a = this.strictDirective(this.end)) && o && this.raiseRecoverable(e.start, "Illegal 'use strict' directive in function with non-simple parameter list");
					var h = this.labels;
					this.labels = [], a && (this.strict = !0), this.checkParams(e, !n && !a && !t && !i && this.isSimpleParamList(e.params)), this.strict && e.id && this.checkLValSimple(e.id, 5), e.body = this.parseBlock(!1, void 0, a && !n), e.expression = !1, this.adaptDirectivePrologue(e.body.body), this.labels = h;
				}
				this.exitScope();
			}, $.isSimpleParamList = function(e) {
				for (var t = 0, i = e; t < i.length; t += 1) if ("Identifier" !== i[t].type) return !1;
				return !0;
			}, $.checkParams = function(e, t) {
				for (var i = Object.create(null), s = 0, r = e.params; s < r.length; s += 1) {
					var n = r[s];
					this.checkLValInnerPattern(n, 1, t ? null : i);
				}
			}, $.parseExprList = function(e, t, i, s) {
				for (var r = [], n = !0; !this.eat(e);) {
					if (n) n = !1;
					else if (this.expect(f.comma), t && this.afterTrailingComma(e)) break;
					var a = void 0;
					i && this.type === f.comma ? a = null : this.type === f.ellipsis ? (a = this.parseSpread(s), s && this.type === f.comma && s.trailingComma < 0 && (s.trailingComma = this.start)) : a = this.parseMaybeAssign(!1, s), r.push(a);
				}
				return r;
			}, $.checkUnreserved = function(e) {
				var t = e.start, i = e.end, s = e.name;
				(this.inGenerator && "yield" === s && this.raiseRecoverable(t, "Cannot use 'yield' as identifier inside a generator"), this.inAsync && "await" === s && this.raiseRecoverable(t, "Cannot use 'await' as identifier inside an async function"), this.currentThisScope().flags & P || "arguments" !== s || this.raiseRecoverable(t, "Cannot use 'arguments' in class field initializer"), !this.inClassStaticBlock || "arguments" !== s && "await" !== s || this.raise(t, "Cannot use " + s + " in class static initialization block"), this.keywords.test(s) && this.raise(t, "Unexpected keyword '" + s + "'"), this.options.ecmaVersion < 6 && -1 !== this.input.slice(t, i).indexOf("\\")) || (this.strict ? this.reservedWordsStrict : this.reservedWords).test(s) && (this.inAsync || "await" !== s || this.raiseRecoverable(t, "Cannot use keyword 'await' outside an async function"), this.raiseRecoverable(t, "The keyword '" + s + "' is reserved"));
			}, $.parseIdent = function(e) {
				var t = this.parseIdentNode();
				return this.next(!!e), this.finishNode(t, "Identifier"), e || (this.checkUnreserved(t), "await" !== t.name || this.awaitIdentPos || (this.awaitIdentPos = t.start)), t;
			}, $.parseIdentNode = function() {
				var e = this.startNode();
				return this.type === f.name ? e.name = this.value : this.type.keyword ? (e.name = this.type.keyword, "class" !== e.name && "function" !== e.name || this.lastTokEnd === this.lastTokStart + 1 && 46 === this.input.charCodeAt(this.lastTokStart) || this.context.pop(), this.type = f.name) : this.unexpected(), e;
			}, $.parsePrivateIdent = function() {
				var e = this.startNode();
				return this.type === f.privateId ? e.name = this.value : this.unexpected(), this.next(), this.finishNode(e, "PrivateIdentifier"), this.options.checkPrivateFields && (0 === this.privateNameStack.length ? this.raise(e.start, "Private field '#" + e.name + "' must be declared in an enclosing class") : this.privateNameStack[this.privateNameStack.length - 1].used.push(e)), e;
			}, $.parseYield = function(e) {
				this.yieldPos || (this.yieldPos = this.start);
				var t = this.startNode();
				return this.next(), this.type === f.semi || this.canInsertSemicolon() || this.type !== f.star && !this.type.startsExpr ? (t.delegate = !1, t.argument = null) : (t.delegate = this.eat(f.star), t.argument = this.parseMaybeAssign(e)), this.finishNode(t, "YieldExpression");
			}, $.parseAwait = function(e) {
				this.awaitPos || (this.awaitPos = this.start);
				var t = this.startNode();
				return this.next(), t.argument = this.parseMaybeUnary(null, !0, !1, e), this.finishNode(t, "AwaitExpression");
			};
			var W = acorn_Parser.prototype;
			W.raise = function(e, t) {
				var i = getLineInfo(this.input, e);
				t += " (" + i.line + ":" + i.column + ")", this.sourceFile && (t += " in " + this.sourceFile);
				var s = new SyntaxError(t);
				throw s.pos = e, s.loc = i, s.raisedAt = this.pos, s;
			}, W.raiseRecoverable = W.raise, W.curPosition = function() {
				if (this.options.locations) return new acorn_Position(this.curLine, this.pos - this.lineStart);
			};
			var G = acorn_Parser.prototype, acorn_Scope = function(e) {
				this.flags = e, this.var = [], this.lexical = [], this.functions = [];
			};
			G.enterScope = function(e) {
				this.scopeStack.push(new acorn_Scope(e));
			}, G.exitScope = function() {
				this.scopeStack.pop();
			}, G.treatFunctionsAsVarInScope = function(e) {
				return 2 & e.flags || !this.inModule && 1 & e.flags;
			}, G.declareName = function(e, t, i) {
				var s = !1;
				if (2 === t) {
					var r = this.currentScope();
					s = r.lexical.indexOf(e) > -1 || r.functions.indexOf(e) > -1 || r.var.indexOf(e) > -1, r.lexical.push(e), this.inModule && 1 & r.flags && delete this.undefinedExports[e];
				} else if (4 === t) this.currentScope().lexical.push(e);
				else if (3 === t) {
					var n = this.currentScope();
					s = this.treatFunctionsAsVar ? n.lexical.indexOf(e) > -1 : n.lexical.indexOf(e) > -1 || n.var.indexOf(e) > -1, n.functions.push(e);
				} else for (var a = this.scopeStack.length - 1; a >= 0; --a) {
					var o = this.scopeStack[a];
					if (o.lexical.indexOf(e) > -1 && !(32 & o.flags && o.lexical[0] === e) || !this.treatFunctionsAsVarInScope(o) && o.functions.indexOf(e) > -1) {
						s = !0;
						break;
					}
					if (o.var.push(e), this.inModule && 1 & o.flags && delete this.undefinedExports[e], o.flags & P) break;
				}
				s && this.raiseRecoverable(i, "Identifier '" + e + "' has already been declared");
			}, G.checkLocalExport = function(e) {
				-1 === this.scopeStack[0].lexical.indexOf(e.name) && -1 === this.scopeStack[0].var.indexOf(e.name) && (this.undefinedExports[e.name] = e);
			}, G.currentScope = function() {
				return this.scopeStack[this.scopeStack.length - 1];
			}, G.currentVarScope = function() {
				for (var e = this.scopeStack.length - 1;; e--) {
					var t = this.scopeStack[e];
					if (771 & t.flags) return t;
				}
			}, G.currentThisScope = function() {
				for (var e = this.scopeStack.length - 1;; e--) {
					var t = this.scopeStack[e];
					if (771 & t.flags && !(16 & t.flags)) return t;
				}
			};
			var acorn_Node = function(e, t, i) {
				this.type = "", this.start = t, this.end = 0, e.options.locations && (this.loc = new acorn_SourceLocation(e, i)), e.options.directSourceFile && (this.sourceFile = e.options.directSourceFile), e.options.ranges && (this.range = [t, 0]);
			}, H = acorn_Parser.prototype;
			function finishNodeAt(e, t, i, s) {
				return e.type = t, e.end = i, this.options.locations && (e.loc.end = s), this.options.ranges && (e.range[1] = i), e;
			}
			H.startNode = function() {
				return new acorn_Node(this, this.start, this.startLoc);
			}, H.startNodeAt = function(e, t) {
				return new acorn_Node(this, e, t);
			}, H.finishNode = function(e, t) {
				return finishNodeAt.call(this, e, t, this.lastTokEnd, this.lastTokEndLoc);
			}, H.finishNodeAt = function(e, t, i, s) {
				return finishNodeAt.call(this, e, t, i, s);
			}, H.copyNode = function(e) {
				var t = new acorn_Node(this, e.start, this.startLoc);
				for (var i in e) t[i] = e[i];
				return t;
			};
			var K = "ASCII ASCII_Hex_Digit AHex Alphabetic Alpha Any Assigned Bidi_Control Bidi_C Bidi_Mirrored Bidi_M Case_Ignorable CI Cased Changes_When_Casefolded CWCF Changes_When_Casemapped CWCM Changes_When_Lowercased CWL Changes_When_NFKC_Casefolded CWKCF Changes_When_Titlecased CWT Changes_When_Uppercased CWU Dash Default_Ignorable_Code_Point DI Deprecated Dep Diacritic Dia Emoji Emoji_Component Emoji_Modifier Emoji_Modifier_Base Emoji_Presentation Extender Ext Grapheme_Base Gr_Base Grapheme_Extend Gr_Ext Hex_Digit Hex IDS_Binary_Operator IDSB IDS_Trinary_Operator IDST ID_Continue IDC ID_Start IDS Ideographic Ideo Join_Control Join_C Logical_Order_Exception LOE Lowercase Lower Math Noncharacter_Code_Point NChar Pattern_Syntax Pat_Syn Pattern_White_Space Pat_WS Quotation_Mark QMark Radical Regional_Indicator RI Sentence_Terminal STerm Soft_Dotted SD Terminal_Punctuation Term Unified_Ideograph UIdeo Uppercase Upper Variation_Selector VS White_Space space XID_Continue XIDC XID_Start XIDS", z = K + " Extended_Pictographic", J = z + " EBase EComp EMod EPres ExtPict", Y = {
				9: K,
				10: z,
				11: z,
				12: J,
				13: J,
				14: J
			}, Q = {
				9: "",
				10: "",
				11: "",
				12: "",
				13: "",
				14: "Basic_Emoji Emoji_Keycap_Sequence RGI_Emoji_Modifier_Sequence RGI_Emoji_Flag_Sequence RGI_Emoji_Tag_Sequence RGI_Emoji_ZWJ_Sequence RGI_Emoji"
			}, Z = "Cased_Letter LC Close_Punctuation Pe Connector_Punctuation Pc Control Cc cntrl Currency_Symbol Sc Dash_Punctuation Pd Decimal_Number Nd digit Enclosing_Mark Me Final_Punctuation Pf Format Cf Initial_Punctuation Pi Letter L Letter_Number Nl Line_Separator Zl Lowercase_Letter Ll Mark M Combining_Mark Math_Symbol Sm Modifier_Letter Lm Modifier_Symbol Sk Nonspacing_Mark Mn Number N Open_Punctuation Ps Other C Other_Letter Lo Other_Number No Other_Punctuation Po Other_Symbol So Paragraph_Separator Zp Private_Use Co Punctuation P punct Separator Z Space_Separator Zs Spacing_Mark Mc Surrogate Cs Symbol S Titlecase_Letter Lt Unassigned Cn Uppercase_Letter Lu", X = "Adlam Adlm Ahom Anatolian_Hieroglyphs Hluw Arabic Arab Armenian Armn Avestan Avst Balinese Bali Bamum Bamu Bassa_Vah Bass Batak Batk Bengali Beng Bhaiksuki Bhks Bopomofo Bopo Brahmi Brah Braille Brai Buginese Bugi Buhid Buhd Canadian_Aboriginal Cans Carian Cari Caucasian_Albanian Aghb Chakma Cakm Cham Cham Cherokee Cher Common Zyyy Coptic Copt Qaac Cuneiform Xsux Cypriot Cprt Cyrillic Cyrl Deseret Dsrt Devanagari Deva Duployan Dupl Egyptian_Hieroglyphs Egyp Elbasan Elba Ethiopic Ethi Georgian Geor Glagolitic Glag Gothic Goth Grantha Gran Greek Grek Gujarati Gujr Gurmukhi Guru Han Hani Hangul Hang Hanunoo Hano Hatran Hatr Hebrew Hebr Hiragana Hira Imperial_Aramaic Armi Inherited Zinh Qaai Inscriptional_Pahlavi Phli Inscriptional_Parthian Prti Javanese Java Kaithi Kthi Kannada Knda Katakana Kana Kayah_Li Kali Kharoshthi Khar Khmer Khmr Khojki Khoj Khudawadi Sind Lao Laoo Latin Latn Lepcha Lepc Limbu Limb Linear_A Lina Linear_B Linb Lisu Lisu Lycian Lyci Lydian Lydi Mahajani Mahj Malayalam Mlym Mandaic Mand Manichaean Mani Marchen Marc Masaram_Gondi Gonm Meetei_Mayek Mtei Mende_Kikakui Mend Meroitic_Cursive Merc Meroitic_Hieroglyphs Mero Miao Plrd Modi Mongolian Mong Mro Mroo Multani Mult Myanmar Mymr Nabataean Nbat New_Tai_Lue Talu Newa Newa Nko Nkoo Nushu Nshu Ogham Ogam Ol_Chiki Olck Old_Hungarian Hung Old_Italic Ital Old_North_Arabian Narb Old_Permic Perm Old_Persian Xpeo Old_South_Arabian Sarb Old_Turkic Orkh Oriya Orya Osage Osge Osmanya Osma Pahawh_Hmong Hmng Palmyrene Palm Pau_Cin_Hau Pauc Phags_Pa Phag Phoenician Phnx Psalter_Pahlavi Phlp Rejang Rjng Runic Runr Samaritan Samr Saurashtra Saur Sharada Shrd Shavian Shaw Siddham Sidd SignWriting Sgnw Sinhala Sinh Sora_Sompeng Sora Soyombo Soyo Sundanese Sund Syloti_Nagri Sylo Syriac Syrc Tagalog Tglg Tagbanwa Tagb Tai_Le Tale Tai_Tham Lana Tai_Viet Tavt Takri Takr Tamil Taml Tangut Tang Telugu Telu Thaana Thaa Thai Thai Tibetan Tibt Tifinagh Tfng Tirhuta Tirh Ugaritic Ugar Vai Vaii Warang_Citi Wara Yi Yiii Zanabazar_Square Zanb", ee = X + " Dogra Dogr Gunjala_Gondi Gong Hanifi_Rohingya Rohg Makasar Maka Medefaidrin Medf Old_Sogdian Sogo Sogdian Sogd", te = ee + " Elymaic Elym Nandinagari Nand Nyiakeng_Puachue_Hmong Hmnp Wancho Wcho", ie = te + " Chorasmian Chrs Diak Dives_Akuru Khitan_Small_Script Kits Yezi Yezidi", se = ie + " Cypro_Minoan Cpmn Old_Uyghur Ougr Tangsa Tnsa Toto Vithkuqi Vith", re = {
				9: X,
				10: ee,
				11: te,
				12: ie,
				13: se,
				14: se + " Gara Garay Gukh Gurung_Khema Hrkt Katakana_Or_Hiragana Kawi Kirat_Rai Krai Nag_Mundari Nagm Ol_Onal Onao Sunu Sunuwar Todhri Todr Tulu_Tigalari Tutg Unknown Zzzz"
			}, ne = {};
			function buildUnicodeData(e) {
				var t = ne[e] = {
					binary: wordsRegexp(Y[e] + " " + Z),
					binaryOfStrings: wordsRegexp(Q[e]),
					nonBinary: {
						General_Category: wordsRegexp(Z),
						Script: wordsRegexp(re[e])
					}
				};
				t.nonBinary.Script_Extensions = t.nonBinary.Script, t.nonBinary.gc = t.nonBinary.General_Category, t.nonBinary.sc = t.nonBinary.Script, t.nonBinary.scx = t.nonBinary.Script_Extensions;
			}
			for (var ae = 0, oe = [
				9,
				10,
				11,
				12,
				13,
				14
			]; ae < oe.length; ae += 1) buildUnicodeData(oe[ae]);
			var he = acorn_Parser.prototype, acorn_BranchID = function(e, t) {
				this.parent = e, this.base = t || this;
			};
			acorn_BranchID.prototype.separatedFrom = function(e) {
				for (var t = this; t; t = t.parent) for (var i = e; i; i = i.parent) if (t.base === i.base && t !== i) return !0;
				return !1;
			}, acorn_BranchID.prototype.sibling = function() {
				return new acorn_BranchID(this.parent, this.base);
			};
			var acorn_RegExpValidationState = function(e) {
				this.parser = e, this.validFlags = "gim" + (e.options.ecmaVersion >= 6 ? "uy" : "") + (e.options.ecmaVersion >= 9 ? "s" : "") + (e.options.ecmaVersion >= 13 ? "d" : "") + (e.options.ecmaVersion >= 15 ? "v" : ""), this.unicodeProperties = ne[e.options.ecmaVersion >= 14 ? 14 : e.options.ecmaVersion], this.source = "", this.flags = "", this.start = 0, this.switchU = !1, this.switchV = !1, this.switchN = !1, this.pos = 0, this.lastIntValue = 0, this.lastStringValue = "", this.lastAssertionIsQuantifiable = !1, this.numCapturingParens = 0, this.maxBackReference = 0, this.groupNames = Object.create(null), this.backReferenceNames = [], this.branchID = null;
			};
			function isRegularExpressionModifier(e) {
				return 105 === e || 109 === e || 115 === e;
			}
			function isSyntaxCharacter(e) {
				return 36 === e || e >= 40 && e <= 43 || 46 === e || 63 === e || e >= 91 && e <= 94 || e >= 123 && e <= 125;
			}
			function isControlLetter(e) {
				return e >= 65 && e <= 90 || e >= 97 && e <= 122;
			}
			acorn_RegExpValidationState.prototype.reset = function(e, t, i) {
				var s = -1 !== i.indexOf("v"), r = -1 !== i.indexOf("u");
				this.start = 0 | e, this.source = t + "", this.flags = i, s && this.parser.options.ecmaVersion >= 15 ? (this.switchU = !0, this.switchV = !0, this.switchN = !0) : (this.switchU = r && this.parser.options.ecmaVersion >= 6, this.switchV = !1, this.switchN = r && this.parser.options.ecmaVersion >= 9);
			}, acorn_RegExpValidationState.prototype.raise = function(e) {
				this.parser.raiseRecoverable(this.start, "Invalid regular expression: /" + this.source + "/: " + e);
			}, acorn_RegExpValidationState.prototype.at = function(e, t) {
				void 0 === t && (t = !1);
				var i = this.source, s = i.length;
				if (e >= s) return -1;
				var r = i.charCodeAt(e);
				if (!t && !this.switchU || r <= 55295 || r >= 57344 || e + 1 >= s) return r;
				var n = i.charCodeAt(e + 1);
				return n >= 56320 && n <= 57343 ? (r << 10) + n - 56613888 : r;
			}, acorn_RegExpValidationState.prototype.nextIndex = function(e, t) {
				void 0 === t && (t = !1);
				var i = this.source, s = i.length;
				if (e >= s) return s;
				var r, n = i.charCodeAt(e);
				return !t && !this.switchU || n <= 55295 || n >= 57344 || e + 1 >= s || (r = i.charCodeAt(e + 1)) < 56320 || r > 57343 ? e + 1 : e + 2;
			}, acorn_RegExpValidationState.prototype.current = function(e) {
				return void 0 === e && (e = !1), this.at(this.pos, e);
			}, acorn_RegExpValidationState.prototype.lookahead = function(e) {
				return void 0 === e && (e = !1), this.at(this.nextIndex(this.pos, e), e);
			}, acorn_RegExpValidationState.prototype.advance = function(e) {
				void 0 === e && (e = !1), this.pos = this.nextIndex(this.pos, e);
			}, acorn_RegExpValidationState.prototype.eat = function(e, t) {
				return void 0 === t && (t = !1), this.current(t) === e && (this.advance(t), !0);
			}, acorn_RegExpValidationState.prototype.eatChars = function(e, t) {
				void 0 === t && (t = !1);
				for (var i = this.pos, s = 0, r = e; s < r.length; s += 1) {
					var n = r[s], a = this.at(i, t);
					if (-1 === a || a !== n) return !1;
					i = this.nextIndex(i, t);
				}
				return this.pos = i, !0;
			}, he.validateRegExpFlags = function(e) {
				for (var t = e.validFlags, i = e.flags, s = !1, r = !1, n = 0; n < i.length; n++) {
					var a = i.charAt(n);
					-1 === t.indexOf(a) && this.raise(e.start, "Invalid regular expression flag"), i.indexOf(a, n + 1) > -1 && this.raise(e.start, "Duplicate regular expression flag"), "u" === a && (s = !0), "v" === a && (r = !0);
				}
				this.options.ecmaVersion >= 15 && s && r && this.raise(e.start, "Invalid regular expression flag");
			}, he.validateRegExpPattern = function(e) {
				this.regexp_pattern(e), !e.switchN && this.options.ecmaVersion >= 9 && function(e) {
					for (var t in e) return !0;
					return !1;
				}(e.groupNames) && (e.switchN = !0, this.regexp_pattern(e));
			}, he.regexp_pattern = function(e) {
				e.pos = 0, e.lastIntValue = 0, e.lastStringValue = "", e.lastAssertionIsQuantifiable = !1, e.numCapturingParens = 0, e.maxBackReference = 0, e.groupNames = Object.create(null), e.backReferenceNames.length = 0, e.branchID = null, this.regexp_disjunction(e), e.pos !== e.source.length && (e.eat(41) && e.raise("Unmatched ')'"), (e.eat(93) || e.eat(125)) && e.raise("Lone quantifier brackets")), e.maxBackReference > e.numCapturingParens && e.raise("Invalid escape");
				for (var t = 0, i = e.backReferenceNames; t < i.length; t += 1) {
					var s = i[t];
					e.groupNames[s] || e.raise("Invalid named capture referenced");
				}
			}, he.regexp_disjunction = function(e) {
				var t = this.options.ecmaVersion >= 16;
				for (t && (e.branchID = new acorn_BranchID(e.branchID, null)), this.regexp_alternative(e); e.eat(124);) t && (e.branchID = e.branchID.sibling()), this.regexp_alternative(e);
				t && (e.branchID = e.branchID.parent), this.regexp_eatQuantifier(e, !0) && e.raise("Nothing to repeat"), e.eat(123) && e.raise("Lone quantifier brackets");
			}, he.regexp_alternative = function(e) {
				for (; e.pos < e.source.length && this.regexp_eatTerm(e););
			}, he.regexp_eatTerm = function(e) {
				return this.regexp_eatAssertion(e) ? (e.lastAssertionIsQuantifiable && this.regexp_eatQuantifier(e) && e.switchU && e.raise("Invalid quantifier"), !0) : !!(e.switchU ? this.regexp_eatAtom(e) : this.regexp_eatExtendedAtom(e)) && (this.regexp_eatQuantifier(e), !0);
			}, he.regexp_eatAssertion = function(e) {
				var t = e.pos;
				if (e.lastAssertionIsQuantifiable = !1, e.eat(94) || e.eat(36)) return !0;
				if (e.eat(92)) {
					if (e.eat(66) || e.eat(98)) return !0;
					e.pos = t;
				}
				if (e.eat(40) && e.eat(63)) {
					var i = !1;
					if (this.options.ecmaVersion >= 9 && (i = e.eat(60)), e.eat(61) || e.eat(33)) return this.regexp_disjunction(e), e.eat(41) || e.raise("Unterminated group"), e.lastAssertionIsQuantifiable = !i, !0;
				}
				return e.pos = t, !1;
			}, he.regexp_eatQuantifier = function(e, t) {
				return void 0 === t && (t = !1), !!this.regexp_eatQuantifierPrefix(e, t) && (e.eat(63), !0);
			}, he.regexp_eatQuantifierPrefix = function(e, t) {
				return e.eat(42) || e.eat(43) || e.eat(63) || this.regexp_eatBracedQuantifier(e, t);
			}, he.regexp_eatBracedQuantifier = function(e, t) {
				var i = e.pos;
				if (e.eat(123)) {
					var s = 0, r = -1;
					if (this.regexp_eatDecimalDigits(e) && (s = e.lastIntValue, e.eat(44) && this.regexp_eatDecimalDigits(e) && (r = e.lastIntValue), e.eat(125))) return -1 !== r && r < s && !t && e.raise("numbers out of order in {} quantifier"), !0;
					e.switchU && !t && e.raise("Incomplete quantifier"), e.pos = i;
				}
				return !1;
			}, he.regexp_eatAtom = function(e) {
				return this.regexp_eatPatternCharacters(e) || e.eat(46) || this.regexp_eatReverseSolidusAtomEscape(e) || this.regexp_eatCharacterClass(e) || this.regexp_eatUncapturingGroup(e) || this.regexp_eatCapturingGroup(e);
			}, he.regexp_eatReverseSolidusAtomEscape = function(e) {
				var t = e.pos;
				if (e.eat(92)) {
					if (this.regexp_eatAtomEscape(e)) return !0;
					e.pos = t;
				}
				return !1;
			}, he.regexp_eatUncapturingGroup = function(e) {
				var t = e.pos;
				if (e.eat(40)) {
					if (e.eat(63)) {
						if (this.options.ecmaVersion >= 16) {
							var i = this.regexp_eatModifiers(e), s = e.eat(45);
							if (i || s) {
								for (var r = 0; r < i.length; r++) {
									var n = i.charAt(r);
									i.indexOf(n, r + 1) > -1 && e.raise("Duplicate regular expression modifiers");
								}
								if (s) {
									var a = this.regexp_eatModifiers(e);
									i || a || 58 !== e.current() || e.raise("Invalid regular expression modifiers");
									for (var o = 0; o < a.length; o++) {
										var h = a.charAt(o);
										(a.indexOf(h, o + 1) > -1 || i.indexOf(h) > -1) && e.raise("Duplicate regular expression modifiers");
									}
								}
							}
						}
						if (e.eat(58)) {
							if (this.regexp_disjunction(e), e.eat(41)) return !0;
							e.raise("Unterminated group");
						}
					}
					e.pos = t;
				}
				return !1;
			}, he.regexp_eatCapturingGroup = function(e) {
				if (e.eat(40)) {
					if (this.options.ecmaVersion >= 9 ? this.regexp_groupSpecifier(e) : 63 === e.current() && e.raise("Invalid group"), this.regexp_disjunction(e), e.eat(41)) return e.numCapturingParens += 1, !0;
					e.raise("Unterminated group");
				}
				return !1;
			}, he.regexp_eatModifiers = function(e) {
				for (var t = "", i = 0; -1 !== (i = e.current()) && isRegularExpressionModifier(i);) t += codePointToString(i), e.advance();
				return t;
			}, he.regexp_eatExtendedAtom = function(e) {
				return e.eat(46) || this.regexp_eatReverseSolidusAtomEscape(e) || this.regexp_eatCharacterClass(e) || this.regexp_eatUncapturingGroup(e) || this.regexp_eatCapturingGroup(e) || this.regexp_eatInvalidBracedQuantifier(e) || this.regexp_eatExtendedPatternCharacter(e);
			}, he.regexp_eatInvalidBracedQuantifier = function(e) {
				return this.regexp_eatBracedQuantifier(e, !0) && e.raise("Nothing to repeat"), !1;
			}, he.regexp_eatSyntaxCharacter = function(e) {
				var t = e.current();
				return !!isSyntaxCharacter(t) && (e.lastIntValue = t, e.advance(), !0);
			}, he.regexp_eatPatternCharacters = function(e) {
				for (var t = e.pos, i = 0; -1 !== (i = e.current()) && !isSyntaxCharacter(i);) e.advance();
				return e.pos !== t;
			}, he.regexp_eatExtendedPatternCharacter = function(e) {
				var t = e.current();
				return !(-1 === t || 36 === t || t >= 40 && t <= 43 || 46 === t || 63 === t || 91 === t || 94 === t || 124 === t) && (e.advance(), !0);
			}, he.regexp_groupSpecifier = function(e) {
				if (e.eat(63)) {
					this.regexp_eatGroupName(e) || e.raise("Invalid group");
					var t = this.options.ecmaVersion >= 16, i = e.groupNames[e.lastStringValue];
					if (i) if (t) for (var s = 0, r = i; s < r.length; s += 1) r[s].separatedFrom(e.branchID) || e.raise("Duplicate capture group name");
					else e.raise("Duplicate capture group name");
					t ? (i || (e.groupNames[e.lastStringValue] = [])).push(e.branchID) : e.groupNames[e.lastStringValue] = !0;
				}
			}, he.regexp_eatGroupName = function(e) {
				if (e.lastStringValue = "", e.eat(60)) {
					if (this.regexp_eatRegExpIdentifierName(e) && e.eat(62)) return !0;
					e.raise("Invalid capture group name");
				}
				return !1;
			}, he.regexp_eatRegExpIdentifierName = function(e) {
				if (e.lastStringValue = "", this.regexp_eatRegExpIdentifierStart(e)) {
					for (e.lastStringValue += codePointToString(e.lastIntValue); this.regexp_eatRegExpIdentifierPart(e);) e.lastStringValue += codePointToString(e.lastIntValue);
					return !0;
				}
				return !1;
			}, he.regexp_eatRegExpIdentifierStart = function(e) {
				var t = e.pos, i = this.options.ecmaVersion >= 11, s = e.current(i);
				return e.advance(i), 92 === s && this.regexp_eatRegExpUnicodeEscapeSequence(e, i) && (s = e.lastIntValue), function(e) {
					return isIdentifierStart(e, !0) || 36 === e || 95 === e;
				}(s) ? (e.lastIntValue = s, !0) : (e.pos = t, !1);
			}, he.regexp_eatRegExpIdentifierPart = function(e) {
				var t = e.pos, i = this.options.ecmaVersion >= 11, s = e.current(i);
				return e.advance(i), 92 === s && this.regexp_eatRegExpUnicodeEscapeSequence(e, i) && (s = e.lastIntValue), function(e) {
					return isIdentifierChar(e, !0) || 36 === e || 95 === e || 8204 === e || 8205 === e;
				}(s) ? (e.lastIntValue = s, !0) : (e.pos = t, !1);
			}, he.regexp_eatAtomEscape = function(e) {
				return !!(this.regexp_eatBackReference(e) || this.regexp_eatCharacterClassEscape(e) || this.regexp_eatCharacterEscape(e) || e.switchN && this.regexp_eatKGroupName(e)) || (e.switchU && (99 === e.current() && e.raise("Invalid unicode escape"), e.raise("Invalid escape")), !1);
			}, he.regexp_eatBackReference = function(e) {
				var t = e.pos;
				if (this.regexp_eatDecimalEscape(e)) {
					var i = e.lastIntValue;
					if (e.switchU) return i > e.maxBackReference && (e.maxBackReference = i), !0;
					if (i <= e.numCapturingParens) return !0;
					e.pos = t;
				}
				return !1;
			}, he.regexp_eatKGroupName = function(e) {
				if (e.eat(107)) {
					if (this.regexp_eatGroupName(e)) return e.backReferenceNames.push(e.lastStringValue), !0;
					e.raise("Invalid named reference");
				}
				return !1;
			}, he.regexp_eatCharacterEscape = function(e) {
				return this.regexp_eatControlEscape(e) || this.regexp_eatCControlLetter(e) || this.regexp_eatZero(e) || this.regexp_eatHexEscapeSequence(e) || this.regexp_eatRegExpUnicodeEscapeSequence(e, !1) || !e.switchU && this.regexp_eatLegacyOctalEscapeSequence(e) || this.regexp_eatIdentityEscape(e);
			}, he.regexp_eatCControlLetter = function(e) {
				var t = e.pos;
				if (e.eat(99)) {
					if (this.regexp_eatControlLetter(e)) return !0;
					e.pos = t;
				}
				return !1;
			}, he.regexp_eatZero = function(e) {
				return 48 === e.current() && !isDecimalDigit(e.lookahead()) && (e.lastIntValue = 0, e.advance(), !0);
			}, he.regexp_eatControlEscape = function(e) {
				var t = e.current();
				return 116 === t ? (e.lastIntValue = 9, e.advance(), !0) : 110 === t ? (e.lastIntValue = 10, e.advance(), !0) : 118 === t ? (e.lastIntValue = 11, e.advance(), !0) : 102 === t ? (e.lastIntValue = 12, e.advance(), !0) : 114 === t && (e.lastIntValue = 13, e.advance(), !0);
			}, he.regexp_eatControlLetter = function(e) {
				var t = e.current();
				return !!isControlLetter(t) && (e.lastIntValue = t % 32, e.advance(), !0);
			}, he.regexp_eatRegExpUnicodeEscapeSequence = function(e, t) {
				void 0 === t && (t = !1);
				var i, s = e.pos, r = t || e.switchU;
				if (e.eat(117)) {
					if (this.regexp_eatFixedHexDigits(e, 4)) {
						var n = e.lastIntValue;
						if (r && n >= 55296 && n <= 56319) {
							var a = e.pos;
							if (e.eat(92) && e.eat(117) && this.regexp_eatFixedHexDigits(e, 4)) {
								var o = e.lastIntValue;
								if (o >= 56320 && o <= 57343) return e.lastIntValue = 1024 * (n - 55296) + (o - 56320) + 65536, !0;
							}
							e.pos = a, e.lastIntValue = n;
						}
						return !0;
					}
					if (r && e.eat(123) && this.regexp_eatHexDigits(e) && e.eat(125) && (i = e.lastIntValue) >= 0 && i <= 1114111) return !0;
					r && e.raise("Invalid unicode escape"), e.pos = s;
				}
				return !1;
			}, he.regexp_eatIdentityEscape = function(e) {
				if (e.switchU) return !!this.regexp_eatSyntaxCharacter(e) || !!e.eat(47) && (e.lastIntValue = 47, !0);
				var t = e.current();
				return !(99 === t || e.switchN && 107 === t) && (e.lastIntValue = t, e.advance(), !0);
			}, he.regexp_eatDecimalEscape = function(e) {
				e.lastIntValue = 0;
				var t = e.current();
				if (t >= 49 && t <= 57) {
					do
						e.lastIntValue = 10 * e.lastIntValue + (t - 48), e.advance();
					while ((t = e.current()) >= 48 && t <= 57);
					return !0;
				}
				return !1;
			};
			function isUnicodePropertyNameCharacter(e) {
				return isControlLetter(e) || 95 === e;
			}
			function isUnicodePropertyValueCharacter(e) {
				return isUnicodePropertyNameCharacter(e) || isDecimalDigit(e);
			}
			function isDecimalDigit(e) {
				return e >= 48 && e <= 57;
			}
			function isHexDigit(e) {
				return e >= 48 && e <= 57 || e >= 65 && e <= 70 || e >= 97 && e <= 102;
			}
			function hexToInt(e) {
				return e >= 65 && e <= 70 ? e - 65 + 10 : e >= 97 && e <= 102 ? e - 97 + 10 : e - 48;
			}
			function isOctalDigit(e) {
				return e >= 48 && e <= 55;
			}
			he.regexp_eatCharacterClassEscape = function(e) {
				var t = e.current();
				if (function(e) {
					return 100 === e || 68 === e || 115 === e || 83 === e || 119 === e || 87 === e;
				}(t)) return e.lastIntValue = -1, e.advance(), 1;
				var i = !1;
				if (e.switchU && this.options.ecmaVersion >= 9 && ((i = 80 === t) || 112 === t)) {
					var s;
					if (e.lastIntValue = -1, e.advance(), e.eat(123) && (s = this.regexp_eatUnicodePropertyValueExpression(e)) && e.eat(125)) return i && 2 === s && e.raise("Invalid property name"), s;
					e.raise("Invalid property name");
				}
				return 0;
			}, he.regexp_eatUnicodePropertyValueExpression = function(e) {
				var t = e.pos;
				if (this.regexp_eatUnicodePropertyName(e) && e.eat(61)) {
					var i = e.lastStringValue;
					if (this.regexp_eatUnicodePropertyValue(e)) {
						var s = e.lastStringValue;
						return this.regexp_validateUnicodePropertyNameAndValue(e, i, s), 1;
					}
				}
				if (e.pos = t, this.regexp_eatLoneUnicodePropertyNameOrValue(e)) {
					var r = e.lastStringValue;
					return this.regexp_validateUnicodePropertyNameOrValue(e, r);
				}
				return 0;
			}, he.regexp_validateUnicodePropertyNameAndValue = function(e, t, i) {
				b(e.unicodeProperties.nonBinary, t) || e.raise("Invalid property name"), e.unicodeProperties.nonBinary[t].test(i) || e.raise("Invalid property value");
			}, he.regexp_validateUnicodePropertyNameOrValue = function(e, t) {
				return e.unicodeProperties.binary.test(t) ? 1 : e.switchV && e.unicodeProperties.binaryOfStrings.test(t) ? 2 : void e.raise("Invalid property name");
			}, he.regexp_eatUnicodePropertyName = function(e) {
				var t = 0;
				for (e.lastStringValue = ""; isUnicodePropertyNameCharacter(t = e.current());) e.lastStringValue += codePointToString(t), e.advance();
				return "" !== e.lastStringValue;
			}, he.regexp_eatUnicodePropertyValue = function(e) {
				var t = 0;
				for (e.lastStringValue = ""; isUnicodePropertyValueCharacter(t = e.current());) e.lastStringValue += codePointToString(t), e.advance();
				return "" !== e.lastStringValue;
			}, he.regexp_eatLoneUnicodePropertyNameOrValue = function(e) {
				return this.regexp_eatUnicodePropertyValue(e);
			}, he.regexp_eatCharacterClass = function(e) {
				if (e.eat(91)) {
					var t = e.eat(94), i = this.regexp_classContents(e);
					return e.eat(93) || e.raise("Unterminated character class"), t && 2 === i && e.raise("Negated character class may contain strings"), !0;
				}
				return !1;
			}, he.regexp_classContents = function(e) {
				return 93 === e.current() ? 1 : e.switchV ? this.regexp_classSetExpression(e) : (this.regexp_nonEmptyClassRanges(e), 1);
			}, he.regexp_nonEmptyClassRanges = function(e) {
				for (; this.regexp_eatClassAtom(e);) {
					var t = e.lastIntValue;
					if (e.eat(45) && this.regexp_eatClassAtom(e)) {
						var i = e.lastIntValue;
						!e.switchU || -1 !== t && -1 !== i || e.raise("Invalid character class"), -1 !== t && -1 !== i && t > i && e.raise("Range out of order in character class");
					}
				}
			}, he.regexp_eatClassAtom = function(e) {
				var t = e.pos;
				if (e.eat(92)) {
					if (this.regexp_eatClassEscape(e)) return !0;
					if (e.switchU) {
						var i = e.current();
						(99 === i || isOctalDigit(i)) && e.raise("Invalid class escape"), e.raise("Invalid escape");
					}
					e.pos = t;
				}
				var s = e.current();
				return 93 !== s && (e.lastIntValue = s, e.advance(), !0);
			}, he.regexp_eatClassEscape = function(e) {
				var t = e.pos;
				if (e.eat(98)) return e.lastIntValue = 8, !0;
				if (e.switchU && e.eat(45)) return e.lastIntValue = 45, !0;
				if (!e.switchU && e.eat(99)) {
					if (this.regexp_eatClassControlLetter(e)) return !0;
					e.pos = t;
				}
				return this.regexp_eatCharacterClassEscape(e) || this.regexp_eatCharacterEscape(e);
			}, he.regexp_classSetExpression = function(e) {
				var t, i = 1;
				if (this.regexp_eatClassSetRange(e));
				else if (t = this.regexp_eatClassSetOperand(e)) {
					2 === t && (i = 2);
					for (var s = e.pos; e.eatChars([38, 38]);) 38 !== e.current() && (t = this.regexp_eatClassSetOperand(e)) ? 2 !== t && (i = 1) : e.raise("Invalid character in character class");
					if (s !== e.pos) return i;
					for (; e.eatChars([45, 45]);) this.regexp_eatClassSetOperand(e) || e.raise("Invalid character in character class");
					if (s !== e.pos) return i;
				} else e.raise("Invalid character in character class");
				for (;;) if (!this.regexp_eatClassSetRange(e)) {
					if (!(t = this.regexp_eatClassSetOperand(e))) return i;
					2 === t && (i = 2);
				}
			}, he.regexp_eatClassSetRange = function(e) {
				var t = e.pos;
				if (this.regexp_eatClassSetCharacter(e)) {
					var i = e.lastIntValue;
					if (e.eat(45) && this.regexp_eatClassSetCharacter(e)) {
						var s = e.lastIntValue;
						return -1 !== i && -1 !== s && i > s && e.raise("Range out of order in character class"), !0;
					}
					e.pos = t;
				}
				return !1;
			}, he.regexp_eatClassSetOperand = function(e) {
				return this.regexp_eatClassSetCharacter(e) ? 1 : this.regexp_eatClassStringDisjunction(e) || this.regexp_eatNestedClass(e);
			}, he.regexp_eatNestedClass = function(e) {
				var t = e.pos;
				if (e.eat(91)) {
					var i = e.eat(94), s = this.regexp_classContents(e);
					if (e.eat(93)) return i && 2 === s && e.raise("Negated character class may contain strings"), s;
					e.pos = t;
				}
				if (e.eat(92)) {
					var r = this.regexp_eatCharacterClassEscape(e);
					if (r) return r;
					e.pos = t;
				}
				return null;
			}, he.regexp_eatClassStringDisjunction = function(e) {
				var t = e.pos;
				if (e.eatChars([92, 113])) {
					if (e.eat(123)) {
						var i = this.regexp_classStringDisjunctionContents(e);
						if (e.eat(125)) return i;
					} else e.raise("Invalid escape");
					e.pos = t;
				}
				return null;
			}, he.regexp_classStringDisjunctionContents = function(e) {
				for (var t = this.regexp_classString(e); e.eat(124);) 2 === this.regexp_classString(e) && (t = 2);
				return t;
			}, he.regexp_classString = function(e) {
				for (var t = 0; this.regexp_eatClassSetCharacter(e);) t++;
				return 1 === t ? 1 : 2;
			}, he.regexp_eatClassSetCharacter = function(e) {
				var t = e.pos;
				if (e.eat(92)) return !(!this.regexp_eatCharacterEscape(e) && !this.regexp_eatClassSetReservedPunctuator(e)) || (e.eat(98) ? (e.lastIntValue = 8, !0) : (e.pos = t, !1));
				var i = e.current();
				return !(i < 0 || i === e.lookahead() && function(e) {
					return 33 === e || e >= 35 && e <= 38 || e >= 42 && e <= 44 || 46 === e || e >= 58 && e <= 64 || 94 === e || 96 === e || 126 === e;
				}(i)) && !function(e) {
					return 40 === e || 41 === e || 45 === e || 47 === e || e >= 91 && e <= 93 || e >= 123 && e <= 125;
				}(i) && (e.advance(), e.lastIntValue = i, !0);
			}, he.regexp_eatClassSetReservedPunctuator = function(e) {
				var t = e.current();
				return !!function(e) {
					return 33 === e || 35 === e || 37 === e || 38 === e || 44 === e || 45 === e || e >= 58 && e <= 62 || 64 === e || 96 === e || 126 === e;
				}(t) && (e.lastIntValue = t, e.advance(), !0);
			}, he.regexp_eatClassControlLetter = function(e) {
				var t = e.current();
				return !(!isDecimalDigit(t) && 95 !== t) && (e.lastIntValue = t % 32, e.advance(), !0);
			}, he.regexp_eatHexEscapeSequence = function(e) {
				var t = e.pos;
				if (e.eat(120)) {
					if (this.regexp_eatFixedHexDigits(e, 2)) return !0;
					e.switchU && e.raise("Invalid escape"), e.pos = t;
				}
				return !1;
			}, he.regexp_eatDecimalDigits = function(e) {
				var t = e.pos, i = 0;
				for (e.lastIntValue = 0; isDecimalDigit(i = e.current());) e.lastIntValue = 10 * e.lastIntValue + (i - 48), e.advance();
				return e.pos !== t;
			}, he.regexp_eatHexDigits = function(e) {
				var t = e.pos, i = 0;
				for (e.lastIntValue = 0; isHexDigit(i = e.current());) e.lastIntValue = 16 * e.lastIntValue + hexToInt(i), e.advance();
				return e.pos !== t;
			}, he.regexp_eatLegacyOctalEscapeSequence = function(e) {
				if (this.regexp_eatOctalDigit(e)) {
					var t = e.lastIntValue;
					if (this.regexp_eatOctalDigit(e)) {
						var i = e.lastIntValue;
						t <= 3 && this.regexp_eatOctalDigit(e) ? e.lastIntValue = 64 * t + 8 * i + e.lastIntValue : e.lastIntValue = 8 * t + i;
					} else e.lastIntValue = t;
					return !0;
				}
				return !1;
			}, he.regexp_eatOctalDigit = function(e) {
				var t = e.current();
				return isOctalDigit(t) ? (e.lastIntValue = t - 48, e.advance(), !0) : (e.lastIntValue = 0, !1);
			}, he.regexp_eatFixedHexDigits = function(e, t) {
				var i = e.pos;
				e.lastIntValue = 0;
				for (var s = 0; s < t; ++s) {
					var r = e.current();
					if (!isHexDigit(r)) return e.pos = i, !1;
					e.lastIntValue = 16 * e.lastIntValue + hexToInt(r), e.advance();
				}
				return !0;
			};
			var acorn_Token = function(e) {
				this.type = e.type, this.value = e.value, this.start = e.start, this.end = e.end, e.options.locations && (this.loc = new acorn_SourceLocation(e, e.startLoc, e.endLoc)), e.options.ranges && (this.range = [e.start, e.end]);
			}, ce = acorn_Parser.prototype;
			function stringToBigInt(e) {
				return "function" != typeof BigInt ? null : BigInt(e.replace(/_/g, ""));
			}
			ce.next = function(e) {
				!e && this.type.keyword && this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword " + this.type.keyword), this.options.onToken && this.options.onToken(new acorn_Token(this)), this.lastTokEnd = this.end, this.lastTokStart = this.start, this.lastTokEndLoc = this.endLoc, this.lastTokStartLoc = this.startLoc, this.nextToken();
			}, ce.getToken = function() {
				return this.next(), new acorn_Token(this);
			}, "undefined" != typeof Symbol && (ce[Symbol.iterator] = function() {
				var e = this;
				return { next: function() {
					var t = e.getToken();
					return {
						done: t.type === f.eof,
						value: t
					};
				} };
			}), ce.nextToken = function() {
				var e = this.curContext();
				return e && e.preserveSpace || this.skipSpace(), this.start = this.pos, this.options.locations && (this.startLoc = this.curPosition()), this.pos >= this.input.length ? this.finishToken(f.eof) : e.override ? e.override(this) : void this.readToken(this.fullCharCodeAtPos());
			}, ce.readToken = function(e) {
				return isIdentifierStart(e, this.options.ecmaVersion >= 6) || 92 === e ? this.readWord() : this.getTokenFromCode(e);
			}, ce.fullCharCodeAtPos = function() {
				var e = this.input.charCodeAt(this.pos);
				if (e <= 55295 || e >= 56320) return e;
				var t = this.input.charCodeAt(this.pos + 1);
				return t <= 56319 || t >= 57344 ? e : (e << 10) + t - 56613888;
			}, ce.skipBlockComment = function() {
				var e = this.options.onComment && this.curPosition(), t = this.pos, i = this.input.indexOf("*/", this.pos += 2);
				if (-1 === i && this.raise(this.pos - 2, "Unterminated comment"), this.pos = i + 2, this.options.locations) for (var s = void 0, r = t; (s = nextLineBreak(this.input, r, this.pos)) > -1;) ++this.curLine, r = this.lineStart = s;
				this.options.onComment && this.options.onComment(!0, this.input.slice(t + 2, i), t, this.pos, e, this.curPosition());
			}, ce.skipLineComment = function(e) {
				for (var t = this.pos, i = this.options.onComment && this.curPosition(), s = this.input.charCodeAt(this.pos += e); this.pos < this.input.length && !isNewLine(s);) s = this.input.charCodeAt(++this.pos);
				this.options.onComment && this.options.onComment(!1, this.input.slice(t + e, this.pos), t, this.pos, i, this.curPosition());
			}, ce.skipSpace = function() {
				e: for (; this.pos < this.input.length;) {
					var e = this.input.charCodeAt(this.pos);
					switch (e) {
						case 32:
						case 160:
							++this.pos;
							break;
						case 13: 10 === this.input.charCodeAt(this.pos + 1) && ++this.pos;
						case 10:
						case 8232:
						case 8233:
							++this.pos, this.options.locations && (++this.curLine, this.lineStart = this.pos);
							break;
						case 47:
							switch (this.input.charCodeAt(this.pos + 1)) {
								case 42:
									this.skipBlockComment();
									break;
								case 47:
									this.skipLineComment(2);
									break;
								default: break e;
							}
							break;
						default:
							if (!(e > 8 && e < 14 || e >= 5760 && x.test(String.fromCharCode(e)))) break e;
							++this.pos;
					}
				}
			}, ce.finishToken = function(e, t) {
				this.end = this.pos, this.options.locations && (this.endLoc = this.curPosition());
				var i = this.type;
				this.type = e, this.value = t, this.updateContext(i);
			}, ce.readToken_dot = function() {
				var e = this.input.charCodeAt(this.pos + 1);
				if (e >= 48 && e <= 57) return this.readNumber(!0);
				var t = this.input.charCodeAt(this.pos + 2);
				return this.options.ecmaVersion >= 6 && 46 === e && 46 === t ? (this.pos += 3, this.finishToken(f.ellipsis)) : (++this.pos, this.finishToken(f.dot));
			}, ce.readToken_slash = function() {
				var e = this.input.charCodeAt(this.pos + 1);
				return this.exprAllowed ? (++this.pos, this.readRegexp()) : 61 === e ? this.finishOp(f.assign, 2) : this.finishOp(f.slash, 1);
			}, ce.readToken_mult_modulo_exp = function(e) {
				var t = this.input.charCodeAt(this.pos + 1), i = 1, s = 42 === e ? f.star : f.modulo;
				return this.options.ecmaVersion >= 7 && 42 === e && 42 === t && (++i, s = f.starstar, t = this.input.charCodeAt(this.pos + 2)), 61 === t ? this.finishOp(f.assign, i + 1) : this.finishOp(s, i);
			}, ce.readToken_pipe_amp = function(e) {
				var t = this.input.charCodeAt(this.pos + 1);
				if (t === e) {
					if (this.options.ecmaVersion >= 12) {
						if (61 === this.input.charCodeAt(this.pos + 2)) return this.finishOp(f.assign, 3);
					}
					return this.finishOp(124 === e ? f.logicalOR : f.logicalAND, 2);
				}
				return 61 === t ? this.finishOp(f.assign, 2) : this.finishOp(124 === e ? f.bitwiseOR : f.bitwiseAND, 1);
			}, ce.readToken_caret = function() {
				return 61 === this.input.charCodeAt(this.pos + 1) ? this.finishOp(f.assign, 2) : this.finishOp(f.bitwiseXOR, 1);
			}, ce.readToken_plus_min = function(e) {
				var t = this.input.charCodeAt(this.pos + 1);
				return t === e ? 45 !== t || this.inModule || 62 !== this.input.charCodeAt(this.pos + 2) || 0 !== this.lastTokEnd && !m.test(this.input.slice(this.lastTokEnd, this.pos)) ? this.finishOp(f.incDec, 2) : (this.skipLineComment(3), this.skipSpace(), this.nextToken()) : 61 === t ? this.finishOp(f.assign, 2) : this.finishOp(f.plusMin, 1);
			}, ce.readToken_lt_gt = function(e) {
				var t = this.input.charCodeAt(this.pos + 1), i = 1;
				return t === e ? (i = 62 === e && 62 === this.input.charCodeAt(this.pos + 2) ? 3 : 2, 61 === this.input.charCodeAt(this.pos + i) ? this.finishOp(f.assign, i + 1) : this.finishOp(f.bitShift, i)) : 33 !== t || 60 !== e || this.inModule || 45 !== this.input.charCodeAt(this.pos + 2) || 45 !== this.input.charCodeAt(this.pos + 3) ? (61 === t && (i = 2), this.finishOp(f.relational, i)) : (this.skipLineComment(4), this.skipSpace(), this.nextToken());
			}, ce.readToken_eq_excl = function(e) {
				var t = this.input.charCodeAt(this.pos + 1);
				return 61 === t ? this.finishOp(f.equality, 61 === this.input.charCodeAt(this.pos + 2) ? 3 : 2) : 61 === e && 62 === t && this.options.ecmaVersion >= 6 ? (this.pos += 2, this.finishToken(f.arrow)) : this.finishOp(61 === e ? f.eq : f.prefix, 1);
			}, ce.readToken_question = function() {
				var e = this.options.ecmaVersion;
				if (e >= 11) {
					var t = this.input.charCodeAt(this.pos + 1);
					if (46 === t) {
						var i = this.input.charCodeAt(this.pos + 2);
						if (i < 48 || i > 57) return this.finishOp(f.questionDot, 2);
					}
					if (63 === t) {
						if (e >= 12) {
							if (61 === this.input.charCodeAt(this.pos + 2)) return this.finishOp(f.assign, 3);
						}
						return this.finishOp(f.coalesce, 2);
					}
				}
				return this.finishOp(f.question, 1);
			}, ce.readToken_numberSign = function() {
				var e = 35;
				if (this.options.ecmaVersion >= 13 && (++this.pos, isIdentifierStart(e = this.fullCharCodeAtPos(), !0) || 92 === e)) return this.finishToken(f.privateId, this.readWord1());
				this.raise(this.pos, "Unexpected character '" + codePointToString(e) + "'");
			}, ce.getTokenFromCode = function(e) {
				switch (e) {
					case 46: return this.readToken_dot();
					case 40: return ++this.pos, this.finishToken(f.parenL);
					case 41: return ++this.pos, this.finishToken(f.parenR);
					case 59: return ++this.pos, this.finishToken(f.semi);
					case 44: return ++this.pos, this.finishToken(f.comma);
					case 91: return ++this.pos, this.finishToken(f.bracketL);
					case 93: return ++this.pos, this.finishToken(f.bracketR);
					case 123: return ++this.pos, this.finishToken(f.braceL);
					case 125: return ++this.pos, this.finishToken(f.braceR);
					case 58: return ++this.pos, this.finishToken(f.colon);
					case 96:
						if (this.options.ecmaVersion < 6) break;
						return ++this.pos, this.finishToken(f.backQuote);
					case 48:
						var t = this.input.charCodeAt(this.pos + 1);
						if (120 === t || 88 === t) return this.readRadixNumber(16);
						if (this.options.ecmaVersion >= 6) {
							if (111 === t || 79 === t) return this.readRadixNumber(8);
							if (98 === t || 66 === t) return this.readRadixNumber(2);
						}
					case 49:
					case 50:
					case 51:
					case 52:
					case 53:
					case 54:
					case 55:
					case 56:
					case 57: return this.readNumber(!1);
					case 34:
					case 39: return this.readString(e);
					case 47: return this.readToken_slash();
					case 37:
					case 42: return this.readToken_mult_modulo_exp(e);
					case 124:
					case 38: return this.readToken_pipe_amp(e);
					case 94: return this.readToken_caret();
					case 43:
					case 45: return this.readToken_plus_min(e);
					case 60:
					case 62: return this.readToken_lt_gt(e);
					case 61:
					case 33: return this.readToken_eq_excl(e);
					case 63: return this.readToken_question();
					case 126: return this.finishOp(f.prefix, 1);
					case 35: return this.readToken_numberSign();
				}
				this.raise(this.pos, "Unexpected character '" + codePointToString(e) + "'");
			}, ce.finishOp = function(e, t) {
				var i = this.input.slice(this.pos, this.pos + t);
				return this.pos += t, this.finishToken(e, i);
			}, ce.readRegexp = function() {
				for (var e, t, i = this.pos;;) {
					this.pos >= this.input.length && this.raise(i, "Unterminated regular expression");
					var s = this.input.charAt(this.pos);
					if (m.test(s) && this.raise(i, "Unterminated regular expression"), e) e = !1;
					else {
						if ("[" === s) t = !0;
						else if ("]" === s && t) t = !1;
						else if ("/" === s && !t) break;
						e = "\\" === s;
					}
					++this.pos;
				}
				var r = this.input.slice(i, this.pos);
				++this.pos;
				var n = this.pos, a = this.readWord1();
				this.containsEsc && this.unexpected(n);
				var o = this.regexpState || (this.regexpState = new acorn_RegExpValidationState(this));
				o.reset(i, r, a), this.validateRegExpFlags(o), this.validateRegExpPattern(o);
				var h = null;
				try {
					h = new RegExp(r, a);
				} catch (e) {}
				return this.finishToken(f.regexp, {
					pattern: r,
					flags: a,
					value: h
				});
			}, ce.readInt = function(e, t, i) {
				for (var s = this.options.ecmaVersion >= 12 && void 0 === t, r = i && 48 === this.input.charCodeAt(this.pos), n = this.pos, a = 0, o = 0, h = 0, c = null == t ? Infinity : t; h < c; ++h, ++this.pos) {
					var p = this.input.charCodeAt(this.pos), l = void 0;
					if (s && 95 === p) r && this.raiseRecoverable(this.pos, "Numeric separator is not allowed in legacy octal numeric literals"), 95 === o && this.raiseRecoverable(this.pos, "Numeric separator must be exactly one underscore"), 0 === h && this.raiseRecoverable(this.pos, "Numeric separator is not allowed at the first of digits"), o = p;
					else {
						if ((l = p >= 97 ? p - 97 + 10 : p >= 65 ? p - 65 + 10 : p >= 48 && p <= 57 ? p - 48 : Infinity) >= e) break;
						o = p, a = a * e + l;
					}
				}
				return s && 95 === o && this.raiseRecoverable(this.pos - 1, "Numeric separator is not allowed at the last of digits"), this.pos === n || null != t && this.pos - n !== t ? null : a;
			}, ce.readRadixNumber = function(e) {
				var t = this.pos;
				this.pos += 2;
				var i = this.readInt(e);
				return i ?? this.raise(this.start + 2, "Expected number in radix " + e), this.options.ecmaVersion >= 11 && 110 === this.input.charCodeAt(this.pos) ? (i = stringToBigInt(this.input.slice(t, this.pos)), ++this.pos) : isIdentifierStart(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number"), this.finishToken(f.num, i);
			}, ce.readNumber = function(e) {
				var t = this.pos;
				e || null !== this.readInt(10, void 0, !0) || this.raise(t, "Invalid number");
				var i = this.pos - t >= 2 && 48 === this.input.charCodeAt(t);
				i && this.strict && this.raise(t, "Invalid number");
				var s = this.input.charCodeAt(this.pos);
				if (!i && !e && this.options.ecmaVersion >= 11 && 110 === s) {
					var r = stringToBigInt(this.input.slice(t, this.pos));
					return ++this.pos, isIdentifierStart(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number"), this.finishToken(f.num, r);
				}
				i && /[89]/.test(this.input.slice(t, this.pos)) && (i = !1), 46 !== s || i || (++this.pos, this.readInt(10), s = this.input.charCodeAt(this.pos)), 69 !== s && 101 !== s || i || (43 !== (s = this.input.charCodeAt(++this.pos)) && 45 !== s || ++this.pos, null === this.readInt(10) && this.raise(t, "Invalid number")), isIdentifierStart(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number");
				var n, a = (n = this.input.slice(t, this.pos), i ? parseInt(n, 8) : parseFloat(n.replace(/_/g, "")));
				return this.finishToken(f.num, a);
			}, ce.readCodePoint = function() {
				var e;
				if (123 === this.input.charCodeAt(this.pos)) {
					this.options.ecmaVersion < 6 && this.unexpected();
					var t = ++this.pos;
					e = this.readHexChar(this.input.indexOf("}", this.pos) - this.pos), ++this.pos, e > 1114111 && this.invalidStringToken(t, "Code point out of bounds");
				} else e = this.readHexChar(4);
				return e;
			}, ce.readString = function(e) {
				for (var t = "", i = ++this.pos;;) {
					this.pos >= this.input.length && this.raise(this.start, "Unterminated string constant");
					var s = this.input.charCodeAt(this.pos);
					if (s === e) break;
					92 === s ? (t += this.input.slice(i, this.pos), t += this.readEscapedChar(!1), i = this.pos) : 8232 === s || 8233 === s ? (this.options.ecmaVersion < 10 && this.raise(this.start, "Unterminated string constant"), ++this.pos, this.options.locations && (this.curLine++, this.lineStart = this.pos)) : (isNewLine(s) && this.raise(this.start, "Unterminated string constant"), ++this.pos);
				}
				return t += this.input.slice(i, this.pos++), this.finishToken(f.string, t);
			};
			var pe = {};
			ce.tryReadTemplateToken = function() {
				this.inTemplateElement = !0;
				try {
					this.readTmplToken();
				} catch (e) {
					if (e !== pe) throw e;
					this.readInvalidTemplateToken();
				}
				this.inTemplateElement = !1;
			}, ce.invalidStringToken = function(e, t) {
				if (this.inTemplateElement && this.options.ecmaVersion >= 9) throw pe;
				this.raise(e, t);
			}, ce.readTmplToken = function() {
				for (var e = "", t = this.pos;;) {
					this.pos >= this.input.length && this.raise(this.start, "Unterminated template");
					var i = this.input.charCodeAt(this.pos);
					if (96 === i || 36 === i && 123 === this.input.charCodeAt(this.pos + 1)) return this.pos !== this.start || this.type !== f.template && this.type !== f.invalidTemplate ? (e += this.input.slice(t, this.pos), this.finishToken(f.template, e)) : 36 === i ? (this.pos += 2, this.finishToken(f.dollarBraceL)) : (++this.pos, this.finishToken(f.backQuote));
					if (92 === i) e += this.input.slice(t, this.pos), e += this.readEscapedChar(!0), t = this.pos;
					else if (isNewLine(i)) {
						switch (e += this.input.slice(t, this.pos), ++this.pos, i) {
							case 13: 10 === this.input.charCodeAt(this.pos) && ++this.pos;
							case 10:
								e += "\n";
								break;
							default: e += String.fromCharCode(i);
						}
						this.options.locations && (++this.curLine, this.lineStart = this.pos), t = this.pos;
					} else ++this.pos;
				}
			}, ce.readInvalidTemplateToken = function() {
				for (; this.pos < this.input.length; this.pos++) switch (this.input[this.pos]) {
					case "\\":
						++this.pos;
						break;
					case "$": if ("{" !== this.input[this.pos + 1]) break;
					case "`": return this.finishToken(f.invalidTemplate, this.input.slice(this.start, this.pos));
					case "\r": "\n" === this.input[this.pos + 1] && ++this.pos;
					case "\n":
					case "\u2028":
					case "\u2029": ++this.curLine, this.lineStart = this.pos + 1;
				}
				this.raise(this.start, "Unterminated template");
			}, ce.readEscapedChar = function(e) {
				var t = this.input.charCodeAt(++this.pos);
				switch (++this.pos, t) {
					case 110: return "\n";
					case 114: return "\r";
					case 120: return String.fromCharCode(this.readHexChar(2));
					case 117: return codePointToString(this.readCodePoint());
					case 116: return "	";
					case 98: return "\b";
					case 118: return "\v";
					case 102: return "\f";
					case 13: 10 === this.input.charCodeAt(this.pos) && ++this.pos;
					case 10: return this.options.locations && (this.lineStart = this.pos, ++this.curLine), "";
					case 56:
					case 57: if (this.strict && this.invalidStringToken(this.pos - 1, "Invalid escape sequence"), e) {
						var i = this.pos - 1;
						this.invalidStringToken(i, "Invalid escape sequence in template string");
					}
					default:
						if (t >= 48 && t <= 55) {
							var s = this.input.substr(this.pos - 1, 3).match(/^[0-7]+/)[0], r = parseInt(s, 8);
							return r > 255 && (s = s.slice(0, -1), r = parseInt(s, 8)), this.pos += s.length - 1, t = this.input.charCodeAt(this.pos), "0" === s && 56 !== t && 57 !== t || !this.strict && !e || this.invalidStringToken(this.pos - 1 - s.length, e ? "Octal literal in template string" : "Octal literal in strict mode"), String.fromCharCode(r);
						}
						return isNewLine(t) ? (this.options.locations && (this.lineStart = this.pos, ++this.curLine), "") : String.fromCharCode(t);
				}
			}, ce.readHexChar = function(e) {
				var t = this.pos, i = this.readInt(16, e);
				return null === i && this.invalidStringToken(t, "Bad character escape sequence"), i;
			}, ce.readWord1 = function() {
				this.containsEsc = !1;
				for (var e = "", t = !0, i = this.pos, s = this.options.ecmaVersion >= 6; this.pos < this.input.length;) {
					var r = this.fullCharCodeAtPos();
					if (isIdentifierChar(r, s)) this.pos += r <= 65535 ? 1 : 2;
					else {
						if (92 !== r) break;
						this.containsEsc = !0, e += this.input.slice(i, this.pos);
						var n = this.pos;
						117 !== this.input.charCodeAt(++this.pos) && this.invalidStringToken(this.pos, "Expecting Unicode escape sequence \\uXXXX"), ++this.pos;
						var a = this.readCodePoint();
						(t ? isIdentifierStart : isIdentifierChar)(a, s) || this.invalidStringToken(n, "Invalid Unicode escape"), e += codePointToString(a), i = this.pos;
					}
					t = !1;
				}
				return e + this.input.slice(i, this.pos);
			}, ce.readWord = function() {
				var e = this.readWord1(), t = f.name;
				return this.keywords.test(e) && (t = d[e]), this.finishToken(t, e);
			};
			acorn_Parser.acorn = {
				Parser: acorn_Parser,
				version: "8.15.0",
				defaultOptions: I,
				Position: acorn_Position,
				SourceLocation: acorn_SourceLocation,
				getLineInfo,
				Node: acorn_Node,
				TokenType: acorn_TokenType,
				tokTypes: f,
				keywordTypes: d,
				TokContext: acorn_TokContext,
				tokContexts: F,
				isIdentifierChar,
				isIdentifierStart,
				Token: acorn_Token,
				isNewLine,
				lineBreak: m,
				lineBreakG: g,
				nonASCIIwhitespace: x
			};
			const le = __require("node:module"), ue = __require("node:fs");
			String.fromCharCode;
			const de = /\/$|\/\?|\/#/, fe = /^\.?\//;
			function hasTrailingSlash(e = "", t) {
				return t ? de.test(e) : e.endsWith("/");
			}
			function withTrailingSlash(e = "", t) {
				if (!t) return e.endsWith("/") ? e : e + "/";
				if (hasTrailingSlash(e, !0)) return e || "/";
				let i = e, s = "";
				const r = e.indexOf("#");
				if (-1 !== r && (i = e.slice(0, r), s = e.slice(r), !i)) return s;
				const [n, ...a] = i.split("?");
				return n + "/" + (a.length > 0 ? `?${a.join("?")}` : "") + s;
			}
			function isNonEmptyURL(e) {
				return e && "/" !== e;
			}
			function dist_joinURL(e, ...t) {
				let i = e || "";
				for (const e of t.filter((e) => isNonEmptyURL(e))) if (i) {
					const t = e.replace(fe, "");
					i = withTrailingSlash(i) + t;
				} else i = e;
				return i;
			}
			const me = /^[A-Za-z]:\//;
			function pathe_M_eThtNZ_normalizeWindowsPath(e = "") {
				return e ? e.replace(/\\/g, "/").replace(me, (e) => e.toUpperCase()) : e;
			}
			const ge = /^[/\\]{2}/, xe = /^[/\\](?![/\\])|^[/\\]{2}(?!\.)|^[A-Za-z]:[/\\]/, ve = /^[A-Za-z]:$/, ye = /.(\.[^./]+|\.)$/, pathe_M_eThtNZ_normalize = function(e) {
				if (0 === e.length) return ".";
				const t = (e = pathe_M_eThtNZ_normalizeWindowsPath(e)).match(ge), i = isAbsolute(e), s = "/" === e[e.length - 1];
				return 0 === (e = normalizeString(e, !i)).length ? i ? "/" : s ? "./" : "." : (s && (e += "/"), ve.test(e) && (e += "/"), t ? i ? `//${e}` : `//./${e}` : i && !isAbsolute(e) ? `/${e}` : e);
			}, pathe_M_eThtNZ_join = function(...e) {
				let t = "";
				for (const i of e) if (i) if (t.length > 0) {
					const e = "/" === t[t.length - 1], s = "/" === i[0];
					t += e && s ? i.slice(1) : e || s ? i : `/${i}`;
				} else t += i;
				return pathe_M_eThtNZ_normalize(t);
			};
			function pathe_M_eThtNZ_cwd() {
				return "undefined" != typeof process && "function" == typeof process.cwd ? process.cwd().replace(/\\/g, "/") : "/";
			}
			const pathe_M_eThtNZ_resolve = function(...e) {
				let t = "", i = !1;
				for (let s = (e = e.map((e) => pathe_M_eThtNZ_normalizeWindowsPath(e))).length - 1; s >= -1 && !i; s--) {
					const r = s >= 0 ? e[s] : pathe_M_eThtNZ_cwd();
					r && 0 !== r.length && (t = `${r}/${t}`, i = isAbsolute(r));
				}
				return t = normalizeString(t, !i), i && !isAbsolute(t) ? `/${t}` : t.length > 0 ? t : ".";
			};
			function normalizeString(e, t) {
				let i = "", s = 0, r = -1, n = 0, a = null;
				for (let o = 0; o <= e.length; ++o) {
					if (o < e.length) a = e[o];
					else {
						if ("/" === a) break;
						a = "/";
					}
					if ("/" === a) {
						if (r === o - 1 || 1 === n);
						else if (2 === n) {
							if (i.length < 2 || 2 !== s || "." !== i[i.length - 1] || "." !== i[i.length - 2]) {
								if (i.length > 2) {
									const e = i.lastIndexOf("/");
									-1 === e ? (i = "", s = 0) : (i = i.slice(0, e), s = i.length - 1 - i.lastIndexOf("/")), r = o, n = 0;
									continue;
								}
								if (i.length > 0) {
									i = "", s = 0, r = o, n = 0;
									continue;
								}
							}
							t && (i += i.length > 0 ? "/.." : "..", s = 2);
						} else i.length > 0 ? i += `/${e.slice(r + 1, o)}` : i = e.slice(r + 1, o), s = o - r - 1;
						r = o, n = 0;
					} else "." === a && -1 !== n ? ++n : n = -1;
				}
				return i;
			}
			const isAbsolute = function(e) {
				return xe.test(e);
			}, extname = function(e) {
				if (".." === e) return "";
				const t = ye.exec(pathe_M_eThtNZ_normalizeWindowsPath(e));
				return t && t[1] || "";
			}, pathe_M_eThtNZ_dirname = function(e) {
				const t = pathe_M_eThtNZ_normalizeWindowsPath(e).replace(/\/$/, "").split("/").slice(0, -1);
				return 1 === t.length && ve.test(t[0]) && (t[0] += "/"), t.join("/") || (isAbsolute(e) ? "/" : ".");
			}, basename = function(e, t) {
				const i = pathe_M_eThtNZ_normalizeWindowsPath(e).split("/");
				let s = "";
				for (let e = i.length - 1; e >= 0; e--) {
					const t = i[e];
					if (t) {
						s = t;
						break;
					}
				}
				return t && s.endsWith(t) ? s.slice(0, -t.length) : s;
			}, _e = __require("node:url"), Ee = __require("node:assert"), be = __require("node:process"), Se = __require("node:path"), ke = __require("node:v8"), we = __require("node:util"), Ie = new Set(le.builtinModules);
			function normalizeSlash(e) {
				return e.replace(/\\/g, "/");
			}
			const Ce = {}.hasOwnProperty, Re = /^([A-Z][a-z\d]*)+$/, Pe = new Set([
				"string",
				"function",
				"number",
				"object",
				"Function",
				"Object",
				"boolean",
				"bigint",
				"symbol"
			]), Te = {};
			function formatList(e, t = "and") {
				return e.length < 3 ? e.join(` ${t} `) : `${e.slice(0, -1).join(", ")}, ${t} ${e[e.length - 1]}`;
			}
			const Ae = /* @__PURE__ */ new Map();
			let Ne;
			function createError(e, t, i) {
				return Ae.set(e, t), function(e, t) {
					return NodeError;
					function NodeError(...i) {
						const s = Error.stackTraceLimit;
						isErrorStackTraceLimitWritable() && (Error.stackTraceLimit = 0);
						const r = new e();
						isErrorStackTraceLimitWritable() && (Error.stackTraceLimit = s);
						const n = function(e, t, i) {
							const s = Ae.get(e);
							if (Ee(void 0 !== s, "expected `message` to be found"), "function" == typeof s) return Ee(s.length <= t.length, `Code: ${e}; The provided arguments length (${t.length}) does not match the required ones (${s.length}).`), Reflect.apply(s, i, t);
							const r = /%[dfijoOs]/g;
							let n = 0;
							for (; null !== r.exec(s);) n++;
							return Ee(n === t.length, `Code: ${e}; The provided arguments length (${t.length}) does not match the required ones (${n}).`), 0 === t.length ? s : (t.unshift(s), Reflect.apply(we.format, null, t));
						}(t, i, r);
						return Object.defineProperties(r, {
							message: {
								value: n,
								enumerable: !1,
								writable: !0,
								configurable: !0
							},
							toString: {
								value() {
									return `${this.name} [${t}]: ${this.message}`;
								},
								enumerable: !1,
								writable: !0,
								configurable: !0
							}
						}), Le(r), r.code = t, r;
					}
				}(i, e);
			}
			function isErrorStackTraceLimitWritable() {
				try {
					if (ke.startupSnapshot.isBuildingSnapshot()) return !1;
				} catch {}
				const e = Object.getOwnPropertyDescriptor(Error, "stackTraceLimit");
				return void 0 === e ? Object.isExtensible(Error) : Ce.call(e, "writable") && void 0 !== e.writable ? e.writable : void 0 !== e.set;
			}
			Te.ERR_INVALID_ARG_TYPE = createError("ERR_INVALID_ARG_TYPE", (e, t, i) => {
				Ee("string" == typeof e, "'name' must be a string"), Array.isArray(t) || (t = [t]);
				let s = "The ";
				if (e.endsWith(" argument")) s += `${e} `;
				else {
					const t = e.includes(".") ? "property" : "argument";
					s += `"${e}" ${t} `;
				}
				s += "must be ";
				const r = [], n = [], a = [];
				for (const e of t) Ee("string" == typeof e, "All expected entries have to be of type string"), Pe.has(e) ? r.push(e.toLowerCase()) : null === Re.exec(e) ? (Ee("object" !== e, "The value \"object\" should be written as \"Object\""), a.push(e)) : n.push(e);
				if (n.length > 0) {
					const e = r.indexOf("object");
					-1 !== e && (r.slice(e, 1), n.push("Object"));
				}
				return r.length > 0 && (s += `${r.length > 1 ? "one of type" : "of type"} ${formatList(r, "or")}`, (n.length > 0 || a.length > 0) && (s += " or ")), n.length > 0 && (s += `an instance of ${formatList(n, "or")}`, a.length > 0 && (s += " or ")), a.length > 0 && (a.length > 1 ? s += `one of ${formatList(a, "or")}` : (a[0].toLowerCase() !== a[0] && (s += "an "), s += `${a[0]}`)), s += `. Received ${function(e) {
					if (null == e) return String(e);
					if ("function" == typeof e && e.name) return `function ${e.name}`;
					if ("object" == typeof e) return e.constructor && e.constructor.name ? `an instance of ${e.constructor.name}` : `${(0, we.inspect)(e, { depth: -1 })}`;
					let t = (0, we.inspect)(e, { colors: !1 });
					t.length > 28 && (t = `${t.slice(0, 25)}...`);
					return `type ${typeof e} (${t})`;
				}(i)}`, s;
			}, TypeError), Te.ERR_INVALID_MODULE_SPECIFIER = createError("ERR_INVALID_MODULE_SPECIFIER", (e, t, i = void 0) => `Invalid module "${e}" ${t}${i ? ` imported from ${i}` : ""}`, TypeError), Te.ERR_INVALID_PACKAGE_CONFIG = createError("ERR_INVALID_PACKAGE_CONFIG", (e, t, i) => `Invalid package config ${e}${t ? ` while importing ${t}` : ""}${i ? `. ${i}` : ""}`, Error), Te.ERR_INVALID_PACKAGE_TARGET = createError("ERR_INVALID_PACKAGE_TARGET", (e, t, i, s = !1, r = void 0) => {
				const n = "string" == typeof i && !s && i.length > 0 && !i.startsWith("./");
				return "." === t ? (Ee(!1 === s), `Invalid "exports" main target ${JSON.stringify(i)} defined in the package config ${e}package.json${r ? ` imported from ${r}` : ""}${n ? "; targets must start with \"./\"" : ""}`) : `Invalid "${s ? "imports" : "exports"}" target ${JSON.stringify(i)} defined for '${t}' in the package config ${e}package.json${r ? ` imported from ${r}` : ""}${n ? "; targets must start with \"./\"" : ""}`;
			}, Error), Te.ERR_MODULE_NOT_FOUND = createError("ERR_MODULE_NOT_FOUND", (e, t, i = !1) => `Cannot find ${i ? "module" : "package"} '${e}' imported from ${t}`, Error), Te.ERR_NETWORK_IMPORT_DISALLOWED = createError("ERR_NETWORK_IMPORT_DISALLOWED", "import of '%s' by %s is not supported: %s", Error), Te.ERR_PACKAGE_IMPORT_NOT_DEFINED = createError("ERR_PACKAGE_IMPORT_NOT_DEFINED", (e, t, i) => `Package import specifier "${e}" is not defined${t ? ` in package ${t}package.json` : ""} imported from ${i}`, TypeError), Te.ERR_PACKAGE_PATH_NOT_EXPORTED = createError("ERR_PACKAGE_PATH_NOT_EXPORTED", (e, t, i = void 0) => "." === t ? `No "exports" main defined in ${e}package.json${i ? ` imported from ${i}` : ""}` : `Package subpath '${t}' is not defined by "exports" in ${e}package.json${i ? ` imported from ${i}` : ""}`, Error), Te.ERR_UNSUPPORTED_DIR_IMPORT = createError("ERR_UNSUPPORTED_DIR_IMPORT", "Directory import '%s' is not supported resolving ES modules imported from %s", Error), Te.ERR_UNSUPPORTED_RESOLVE_REQUEST = createError("ERR_UNSUPPORTED_RESOLVE_REQUEST", "Failed to resolve module specifier \"%s\" from \"%s\": Invalid relative URL or base scheme is not hierarchical.", TypeError), Te.ERR_UNKNOWN_FILE_EXTENSION = createError("ERR_UNKNOWN_FILE_EXTENSION", (e, t) => `Unknown file extension "${e}" for ${t}`, TypeError), Te.ERR_INVALID_ARG_VALUE = createError("ERR_INVALID_ARG_VALUE", (e, t, i = "is invalid") => {
				let s = (0, we.inspect)(t);
				s.length > 128 && (s = `${s.slice(0, 128)}...`);
				return `The ${e.includes(".") ? "property" : "argument"} '${e}' ${i}. Received ${s}`;
			}, TypeError);
			const Le = function(e) {
				const t = "__node_internal_" + e.name;
				return Object.defineProperty(e, "name", { value: t }), e;
			}(function(e) {
				const t = isErrorStackTraceLimitWritable();
				return t && (Ne = Error.stackTraceLimit, Error.stackTraceLimit = Number.POSITIVE_INFINITY), Error.captureStackTrace(e), t && (Error.stackTraceLimit = Ne), e;
			});
			const Oe = {}.hasOwnProperty, { ERR_INVALID_PACKAGE_CONFIG: De } = Te, Ve = /* @__PURE__ */ new Map();
			function read(e, { base: t, specifier: i }) {
				const s = Ve.get(e);
				if (s) return s;
				let r;
				try {
					r = ue.readFileSync(Se.toNamespacedPath(e), "utf8");
				} catch (e) {
					const t = e;
					if ("ENOENT" !== t.code) throw t;
				}
				const n = {
					exists: !1,
					pjsonPath: e,
					main: void 0,
					name: void 0,
					type: "none",
					exports: void 0,
					imports: void 0
				};
				if (void 0 !== r) {
					let s;
					try {
						s = JSON.parse(r);
					} catch (s) {
						const r = s, n = new De(e, (t ? `"${i}" from ` : "") + (0, _e.fileURLToPath)(t || i), r.message);
						throw n.cause = r, n;
					}
					n.exists = !0, Oe.call(s, "name") && "string" == typeof s.name && (n.name = s.name), Oe.call(s, "main") && "string" == typeof s.main && (n.main = s.main), Oe.call(s, "exports") && (n.exports = s.exports), Oe.call(s, "imports") && (n.imports = s.imports), !Oe.call(s, "type") || "commonjs" !== s.type && "module" !== s.type || (n.type = s.type);
				}
				return Ve.set(e, n), n;
			}
			function getPackageScopeConfig(e) {
				let t = new URL("package.json", e);
				for (;;) {
					if (t.pathname.endsWith("node_modules/package.json")) break;
					const i = read((0, _e.fileURLToPath)(t), { specifier: e });
					if (i.exists) return i;
					const s = t;
					if (t = new URL("../package.json", t), t.pathname === s.pathname) break;
				}
				return {
					pjsonPath: (0, _e.fileURLToPath)(t),
					exists: !1,
					type: "none"
				};
			}
			function getPackageType(e) {
				return getPackageScopeConfig(e).type;
			}
			const { ERR_UNKNOWN_FILE_EXTENSION: Ue } = Te, Me = {}.hasOwnProperty, je = {
				__proto__: null,
				".cjs": "commonjs",
				".js": "module",
				".json": "json",
				".mjs": "module"
			};
			const Fe = {
				__proto__: null,
				"data:": function(e) {
					const { 1: t } = /^([^/]+\/[^;,]+)[^,]*?(;base64)?,/.exec(e.pathname) || [
						null,
						null,
						null
					];
					return function(e) {
						return e && /\s*(text|application)\/javascript\s*(;\s*charset=utf-?8\s*)?/i.test(e) ? "module" : "application/json" === e ? "json" : null;
					}(t);
				},
				"file:": function(e, t, i) {
					const s = function(e) {
						const t = e.pathname;
						let i = t.length;
						for (; i--;) {
							const e = t.codePointAt(i);
							if (47 === e) return "";
							if (46 === e) return 47 === t.codePointAt(i - 1) ? "" : t.slice(i);
						}
						return "";
					}(e);
					if (".js" === s) {
						const t = getPackageType(e);
						return "none" !== t ? t : "commonjs";
					}
					if ("" === s) {
						const t = getPackageType(e);
						return "none" === t || "commonjs" === t ? "commonjs" : "module";
					}
					const r = je[s];
					if (r) return r;
					if (i) return;
					throw new Ue(s, (0, _e.fileURLToPath)(e));
				},
				"http:": getHttpProtocolModuleFormat,
				"https:": getHttpProtocolModuleFormat,
				"node:": () => "builtin"
			};
			function getHttpProtocolModuleFormat() {}
			const Be = RegExp.prototype[Symbol.replace], { ERR_INVALID_MODULE_SPECIFIER: $e, ERR_INVALID_PACKAGE_CONFIG: qe, ERR_INVALID_PACKAGE_TARGET: We, ERR_MODULE_NOT_FOUND: Ge, ERR_PACKAGE_IMPORT_NOT_DEFINED: He, ERR_PACKAGE_PATH_NOT_EXPORTED: Ke, ERR_UNSUPPORTED_DIR_IMPORT: ze, ERR_UNSUPPORTED_RESOLVE_REQUEST: Je } = Te, Ye = {}.hasOwnProperty, Qe = /(^|\\|\/)((\.|%2e)(\.|%2e)?|(n|%6e|%4e)(o|%6f|%4f)(d|%64|%44)(e|%65|%45)(_|%5f)(m|%6d|%4d)(o|%6f|%4f)(d|%64|%44)(u|%75|%55)(l|%6c|%4c)(e|%65|%45)(s|%73|%53))?(\\|\/|$)/i, Ze = /(^|\\|\/)((\.|%2e)(\.|%2e)?|(n|%6e|%4e)(o|%6f|%4f)(d|%64|%44)(e|%65|%45)(_|%5f)(m|%6d|%4d)(o|%6f|%4f)(d|%64|%44)(u|%75|%55)(l|%6c|%4c)(e|%65|%45)(s|%73|%53))(\\|\/|$)/i, Xe = /^\.|%|\\/, et = /\*/g, tt = /%2f|%5c/i, it = /* @__PURE__ */ new Set(), st = /[/\\]{2}/;
			function emitInvalidSegmentDeprecation(e, t, i, s, r, n, a) {
				if (be.noDeprecation) return;
				const o = (0, _e.fileURLToPath)(s), h = null !== st.exec(a ? e : t);
				be.emitWarning(`Use of deprecated ${h ? "double slash" : "leading or trailing slash matching"} resolving "${e}" for module request "${t}" ${t === i ? "" : `matched to "${i}" `}in the "${r ? "imports" : "exports"}" field module resolution of the package at ${o}${n ? ` imported from ${(0, _e.fileURLToPath)(n)}` : ""}.`, "DeprecationWarning", "DEP0166");
			}
			function emitLegacyIndexDeprecation(e, t, i, s) {
				if (be.noDeprecation) return;
				if ("module" !== function(e, t) {
					const i = e.protocol;
					return Me.call(Fe, i) && Fe[i](e, t, !0) || null;
				}(e, { parentURL: i.href })) return;
				const n = (0, _e.fileURLToPath)(e.href), a = (0, _e.fileURLToPath)(new _e.URL(".", t)), o = (0, _e.fileURLToPath)(i);
				s ? Se.resolve(a, s) !== n && be.emitWarning(`Package ${a} has a "main" field set to "${s}", excluding the full filename and extension to the resolved file at "${n.slice(a.length)}", imported from ${o}.\n Automatic extension resolution of the "main" field is deprecated for ES modules.`, "DeprecationWarning", "DEP0151") : be.emitWarning(`No "main" or "exports" field defined in the package.json for ${a} resolving the main entry point "${n.slice(a.length)}", imported from ${o}.\nDefault "index" lookups for the main are deprecated for ES modules.`, "DeprecationWarning", "DEP0151");
			}
			function tryStatSync(e) {
				try {
					return (0, ue.statSync)(e);
				} catch {}
			}
			function fileExists(e) {
				const t = (0, ue.statSync)(e, { throwIfNoEntry: !1 }), i = t ? t.isFile() : void 0;
				return null != i && i;
			}
			function legacyMainResolve(e, t, i) {
				let s;
				if (void 0 !== t.main) {
					if (s = new _e.URL(t.main, e), fileExists(s)) return s;
					const r = [
						`./${t.main}.js`,
						`./${t.main}.json`,
						`./${t.main}.node`,
						`./${t.main}/index.js`,
						`./${t.main}/index.json`,
						`./${t.main}/index.node`
					];
					let n = -1;
					for (; ++n < r.length && (s = new _e.URL(r[n], e), !fileExists(s));) s = void 0;
					if (s) return emitLegacyIndexDeprecation(s, e, i, t.main), s;
				}
				const r = [
					"./index.js",
					"./index.json",
					"./index.node"
				];
				let n = -1;
				for (; ++n < r.length && (s = new _e.URL(r[n], e), !fileExists(s));) s = void 0;
				if (s) return emitLegacyIndexDeprecation(s, e, i, t.main), s;
				throw new Ge((0, _e.fileURLToPath)(new _e.URL(".", e)), (0, _e.fileURLToPath)(i));
			}
			function exportsNotFound(e, t, i) {
				return new Ke((0, _e.fileURLToPath)(new _e.URL(".", t)), e, i && (0, _e.fileURLToPath)(i));
			}
			function invalidPackageTarget(e, t, i, s, r) {
				return t = "object" == typeof t && null !== t ? JSON.stringify(t, null, "") : `${t}`, new We((0, _e.fileURLToPath)(new _e.URL(".", i)), e, t, s, r && (0, _e.fileURLToPath)(r));
			}
			function resolvePackageTargetString(e, t, i, s, r, n, a, o, h) {
				if ("" !== t && !n && "/" !== e[e.length - 1]) throw invalidPackageTarget(i, e, s, a, r);
				if (!e.startsWith("./")) {
					if (a && !e.startsWith("../") && !e.startsWith("/")) {
						let i = !1;
						try {
							new _e.URL(e), i = !0;
						} catch {}
						if (!i) return packageResolve(n ? Be.call(et, e, () => t) : e + t, s, h);
					}
					throw invalidPackageTarget(i, e, s, a, r);
				}
				if (null !== Qe.exec(e.slice(2))) {
					if (null !== Ze.exec(e.slice(2))) throw invalidPackageTarget(i, e, s, a, r);
					if (!o) {
						const o = n ? i.replace("*", () => t) : i + t;
						emitInvalidSegmentDeprecation(n ? Be.call(et, e, () => t) : e, o, i, s, a, r, !0);
					}
				}
				const c = new _e.URL(e, s), p = c.pathname, l = new _e.URL(".", s).pathname;
				if (!p.startsWith(l)) throw invalidPackageTarget(i, e, s, a, r);
				if ("" === t) return c;
				if (null !== Qe.exec(t)) {
					const h = n ? i.replace("*", () => t) : i + t;
					if (null === Ze.exec(t)) {
						if (!o) emitInvalidSegmentDeprecation(n ? Be.call(et, e, () => t) : e, h, i, s, a, r, !1);
					} else (function(e, t, i, s, r) {
						throw new $e(e, `request is not a valid match in pattern "${t}" for the "${s ? "imports" : "exports"}" resolution of ${(0, _e.fileURLToPath)(i)}`, r && (0, _e.fileURLToPath)(r));
					})(h, i, s, a, r);
				}
				return n ? new _e.URL(Be.call(et, c.href, () => t)) : new _e.URL(t, c);
			}
			function isArrayIndex(e) {
				const t = Number(e);
				return `${t}` === e && t >= 0 && t < 4294967295;
			}
			function resolvePackageTarget(e, t, i, s, r, n, a, o, h) {
				if ("string" == typeof t) return resolvePackageTargetString(t, i, s, e, r, n, a, o, h);
				if (Array.isArray(t)) {
					const c = t;
					if (0 === c.length) return null;
					let p, l = -1;
					for (; ++l < c.length;) {
						const t = c[l];
						let u;
						try {
							u = resolvePackageTarget(e, t, i, s, r, n, a, o, h);
						} catch (e) {
							if (p = e, "ERR_INVALID_PACKAGE_TARGET" === e.code) continue;
							throw e;
						}
						if (void 0 !== u) {
							if (null !== u) return u;
							p = null;
						}
					}
					if (null == p) return null;
					throw p;
				}
				if ("object" == typeof t && null !== t) {
					const c = Object.getOwnPropertyNames(t);
					let p = -1;
					for (; ++p < c.length;) if (isArrayIndex(c[p])) throw new qe((0, _e.fileURLToPath)(e), r, "\"exports\" cannot contain numeric property keys.");
					for (p = -1; ++p < c.length;) {
						const l = c[p];
						if ("default" === l || h && h.has(l)) {
							const c = resolvePackageTarget(e, t[l], i, s, r, n, a, o, h);
							if (void 0 === c) continue;
							return c;
						}
					}
					return null;
				}
				if (null === t) return null;
				throw invalidPackageTarget(s, t, e, a, r);
			}
			function emitTrailingSlashPatternDeprecation(e, t, i) {
				if (be.noDeprecation) return;
				const s = (0, _e.fileURLToPath)(t);
				it.has(s + "|" + e) || (it.add(s + "|" + e), be.emitWarning(`Use of deprecated trailing slash pattern mapping "${e}" in the "exports" field module resolution of the package at ${s}${i ? ` imported from ${(0, _e.fileURLToPath)(i)}` : ""}. Mapping specifiers ending in "/" is no longer supported.`, "DeprecationWarning", "DEP0155"));
			}
			function packageExportsResolve(e, t, i, s, r) {
				let n = i.exports;
				if (function(e, t, i) {
					if ("string" == typeof e || Array.isArray(e)) return !0;
					if ("object" != typeof e || null === e) return !1;
					const s = Object.getOwnPropertyNames(e);
					let r = !1, n = 0, a = -1;
					for (; ++a < s.length;) {
						const e = s[a], o = "" === e || "." !== e[0];
						if (0 === n++) r = o;
						else if (r !== o) throw new qe((0, _e.fileURLToPath)(t), i, "\"exports\" cannot contain some keys starting with '.' and some not. The exports object must either be an object of package subpath keys or an object of main entry condition name keys only.");
					}
					return r;
				}(n, e, s) && (n = { ".": n }), Ye.call(n, t) && !t.includes("*") && !t.endsWith("/")) {
					const i = resolvePackageTarget(e, n[t], "", t, s, !1, !1, !1, r);
					if (null == i) throw exportsNotFound(t, e, s);
					return i;
				}
				let a = "", o = "";
				const h = Object.getOwnPropertyNames(n);
				let c = -1;
				for (; ++c < h.length;) {
					const i = h[c], r = i.indexOf("*");
					if (-1 !== r && t.startsWith(i.slice(0, r))) {
						t.endsWith("/") && emitTrailingSlashPatternDeprecation(t, e, s);
						const n = i.slice(r + 1);
						t.length >= i.length && t.endsWith(n) && 1 === patternKeyCompare(a, i) && i.lastIndexOf("*") === r && (a = i, o = t.slice(r, t.length - n.length));
					}
				}
				if (a) {
					const i = resolvePackageTarget(e, n[a], o, a, s, !0, !1, t.endsWith("/"), r);
					if (null == i) throw exportsNotFound(t, e, s);
					return i;
				}
				throw exportsNotFound(t, e, s);
			}
			function patternKeyCompare(e, t) {
				const i = e.indexOf("*"), s = t.indexOf("*"), r = -1 === i ? e.length : i + 1, n = -1 === s ? t.length : s + 1;
				return r > n ? -1 : n > r || -1 === i ? 1 : -1 === s || e.length > t.length ? -1 : t.length > e.length ? 1 : 0;
			}
			function packageImportsResolve(e, t, i) {
				if ("#" === e || e.startsWith("#/") || e.endsWith("/")) throw new $e(e, "is not a valid internal imports specifier name", (0, _e.fileURLToPath)(t));
				let s;
				const r = getPackageScopeConfig(t);
				if (r.exists) {
					s = (0, _e.pathToFileURL)(r.pjsonPath);
					const n = r.imports;
					if (n) if (Ye.call(n, e) && !e.includes("*")) {
						const r = resolvePackageTarget(s, n[e], "", e, t, !1, !0, !1, i);
						if (null != r) return r;
					} else {
						let r = "", a = "";
						const o = Object.getOwnPropertyNames(n);
						let h = -1;
						for (; ++h < o.length;) {
							const t = o[h], i = t.indexOf("*");
							if (-1 !== i && e.startsWith(t.slice(0, -1))) {
								const s = t.slice(i + 1);
								e.length >= t.length && e.endsWith(s) && 1 === patternKeyCompare(r, t) && t.lastIndexOf("*") === i && (r = t, a = e.slice(i, e.length - s.length));
							}
						}
						if (r) {
							const e = resolvePackageTarget(s, n[r], a, r, t, !0, !0, !1, i);
							if (null != e) return e;
						}
					}
				}
				throw function(e, t, i) {
					return new He(e, t && (0, _e.fileURLToPath)(new _e.URL(".", t)), (0, _e.fileURLToPath)(i));
				}(e, s, t);
			}
			function packageResolve(e, t, i) {
				if (le.builtinModules.includes(e)) return new _e.URL("node:" + e);
				const { packageName: s, packageSubpath: r, isScoped: n } = function(e, t) {
					let i = e.indexOf("/"), s = !0, r = !1;
					"@" === e[0] && (r = !0, -1 === i || 0 === e.length ? s = !1 : i = e.indexOf("/", i + 1));
					const n = -1 === i ? e : e.slice(0, i);
					if (null !== Xe.exec(n) && (s = !1), !s) throw new $e(e, "is not a valid package name", (0, _e.fileURLToPath)(t));
					return {
						packageName: n,
						packageSubpath: "." + (-1 === i ? "" : e.slice(i)),
						isScoped: r
					};
				}(e, t), a = getPackageScopeConfig(t);
				if (a.exists) {
					const e = (0, _e.pathToFileURL)(a.pjsonPath);
					if (a.name === s && void 0 !== a.exports && null !== a.exports) return packageExportsResolve(e, r, a, t, i);
				}
				let o, h = new _e.URL("./node_modules/" + s + "/package.json", t), c = (0, _e.fileURLToPath)(h);
				do {
					const a = tryStatSync(c.slice(0, -13));
					if (!a || !a.isDirectory()) {
						o = c, h = new _e.URL((n ? "../../../../node_modules/" : "../../../node_modules/") + s + "/package.json", h), c = (0, _e.fileURLToPath)(h);
						continue;
					}
					const p = read(c, {
						base: t,
						specifier: e
					});
					return void 0 !== p.exports && null !== p.exports ? packageExportsResolve(h, r, p, t, i) : "." === r ? legacyMainResolve(h, p, t) : new _e.URL(r, h);
				} while (c.length !== o.length);
				throw new Ge(s, (0, _e.fileURLToPath)(t), !1);
			}
			function moduleResolve(e, t, i, s) {
				const r = t.protocol, n = "data:" === r || "http:" === r || "https:" === r;
				let a;
				if (function(e) {
					return "" !== e && ("/" === e[0] || function(e) {
						if ("." === e[0]) {
							if (1 === e.length || "/" === e[1]) return !0;
							if ("." === e[1] && (2 === e.length || "/" === e[2])) return !0;
						}
						return !1;
					}(e));
				}(e)) try {
					a = new _e.URL(e, t);
				} catch (i) {
					const s = new Je(e, t);
					throw s.cause = i, s;
				}
				else if ("file:" === r && "#" === e[0]) a = packageImportsResolve(e, t, i);
				else try {
					a = new _e.URL(e);
				} catch (s) {
					if (n && !le.builtinModules.includes(e)) {
						const i = new Je(e, t);
						throw i.cause = s, i;
					}
					a = packageResolve(e, t, i);
				}
				return Ee(void 0 !== a, "expected to be defined"), "file:" !== a.protocol ? a : function(e, t) {
					if (null !== tt.exec(e.pathname)) throw new $e(e.pathname, "must not include encoded \"/\" or \"\\\" characters", (0, _e.fileURLToPath)(t));
					let i;
					try {
						i = (0, _e.fileURLToPath)(e);
					} catch (i) {
						const s = i;
						throw Object.defineProperty(s, "input", { value: String(e) }), Object.defineProperty(s, "module", { value: String(t) }), s;
					}
					const s = tryStatSync(i.endsWith("/") ? i.slice(-1) : i);
					if (s && s.isDirectory()) {
						const s = new ze(i, (0, _e.fileURLToPath)(t));
						throw s.url = String(e), s;
					}
					if (!s || !s.isFile()) {
						const s = new Ge(i || e.pathname, t && (0, _e.fileURLToPath)(t), !0);
						throw s.url = String(e), s;
					}
					{
						const t = (0, ue.realpathSync)(i), { search: s, hash: r } = e;
						(e = (0, _e.pathToFileURL)(t + (i.endsWith(Se.sep) ? "/" : ""))).search = s, e.hash = r;
					}
					return e;
				}(a, t);
			}
			function fileURLToPath(e) {
				return "string" != typeof e || e.startsWith("file://") ? normalizeSlash((0, _e.fileURLToPath)(e)) : normalizeSlash(e);
			}
			function pathToFileURL(e) {
				return (0, _e.pathToFileURL)(fileURLToPath(e)).toString();
			}
			const rt = new Set(["node", "import"]), nt = [
				".mjs",
				".cjs",
				".js",
				".json"
			], at = new Set([
				"ERR_MODULE_NOT_FOUND",
				"ERR_UNSUPPORTED_DIR_IMPORT",
				"MODULE_NOT_FOUND",
				"ERR_PACKAGE_PATH_NOT_EXPORTED"
			]);
			function _tryModuleResolve(e, t, i) {
				try {
					return moduleResolve(e, t, i);
				} catch (e) {
					if (!at.has(e === null || e === void 0 ? void 0 : e.code)) throw e;
				}
			}
			function _resolve(e, t = {}) {
				if ("string" != typeof e) {
					if (!(e instanceof URL)) throw new TypeError("input must be a `string` or `URL`");
					e = fileURLToPath(e);
				}
				if (/(?:node|data|http|https):/.test(e)) return e;
				if (Ie.has(e)) return "node:" + e;
				if (e.startsWith("file://") && (e = fileURLToPath(e)), isAbsolute(e)) try {
					if ((0, ue.statSync)(e).isFile()) return pathToFileURL(e);
				} catch (e) {
					if ("ENOENT" !== (e === null || e === void 0 ? void 0 : e.code)) throw e;
				}
				const i = t.conditions ? new Set(t.conditions) : rt, s = (Array.isArray(t.url) ? t.url : [t.url]).filter(Boolean).map((e) => new URL(function(e) {
					return "string" != typeof e && (e = e.toString()), /(?:node|data|http|https|file):/.test(e) ? e : Ie.has(e) ? "node:" + e : "file://" + encodeURI(normalizeSlash(e));
				}(e.toString())));
				0 === s.length && s.push(new URL(pathToFileURL(process.cwd())));
				const r = [...s];
				for (const e of s) "file:" === e.protocol && r.push(new URL("./", e), new URL(dist_joinURL(e.pathname, "_index.js"), e), new URL("node_modules", e));
				let n;
				for (const s of r) {
					if (n = _tryModuleResolve(e, s, i), n) break;
					for (const r of ["", "/index"]) {
						for (const a of t.extensions || nt) if (n = _tryModuleResolve(dist_joinURL(e, r) + a, s, i), n) break;
						if (n) break;
					}
					if (n) break;
				}
				if (!n) {
					const t = /* @__PURE__ */ new Error(`Cannot find module ${e} imported from ${r.join(", ")}`);
					throw t.code = "ERR_MODULE_NOT_FOUND", t;
				}
				return pathToFileURL(n);
			}
			function resolveSync(e, t) {
				return _resolve(e, t);
			}
			function resolvePathSync(e, t) {
				return fileURLToPath(resolveSync(e, t));
			}
			const ot = /(?:[\s;]|^)(?:import[\s\w*,{}]*from|import\s*["'*{]|export\b\s*(?:[*{]|default|class|type|function|const|var|let|async function)|import\.meta\b)/m, ht = /\/\*.+?\*\/|\/\/.*(?=[nr])/g;
			function hasESMSyntax(e, t = {}) {
				return t.stripComments && (e = e.replace(ht, "")), ot.test(e);
			}
			function escapeStringRegexp(e) {
				if ("string" != typeof e) throw new TypeError("Expected a string");
				return e.replace(/[|\\{}()[\]^$+*?.]/g, "\\$&").replace(/-/g, "\\x2d");
			}
			const ct = new Set([
				"/",
				"\\",
				void 0
			]), pt = Symbol.for("pathe:normalizedAlias"), lt = /[/\\]/;
			function normalizeAliases(e) {
				var _t$e;
				if (e[pt]) return e;
				const t = Object.fromEntries(Object.entries(e).sort(([e], [t]) => function(e, t) {
					return t.split("/").length - e.split("/").length;
				}(e, t)));
				for (const e in t) for (const i in t) i === e || e.startsWith(i) || !((_t$e = t[e]) === null || _t$e === void 0) && _t$e.startsWith(i) && ct.has(t[e][i.length]) && (t[e] = t[i] + t[e].slice(i.length));
				return Object.defineProperty(t, pt, {
					value: !0,
					enumerable: !1
				}), t;
			}
			function utils_hasTrailingSlash(e = "/") {
				const t = e[e.length - 1];
				return "/" === t || "\\" === t;
			}
			var ut = { rE: "2.6.1" };
			const dt = __require("node:crypto");
			var ft = __webpack_require__.n(dt);
			const mt = Object.create(null), dist_i = (e) => {
				var _globalThis$process, _globalThis$Deno;
				return ((_globalThis$process = globalThis.process) === null || _globalThis$process === void 0 ? void 0 : _globalThis$process.env) || ((_globalThis$Deno = globalThis.Deno) === null || _globalThis$Deno === void 0 ? void 0 : _globalThis$Deno.env.toObject()) || globalThis.__env__ || (e ? mt : globalThis);
			}, gt = new Proxy(mt, {
				get: (e, t) => dist_i()[t] ?? mt[t],
				has: (e, t) => t in dist_i() || t in mt,
				set: (e, t, i) => (dist_i(!0)[t] = i, !0),
				deleteProperty(e, t) {
					if (!t) return !1;
					return delete dist_i(!0)[t], !0;
				},
				ownKeys() {
					const e = dist_i(!0);
					return Object.keys(e);
				}
			}), xt = typeof process < "u" && process.env && process.env.NODE_ENV || "", vt = [
				["APPVEYOR"],
				[
					"AWS_AMPLIFY",
					"AWS_APP_ID",
					{ ci: !0 }
				],
				["AZURE_PIPELINES", "SYSTEM_TEAMFOUNDATIONCOLLECTIONURI"],
				["AZURE_STATIC", "INPUT_AZURE_STATIC_WEB_APPS_API_TOKEN"],
				["APPCIRCLE", "AC_APPCIRCLE"],
				["BAMBOO", "bamboo_planKey"],
				["BITBUCKET", "BITBUCKET_COMMIT"],
				["BITRISE", "BITRISE_IO"],
				["BUDDY", "BUDDY_WORKSPACE_ID"],
				["BUILDKITE"],
				["CIRCLE", "CIRCLECI"],
				["CIRRUS", "CIRRUS_CI"],
				[
					"CLOUDFLARE_PAGES",
					"CF_PAGES",
					{ ci: !0 }
				],
				[
					"CLOUDFLARE_WORKERS",
					"WORKERS_CI",
					{ ci: !0 }
				],
				["CODEBUILD", "CODEBUILD_BUILD_ARN"],
				["CODEFRESH", "CF_BUILD_ID"],
				["DRONE"],
				["DRONE", "DRONE_BUILD_EVENT"],
				["DSARI"],
				["GITHUB_ACTIONS"],
				["GITLAB", "GITLAB_CI"],
				["GITLAB", "CI_MERGE_REQUEST_ID"],
				["GOCD", "GO_PIPELINE_LABEL"],
				["LAYERCI"],
				["HUDSON", "HUDSON_URL"],
				["JENKINS", "JENKINS_URL"],
				["MAGNUM"],
				["NETLIFY"],
				[
					"NETLIFY",
					"NETLIFY_LOCAL",
					{ ci: !1 }
				],
				["NEVERCODE"],
				["RENDER"],
				["SAIL", "SAILCI"],
				["SEMAPHORE"],
				["SCREWDRIVER"],
				["SHIPPABLE"],
				["SOLANO", "TDDIUM"],
				["STRIDER"],
				["TEAMCITY", "TEAMCITY_VERSION"],
				["TRAVIS"],
				["VERCEL", "NOW_BUILDER"],
				[
					"VERCEL",
					"VERCEL",
					{ ci: !1 }
				],
				[
					"VERCEL",
					"VERCEL_ENV",
					{ ci: !1 }
				],
				["APPCENTER", "APPCENTER_BUILD_ID"],
				[
					"CODESANDBOX",
					"CODESANDBOX_SSE",
					{ ci: !1 }
				],
				[
					"CODESANDBOX",
					"CODESANDBOX_HOST",
					{ ci: !1 }
				],
				["STACKBLITZ"],
				["STORMKIT"],
				["CLEAVR"],
				["ZEABUR"],
				[
					"CODESPHERE",
					"CODESPHERE_APP_ID",
					{ ci: !0 }
				],
				["RAILWAY", "RAILWAY_PROJECT_ID"],
				["RAILWAY", "RAILWAY_SERVICE_ID"],
				["DENO-DEPLOY", "DENO_DEPLOYMENT_ID"],
				[
					"FIREBASE_APP_HOSTING",
					"FIREBASE_APP_HOSTING",
					{ ci: !0 }
				]
			];
			const yt = function() {
				var _globalThis$process2, _globalThis$process4, _globalThis$process5;
				if ((_globalThis$process2 = globalThis.process) === null || _globalThis$process2 === void 0 ? void 0 : _globalThis$process2.env) for (const e of vt) {
					var _globalThis$process3;
					const t = e[1] || e[0];
					if ((_globalThis$process3 = globalThis.process) === null || _globalThis$process3 === void 0 ? void 0 : _globalThis$process3.env[t]) return {
						name: e[0].toLowerCase(),
						...e[2]
					};
				}
				return "/bin/jsh" === ((_globalThis$process4 = globalThis.process) === null || _globalThis$process4 === void 0 || (_globalThis$process4 = _globalThis$process4.env) === null || _globalThis$process4 === void 0 ? void 0 : _globalThis$process4.SHELL) && ((_globalThis$process5 = globalThis.process) === null || _globalThis$process5 === void 0 || (_globalThis$process5 = _globalThis$process5.versions) === null || _globalThis$process5 === void 0 ? void 0 : _globalThis$process5.webcontainer) ? {
					name: "stackblitz",
					ci: !1
				} : {
					name: "",
					ci: !1
				};
			}();
			yt.name;
			function std_env_dist_n(e) {
				return !!e && "false" !== e;
			}
			const _t = ((_globalThis$process6 = globalThis.process) === null || _globalThis$process6 === void 0 ? void 0 : _globalThis$process6.platform) || "";
			std_env_dist_n(gt.CI) || yt.ci;
			const bt = std_env_dist_n(((_globalThis$process7 = globalThis.process) === null || _globalThis$process7 === void 0 ? void 0 : _globalThis$process7.stdout) && ((_globalThis$process8 = globalThis.process) === null || _globalThis$process8 === void 0 ? void 0 : _globalThis$process8.stdout.isTTY));
			std_env_dist_n(gt.DEBUG), "test" === xt || std_env_dist_n(gt.TEST);
			const kt = (std_env_dist_n(gt.MINIMAL), /^win/i.test(_t)), wt = (/^linux/i.test(_t), /^darwin/i.test(_t), !std_env_dist_n(gt.NO_COLOR) && (std_env_dist_n(gt.FORCE_COLOR) || (bt || kt) && gt.TERM), (((_globalThis$process9 = globalThis.process) === null || _globalThis$process9 === void 0 || (_globalThis$process9 = _globalThis$process9.versions) === null || _globalThis$process9 === void 0 ? void 0 : _globalThis$process9.node) || "").replace(/^v/, "") || null), It = (Number(wt === null || wt === void 0 ? void 0 : wt.split(".")[0]), globalThis.process || Object.create(null)), Ct = { versions: {} }, Rt = (new Proxy(It, { get: (e, t) => "env" === t ? gt : t in e ? e[t] : t in Ct ? Ct[t] : void 0 }), "node" === ((_globalThis$process10 = globalThis.process) === null || _globalThis$process10 === void 0 || (_globalThis$process10 = _globalThis$process10.release) === null || _globalThis$process10 === void 0 ? void 0 : _globalThis$process10.name)), Pt = !!globalThis.Bun || !!((_globalThis$process11 = globalThis.process) === null || _globalThis$process11 === void 0 || (_globalThis$process11 = _globalThis$process11.versions) === null || _globalThis$process11 === void 0 ? void 0 : _globalThis$process11.bun), Tt = !!globalThis.Deno, At = !!globalThis.fastly, Nt = [
				[!!globalThis.Netlify, "netlify"],
				[!!globalThis.EdgeRuntime, "edge-light"],
				["Cloudflare-Workers" === ((_globalThis$navigator = globalThis.navigator) === null || _globalThis$navigator === void 0 ? void 0 : _globalThis$navigator.userAgent), "workerd"],
				[At, "fastly"],
				[Tt, "deno"],
				[Pt, "bun"],
				[Rt, "node"]
			];
			(function() {
				const e = Nt.find((e) => e[0]);
				if (e) e[1];
			})();
			const Lt = __require("node:tty"), Ot = (Lt === null || Lt === void 0 || (_Lt$WriteStream = Lt.WriteStream) === null || _Lt$WriteStream === void 0 || (_Lt$WriteStream = _Lt$WriteStream.prototype) === null || _Lt$WriteStream === void 0 || (_Lt$WriteStream$hasCo = _Lt$WriteStream.hasColors) === null || _Lt$WriteStream$hasCo === void 0 ? void 0 : _Lt$WriteStream$hasCo.call(_Lt$WriteStream)) ?? !1, base_format = (e, t) => {
				if (!Ot) return (e) => e;
				const i = `[${e}m`, s = `[${t}m`;
				return (e) => {
					const r = e + "";
					let n = r.indexOf(s);
					if (-1 === n) return i + r + s;
					let a = i, o = 0;
					const h = (22 === t ? s : "") + i;
					for (; -1 !== n;) a += r.slice(o, n) + h, o = n + s.length, n = r.indexOf(s, o);
					return a += r.slice(o) + s, a;
				};
			}, Dt = (base_format(0, 0), base_format(1, 22), base_format(2, 22), base_format(3, 23), base_format(4, 24), base_format(53, 55), base_format(7, 27), base_format(8, 28), base_format(9, 29), base_format(30, 39), base_format(31, 39)), Vt = base_format(32, 39), Ut = base_format(33, 39), Mt = base_format(34, 39), jt = (base_format(35, 39), base_format(36, 39)), Ft = (base_format(37, 39), base_format(90, 39));
			base_format(40, 49), base_format(41, 49), base_format(42, 49), base_format(43, 49), base_format(44, 49), base_format(45, 49), base_format(46, 49), base_format(47, 49), base_format(100, 49), base_format(91, 39), base_format(92, 39), base_format(93, 39), base_format(94, 39), base_format(95, 39), base_format(96, 39), base_format(97, 39), base_format(101, 49), base_format(102, 49), base_format(103, 49), base_format(104, 49), base_format(105, 49), base_format(106, 49), base_format(107, 49);
			function isDir(e) {
				if ("string" != typeof e || e.startsWith("file://")) return !1;
				try {
					return (0, ue.lstatSync)(e).isDirectory();
				} catch {
					return !1;
				}
			}
			function utils_hash(e, t = 8) {
				return (function() {
					if (void 0 !== $t) return $t;
					try {
						var _ft$getFips, _ft;
						return $t = !!((_ft$getFips = (_ft = ft()).getFips) === null || _ft$getFips === void 0 ? void 0 : _ft$getFips.call(_ft)), $t;
					} catch {
						return $t = !1, $t;
					}
				}() ? ft().createHash("sha256") : ft().createHash("md5")).update(e).digest("hex").slice(0, t);
			}
			const Bt = {
				true: Vt("true"),
				false: Ut("false"),
				"[rebuild]": Ut("[rebuild]"),
				"[esm]": Mt("[esm]"),
				"[cjs]": Vt("[cjs]"),
				"[import]": Mt("[import]"),
				"[require]": Vt("[require]"),
				"[native]": jt("[native]"),
				"[transpile]": Ut("[transpile]"),
				"[fallback]": Dt("[fallback]"),
				"[unknown]": Dt("[unknown]"),
				"[hit]": Vt("[hit]"),
				"[miss]": Ut("[miss]"),
				"[json]": Vt("[json]"),
				"[data]": Vt("[data]")
			};
			function debug(e, ...t) {
				if (!e.opts.debug) return;
				const i = process.cwd();
				console.log(Ft(["[jiti]", ...t.map((e) => e in Bt ? Bt[e] : "string" != typeof e ? JSON.stringify(e) : e.replace(i, "."))].join(" ")));
			}
			function jitiInteropDefault(e, t) {
				return e.opts.interopDefault ? function(e) {
					const t = typeof e;
					if (null === e || "object" !== t && "function" !== t) return e;
					const i = e.default, s = typeof i, r = null == i, n = "object" === s || "function" === s;
					if (r && e instanceof Promise) return e;
					return new Proxy(e, {
						get(t, s, a) {
							if ("__esModule" === s) return !0;
							if ("default" === s) return r ? e : "function" == typeof (i === null || i === void 0 ? void 0 : i.default) && e.__esModule ? i.default : i;
							if (Reflect.has(t, s)) return Reflect.get(t, s, a);
							if (n && !(i instanceof Promise)) {
								let e = Reflect.get(i, s, a);
								return "function" == typeof e && (e = e.bind(i)), e;
							}
						},
						apply: (e, t, r) => "function" == typeof e ? Reflect.apply(e, t, r) : "function" === s ? Reflect.apply(i, t, r) : void 0
					});
				}(t) : t;
			}
			let $t;
			function _booleanEnv(e, t) {
				const i = _jsonEnv(e, t);
				return Boolean(i);
			}
			function _jsonEnv(e, t) {
				const i = process.env[e];
				if (!(e in process.env)) return t;
				try {
					return JSON.parse(i);
				} catch {
					return t;
				}
			}
			const qt = /\.(c|m)?j(sx?)$/, Wt = /\.(c|m)?t(sx?)$/;
			function jitiResolve(e, t, i) {
				let s, r;
				if (e.isNativeRe.test(t)) return t;
				e.alias && (t = function(e, t) {
					const i = pathe_M_eThtNZ_normalizeWindowsPath(e);
					t = normalizeAliases(t);
					for (const [e, s] of Object.entries(t)) {
						if (!i.startsWith(e)) continue;
						if (utils_hasTrailingSlash(i[(utils_hasTrailingSlash(e) ? e.slice(0, -1) : e).length])) return pathe_M_eThtNZ_join(s, i.slice(e.length));
					}
					return i;
				}(t, e.alias));
				let n = (i === null || i === void 0 ? void 0 : i.parentURL) || e.url;
				isDir(n) && (n = pathe_M_eThtNZ_join(n, "_index.js"));
				const a = ((i === null || i === void 0 ? void 0 : i.async) ? [
					i === null || i === void 0 ? void 0 : i.conditions,
					["node", "import"],
					["node", "require"]
				] : [
					i === null || i === void 0 ? void 0 : i.conditions,
					["node", "require"],
					["node", "import"]
				]).filter(Boolean);
				for (const i of a) {
					try {
						s = resolvePathSync(t, {
							url: n,
							conditions: i,
							extensions: e.opts.extensions
						});
					} catch (e) {
						r = e;
					}
					if (s) return s;
				}
				try {
					return e.nativeRequire.resolve(t, { paths: i.paths });
				} catch (e) {
					r = e;
				}
				for (const r of e.additionalExts) {
					var _e$parentModule;
					if (s = tryNativeRequireResolve(e, t + r, n, i) || tryNativeRequireResolve(e, t + "/index" + r, n, i), s) return s;
					if ((Wt.test(e.filename) || Wt.test(((_e$parentModule = e.parentModule) === null || _e$parentModule === void 0 ? void 0 : _e$parentModule.filename) || "") || qt.test(t)) && (s = tryNativeRequireResolve(e, t.replace(qt, ".$1t$2"), n, i), s)) return s;
				}
				if (!(i === null || i === void 0 ? void 0 : i.try)) throw r;
			}
			function tryNativeRequireResolve(e, t, i, s) {
				try {
					return e.nativeRequire.resolve(t, {
						...s,
						paths: [pathe_M_eThtNZ_dirname(fileURLToPath(i)), ...(s === null || s === void 0 ? void 0 : s.paths) || []]
					});
				} catch {}
			}
			const Gt = __require("node:perf_hooks"), Ht = __require("node:vm");
			var Kt = __webpack_require__.n(Ht);
			function jitiRequire(e, t, i) {
				var _s$r;
				const s = e.parentCache || {};
				if (t.startsWith("node:")) return nativeImportOrRequire(e, t, i.async);
				if (t.startsWith("file:")) t = (0, _e.fileURLToPath)(t);
				else if (t.startsWith("data:")) {
					if (!i.async) throw new Error("`data:` URLs are only supported in ESM context. Use `import` or `jiti.import` instead.");
					return debug(e, "[native]", "[data]", "[import]", t), nativeImportOrRequire(e, t, !0);
				}
				if (le.builtinModules.includes(t) || ".pnp.js" === t) return nativeImportOrRequire(e, t, i.async);
				if (e.opts.tryNative && !e.opts.transformOptions) try {
					if (!(t = jitiResolve(e, t, i)) && i.try) return;
					if (debug(e, "[try-native]", i.async && e.nativeImport ? "[import]" : "[require]", t), i.async && e.nativeImport) return e.nativeImport(t).then((i) => (!1 === e.opts.moduleCache && delete e.nativeRequire.cache[t], jitiInteropDefault(e, i)));
					{
						const i = e.nativeRequire(t);
						return !1 === e.opts.moduleCache && delete e.nativeRequire.cache[t], jitiInteropDefault(e, i);
					}
				} catch (i) {
					debug(e, `[try-native] Using fallback for ${t} because of an error:`, i);
				}
				const r = jitiResolve(e, t, i);
				if (!r && i.try) return;
				const n = extname(r);
				if (".json" === n) {
					debug(e, "[json]", r);
					const t = e.nativeRequire(r);
					return t && !("default" in t) && Object.defineProperty(t, "default", {
						value: t,
						enumerable: !1
					}), t;
				}
				if (n && !e.opts.extensions.includes(n)) return debug(e, "[native]", "[unknown]", i.async ? "[import]" : "[require]", r), nativeImportOrRequire(e, r, i.async);
				if (e.isNativeRe.test(r)) return debug(e, "[native]", i.async ? "[import]" : "[require]", r), nativeImportOrRequire(e, r, i.async);
				if (s[r]) return jitiInteropDefault(e, (_s$r = s[r]) === null || _s$r === void 0 ? void 0 : _s$r.exports);
				if (e.opts.moduleCache) {
					const t = e.nativeRequire.cache[r];
					if (t === null || t === void 0 ? void 0 : t.loaded) return jitiInteropDefault(e, t.exports);
				}
				return eval_evalModule(e, (0, ue.readFileSync)(r, "utf8"), {
					id: t,
					filename: r,
					ext: n,
					cache: s,
					async: i.async
				});
			}
			function nativeImportOrRequire(e, t, i) {
				return i && e.nativeImport ? e.nativeImport(function(e) {
					return kt && isAbsolute(e) ? pathToFileURL(e) : e;
				}(t)).then((t) => jitiInteropDefault(e, t)) : jitiInteropDefault(e, e.nativeRequire(t));
			}
			const zt = "9";
			function getCache(e, t, i) {
				if (!e.opts.fsCache || !t.filename) return i();
				const s = ` /* v${zt}-${utils_hash(t.source, 16)} */\n`;
				let r = `${basename(pathe_M_eThtNZ_dirname(t.filename))}-${function(e) {
					const t = e.split(lt).pop();
					if (!t) return;
					const i = t.lastIndexOf(".");
					return i <= 0 ? t : t.slice(0, i);
				}(t.filename)}` + (e.opts.sourceMaps ? "+map" : "") + (t.interopDefault ? ".i" : "") + `.${utils_hash(t.filename)}` + (t.async ? ".mjs" : ".cjs");
				t.jsx && t.filename.endsWith("x") && (r += "x");
				const n = e.opts.fsCache, a = pathe_M_eThtNZ_join(n, r);
				if (!e.opts.rebuildFsCache && (0, ue.existsSync)(a)) {
					const i = (0, ue.readFileSync)(a, "utf8");
					if (i.endsWith(s)) return debug(e, "[cache]", "[hit]", t.filename, "~>", a), i;
				}
				debug(e, "[cache]", "[miss]", t.filename);
				const o = i();
				return o.includes("__JITI_ERROR__") || ((0, ue.writeFileSync)(a, o + s, "utf8"), debug(e, "[cache]", "[store]", t.filename, "~>", a)), o;
			}
			function prepareCacheDir(t) {
				if (!0 === t.opts.fsCache && (t.opts.fsCache = function(t) {
					const i = t.filename && pathe_M_eThtNZ_resolve(t.filename, "../node_modules");
					if (i && (0, ue.existsSync)(i)) return pathe_M_eThtNZ_join(i, ".cache/jiti");
					let s = (0, e.tmpdir)();
					if (process.env.TMPDIR && s === process.cwd() && !process.env.JITI_RESPECT_TMPDIR_ENV) {
						const t = process.env.TMPDIR;
						delete process.env.TMPDIR, s = (0, e.tmpdir)(), process.env.TMPDIR = t;
					}
					return pathe_M_eThtNZ_join(s, "jiti");
				}(t)), t.opts.fsCache) try {
					if ((0, ue.mkdirSync)(t.opts.fsCache, { recursive: !0 }), !function(e) {
						try {
							return (0, ue.accessSync)(e, ue.constants.W_OK), !0;
						} catch {
							return !1;
						}
					}(t.opts.fsCache)) throw new Error("directory is not writable!");
				} catch (e) {
					debug(t, "Error creating cache directory at ", t.opts.fsCache, e), t.opts.fsCache = !1;
				}
			}
			function transform(e, t) {
				let i = getCache(e, t, () => {
					var _e$opts$transformOpti;
					const i = e.opts.transform({
						...e.opts.transformOptions,
						babel: {
							...e.opts.sourceMaps ? {
								sourceFileName: t.filename,
								sourceMaps: "inline"
							} : {},
							...(_e$opts$transformOpti = e.opts.transformOptions) === null || _e$opts$transformOpti === void 0 ? void 0 : _e$opts$transformOpti.babel
						},
						interopDefault: e.opts.interopDefault,
						...t
					});
					return i.error && e.opts.debug && debug(e, i.error), i.code;
				});
				return i.startsWith("#!") && (i = "// " + i), i;
			}
			function eval_evalModule(e, t, i = {}) {
				var _ref;
				const s = i.id || (i.filename ? basename(i.filename) : `_jitiEval.${i.ext || (i.async ? "mjs" : "js")}`), r = i.filename || jitiResolve(e, s, { async: i.async }), n = i.ext || extname(r), a = i.cache || e.parentCache || {}, o = /\.[cm]?tsx?$/.test(n), h = ".mjs" === n || ".js" === n && "module" === ((_ref = function(e) {
					for (; e && "." !== e && "/" !== e;) {
						e = pathe_M_eThtNZ_join(e, "..");
						try {
							const t = (0, ue.readFileSync)(pathe_M_eThtNZ_join(e, "package.json"), "utf8");
							try {
								return JSON.parse(t);
							} catch {}
							break;
						} catch {}
					}
				}(r)) === null || _ref === void 0 ? void 0 : _ref.type), c = ".cjs" === n, p = i.forceTranspile ?? (!c && !(h && i.async) && (o || h || e.isTransformRe.test(r) || hasESMSyntax(t))), l = Gt.performance.now();
				if (p) {
					t = transform(e, {
						filename: r,
						source: t,
						ts: o,
						async: i.async ?? !1,
						jsx: e.opts.jsx
					});
					const s = Math.round(1e3 * (Gt.performance.now() - l)) / 1e3;
					debug(e, "[transpile]", i.async ? "[esm]" : "[cjs]", r, `(${s}ms)`);
				} else {
					if (debug(e, "[native]", i.async ? "[import]" : "[require]", r), i.async) return Promise.resolve(nativeImportOrRequire(e, r, i.async)).catch((s) => (debug(e, "Native import error:", s), debug(e, "[fallback]", r), eval_evalModule(e, t, {
						...i,
						forceTranspile: !0
					})));
					try {
						return nativeImportOrRequire(e, r, i.async);
					} catch (s) {
						debug(e, "Native require error:", s), debug(e, "[fallback]", r), t = transform(e, {
							filename: r,
							source: t,
							ts: o,
							async: i.async ?? !1,
							jsx: e.opts.jsx
						});
					}
				}
				const u = new le.Module(r);
				u.filename = r, e.parentModule && (u.parent = e.parentModule, Array.isArray(e.parentModule.children) && !e.parentModule.children.includes(u) && e.parentModule.children.push(u));
				const d = createJiti(r, e.opts, {
					parentModule: u,
					parentCache: a,
					nativeImport: e.nativeImport,
					onError: e.onError,
					createRequire: e.createRequire
				}, !0);
				let f;
				u.require = d, u.path = pathe_M_eThtNZ_dirname(r), u.paths = le.Module._nodeModulePaths(u.path), a[r] = u, e.opts.moduleCache && (e.nativeRequire.cache[r] = u);
				const m = function(e, t) {
					return `(${(t === null || t === void 0 ? void 0 : t.async) ? "async " : ""}function (exports, require, module, __filename, __dirname, jitiImport, jitiESMResolve) { ${e}\n});`;
				}(t, { async: i.async });
				try {
					f = Kt().runInThisContext(m, {
						filename: r,
						lineOffset: 0,
						displayErrors: !1
					});
				} catch (t) {
					"SyntaxError" === t.name && i.async && e.nativeImport ? (debug(e, "[esm]", "[import]", "[fallback]", r), f = function(e, t) {
						const i = `data:text/javascript;base64,${Buffer.from(`export default ${e}`).toString("base64")}`;
						return (...e) => t(i).then((t) => t.default(...e));
					}(m, e.nativeImport)) : (e.opts.moduleCache && delete e.nativeRequire.cache[r], e.onError(t));
				}
				let g;
				try {
					g = f(u.exports, u.require, u, u.filename, pathe_M_eThtNZ_dirname(u.filename), d.import, d.esmResolve);
				} catch (t) {
					e.opts.moduleCache && delete e.nativeRequire.cache[r], e.onError(t);
				}
				function next() {
					if (u.exports && u.exports.__JITI_ERROR__) {
						const { filename: t, line: i, column: s, code: r, message: n } = u.exports.__JITI_ERROR__, a = /* @__PURE__ */ new Error(`${r}: ${n} \n ${`${t}:${i}:${s}`}`);
						Error.captureStackTrace(a, jitiRequire), e.onError(a);
					}
					u.loaded = !0;
					return jitiInteropDefault(e, u.exports);
				}
				return i.async ? Promise.resolve(g).then(next) : next();
			}
			const Jt = "win32" === (0, e.platform)();
			function createJiti(e, t = {}, i, s = !1) {
				const r = s ? t : function(e) {
					const t = {
						fsCache: _booleanEnv("JITI_FS_CACHE", _booleanEnv("JITI_CACHE", !0)),
						rebuildFsCache: _booleanEnv("JITI_REBUILD_FS_CACHE", !1),
						moduleCache: _booleanEnv("JITI_MODULE_CACHE", _booleanEnv("JITI_REQUIRE_CACHE", !0)),
						debug: _booleanEnv("JITI_DEBUG", !1),
						sourceMaps: _booleanEnv("JITI_SOURCE_MAPS", !1),
						interopDefault: _booleanEnv("JITI_INTEROP_DEFAULT", !0),
						extensions: _jsonEnv("JITI_EXTENSIONS", [
							".js",
							".mjs",
							".cjs",
							".ts",
							".tsx",
							".mts",
							".cts",
							".mtsx",
							".ctsx"
						]),
						alias: _jsonEnv("JITI_ALIAS", {}),
						nativeModules: _jsonEnv("JITI_NATIVE_MODULES", []),
						transformModules: _jsonEnv("JITI_TRANSFORM_MODULES", []),
						tryNative: _jsonEnv("JITI_TRY_NATIVE", "Bun" in globalThis),
						jsx: _booleanEnv("JITI_JSX", !1)
					};
					t.jsx && t.extensions.push(".jsx", ".tsx");
					const i = {};
					return void 0 !== e.cache && (i.fsCache = e.cache), void 0 !== e.requireCache && (i.moduleCache = e.requireCache), {
						...t,
						...i,
						...e
					};
				}(t), n = r.alias && Object.keys(r.alias).length > 0 ? normalizeAliases(r.alias || {}) : void 0, a = [
					"typescript",
					"jiti",
					...r.nativeModules || []
				], o = new RegExp(`node_modules/(${a.map((e) => escapeStringRegexp(e)).join("|")})/`), h = [...r.transformModules || []], c = new RegExp(`node_modules/(${h.map((e) => escapeStringRegexp(e)).join("|")})/`);
				e || (e = process.cwd()), !s && isDir(e) && (e = pathe_M_eThtNZ_join(e, "_index.js"));
				const p = pathToFileURL(e), l = [...r.extensions].filter((e) => ".js" !== e), u = i.createRequire(Jt ? e.replace(/\//g, "\\") : e), d = {
					filename: e,
					url: p,
					opts: r,
					alias: n,
					nativeModules: a,
					transformModules: h,
					isNativeRe: o,
					isTransformRe: c,
					additionalExts: l,
					nativeRequire: u,
					onError: i.onError,
					parentModule: i.parentModule,
					parentCache: i.parentCache,
					nativeImport: i.nativeImport,
					createRequire: i.createRequire
				};
				s || debug(d, "[init]", ...[
					["version:", ut.rE],
					["module-cache:", r.moduleCache],
					["fs-cache:", r.fsCache],
					["rebuild-fs-cache:", r.rebuildFsCache],
					["interop-defaults:", r.interopDefault]
				].flat()), s || prepareCacheDir(d);
				return Object.assign(function(e) {
					return jitiRequire(d, e, { async: !1 });
				}, {
					cache: r.moduleCache ? u.cache : Object.create(null),
					extensions: u.extensions,
					main: u.main,
					options: r,
					resolve: Object.assign(function(e) {
						return jitiResolve(d, e, { async: !1 });
					}, { paths: u.resolve.paths }),
					transform: (e) => transform(d, e),
					evalModule: (e, t) => eval_evalModule(d, e, t),
					async import(e, t) {
						const i = await jitiRequire(d, e, {
							...t,
							async: !0
						});
						return (t === null || t === void 0 ? void 0 : t.default) ? (i === null || i === void 0 ? void 0 : i.default) ?? i : i;
					},
					esmResolve(e, t) {
						"string" == typeof t && (t = { parentURL: t });
						const i = jitiResolve(d, e, {
							parentURL: p,
							...t,
							async: !0
						});
						return !i || "string" != typeof i || i.startsWith("file://") ? i : pathToFileURL(i);
					}
				});
			}
		})(), module.exports = i.default;
	})();
}));
var require_babel = /* @__PURE__ */ __commonJSMin(((exports, module) => {
	(() => {
		var e = {
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files lazy recursive": function(e) {
				function webpackEmptyAsyncContext(e) {
					return Promise.resolve().then(function() {
						var t = /* @__PURE__ */ new Error("Cannot find module '" + e + "'");
						throw t.code = "MODULE_NOT_FOUND", t;
					});
				}
				webpackEmptyAsyncContext.keys = () => [], webpackEmptyAsyncContext.resolve = webpackEmptyAsyncContext, webpackEmptyAsyncContext.id = "./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files lazy recursive", e.exports = webpackEmptyAsyncContext;
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files sync recursive": function(e) {
				function webpackEmptyContext(e) {
					var t = /* @__PURE__ */ new Error("Cannot find module '" + e + "'");
					throw t.code = "MODULE_NOT_FOUND", t;
				}
				webpackEmptyContext.keys = () => [], webpackEmptyContext.resolve = webpackEmptyContext, webpackEmptyContext.id = "./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files sync recursive", e.exports = webpackEmptyContext;
			},
			"./node_modules/.pnpm/@babel+plugin-syntax-class-properties@7.12.13_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-class-properties/lib/index.js": function(e, t, r) {
				"use strict";
				t.default = void 0;
				t.default = (0, r("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js").declare)((e) => (e.assertVersion(7), {
					name: "syntax-class-properties",
					manipulateOptions(e, t) {
						t.plugins.push("classProperties", "classPrivateProperties", "classPrivateMethods");
					}
				}));
			},
			"./node_modules/.pnpm/@jridgewell+gen-mapping@0.3.13/node_modules/@jridgewell/gen-mapping/dist/gen-mapping.umd.js": function(e, t, r) {
				var n;
				(function(e, t, r) {
					"use strict";
					var n = Object.create, s = Object.defineProperty, i = Object.getOwnPropertyDescriptor, o = Object.getOwnPropertyNames, a = Object.getPrototypeOf, l = Object.prototype.hasOwnProperty, __commonJS = (e, t) => function() {
						return t || (0, e[o(e)[0]])((t = { exports: {} }).exports, t), t.exports;
					}, __export = (e, t) => {
						for (var r in t) s(e, r, {
							get: t[r],
							enumerable: !0
						});
					}, __copyProps = (e, t, r, n) => {
						if (t && "object" == typeof t || "function" == typeof t) for (let a of o(t)) l.call(e, a) || a === r || s(e, a, {
							get: () => t[a],
							enumerable: !(n = i(t, a)) || n.enumerable
						});
						return e;
					}, __toESM = (e, t, r) => (r = null != e ? n(a(e)) : {}, __copyProps(!t && e && e.__esModule ? r : s(r, "default", {
						value: e,
						enumerable: !0
					}), e)), __toCommonJS = (e) => __copyProps(s({}, "__esModule", { value: !0 }), e), p = __commonJS({ "umd:@jridgewell/sourcemap-codec"(e, r) {
						r.exports = t;
					} }), c = __commonJS({ "umd:@jridgewell/trace-mapping"(e, t) {
						t.exports = r;
					} }), u = {};
					__export(u, {
						GenMapping: () => E,
						addMapping: () => addMapping,
						addSegment: () => addSegment,
						allMappings: () => allMappings,
						fromMap: () => fromMap,
						maybeAddMapping: () => maybeAddMapping,
						maybeAddSegment: () => maybeAddSegment,
						setIgnore: () => setIgnore,
						setSourceContent: () => setSourceContent,
						toDecodedMap: () => toDecodedMap,
						toEncodedMap: () => toEncodedMap
					}), e.exports = __toCommonJS(u);
					var d = class {
						constructor() {
							this._indexes = { __proto__: null }, this.array = [];
						}
					};
					function cast(e) {
						return e;
					}
					function get(e, t) {
						return cast(e)._indexes[t];
					}
					function put(e, t) {
						const r = get(e, t);
						if (void 0 !== r) return r;
						const { array: n, _indexes: s } = cast(e);
						return s[t] = n.push(t) - 1;
					}
					function remove(e, t) {
						const r = get(e, t);
						if (void 0 === r) return;
						const { array: n, _indexes: s } = cast(e);
						for (let e = r + 1; e < n.length; e++) {
							const t = n[e];
							n[e - 1] = t, s[t]--;
						}
						s[t] = void 0, n.pop();
					}
					var h = __toESM(p()), m = __toESM(c()), f = 0, y = 1, b = 2, g = 3, x = 4, v = -1, E = class {
						constructor({ file: e, sourceRoot: t } = {}) {
							this._names = new d(), this._sources = new d(), this._sourcesContent = [], this._mappings = [], this.file = e, this.sourceRoot = t, this._ignoreList = new d();
						}
					};
					function cast2(e) {
						return e;
					}
					function addSegment(e, t, r, n, s, i, o, a) {
						return addSegmentInternal(!1, e, t, r, n, s, i, o, a);
					}
					function addMapping(e, t) {
						return addMappingInternal(!1, e, t);
					}
					var maybeAddSegment = (e, t, r, n, s, i, o, a) => addSegmentInternal(!0, e, t, r, n, s, i, o, a), maybeAddMapping = (e, t) => addMappingInternal(!0, e, t);
					function setSourceContent(e, t, r) {
						const { _sources: n, _sourcesContent: s } = cast2(e);
						s[put(n, t)] = r;
					}
					function setIgnore(e, t, r = !0) {
						const { _sources: n, _sourcesContent: s, _ignoreList: i } = cast2(e), o = put(n, t);
						o === s.length && (s[o] = null), r ? put(i, o) : remove(i, o);
					}
					function toDecodedMap(e) {
						const { _mappings: t, _sources: r, _sourcesContent: n, _names: s, _ignoreList: i } = cast2(e);
						return removeEmptyFinalLines(t), {
							version: 3,
							file: e.file || void 0,
							names: s.array,
							sourceRoot: e.sourceRoot || void 0,
							sources: r.array,
							sourcesContent: n,
							mappings: t,
							ignoreList: i.array
						};
					}
					function toEncodedMap(e) {
						const t = toDecodedMap(e);
						return Object.assign({}, t, { mappings: (0, h.encode)(t.mappings) });
					}
					function fromMap(e) {
						const t = new m.TraceMap(e), r = new E({
							file: t.file,
							sourceRoot: t.sourceRoot
						});
						return putAll(cast2(r)._names, t.names), putAll(cast2(r)._sources, t.sources), cast2(r)._sourcesContent = t.sourcesContent || t.sources.map(() => null), cast2(r)._mappings = (0, m.decodedMappings)(t), t.ignoreList && putAll(cast2(r)._ignoreList, t.ignoreList), r;
					}
					function allMappings(e) {
						const t = [], { _mappings: r, _sources: n, _names: s } = cast2(e);
						for (let e = 0; e < r.length; e++) {
							const i = r[e];
							for (let r = 0; r < i.length; r++) {
								const o = i[r], a = {
									line: e + 1,
									column: o[f]
								};
								let l, p, c;
								1 !== o.length && (l = n.array[o[y]], p = {
									line: o[b] + 1,
									column: o[g]
								}, 5 === o.length && (c = s.array[o[x]])), t.push({
									generated: a,
									source: l,
									original: p,
									name: c
								});
							}
						}
						return t;
					}
					function addSegmentInternal(e, t, r, n, s, i, o, a, l) {
						const { _mappings: p, _sources: c, _sourcesContent: u, _names: d } = cast2(t), h = getIndex(p, r), m = getColumnIndex(h, n);
						if (!s) {
							if (e && skipSourceless(h, m)) return;
							return insert(h, m, [n]);
						}
						assert(i), assert(o);
						const f = put(c, s), y = a ? put(d, a) : v;
						if (f === u.length && (u[f] = null != l ? l : null), !e || !skipSource(h, m, f, i, o, y)) return insert(h, m, a ? [
							n,
							f,
							i,
							o,
							y
						] : [
							n,
							f,
							i,
							o
						]);
					}
					function assert(e) {}
					function getIndex(e, t) {
						for (let r = e.length; r <= t; r++) e[r] = [];
						return e[t];
					}
					function getColumnIndex(e, t) {
						let r = e.length;
						for (let n = r - 1; n >= 0 && !(t >= e[n][f]); r = n--);
						return r;
					}
					function insert(e, t, r) {
						for (let r = e.length; r > t; r--) e[r] = e[r - 1];
						e[t] = r;
					}
					function removeEmptyFinalLines(e) {
						const { length: t } = e;
						let r = t;
						for (let t = r - 1; t >= 0 && !(e[t].length > 0); r = t, t--);
						r < t && (e.length = r);
					}
					function putAll(e, t) {
						for (let r = 0; r < t.length; r++) put(e, t[r]);
					}
					function skipSourceless(e, t) {
						return 0 === t || 1 === e[t - 1].length;
					}
					function skipSource(e, t, r, n, s, i) {
						if (0 === t) return !1;
						const o = e[t - 1];
						return 1 !== o.length && r === o[y] && n === o[b] && s === o[g] && i === (5 === o.length ? o[x] : v);
					}
					function addMappingInternal(e, t, r) {
						const { generated: n, source: s, original: i, name: o, content: a } = r;
						return s ? (assert(i), addSegmentInternal(e, t, n.line - 1, n.column, s, i.line - 1, i.column, o, a)) : addSegmentInternal(e, t, n.line - 1, n.column, null, null, null, null, null);
					}
				})(e = r.nmd(e), r("./node_modules/.pnpm/@jridgewell+sourcemap-codec@1.5.5/node_modules/@jridgewell/sourcemap-codec/dist/sourcemap-codec.umd.js"), r("./node_modules/.pnpm/@jridgewell+trace-mapping@0.3.31/node_modules/@jridgewell/trace-mapping/dist/trace-mapping.umd.js")), e.exports = "default" in (n = e).exports ? n.exports.default : n.exports;
			},
			"./node_modules/.pnpm/@jridgewell+remapping@2.3.5/node_modules/@jridgewell/remapping/dist/remapping.umd.js": function(e, t, r) {
				var n;
				(function(e, t, r) {
					"use strict";
					var n = Object.create, s = Object.defineProperty, i = Object.getOwnPropertyDescriptor, o = Object.getOwnPropertyNames, a = Object.getPrototypeOf, l = Object.prototype.hasOwnProperty, __commonJS = (e, t) => function() {
						return t || (0, e[o(e)[0]])((t = { exports: {} }).exports, t), t.exports;
					}, __export = (e, t) => {
						for (var r in t) s(e, r, {
							get: t[r],
							enumerable: !0
						});
					}, __copyProps = (e, t, r, n) => {
						if (t && "object" == typeof t || "function" == typeof t) for (let a of o(t)) l.call(e, a) || a === r || s(e, a, {
							get: () => t[a],
							enumerable: !(n = i(t, a)) || n.enumerable
						});
						return e;
					}, __toESM = (e, t, r) => (r = null != e ? n(a(e)) : {}, __copyProps(!t && e && e.__esModule ? r : s(r, "default", {
						value: e,
						enumerable: !0
					}), e)), __toCommonJS = (e) => __copyProps(s({}, "__esModule", { value: !0 }), e), p = __commonJS({ "umd:@jridgewell/trace-mapping"(e, t) {
						t.exports = r;
					} }), c = __commonJS({ "umd:@jridgewell/gen-mapping"(e, r) {
						r.exports = t;
					} }), u = {};
					__export(u, { default: () => remapping }), e.exports = __toCommonJS(u);
					var d = __toESM(p()), h = __toESM(c()), m = __toESM(p()), f = SegmentObject("", -1, -1, "", null, !1), y = [];
					function SegmentObject(e, t, r, n, s, i) {
						return {
							source: e,
							line: t,
							column: r,
							name: n,
							content: s,
							ignore: i
						};
					}
					function Source(e, t, r, n, s) {
						return {
							map: e,
							sources: t,
							source: r,
							content: n,
							ignore: s
						};
					}
					function MapSource(e, t) {
						return Source(e, t, "", null, !1);
					}
					function OriginalSource(e, t, r) {
						return Source(null, y, e, t, r);
					}
					function traceMappings(e) {
						const t = new h.GenMapping({ file: e.map.file }), { sources: r, map: n } = e, s = n.names, i = (0, m.decodedMappings)(n);
						for (let e = 0; e < i.length; e++) {
							const n = i[e];
							for (let i = 0; i < n.length; i++) {
								const o = n[i], a = o[0];
								let l = f;
								if (1 !== o.length && (l = originalPositionFor(r[o[1]], o[2], o[3], 5 === o.length ? s[o[4]] : ""), null == l)) continue;
								const { column: p, line: c, name: u, content: d, source: m, ignore: y } = l;
								(0, h.maybeAddSegment)(t, e, a, m, c, p, u), m && null != d && (0, h.setSourceContent)(t, m, d), y && (0, h.setIgnore)(t, m, !0);
							}
						}
						return t;
					}
					function originalPositionFor(e, t, r, n) {
						if (!e.map) return SegmentObject(e.source, t, r, n, e.content, e.ignore);
						const s = (0, m.traceSegment)(e.map, t, r);
						return null == s ? null : 1 === s.length ? f : originalPositionFor(e.sources[s[1]], s[2], s[3], 5 === s.length ? e.map.names[s[4]] : n);
					}
					function asArray(e) {
						return Array.isArray(e) ? e : [e];
					}
					function buildSourceMapTree(e, t) {
						const r = asArray(e).map((e) => new d.TraceMap(e, "")), n = r.pop();
						for (let e = 0; e < r.length; e++) if (r[e].sources.length > 1) throw new Error(`Transformation map ${e} must have exactly one source file.\nDid you specify these with the most recent transformation maps first?`);
						let s = build(n, t, "", 0);
						for (let e = r.length - 1; e >= 0; e--) s = MapSource(r[e], [s]);
						return s;
					}
					function build(e, t, r, n) {
						const { resolvedSources: s, sourcesContent: i, ignoreList: o } = e, a = n + 1;
						return MapSource(e, s.map((e, n) => {
							const s = {
								importer: r,
								depth: a,
								source: e || "",
								content: void 0,
								ignore: void 0
							}, l = t(s.source, s), { source: p, content: c, ignore: u } = s;
							return l ? build(new d.TraceMap(l, p), t, p, a) : OriginalSource(p, void 0 !== c ? c : i ? i[n] : null, void 0 !== u ? u : !!o && o.includes(n));
						}));
					}
					var b = __toESM(c()), g = class {
						constructor(e, t) {
							const r = t.decodedMappings ? (0, b.toDecodedMap)(e) : (0, b.toEncodedMap)(e);
							this.version = r.version, this.file = r.file, this.mappings = r.mappings, this.names = r.names, this.ignoreList = r.ignoreList, this.sourceRoot = r.sourceRoot, this.sources = r.sources, t.excludeContent || (this.sourcesContent = r.sourcesContent);
						}
						toString() {
							return JSON.stringify(this);
						}
					};
					function remapping(e, t, r) {
						const n = "object" == typeof r ? r : {
							excludeContent: !!r,
							decodedMappings: !1
						};
						return new g(traceMappings(buildSourceMapTree(e, t)), n);
					}
				})(e = r.nmd(e), r("./node_modules/.pnpm/@jridgewell+gen-mapping@0.3.13/node_modules/@jridgewell/gen-mapping/dist/gen-mapping.umd.js"), r("./node_modules/.pnpm/@jridgewell+trace-mapping@0.3.31/node_modules/@jridgewell/trace-mapping/dist/trace-mapping.umd.js")), e.exports = "default" in (n = e).exports ? n.exports.default : n.exports;
			},
			"./node_modules/.pnpm/@jridgewell+resolve-uri@3.1.2/node_modules/@jridgewell/resolve-uri/dist/resolve-uri.umd.js": function(e) {
				e.exports = function() {
					"use strict";
					const e = /^[\w+.-]+:\/\//, t = /^([\w+.-]+:)\/\/([^@/#?]*@)?([^:/#?]*)(:\d+)?(\/[^#?]*)?(\?[^#]*)?(#.*)?/, r = /^file:(?:\/\/((?![a-z]:)[^/#?]*)?)?(\/?[^#?]*)(\?[^#]*)?(#.*)?/i;
					function isAbsoluteUrl(t) {
						return e.test(t);
					}
					function isSchemeRelativeUrl(e) {
						return e.startsWith("//");
					}
					function isAbsolutePath(e) {
						return e.startsWith("/");
					}
					function isFileUrl(e) {
						return e.startsWith("file:");
					}
					function isRelative(e) {
						return /^[.?#]/.test(e);
					}
					function parseAbsoluteUrl(e) {
						const r = t.exec(e);
						return makeUrl(r[1], r[2] || "", r[3], r[4] || "", r[5] || "/", r[6] || "", r[7] || "");
					}
					function parseFileUrl(e) {
						const t = r.exec(e), n = t[2];
						return makeUrl("file:", "", t[1] || "", "", isAbsolutePath(n) ? n : "/" + n, t[3] || "", t[4] || "");
					}
					function makeUrl(e, t, r, n, s, i, o) {
						return {
							scheme: e,
							user: t,
							host: r,
							port: n,
							path: s,
							query: i,
							hash: o,
							type: 7
						};
					}
					function parseUrl(e) {
						if (isSchemeRelativeUrl(e)) {
							const t = parseAbsoluteUrl("http:" + e);
							return t.scheme = "", t.type = 6, t;
						}
						if (isAbsolutePath(e)) {
							const t = parseAbsoluteUrl("http://foo.com" + e);
							return t.scheme = "", t.host = "", t.type = 5, t;
						}
						if (isFileUrl(e)) return parseFileUrl(e);
						if (isAbsoluteUrl(e)) return parseAbsoluteUrl(e);
						const t = parseAbsoluteUrl("http://foo.com/" + e);
						return t.scheme = "", t.host = "", t.type = e ? e.startsWith("?") ? 3 : e.startsWith("#") ? 2 : 4 : 1, t;
					}
					function stripPathFilename(e) {
						if (e.endsWith("/..")) return e;
						const t = e.lastIndexOf("/");
						return e.slice(0, t + 1);
					}
					function mergePaths(e, t) {
						normalizePath(t, t.type), "/" === e.path ? e.path = t.path : e.path = stripPathFilename(t.path) + e.path;
					}
					function normalizePath(e, t) {
						const r = t <= 4, n = e.path.split("/");
						let s = 1, i = 0, o = !1;
						for (let e = 1; e < n.length; e++) {
							const t = n[e];
							t ? (o = !1, "." !== t && (".." !== t ? (n[s++] = t, i++) : i ? (o = !0, i--, s--) : r && (n[s++] = t))) : o = !0;
						}
						let a = "";
						for (let e = 1; e < s; e++) a += "/" + n[e];
						(!a || o && !a.endsWith("/..")) && (a += "/"), e.path = a;
					}
					function resolve(e, t) {
						if (!e && !t) return "";
						const r = parseUrl(e);
						let n = r.type;
						if (t && 7 !== n) {
							const e = parseUrl(t), s = e.type;
							switch (n) {
								case 1: r.hash = e.hash;
								case 2: r.query = e.query;
								case 3:
								case 4: mergePaths(r, e);
								case 5: r.user = e.user, r.host = e.host, r.port = e.port;
								case 6: r.scheme = e.scheme;
							}
							s > n && (n = s);
						}
						normalizePath(r, n);
						const s = r.query + r.hash;
						switch (n) {
							case 2:
							case 3: return s;
							case 4: {
								const n = r.path.slice(1);
								return n ? isRelative(t || e) && !isRelative(n) ? "./" + n + s : n + s : s || ".";
							}
							case 5: return r.path + s;
							default: return r.scheme + "//" + r.user + r.host + r.port + r.path + s;
						}
					}
					return resolve;
				}();
			},
			"./node_modules/.pnpm/@jridgewell+sourcemap-codec@1.5.5/node_modules/@jridgewell/sourcemap-codec/dist/sourcemap-codec.umd.js": function(e, t, r) {
				var n;
				(function(e) {
					"use strict";
					var t = Object.defineProperty, r = Object.getOwnPropertyDescriptor, n = Object.getOwnPropertyNames, s = Object.prototype.hasOwnProperty, __copyProps = (e, i, o, a) => {
						if (i && "object" == typeof i || "function" == typeof i) for (let l of n(i)) s.call(e, l) || l === o || t(e, l, {
							get: () => i[l],
							enumerable: !(a = r(i, l)) || a.enumerable
						});
						return e;
					}, __toCommonJS = (e) => __copyProps(t({}, "__esModule", { value: !0 }), e), i = {};
					((e, r) => {
						for (var n in r) t(e, n, {
							get: r[n],
							enumerable: !0
						});
					})(i, {
						decode: () => decode,
						decodeGeneratedRanges: () => decodeGeneratedRanges,
						decodeOriginalScopes: () => decodeOriginalScopes,
						encode: () => encode,
						encodeGeneratedRanges: () => encodeGeneratedRanges,
						encodeOriginalScopes: () => encodeOriginalScopes
					}), e.exports = __toCommonJS(i);
					var o = ",".charCodeAt(0), a = ";".charCodeAt(0), l = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/", p = new Uint8Array(64), c = new Uint8Array(128);
					for (let e = 0; e < l.length; e++) {
						const t = l.charCodeAt(e);
						p[e] = t, c[t] = e;
					}
					function decodeInteger(e, t) {
						let r = 0, n = 0, s = 0;
						do
							s = c[e.next()], r |= (31 & s) << n, n += 5;
						while (32 & s);
						const i = 1 & r;
						return r >>>= 1, i && (r = -2147483648 | -r), t + r;
					}
					function encodeInteger(e, t, r) {
						let n = t - r;
						n = n < 0 ? -n << 1 | 1 : n << 1;
						do {
							let t = 31 & n;
							n >>>= 5, n > 0 && (t |= 32), e.write(p[t]);
						} while (n > 0);
						return t;
					}
					function hasMoreVlq(e, t) {
						return !(e.pos >= t) && e.peek() !== o;
					}
					var u = 16384, d = "undefined" != typeof TextDecoder ? new TextDecoder() : "undefined" != typeof Buffer ? { decode: (e) => Buffer.from(e.buffer, e.byteOffset, e.byteLength).toString() } : { decode(e) {
						let t = "";
						for (let r = 0; r < e.length; r++) t += String.fromCharCode(e[r]);
						return t;
					} }, h = class {
						constructor() {
							this.pos = 0, this.out = "", this.buffer = new Uint8Array(u);
						}
						write(e) {
							const { buffer: t } = this;
							t[this.pos++] = e, this.pos === u && (this.out += d.decode(t), this.pos = 0);
						}
						flush() {
							const { buffer: e, out: t, pos: r } = this;
							return r > 0 ? t + d.decode(e.subarray(0, r)) : t;
						}
					}, m = class {
						constructor(e) {
							this.pos = 0, this.buffer = e;
						}
						next() {
							return this.buffer.charCodeAt(this.pos++);
						}
						peek() {
							return this.buffer.charCodeAt(this.pos);
						}
						indexOf(e) {
							const { buffer: t, pos: r } = this, n = t.indexOf(e, r);
							return -1 === n ? t.length : n;
						}
					}, f = [];
					function decodeOriginalScopes(e) {
						const { length: t } = e, r = new m(e), n = [], s = [];
						let i = 0;
						for (; r.pos < t; r.pos++) {
							i = decodeInteger(r, i);
							const e = decodeInteger(r, 0);
							if (!hasMoreVlq(r, t)) {
								const t = s.pop();
								t[2] = i, t[3] = e;
								continue;
							}
							const o = decodeInteger(r, 0), a = 1 & decodeInteger(r, 0) ? [
								i,
								e,
								0,
								0,
								o,
								decodeInteger(r, 0)
							] : [
								i,
								e,
								0,
								0,
								o
							];
							let l = f;
							if (hasMoreVlq(r, t)) {
								l = [];
								do {
									const e = decodeInteger(r, 0);
									l.push(e);
								} while (hasMoreVlq(r, t));
							}
							a.vars = l, n.push(a), s.push(a);
						}
						return n;
					}
					function encodeOriginalScopes(e) {
						const t = new h();
						for (let r = 0; r < e.length;) r = _encodeOriginalScopes(e, r, t, [0]);
						return t.flush();
					}
					function _encodeOriginalScopes(e, t, r, n) {
						const s = e[t], { 0: i, 1: a, 2: l, 3: p, 4: c, vars: u } = s;
						t > 0 && r.write(o), n[0] = encodeInteger(r, i, n[0]), encodeInteger(r, a, 0), encodeInteger(r, c, 0), encodeInteger(r, 6 === s.length ? 1 : 0, 0), 6 === s.length && encodeInteger(r, s[5], 0);
						for (const e of u) encodeInteger(r, e, 0);
						for (t++; t < e.length;) {
							const { 0: i, 1: o } = e[t];
							if (i > l || i === l && o >= p) break;
							t = _encodeOriginalScopes(e, t, r, n);
						}
						return r.write(o), n[0] = encodeInteger(r, l, n[0]), encodeInteger(r, p, 0), t;
					}
					function decodeGeneratedRanges(e) {
						const { length: t } = e, r = new m(e), n = [], s = [];
						let i = 0, o = 0, a = 0, l = 0, p = 0, c = 0, u = 0, d = 0;
						do {
							const e = r.indexOf(";");
							let t = 0;
							for (; r.pos < e; r.pos++) {
								if (t = decodeInteger(r, t), !hasMoreVlq(r, e)) {
									const e = s.pop();
									e[2] = i, e[3] = t;
									continue;
								}
								const h = decodeInteger(r, 0), m = 2 & h, y = 4 & h;
								let b, g = null, x = f;
								if (1 & h) {
									const e = decodeInteger(r, o);
									a = decodeInteger(r, o === e ? a : 0), o = e, b = [
										i,
										t,
										0,
										0,
										e,
										a
									];
								} else b = [
									i,
									t,
									0,
									0
								];
								if (b.isScope = !!y, m) {
									const e = l, t = p;
									l = decodeInteger(r, l);
									const n = e === l;
									p = decodeInteger(r, n ? p : 0), c = decodeInteger(r, n && t === p ? c : 0), g = [
										l,
										p,
										c
									];
								}
								if (b.callsite = g, hasMoreVlq(r, e)) {
									x = [];
									do {
										u = i, d = t;
										const e = decodeInteger(r, 0);
										let n;
										if (e < -1) {
											n = [[decodeInteger(r, 0)]];
											for (let t = -1; t > e; t--) {
												const e = u;
												u = decodeInteger(r, u), d = decodeInteger(r, u === e ? d : 0);
												const t = decodeInteger(r, 0);
												n.push([
													t,
													u,
													d
												]);
											}
										} else n = [[e]];
										x.push(n);
									} while (hasMoreVlq(r, e));
								}
								b.bindings = x, n.push(b), s.push(b);
							}
							i++, r.pos = e + 1;
						} while (r.pos < t);
						return n;
					}
					function encodeGeneratedRanges(e) {
						if (0 === e.length) return "";
						const t = new h();
						for (let r = 0; r < e.length;) r = _encodeGeneratedRanges(e, r, t, [
							0,
							0,
							0,
							0,
							0,
							0,
							0
						]);
						return t.flush();
					}
					function _encodeGeneratedRanges(e, t, r, n) {
						const s = e[t], { 0: i, 1: a, 2: l, 3: p, isScope: c, callsite: u, bindings: d } = s;
						if (n[0] < i ? (catchupLine(r, n[0], i), n[0] = i, n[1] = 0) : t > 0 && r.write(o), n[1] = encodeInteger(r, s[1], n[1]), encodeInteger(r, (6 === s.length ? 1 : 0) | (u ? 2 : 0) | (c ? 4 : 0), 0), 6 === s.length) {
							const { 4: e, 5: t } = s;
							e !== n[2] && (n[3] = 0), n[2] = encodeInteger(r, e, n[2]), n[3] = encodeInteger(r, t, n[3]);
						}
						if (u) {
							const { 0: e, 1: t, 2: i } = s.callsite;
							e !== n[4] ? (n[5] = 0, n[6] = 0) : t !== n[5] && (n[6] = 0), n[4] = encodeInteger(r, e, n[4]), n[5] = encodeInteger(r, t, n[5]), n[6] = encodeInteger(r, i, n[6]);
						}
						if (d) for (const e of d) {
							e.length > 1 && encodeInteger(r, -e.length, 0), encodeInteger(r, e[0][0], 0);
							let t = i, n = a;
							for (let s = 1; s < e.length; s++) {
								const i = e[s];
								t = encodeInteger(r, i[1], t), n = encodeInteger(r, i[2], n), encodeInteger(r, i[0], 0);
							}
						}
						for (t++; t < e.length;) {
							const { 0: i, 1: o } = e[t];
							if (i > l || i === l && o >= p) break;
							t = _encodeGeneratedRanges(e, t, r, n);
						}
						return n[0] < l ? (catchupLine(r, n[0], l), n[0] = l, n[1] = 0) : r.write(o), n[1] = encodeInteger(r, p, n[1]), t;
					}
					function catchupLine(e, t, r) {
						do
							e.write(a);
						while (++t < r);
					}
					function decode(e) {
						const { length: t } = e, r = new m(e), n = [];
						let s = 0, i = 0, o = 0, a = 0, l = 0;
						do {
							const e = r.indexOf(";"), t = [];
							let p = !0, c = 0;
							for (s = 0; r.pos < e;) {
								let n;
								s = decodeInteger(r, s), s < c && (p = !1), c = s, hasMoreVlq(r, e) ? (i = decodeInteger(r, i), o = decodeInteger(r, o), a = decodeInteger(r, a), hasMoreVlq(r, e) ? (l = decodeInteger(r, l), n = [
									s,
									i,
									o,
									a,
									l
								]) : n = [
									s,
									i,
									o,
									a
								]) : n = [s], t.push(n), r.pos++;
							}
							p || sort(t), n.push(t), r.pos = e + 1;
						} while (r.pos <= t);
						return n;
					}
					function sort(e) {
						e.sort(sortComparator);
					}
					function sortComparator(e, t) {
						return e[0] - t[0];
					}
					function encode(e) {
						const t = new h();
						let r = 0, n = 0, s = 0, i = 0;
						for (let l = 0; l < e.length; l++) {
							const p = e[l];
							if (l > 0 && t.write(a), 0 === p.length) continue;
							let c = 0;
							for (let e = 0; e < p.length; e++) {
								const a = p[e];
								e > 0 && t.write(o), c = encodeInteger(t, a[0], c), 1 !== a.length && (r = encodeInteger(t, a[1], r), n = encodeInteger(t, a[2], n), s = encodeInteger(t, a[3], s), 4 !== a.length && (i = encodeInteger(t, a[4], i)));
							}
						}
						return t.flush();
					}
				})(e = r.nmd(e)), e.exports = "default" in (n = e).exports ? n.exports.default : n.exports;
			},
			"./node_modules/.pnpm/@jridgewell+trace-mapping@0.3.31/node_modules/@jridgewell/trace-mapping/dist/trace-mapping.umd.js": function(e, t, r) {
				var n;
				(function(e, t, r) {
					"use strict";
					var n = Object.create, s = Object.defineProperty, i = Object.getOwnPropertyDescriptor, o = Object.getOwnPropertyNames, a = Object.getPrototypeOf, l = Object.prototype.hasOwnProperty, __commonJS = (e, t) => function() {
						return t || (0, e[o(e)[0]])((t = { exports: {} }).exports, t), t.exports;
					}, __export = (e, t) => {
						for (var r in t) s(e, r, {
							get: t[r],
							enumerable: !0
						});
					}, __copyProps = (e, t, r, n) => {
						if (t && "object" == typeof t || "function" == typeof t) for (let a of o(t)) l.call(e, a) || a === r || s(e, a, {
							get: () => t[a],
							enumerable: !(n = i(t, a)) || n.enumerable
						});
						return e;
					}, __toESM = (e, t, r) => (r = null != e ? n(a(e)) : {}, __copyProps(!t && e && e.__esModule ? r : s(r, "default", {
						value: e,
						enumerable: !0
					}), e)), __toCommonJS = (e) => __copyProps(s({}, "__esModule", { value: !0 }), e), p = __commonJS({ "umd:@jridgewell/sourcemap-codec"(e, t) {
						t.exports = r;
					} }), c = __commonJS({ "umd:@jridgewell/resolve-uri"(e, r) {
						r.exports = t;
					} }), u = {};
					__export(u, {
						AnyMap: () => FlattenMap,
						FlattenMap: () => FlattenMap,
						GREATEST_LOWER_BOUND: () => _,
						LEAST_UPPER_BOUND: () => P,
						TraceMap: () => A,
						allGeneratedPositionsFor: () => allGeneratedPositionsFor,
						decodedMap: () => decodedMap,
						decodedMappings: () => decodedMappings,
						eachMapping: () => eachMapping,
						encodedMap: () => encodedMap,
						encodedMappings: () => encodedMappings,
						generatedPositionFor: () => generatedPositionFor,
						isIgnored: () => isIgnored,
						originalPositionFor: () => originalPositionFor,
						presortedDecodedMap: () => presortedDecodedMap,
						sourceContentFor: () => sourceContentFor,
						traceSegment: () => traceSegment
					}), e.exports = __toCommonJS(u);
					var d = __toESM(p()), h = __toESM(c());
					function stripFilename(e) {
						if (!e) return "";
						const t = e.lastIndexOf("/");
						return e.slice(0, t + 1);
					}
					function resolver(e, t) {
						const r = stripFilename(e), n = t ? t + "/" : "";
						return (e) => (0, h.default)(n + (e || ""), r);
					}
					var m = 0, f = 1, y = 2, b = 3, g = 4, x = 1, v = 2;
					function maybeSort(e, t) {
						const r = nextUnsortedSegmentLine(e, 0);
						if (r === e.length) return e;
						t || (e = e.slice());
						for (let n = r; n < e.length; n = nextUnsortedSegmentLine(e, n + 1)) e[n] = sortSegments(e[n], t);
						return e;
					}
					function nextUnsortedSegmentLine(e, t) {
						for (let r = t; r < e.length; r++) if (!isSorted(e[r])) return r;
						return e.length;
					}
					function isSorted(e) {
						for (let t = 1; t < e.length; t++) if (e[t][m] < e[t - 1][m]) return !1;
						return !0;
					}
					function sortSegments(e, t) {
						return t || (e = e.slice()), e.sort(sortComparator);
					}
					function sortComparator(e, t) {
						return e[m] - t[m];
					}
					function buildBySources(e, t) {
						const r = t.map(() => []);
						for (let t = 0; t < e.length; t++) {
							const n = e[t];
							for (let e = 0; e < n.length; e++) {
								const s = n[e];
								if (1 === s.length) continue;
								const i = s[f], o = s[y], a = s[b], l = r[i];
								(l[o] || (l[o] = [])).push([
									a,
									t,
									s[m]
								]);
							}
						}
						for (let e = 0; e < r.length; e++) {
							const t = r[e];
							for (let e = 0; e < t.length; e++) {
								const r = t[e];
								r && r.sort(sortComparator);
							}
						}
						return r;
					}
					var E = !1;
					function binarySearch(e, t, r, n) {
						for (; r <= n;) {
							const s = r + (n - r >> 1), i = e[s][m] - t;
							if (0 === i) return E = !0, s;
							i < 0 ? r = s + 1 : n = s - 1;
						}
						return E = !1, r - 1;
					}
					function upperBound(e, t, r) {
						for (let n = r + 1; n < e.length && e[n][m] === t; r = n++);
						return r;
					}
					function lowerBound(e, t, r) {
						for (let n = r - 1; n >= 0 && e[n][m] === t; r = n--);
						return r;
					}
					function memoizedState() {
						return {
							lastKey: -1,
							lastNeedle: -1,
							lastIndex: -1
						};
					}
					function memoizedBinarySearch(e, t, r, n) {
						const { lastKey: s, lastNeedle: i, lastIndex: o } = r;
						let a = 0, l = e.length - 1;
						if (n === s) {
							if (t === i) return E = -1 !== o && e[o][m] === t, o;
							t >= i ? a = -1 === o ? 0 : o : l = o;
						}
						return r.lastKey = n, r.lastNeedle = t, r.lastIndex = binarySearch(e, t, a, l);
					}
					function parse(e) {
						return "string" == typeof e ? JSON.parse(e) : e;
					}
					var FlattenMap = function(e, t) {
						const r = parse(e);
						if (!("sections" in r)) return new A(r, t);
						const n = [], s = [], i = [], o = [], a = [];
						return recurse(r, t, n, s, i, o, a, 0, 0, Infinity, Infinity), presortedDecodedMap({
							version: 3,
							file: r.file,
							names: o,
							sources: s,
							sourcesContent: i,
							mappings: n,
							ignoreList: a
						});
					};
					function recurse(e, t, r, n, s, i, o, a, l, p, c) {
						const { sections: u } = e;
						for (let e = 0; e < u.length; e++) {
							const { map: d, offset: h } = u[e];
							let m = p, f = c;
							if (e + 1 < u.length) {
								const t = u[e + 1].offset;
								m = Math.min(p, a + t.line), m === p ? f = Math.min(c, l + t.column) : m < p && (f = l + t.column);
							}
							addSection(d, t, r, n, s, i, o, a + h.line, l + h.column, m, f);
						}
					}
					function addSection(e, t, r, n, s, i, o, a, l, p, c) {
						const u = parse(e);
						if ("sections" in u) return recurse(...arguments);
						const d = new A(u, t), h = n.length, x = i.length, v = decodedMappings(d), { resolvedSources: E, sourcesContent: T, ignoreList: S } = d;
						if (append(n, E), append(i, d.names), T) append(s, T);
						else for (let e = 0; e < E.length; e++) s.push(null);
						if (S) for (let e = 0; e < S.length; e++) o.push(S[e] + h);
						for (let e = 0; e < v.length; e++) {
							const t = a + e;
							if (t > p) return;
							const n = getLine(r, t), s = 0 === e ? l : 0, i = v[e];
							for (let e = 0; e < i.length; e++) {
								const r = i[e], o = s + r[m];
								if (t === p && o >= c) return;
								if (1 === r.length) {
									n.push([o]);
									continue;
								}
								const a = h + r[f], l = r[y], u = r[b];
								n.push(4 === r.length ? [
									o,
									a,
									l,
									u
								] : [
									o,
									a,
									l,
									u,
									x + r[g]
								]);
							}
						}
					}
					function append(e, t) {
						for (let r = 0; r < t.length; r++) e.push(t[r]);
					}
					function getLine(e, t) {
						for (let r = e.length; r <= t; r++) e[r] = [];
						return e[t];
					}
					var T = "`line` must be greater than 0 (lines start at line 1)", S = "`column` must be greater than or equal to 0 (columns start at column 0)", P = -1, _ = 1, A = class {
						constructor(e, t) {
							const r = "string" == typeof e;
							if (!r && e._decodedMemo) return e;
							const n = parse(e), { version: s, file: i, names: o, sourceRoot: a, sources: l, sourcesContent: p } = n;
							this.version = s, this.file = i, this.names = o || [], this.sourceRoot = a, this.sources = l, this.sourcesContent = p, this.ignoreList = n.ignoreList || n.x_google_ignoreList || void 0;
							const c = resolver(t, a);
							this.resolvedSources = l.map(c);
							const { mappings: u } = n;
							if ("string" == typeof u) this._encoded = u, this._decoded = void 0;
							else {
								if (!Array.isArray(u)) throw n.sections ? /* @__PURE__ */ new Error("TraceMap passed sectioned source map, please use FlattenMap export instead") : /* @__PURE__ */ new Error(`invalid source map: ${JSON.stringify(n)}`);
								this._encoded = void 0, this._decoded = maybeSort(u, r);
							}
							this._decodedMemo = memoizedState(), this._bySources = void 0, this._bySourceMemos = void 0;
						}
					};
					function cast(e) {
						return e;
					}
					function encodedMappings(e) {
						var t, r;
						return null != (r = (t = cast(e))._encoded) ? r : t._encoded = (0, d.encode)(cast(e)._decoded);
					}
					function decodedMappings(e) {
						var t;
						return (t = cast(e))._decoded || (t._decoded = (0, d.decode)(cast(e)._encoded));
					}
					function traceSegment(e, t, r) {
						const n = decodedMappings(e);
						if (t >= n.length) return null;
						const s = n[t], i = traceSegmentInternal(s, cast(e)._decodedMemo, t, r, _);
						return -1 === i ? null : s[i];
					}
					function originalPositionFor(e, t) {
						let { line: r, column: n, bias: s } = t;
						if (r--, r < 0) throw new Error(T);
						if (n < 0) throw new Error(S);
						const i = decodedMappings(e);
						if (r >= i.length) return OMapping(null, null, null, null);
						const o = i[r], a = traceSegmentInternal(o, cast(e)._decodedMemo, r, n, s || _);
						if (-1 === a) return OMapping(null, null, null, null);
						const l = o[a];
						if (1 === l.length) return OMapping(null, null, null, null);
						const { names: p, resolvedSources: c } = e;
						return OMapping(c[l[f]], l[y] + 1, l[b], 5 === l.length ? p[l[g]] : null);
					}
					function generatedPositionFor(e, t) {
						const { source: r, line: n, column: s, bias: i } = t;
						return generatedPosition(e, r, n, s, i || _, !1);
					}
					function allGeneratedPositionsFor(e, t) {
						const { source: r, line: n, column: s, bias: i } = t;
						return generatedPosition(e, r, n, s, i || P, !0);
					}
					function eachMapping(e, t) {
						const r = decodedMappings(e), { names: n, resolvedSources: s } = e;
						for (let e = 0; e < r.length; e++) {
							const i = r[e];
							for (let r = 0; r < i.length; r++) {
								const o = i[r], a = e + 1, l = o[0];
								let p = null, c = null, u = null, d = null;
								1 !== o.length && (p = s[o[1]], c = o[2] + 1, u = o[3]), 5 === o.length && (d = n[o[4]]), t({
									generatedLine: a,
									generatedColumn: l,
									source: p,
									originalLine: c,
									originalColumn: u,
									name: d
								});
							}
						}
					}
					function sourceIndex(e, t) {
						const { sources: r, resolvedSources: n } = e;
						let s = r.indexOf(t);
						return -1 === s && (s = n.indexOf(t)), s;
					}
					function sourceContentFor(e, t) {
						const { sourcesContent: r } = e;
						if (null == r) return null;
						const n = sourceIndex(e, t);
						return -1 === n ? null : r[n];
					}
					function isIgnored(e, t) {
						const { ignoreList: r } = e;
						if (null == r) return !1;
						const n = sourceIndex(e, t);
						return -1 !== n && r.includes(n);
					}
					function presortedDecodedMap(e, t) {
						const r = new A(clone(e, []), t);
						return cast(r)._decoded = e.mappings, r;
					}
					function decodedMap(e) {
						return clone(e, decodedMappings(e));
					}
					function encodedMap(e) {
						return clone(e, encodedMappings(e));
					}
					function clone(e, t) {
						return {
							version: e.version,
							file: e.file,
							names: e.names,
							sourceRoot: e.sourceRoot,
							sources: e.sources,
							sourcesContent: e.sourcesContent,
							mappings: t,
							ignoreList: e.ignoreList || e.x_google_ignoreList
						};
					}
					function OMapping(e, t, r, n) {
						return {
							source: e,
							line: t,
							column: r,
							name: n
						};
					}
					function GMapping(e, t) {
						return {
							line: e,
							column: t
						};
					}
					function traceSegmentInternal(e, t, r, n, s) {
						let i = memoizedBinarySearch(e, n, t, r);
						return E ? i = (s === P ? upperBound : lowerBound)(e, n, i) : s === P && i++, -1 === i || i === e.length ? -1 : i;
					}
					function sliceGeneratedPositions(e, t, r, n, s) {
						let i = traceSegmentInternal(e, t, r, n, _);
						if (E || s !== P || i++, -1 === i || i === e.length) return [];
						const o = E ? n : e[i][m];
						E || (i = lowerBound(e, o, i));
						const a = upperBound(e, o, i), l = [];
						for (; i <= a; i++) {
							const t = e[i];
							l.push(GMapping(t[x] + 1, t[v]));
						}
						return l;
					}
					function generatedPosition(e, t, r, n, s, i) {
						var o, a;
						if (--r < 0) throw new Error(T);
						if (n < 0) throw new Error(S);
						const { sources: l, resolvedSources: p } = e;
						let c = l.indexOf(t);
						if (-1 === c && (c = p.indexOf(t)), -1 === c) return i ? [] : GMapping(null, null);
						const u = (o = cast(e))._bySourceMemos || (o._bySourceMemos = l.map(memoizedState)), d = ((a = cast(e))._bySources || (a._bySources = buildBySources(decodedMappings(e), u)))[c][r];
						if (null == d) return i ? [] : GMapping(null, null);
						const h = u[c];
						if (i) return sliceGeneratedPositions(d, h, r, n, s);
						const m = traceSegmentInternal(d, h, r, n, s);
						if (-1 === m) return GMapping(null, null);
						const f = d[m];
						return GMapping(f[x] + 1, f[v]);
					}
				})(e = r.nmd(e), r("./node_modules/.pnpm/@jridgewell+resolve-uri@3.1.2/node_modules/@jridgewell/resolve-uri/dist/resolve-uri.umd.js"), r("./node_modules/.pnpm/@jridgewell+sourcemap-codec@1.5.5/node_modules/@jridgewell/sourcemap-codec/dist/sourcemap-codec.umd.js")), e.exports = "default" in (n = e).exports ? n.exports.default : n.exports;
			},
			"./node_modules/.pnpm/babel-plugin-parameter-decorator@1.0.16/node_modules/babel-plugin-parameter-decorator/lib/index.js": function(e, t, r) {
				"use strict";
				var n = r("path");
				function isInType(e) {
					switch (e.parent.type) {
						case "TSTypeReference":
						case "TSQualifiedName":
						case "TSExpressionWithTypeArguments":
						case "TSTypeQuery": return !0;
						default: return !1;
					}
				}
				e.exports = function(e) {
					var t = e.types, decoratorExpressionForConstructor = function(e, r) {
						return function(n) {
							var s = t.callExpression(e.expression, [
								t.Identifier(n),
								t.Identifier("undefined"),
								t.NumericLiteral(r.key)
							]), i = t.logicalExpression("||", s, t.Identifier(n)), o = t.assignmentExpression("=", t.Identifier(n), i);
							return t.expressionStatement(o);
						};
					}, decoratorExpressionForMethod = function(e, r) {
						return function(n, s) {
							var i = t.callExpression(e.expression, [
								t.Identifier("".concat(n, ".prototype")),
								t.StringLiteral(s),
								t.NumericLiteral(r.key)
							]);
							return t.expressionStatement(i);
						};
					};
					return { visitor: {
						Program: function(e, t) {
							var r = (0, n.extname)(t.file.opts.filename);
							".ts" !== r && ".tsx" !== r || function() {
								var t = Object.create(null);
								e.node.body.filter(function(e) {
									var t = e.type, r = e.declaration;
									switch (t) {
										case "ClassDeclaration": return !0;
										case "ExportNamedDeclaration":
										case "ExportDefaultDeclaration": return r && "ClassDeclaration" === r.type;
										default: return !1;
									}
								}).map(function(e) {
									return "ClassDeclaration" === e.type ? e : e.declaration;
								}).forEach(function(e) {
									e.body.body.forEach(function(e) {
										(e.params || []).forEach(function(e) {
											(e.decorators || []).forEach(function(e) {
												e.expression.callee ? t[e.expression.callee.name] = e : t[e.expression.name] = e;
											});
										});
									});
								});
								var r = !0, n = !1, s = void 0;
								try {
									for (var i, o = e.get("body")[Symbol.iterator](); !(r = (i = o.next()).done); r = !0) {
										var a = i.value;
										if ("ImportDeclaration" === a.node.type) {
											if (0 === a.node.specifiers.length) continue;
											var l = !0, p = !1, c = void 0;
											try {
												for (var u, _loop = function() {
													var e = u.value, r = a.scope.getBinding(e.local.name);
													r.referencePaths.length ? r.referencePaths.reduce(function(e, t) {
														return e || isInType(t);
													}, !1) && Object.keys(t).forEach(function(n) {
														var s = t[n];
														(s.expression.arguments || []).forEach(function(t) {
															t.name === e.local.name && r.referencePaths.push({ parent: s.expression });
														});
													}) : t[e.local.name] && r.referencePaths.push({ parent: t[e.local.name] });
												}, d = a.node.specifiers[Symbol.iterator](); !(l = (u = d.next()).done); l = !0) _loop();
											} catch (e) {
												p = !0, c = e;
											} finally {
												try {
													l || null == d.return || d.return();
												} finally {
													if (p) throw c;
												}
											}
										}
									}
								} catch (e) {
									n = !0, s = e;
								} finally {
									try {
										r || null == o.return || o.return();
									} finally {
										if (n) throw s;
									}
								}
							}();
						},
						Function: function(e) {
							var r = "";
							e.node.id ? r = e.node.id.name : e.node.key && (r = e.node.key.name), (e.get("params") || []).slice().forEach(function(n) {
								var s = n.node.decorators || [], i = s.length;
								if (s.slice().forEach(function(t) {
									if ("ClassMethod" === e.type) {
										var s, i = e.parentPath.parentPath, o = e.findParent(function(e) {
											return "ClassDeclaration" === e.type;
										});
										if (o ? s = o.node.id.name : (i.insertAfter(null), s = function(e) {
											var t = e.findParent(function(e) {
												return "AssignmentExpression" === e.node.type;
											});
											return "SequenceExpression" === t.node.right.type ? t.node.right.expressions[1].name : "ClassExpression" === t.node.right.type ? t.node.left.name : null;
										}(e)), "constructor" === r) {
											var a = decoratorExpressionForConstructor(t, n)(s);
											i.insertAfter(a);
										} else {
											var l = decoratorExpressionForMethod(t, n)(s, r);
											i.insertAfter(l);
										}
									} else {
										var p = e.findParent(function(e) {
											return "VariableDeclarator" === e.node.type;
										}).node.id.name;
										if (r === p) {
											var c = decoratorExpressionForConstructor(t, n)(p);
											if ("body" === e.parentKey) e.insertAfter(c);
											else e.findParent(function(e) {
												return "body" === e.parentKey;
											}).insertAfter(c);
										} else {
											var u = e.findParent(function(e) {
												return "CallExpression" === e.node.type;
											}), d = decoratorExpressionForMethod(t, n)(p, r);
											u.insertAfter(d);
										}
									}
								}), i) {
									var o = function(e) {
										switch (e.node.type) {
											case "ObjectPattern": return t.ObjectPattern(e.node.properties);
											case "AssignmentPattern": return t.AssignmentPattern(e.node.left, e.node.right);
											case "TSParameterProperty": return t.Identifier(e.node.parameter.name);
											default: return t.Identifier(e.node.name);
										}
									}(n);
									n.replaceWith(o);
								}
							});
						}
					} };
				};
			},
			"./node_modules/.pnpm/convert-source-map@2.0.0/node_modules/convert-source-map/index.js": function(e, t) {
				"use strict";
				var r;
				function Converter(e, t) {
					(t = t || {}).hasComment && (e = function(e) {
						return e.split(",").pop();
					}(e)), "base64" === t.encoding ? e = r(e) : "uri" === t.encoding && (e = decodeURIComponent(e)), (t.isJSON || t.encoding) && (e = JSON.parse(e)), this.sourcemap = e;
				}
				function makeConverter(e) {
					return new Converter(e, { isJSON: !0 });
				}
				Object.defineProperty(t, "commentRegex", { get: function() {
					return /^\s*?\/[\/\*][@#]\s+?sourceMappingURL=data:(((?:application|text)\/json)(?:;charset=([^;,]+?)?)?)?(?:;(base64))?,(.*?)$/gm;
				} }), Object.defineProperty(t, "mapFileCommentRegex", { get: function() {
					return /(?:\/\/[@#][ \t]+?sourceMappingURL=([^\s'"`]+?)[ \t]*?$)|(?:\/\*[@#][ \t]+sourceMappingURL=([^*]+?)[ \t]*?(?:\*\/){1}[ \t]*?$)/gm;
				} }), r = "undefined" != typeof Buffer ? "function" == typeof Buffer.from ? function(e) {
					return Buffer.from(e, "base64").toString();
				} : function(e) {
					if ("number" == typeof value) throw new TypeError("The value to decode must not be of type number.");
					return new Buffer(e, "base64").toString();
				} : function(e) {
					return decodeURIComponent(escape(atob(e)));
				}, Converter.prototype.toJSON = function(e) {
					return JSON.stringify(this.sourcemap, null, e);
				}, "undefined" != typeof Buffer ? "function" == typeof Buffer.from ? Converter.prototype.toBase64 = function() {
					var e = this.toJSON();
					return Buffer.from(e, "utf8").toString("base64");
				} : Converter.prototype.toBase64 = function() {
					var e = this.toJSON();
					if ("number" == typeof e) throw new TypeError("The json to encode must not be of type number.");
					return new Buffer(e, "utf8").toString("base64");
				} : Converter.prototype.toBase64 = function() {
					var e = this.toJSON();
					return btoa(unescape(encodeURIComponent(e)));
				}, Converter.prototype.toURI = function() {
					var e = this.toJSON();
					return encodeURIComponent(e);
				}, Converter.prototype.toComment = function(e) {
					var t, r, n;
					return null != e && "uri" === e.encoding ? (t = "", r = this.toURI()) : (t = ";base64", r = this.toBase64()), n = "sourceMappingURL=data:application/json;charset=utf-8" + t + "," + r, null != e && e.multiline ? "/*# " + n + " */" : "//# " + n;
				}, Converter.prototype.toObject = function() {
					return JSON.parse(this.toJSON());
				}, Converter.prototype.addProperty = function(e, t) {
					if (this.sourcemap.hasOwnProperty(e)) throw new Error("property \"" + e + "\" already exists on the sourcemap, use set property instead");
					return this.setProperty(e, t);
				}, Converter.prototype.setProperty = function(e, t) {
					return this.sourcemap[e] = t, this;
				}, Converter.prototype.getProperty = function(e) {
					return this.sourcemap[e];
				}, t.fromObject = function(e) {
					return new Converter(e);
				}, t.fromJSON = function(e) {
					return new Converter(e, { isJSON: !0 });
				}, t.fromURI = function(e) {
					return new Converter(e, { encoding: "uri" });
				}, t.fromBase64 = function(e) {
					return new Converter(e, { encoding: "base64" });
				}, t.fromComment = function(e) {
					var r;
					return new Converter(e = e.replace(/^\/\*/g, "//").replace(/\*\/$/g, ""), {
						encoding: (r = t.commentRegex.exec(e)) && r[4] || "uri",
						hasComment: !0
					});
				}, t.fromMapFileComment = function(e, r) {
					if ("string" == typeof r) throw new Error("String directory paths are no longer supported with `fromMapFileComment`\nPlease review the Upgrading documentation at https://github.com/thlorenz/convert-source-map#upgrading");
					var n = function(e, r) {
						var n = t.mapFileCommentRegex.exec(e), s = n[1] || n[2];
						try {
							return null != (e = r(s)) && "function" == typeof e.catch ? e.catch(throwError) : e;
						} catch (e) {
							throwError(e);
						}
						function throwError(e) {
							throw new Error("An error occurred while trying to read the map file at " + s + "\n" + e.stack);
						}
					}(e, r);
					return null != n && "function" == typeof n.then ? n.then(makeConverter) : makeConverter(n);
				}, t.fromSource = function(e) {
					var r = e.match(t.commentRegex);
					return r ? t.fromComment(r.pop()) : null;
				}, t.fromMapFileSource = function(e, r) {
					if ("string" == typeof r) throw new Error("String directory paths are no longer supported with `fromMapFileSource`\nPlease review the Upgrading documentation at https://github.com/thlorenz/convert-source-map#upgrading");
					var n = e.match(t.mapFileCommentRegex);
					return n ? t.fromMapFileComment(n.pop(), r) : null;
				}, t.removeComments = function(e) {
					return e.replace(t.commentRegex, "");
				}, t.removeMapFileComments = function(e) {
					return e.replace(t.mapFileCommentRegex, "");
				}, t.generateMapFileComment = function(e, t) {
					var r = "sourceMappingURL=" + e;
					return t && t.multiline ? "/*# " + r + " */" : "//# " + r;
				};
			},
			"./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/browser.js": function(e, t, r) {
				t.formatArgs = function(t) {
					if (t[0] = (this.useColors ? "%c" : "") + this.namespace + (this.useColors ? " %c" : " ") + t[0] + (this.useColors ? "%c " : " ") + "+" + e.exports.humanize(this.diff), !this.useColors) return;
					const r = "color: " + this.color;
					t.splice(1, 0, r, "color: inherit");
					let n = 0, s = 0;
					t[0].replace(/%[a-zA-Z%]/g, (e) => {
						"%%" !== e && (n++, "%c" === e && (s = n));
					}), t.splice(s, 0, r);
				}, t.save = function(e) {
					try {
						e ? t.storage.setItem("debug", e) : t.storage.removeItem("debug");
					} catch (e) {}
				}, t.load = function() {
					let e;
					try {
						e = t.storage.getItem("debug") || t.storage.getItem("DEBUG");
					} catch (e) {}
					!e && "undefined" != typeof process && "env" in process && (e = process.env.DEBUG);
					return e;
				}, t.useColors = function() {
					if ("undefined" != typeof window && window.process && ("renderer" === window.process.type || window.process.__nwjs)) return !0;
					if ("undefined" != typeof navigator && navigator.userAgent && navigator.userAgent.toLowerCase().match(/(edge|trident)\/(\d+)/)) return !1;
					let e;
					return "undefined" != typeof document && document.documentElement && document.documentElement.style && document.documentElement.style.WebkitAppearance || "undefined" != typeof window && window.console && (window.console.firebug || window.console.exception && window.console.table) || "undefined" != typeof navigator && navigator.userAgent && (e = navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/)) && parseInt(e[1], 10) >= 31 || "undefined" != typeof navigator && navigator.userAgent && navigator.userAgent.toLowerCase().match(/applewebkit\/(\d+)/);
				}, t.storage = function() {
					try {
						return localStorage;
					} catch (e) {}
				}(), t.destroy = (() => {
					let e = !1;
					return () => {
						e || (e = !0, console.warn("Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`."));
					};
				})(), t.colors = [
					"#0000CC",
					"#0000FF",
					"#0033CC",
					"#0033FF",
					"#0066CC",
					"#0066FF",
					"#0099CC",
					"#0099FF",
					"#00CC00",
					"#00CC33",
					"#00CC66",
					"#00CC99",
					"#00CCCC",
					"#00CCFF",
					"#3300CC",
					"#3300FF",
					"#3333CC",
					"#3333FF",
					"#3366CC",
					"#3366FF",
					"#3399CC",
					"#3399FF",
					"#33CC00",
					"#33CC33",
					"#33CC66",
					"#33CC99",
					"#33CCCC",
					"#33CCFF",
					"#6600CC",
					"#6600FF",
					"#6633CC",
					"#6633FF",
					"#66CC00",
					"#66CC33",
					"#9900CC",
					"#9900FF",
					"#9933CC",
					"#9933FF",
					"#99CC00",
					"#99CC33",
					"#CC0000",
					"#CC0033",
					"#CC0066",
					"#CC0099",
					"#CC00CC",
					"#CC00FF",
					"#CC3300",
					"#CC3333",
					"#CC3366",
					"#CC3399",
					"#CC33CC",
					"#CC33FF",
					"#CC6600",
					"#CC6633",
					"#CC9900",
					"#CC9933",
					"#CCCC00",
					"#CCCC33",
					"#FF0000",
					"#FF0033",
					"#FF0066",
					"#FF0099",
					"#FF00CC",
					"#FF00FF",
					"#FF3300",
					"#FF3333",
					"#FF3366",
					"#FF3399",
					"#FF33CC",
					"#FF33FF",
					"#FF6600",
					"#FF6633",
					"#FF9900",
					"#FF9933",
					"#FFCC00",
					"#FFCC33"
				], t.log = console.debug || console.log || (() => {}), e.exports = r("./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/common.js")(t);
				const { formatters: n } = e.exports;
				n.j = function(e) {
					try {
						return JSON.stringify(e);
					} catch (e) {
						return "[UnexpectedJSONParseError]: " + e.message;
					}
				};
			},
			"./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/common.js": function(e, t, r) {
				e.exports = function(e) {
					function createDebug(e) {
						let t, r, n, s = null;
						function debug(...e) {
							if (!debug.enabled) return;
							const r = debug, n = Number(/* @__PURE__ */ new Date());
							r.diff = n - (t || n), r.prev = t, r.curr = n, t = n, e[0] = createDebug.coerce(e[0]), "string" != typeof e[0] && e.unshift("%O");
							let i = 0;
							e[0] = e[0].replace(/%([a-zA-Z%])/g, (t, n) => {
								if ("%%" === t) return "%";
								i++;
								const s = createDebug.formatters[n];
								if ("function" == typeof s) {
									const n = e[i];
									t = s.call(r, n), e.splice(i, 1), i--;
								}
								return t;
							}), createDebug.formatArgs.call(r, e);
							(r.log || createDebug.log).apply(r, e);
						}
						return debug.namespace = e, debug.useColors = createDebug.useColors(), debug.color = createDebug.selectColor(e), debug.extend = extend, debug.destroy = createDebug.destroy, Object.defineProperty(debug, "enabled", {
							enumerable: !0,
							configurable: !1,
							get: () => null !== s ? s : (r !== createDebug.namespaces && (r = createDebug.namespaces, n = createDebug.enabled(e)), n),
							set: (e) => {
								s = e;
							}
						}), "function" == typeof createDebug.init && createDebug.init(debug), debug;
					}
					function extend(e, t) {
						const r = createDebug(this.namespace + (void 0 === t ? ":" : t) + e);
						return r.log = this.log, r;
					}
					function matchesTemplate(e, t) {
						let r = 0, n = 0, s = -1, i = 0;
						for (; r < e.length;) if (n < t.length && (t[n] === e[r] || "*" === t[n])) "*" === t[n] ? (s = n, i = r, n++) : (r++, n++);
						else {
							if (-1 === s) return !1;
							n = s + 1, i++, r = i;
						}
						for (; n < t.length && "*" === t[n];) n++;
						return n === t.length;
					}
					return createDebug.debug = createDebug, createDebug.default = createDebug, createDebug.coerce = function(e) {
						if (e instanceof Error) return e.stack || e.message;
						return e;
					}, createDebug.disable = function() {
						const e = [...createDebug.names, ...createDebug.skips.map((e) => "-" + e)].join(",");
						return createDebug.enable(""), e;
					}, createDebug.enable = function(e) {
						createDebug.save(e), createDebug.namespaces = e, createDebug.names = [], createDebug.skips = [];
						const t = ("string" == typeof e ? e : "").trim().replace(/\s+/g, ",").split(",").filter(Boolean);
						for (const e of t) "-" === e[0] ? createDebug.skips.push(e.slice(1)) : createDebug.names.push(e);
					}, createDebug.enabled = function(e) {
						for (const t of createDebug.skips) if (matchesTemplate(e, t)) return !1;
						for (const t of createDebug.names) if (matchesTemplate(e, t)) return !0;
						return !1;
					}, createDebug.humanize = r("./node_modules/.pnpm/ms@2.1.3/node_modules/ms/index.js"), createDebug.destroy = function() {
						console.warn("Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.");
					}, Object.keys(e).forEach((t) => {
						createDebug[t] = e[t];
					}), createDebug.names = [], createDebug.skips = [], createDebug.formatters = {}, createDebug.selectColor = function(e) {
						let t = 0;
						for (let r = 0; r < e.length; r++) t = (t << 5) - t + e.charCodeAt(r), t |= 0;
						return createDebug.colors[Math.abs(t) % createDebug.colors.length];
					}, createDebug.enable(createDebug.load()), createDebug;
				};
			},
			"./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/index.js": function(e, t, r) {
				"undefined" == typeof process || "renderer" === process.type || !0 === process.browser || process.__nwjs ? e.exports = r("./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/browser.js") : e.exports = r("./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/node.js");
			},
			"./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/node.js": function(e, t, r) {
				const n = r("tty"), s = r("util");
				t.init = function(e) {
					e.inspectOpts = {};
					const r = Object.keys(t.inspectOpts);
					for (let n = 0; n < r.length; n++) e.inspectOpts[r[n]] = t.inspectOpts[r[n]];
				}, t.log = function(...e) {
					return process.stderr.write(s.formatWithOptions(t.inspectOpts, ...e) + "\n");
				}, t.formatArgs = function(r) {
					const { namespace: n, useColors: s } = this;
					if (s) {
						const t = this.color, s = "\x1B[3" + (t < 8 ? t : "8;5;" + t), i = `  ${s};1m${n} [0m`;
						r[0] = i + r[0].split("\n").join("\n" + i), r.push(s + "m+" + e.exports.humanize(this.diff) + "\x1B[0m");
					} else r[0] = function() {
						if (t.inspectOpts.hideDate) return "";
						return (/* @__PURE__ */ new Date()).toISOString() + " ";
					}() + n + " " + r[0];
				}, t.save = function(e) {
					e ? process.env.DEBUG = e : delete process.env.DEBUG;
				}, t.load = function() {
					return process.env.DEBUG;
				}, t.useColors = function() {
					return "colors" in t.inspectOpts ? Boolean(t.inspectOpts.colors) : n.isatty(process.stderr.fd);
				}, t.destroy = s.deprecate(() => {}, "Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`."), t.colors = [
					6,
					2,
					3,
					4,
					5,
					1
				];
				try {
					const e = r("./node_modules/.pnpm/supports-color@7.2.0/node_modules/supports-color/index.js");
					e && (e.stderr || e).level >= 2 && (t.colors = [
						20,
						21,
						26,
						27,
						32,
						33,
						38,
						39,
						40,
						41,
						42,
						43,
						44,
						45,
						56,
						57,
						62,
						63,
						68,
						69,
						74,
						75,
						76,
						77,
						78,
						79,
						80,
						81,
						92,
						93,
						98,
						99,
						112,
						113,
						128,
						129,
						134,
						135,
						148,
						149,
						160,
						161,
						162,
						163,
						164,
						165,
						166,
						167,
						168,
						169,
						170,
						171,
						172,
						173,
						178,
						179,
						184,
						185,
						196,
						197,
						198,
						199,
						200,
						201,
						202,
						203,
						204,
						205,
						206,
						207,
						208,
						209,
						214,
						215,
						220,
						221
					]);
				} catch (e) {}
				t.inspectOpts = Object.keys(process.env).filter((e) => /^debug_/i.test(e)).reduce((e, t) => {
					const r = t.substring(6).toLowerCase().replace(/_([a-z])/g, (e, t) => t.toUpperCase());
					let n = process.env[t];
					return n = !!/^(yes|on|true|enabled)$/i.test(n) || !/^(no|off|false|disabled)$/i.test(n) && ("null" === n ? null : Number(n)), e[r] = n, e;
				}, {}), e.exports = r("./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/common.js")(t);
				const { formatters: i } = e.exports;
				i.o = function(e) {
					return this.inspectOpts.colors = this.useColors, s.inspect(e, this.inspectOpts).split("\n").map((e) => e.trim()).join(" ");
				}, i.O = function(e) {
					return this.inspectOpts.colors = this.useColors, s.inspect(e, this.inspectOpts);
				};
			},
			"./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js": function(e) {
				"use strict";
				const t = Symbol.for("gensync:v1:start"), r = Symbol.for("gensync:v1:suspend"), n = "GENSYNC_OPTIONS_ERROR", s = "GENSYNC_RACE_NONEMPTY", i = "GENSYNC_ERRBACK_NO_CALLBACK";
				function assertTypeof(e, t, r, s) {
					if (typeof r === e || s && void 0 === r) return;
					let i;
					throw i = s ? `Expected opts.${t} to be either a ${e}, or undefined.` : `Expected opts.${t} to be a ${e}.`, makeError(i, n);
				}
				function makeError(e, t) {
					return Object.assign(new Error(e), { code: t });
				}
				function buildOperation({ name: e, arity: n, sync: s, async: i }) {
					return setFunctionMetadata(e, n, function* (...e) {
						const n = yield t;
						if (!n) return s.call(this, e);
						let o;
						try {
							i.call(this, e, (e) => {
								o || (o = { value: e }, n());
							}, (e) => {
								o || (o = { err: e }, n());
							});
						} catch (e) {
							o = { err: e }, n();
						}
						if (yield r, o.hasOwnProperty("err")) throw o.err;
						return o.value;
					});
				}
				function evaluateSync(e) {
					let t;
					for (; !({value: t} = e.next()).done;) assertStart(t, e);
					return t;
				}
				function evaluateAsync(e, t, r) {
					(function step() {
						try {
							let r;
							for (; !({value: r} = e.next()).done;) {
								assertStart(r, e);
								let t = !0, n = !1;
								const s = e.next(() => {
									t ? n = !0 : step();
								});
								if (t = !1, assertSuspend(s, e), !n) return;
							}
							return t(r);
						} catch (e) {
							return r(e);
						}
					})();
				}
				function assertStart(e, r) {
					e !== t && throwError(r, makeError(`Got unexpected yielded value in gensync generator: ${JSON.stringify(e)}. Did you perhaps mean to use 'yield*' instead of 'yield'?`, "GENSYNC_EXPECTED_START"));
				}
				function assertSuspend({ value: e, done: t }, n) {
					(t || e !== r) && throwError(n, makeError(t ? "Unexpected generator completion. If you get this, it is probably a gensync bug." : `Expected GENSYNC_SUSPEND, got ${JSON.stringify(e)}. If you get this, it is probably a gensync bug.`, "GENSYNC_EXPECTED_SUSPEND"));
				}
				function throwError(e, t) {
					throw e.throw && e.throw(t), t;
				}
				function setFunctionMetadata(e, t, r) {
					if ("string" == typeof e) {
						const t = Object.getOwnPropertyDescriptor(r, "name");
						t && !t.configurable || Object.defineProperty(r, "name", Object.assign(t || {}, {
							configurable: !0,
							value: e
						}));
					}
					if ("number" == typeof t) {
						const e = Object.getOwnPropertyDescriptor(r, "length");
						e && !e.configurable || Object.defineProperty(r, "length", Object.assign(e || {}, {
							configurable: !0,
							value: t
						}));
					}
					return r;
				}
				e.exports = Object.assign(function(e) {
					let t = e;
					return t = "function" != typeof e ? function({ name: e, arity: t, sync: r, async: s, errback: i }) {
						if (assertTypeof("string", "name", e, !0), assertTypeof("number", "arity", t, !0), assertTypeof("function", "sync", r), assertTypeof("function", "async", s, !0), assertTypeof("function", "errback", i, !0), s && i) throw makeError("Expected one of either opts.async or opts.errback, but got _both_.", n);
						if ("string" != typeof e) {
							let t;
							i && i.name && "errback" !== i.name && (t = i.name), s && s.name && "async" !== s.name && (t = s.name.replace(/Async$/, "")), r && r.name && "sync" !== r.name && (t = r.name.replace(/Sync$/, "")), "string" == typeof t && (e = t);
						}
						"number" != typeof t && (t = r.length);
						return buildOperation({
							name: e,
							arity: t,
							sync: function(e) {
								return r.apply(this, e);
							},
							async: function(e, t, n) {
								s ? s.apply(this, e).then(t, n) : i ? i.call(this, ...e, (e, r) => {
									null == e ? t(r) : n(e);
								}) : t(r.apply(this, e));
							}
						});
					}(e) : function(e) {
						return setFunctionMetadata(e.name, e.length, function(...t) {
							return e.apply(this, t);
						});
					}(e), Object.assign(t, function(e) {
						return {
							sync: function(...t) {
								return evaluateSync(e.apply(this, t));
							},
							async: function(...t) {
								return new Promise((r, n) => {
									evaluateAsync(e.apply(this, t), r, n);
								});
							},
							errback: function(...t) {
								const r = t.pop();
								if ("function" != typeof r) throw makeError("Asynchronous function called without callback", i);
								let n;
								try {
									n = e.apply(this, t);
								} catch (e) {
									r(e);
									return;
								}
								evaluateAsync(n, (e) => r(void 0, e), (e) => r(e));
							}
						};
					}(t));
				}, {
					all: buildOperation({
						name: "all",
						arity: 1,
						sync: function(e) {
							return Array.from(e[0]).map((e) => evaluateSync(e));
						},
						async: function(e, t, r) {
							const n = Array.from(e[0]);
							if (0 === n.length) return void Promise.resolve().then(() => t([]));
							let s = 0;
							const i = n.map(() => {});
							n.forEach((e, n) => {
								evaluateAsync(e, (e) => {
									i[n] = e, s += 1, s === i.length && t(i);
								}, r);
							});
						}
					}),
					race: buildOperation({
						name: "race",
						arity: 1,
						sync: function(e) {
							const t = Array.from(e[0]);
							if (0 === t.length) throw makeError("Must race at least 1 item", s);
							return evaluateSync(t[0]);
						},
						async: function(e, t, r) {
							const n = Array.from(e[0]);
							if (0 === n.length) throw makeError("Must race at least 1 item", s);
							for (const e of n) evaluateAsync(e, t, r);
						}
					})
				});
			},
			"./node_modules/.pnpm/has-flag@4.0.0/node_modules/has-flag/index.js": function(e) {
				"use strict";
				e.exports = (e, t = process.argv) => {
					const r = e.startsWith("-") ? "" : 1 === e.length ? "-" : "--", n = t.indexOf(r + e), s = t.indexOf("--");
					return -1 !== n && (-1 === s || n < s);
				};
			},
			"./node_modules/.pnpm/jsesc@3.1.0/node_modules/jsesc/jsesc.js": function(e) {
				"use strict";
				const t = {}, r = t.hasOwnProperty, forOwn = (e, t) => {
					for (const n in e) r.call(e, n) && t(n, e[n]);
				}, fourHexEscape = (e) => "\\u" + ("0000" + e).slice(-4), hexadecimal = (e, t) => {
					let r = e.toString(16);
					return t ? r : r.toUpperCase();
				}, n = t.toString, s = Array.isArray, isBigInt = (e) => "bigint" == typeof e, i = {
					"\\": "\\\\",
					"\b": "\\b",
					"\f": "\\f",
					"\n": "\\n",
					"\r": "\\r",
					"	": "\\t"
				}, o = /[\\\b\f\n\r\t]/, a = /[0-9]/, l = /[\xA0\u1680\u2000-\u200A\u2028\u2029\u202F\u205F\u3000]/, p = /([\uD800-\uDBFF][\uDC00-\uDFFF])|([\uD800-\uDFFF])|(['"`])|[^]/g, c = /([\uD800-\uDBFF][\uDC00-\uDFFF])|([\uD800-\uDFFF])|(['"`])|[^ !#-&\(-\[\]-_a-~]/g, jsesc = (e, t) => {
					const increaseIndentation = () => {
						g = b, ++t.indentLevel, b = t.indent.repeat(t.indentLevel);
					}, r = {
						escapeEverything: !1,
						minimal: !1,
						isScriptContext: !1,
						quotes: "single",
						wrap: !1,
						es6: !1,
						json: !1,
						compact: !0,
						lowercaseHex: !1,
						numbers: "decimal",
						indent: "	",
						indentLevel: 0,
						__inline1__: !1,
						__inline2__: !1
					}, u = t && t.json;
					var d, h;
					u && (r.quotes = "double", r.wrap = !0), d = r, "single" != (t = (h = t) ? (forOwn(h, (e, t) => {
						d[e] = t;
					}), d) : d).quotes && "double" != t.quotes && "backtick" != t.quotes && (t.quotes = "single");
					const m = "double" == t.quotes ? "\"" : "backtick" == t.quotes ? "`" : "'", f = t.compact, y = t.lowercaseHex;
					let b = t.indent.repeat(t.indentLevel), g = "";
					const x = t.__inline1__, v = t.__inline2__, E = f ? "" : "\n";
					let T, S = !0;
					const P = "binary" == t.numbers, _ = "octal" == t.numbers, A = "decimal" == t.numbers, C = "hexadecimal" == t.numbers;
					if (u && e && ((e) => "function" == typeof e)(e.toJSON) && (e = e.toJSON()), !((e) => "string" == typeof e || "[object String]" == n.call(e))(e)) {
						if (((e) => "[object Map]" == n.call(e))(e)) return 0 == e.size ? "new Map()" : (f || (t.__inline1__ = !0, t.__inline2__ = !1), "new Map(" + jsesc(Array.from(e), t) + ")");
						if (((e) => "[object Set]" == n.call(e))(e)) return 0 == e.size ? "new Set()" : "new Set(" + jsesc(Array.from(e), t) + ")";
						if (((e) => "function" == typeof Buffer && Buffer.isBuffer(e))(e)) return 0 == e.length ? "Buffer.from([])" : "Buffer.from(" + jsesc(Array.from(e), t) + ")";
						if (s(e)) return T = [], t.wrap = !0, x && (t.__inline1__ = !1, t.__inline2__ = !0), v || increaseIndentation(), ((e, t) => {
							const r = e.length;
							let n = -1;
							for (; ++n < r;) t(e[n]);
						})(e, (e) => {
							S = !1, v && (t.__inline2__ = !1), T.push((f || v ? "" : b) + jsesc(e, t));
						}), S ? "[]" : v ? "[" + T.join(", ") + "]" : "[" + E + T.join("," + E) + E + (f ? "" : g) + "]";
						if (((e) => "number" == typeof e || "[object Number]" == n.call(e))(e) || isBigInt(e)) {
							if (u) return JSON.stringify(Number(e));
							let t;
							if (A) t = String(e);
							else if (C) {
								let r = e.toString(16);
								y || (r = r.toUpperCase()), t = "0x" + r;
							} else P ? t = "0b" + e.toString(2) : _ && (t = "0o" + e.toString(8));
							return isBigInt(e) ? t + "n" : t;
						}
						return isBigInt(e) ? u ? JSON.stringify(Number(e)) : e + "n" : ((e) => "[object Object]" == n.call(e))(e) ? (T = [], t.wrap = !0, increaseIndentation(), forOwn(e, (e, r) => {
							S = !1, T.push((f ? "" : b) + jsesc(e, t) + ":" + (f ? "" : " ") + jsesc(r, t));
						}), S ? "{}" : "{" + E + T.join("," + E) + E + (f ? "" : g) + "}") : u ? JSON.stringify(e) || "null" : String(e);
					}
					const w = t.escapeEverything ? p : c;
					return T = e.replace(w, (e, r, n, s, p, c) => {
						if (r) {
							if (t.minimal) return r;
							const e = r.charCodeAt(0), n = r.charCodeAt(1);
							if (t.es6) return "\\u{" + hexadecimal(1024 * (e - 55296) + n - 56320 + 65536, y) + "}";
							return fourHexEscape(hexadecimal(e, y)) + fourHexEscape(hexadecimal(n, y));
						}
						if (n) return fourHexEscape(hexadecimal(n.charCodeAt(0), y));
						if ("\0" == e && !u && !a.test(c.charAt(p + 1))) return "\\0";
						if (s) return s == m || t.escapeEverything ? "\\" + s : s;
						if (o.test(e)) return i[e];
						if (t.minimal && !l.test(e)) return e;
						const d = hexadecimal(e.charCodeAt(0), y);
						return u || d.length > 2 ? fourHexEscape(d) : "\\x" + ("00" + d).slice(-2);
					}), "`" == m && (T = T.replace(/\$\{/g, "\\${")), t.isScriptContext && (T = T.replace(/<\/(script|style)/gi, "<\\/$1").replace(/<!--/g, u ? "\\u003C!--" : "\\x3C!--")), t.wrap && (T = m + T + m), T;
				};
				jsesc.version = "3.0.2", e.exports = jsesc;
			},
			"./node_modules/.pnpm/mlly@1.8.0/node_modules/mlly/dist lazy recursive": function(e) {
				function webpackEmptyAsyncContext(e) {
					return Promise.resolve().then(function() {
						var t = /* @__PURE__ */ new Error("Cannot find module '" + e + "'");
						throw t.code = "MODULE_NOT_FOUND", t;
					});
				}
				webpackEmptyAsyncContext.keys = () => [], webpackEmptyAsyncContext.resolve = webpackEmptyAsyncContext, webpackEmptyAsyncContext.id = "./node_modules/.pnpm/mlly@1.8.0/node_modules/mlly/dist lazy recursive", e.exports = webpackEmptyAsyncContext;
			},
			"./node_modules/.pnpm/ms@2.1.3/node_modules/ms/index.js": function(e) {
				var t = 1e3, r = 60 * t, n = 60 * r, s = 24 * n, i = 7 * s, o = 365.25 * s;
				function plural(e, t, r, n) {
					var s = t >= 1.5 * r;
					return Math.round(e / r) + " " + n + (s ? "s" : "");
				}
				e.exports = function(e, a) {
					a = a || {};
					var l = typeof e;
					if ("string" === l && e.length > 0) return function(e) {
						if ((e = String(e)).length > 100) return;
						var a = /^(-?(?:\d+)?\.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|weeks?|w|years?|yrs?|y)?$/i.exec(e);
						if (!a) return;
						var l = parseFloat(a[1]);
						switch ((a[2] || "ms").toLowerCase()) {
							case "years":
							case "year":
							case "yrs":
							case "yr":
							case "y": return l * o;
							case "weeks":
							case "week":
							case "w": return l * i;
							case "days":
							case "day":
							case "d": return l * s;
							case "hours":
							case "hour":
							case "hrs":
							case "hr":
							case "h": return l * n;
							case "minutes":
							case "minute":
							case "mins":
							case "min":
							case "m": return l * r;
							case "seconds":
							case "second":
							case "secs":
							case "sec":
							case "s": return l * t;
							case "milliseconds":
							case "millisecond":
							case "msecs":
							case "msec":
							case "ms": return l;
							default: return;
						}
					}(e);
					if ("number" === l && isFinite(e)) return a.long ? function(e) {
						var i = Math.abs(e);
						if (i >= s) return plural(e, i, s, "day");
						if (i >= n) return plural(e, i, n, "hour");
						if (i >= r) return plural(e, i, r, "minute");
						if (i >= t) return plural(e, i, t, "second");
						return e + " ms";
					}(e) : function(e) {
						var i = Math.abs(e);
						if (i >= s) return Math.round(e / s) + "d";
						if (i >= n) return Math.round(e / n) + "h";
						if (i >= r) return Math.round(e / r) + "m";
						if (i >= t) return Math.round(e / t) + "s";
						return e + "ms";
					}(e);
					throw new Error("val is not a non-empty string or a valid number. val=" + JSON.stringify(e));
				};
			},
			"./node_modules/.pnpm/semver@6.3.1/node_modules/semver/semver.js": function(e, t) {
				var r;
				t = e.exports = SemVer, r = "object" == typeof process && process.env && process.env.NODE_DEBUG && /\bsemver\b/i.test(process.env.NODE_DEBUG) ? function() {
					var e = Array.prototype.slice.call(arguments, 0);
					e.unshift("SEMVER"), console.log.apply(console, e);
				} : function() {}, t.SEMVER_SPEC_VERSION = "2.0.0";
				var n = 256, s = Number.MAX_SAFE_INTEGER || 9007199254740991, i = n - 6, o = t.re = [], a = t.safeRe = [], l = t.src = [], p = t.tokens = {}, c = 0;
				function tok(e) {
					p[e] = c++;
				}
				var u = "[a-zA-Z0-9-]", d = [
					["\\s", 1],
					["\\d", n],
					[u, i]
				];
				function makeSafeRe(e) {
					for (var t = 0; t < d.length; t++) {
						var r = d[t][0], n = d[t][1];
						e = e.split(r + "*").join(r + "{0," + n + "}").split(r + "+").join(r + "{1," + n + "}");
					}
					return e;
				}
				tok("NUMERICIDENTIFIER"), l[p.NUMERICIDENTIFIER] = "0|[1-9]\\d*", tok("NUMERICIDENTIFIERLOOSE"), l[p.NUMERICIDENTIFIERLOOSE] = "\\d+", tok("NONNUMERICIDENTIFIER"), l[p.NONNUMERICIDENTIFIER] = "\\d*[a-zA-Z-]" + u + "*", tok("MAINVERSION"), l[p.MAINVERSION] = "(" + l[p.NUMERICIDENTIFIER] + ")\\.(" + l[p.NUMERICIDENTIFIER] + ")\\.(" + l[p.NUMERICIDENTIFIER] + ")", tok("MAINVERSIONLOOSE"), l[p.MAINVERSIONLOOSE] = "(" + l[p.NUMERICIDENTIFIERLOOSE] + ")\\.(" + l[p.NUMERICIDENTIFIERLOOSE] + ")\\.(" + l[p.NUMERICIDENTIFIERLOOSE] + ")", tok("PRERELEASEIDENTIFIER"), l[p.PRERELEASEIDENTIFIER] = "(?:" + l[p.NUMERICIDENTIFIER] + "|" + l[p.NONNUMERICIDENTIFIER] + ")", tok("PRERELEASEIDENTIFIERLOOSE"), l[p.PRERELEASEIDENTIFIERLOOSE] = "(?:" + l[p.NUMERICIDENTIFIERLOOSE] + "|" + l[p.NONNUMERICIDENTIFIER] + ")", tok("PRERELEASE"), l[p.PRERELEASE] = "(?:-(" + l[p.PRERELEASEIDENTIFIER] + "(?:\\." + l[p.PRERELEASEIDENTIFIER] + ")*))", tok("PRERELEASELOOSE"), l[p.PRERELEASELOOSE] = "(?:-?(" + l[p.PRERELEASEIDENTIFIERLOOSE] + "(?:\\." + l[p.PRERELEASEIDENTIFIERLOOSE] + ")*))", tok("BUILDIDENTIFIER"), l[p.BUILDIDENTIFIER] = u + "+", tok("BUILD"), l[p.BUILD] = "(?:\\+(" + l[p.BUILDIDENTIFIER] + "(?:\\." + l[p.BUILDIDENTIFIER] + ")*))", tok("FULL"), tok("FULLPLAIN"), l[p.FULLPLAIN] = "v?" + l[p.MAINVERSION] + l[p.PRERELEASE] + "?" + l[p.BUILD] + "?", l[p.FULL] = "^" + l[p.FULLPLAIN] + "$", tok("LOOSEPLAIN"), l[p.LOOSEPLAIN] = "[v=\\s]*" + l[p.MAINVERSIONLOOSE] + l[p.PRERELEASELOOSE] + "?" + l[p.BUILD] + "?", tok("LOOSE"), l[p.LOOSE] = "^" + l[p.LOOSEPLAIN] + "$", tok("GTLT"), l[p.GTLT] = "((?:<|>)?=?)", tok("XRANGEIDENTIFIERLOOSE"), l[p.XRANGEIDENTIFIERLOOSE] = l[p.NUMERICIDENTIFIERLOOSE] + "|x|X|\\*", tok("XRANGEIDENTIFIER"), l[p.XRANGEIDENTIFIER] = l[p.NUMERICIDENTIFIER] + "|x|X|\\*", tok("XRANGEPLAIN"), l[p.XRANGEPLAIN] = "[v=\\s]*(" + l[p.XRANGEIDENTIFIER] + ")(?:\\.(" + l[p.XRANGEIDENTIFIER] + ")(?:\\.(" + l[p.XRANGEIDENTIFIER] + ")(?:" + l[p.PRERELEASE] + ")?" + l[p.BUILD] + "?)?)?", tok("XRANGEPLAINLOOSE"), l[p.XRANGEPLAINLOOSE] = "[v=\\s]*(" + l[p.XRANGEIDENTIFIERLOOSE] + ")(?:\\.(" + l[p.XRANGEIDENTIFIERLOOSE] + ")(?:\\.(" + l[p.XRANGEIDENTIFIERLOOSE] + ")(?:" + l[p.PRERELEASELOOSE] + ")?" + l[p.BUILD] + "?)?)?", tok("XRANGE"), l[p.XRANGE] = "^" + l[p.GTLT] + "\\s*" + l[p.XRANGEPLAIN] + "$", tok("XRANGELOOSE"), l[p.XRANGELOOSE] = "^" + l[p.GTLT] + "\\s*" + l[p.XRANGEPLAINLOOSE] + "$", tok("COERCE"), l[p.COERCE] = "(^|[^\\d])(\\d{1,16})(?:\\.(\\d{1,16}))?(?:\\.(\\d{1,16}))?(?:$|[^\\d])", tok("COERCERTL"), o[p.COERCERTL] = new RegExp(l[p.COERCE], "g"), a[p.COERCERTL] = new RegExp(makeSafeRe(l[p.COERCE]), "g"), tok("LONETILDE"), l[p.LONETILDE] = "(?:~>?)", tok("TILDETRIM"), l[p.TILDETRIM] = "(\\s*)" + l[p.LONETILDE] + "\\s+", o[p.TILDETRIM] = new RegExp(l[p.TILDETRIM], "g"), a[p.TILDETRIM] = new RegExp(makeSafeRe(l[p.TILDETRIM]), "g");
				tok("TILDE"), l[p.TILDE] = "^" + l[p.LONETILDE] + l[p.XRANGEPLAIN] + "$", tok("TILDELOOSE"), l[p.TILDELOOSE] = "^" + l[p.LONETILDE] + l[p.XRANGEPLAINLOOSE] + "$", tok("LONECARET"), l[p.LONECARET] = "(?:\\^)", tok("CARETTRIM"), l[p.CARETTRIM] = "(\\s*)" + l[p.LONECARET] + "\\s+", o[p.CARETTRIM] = new RegExp(l[p.CARETTRIM], "g"), a[p.CARETTRIM] = new RegExp(makeSafeRe(l[p.CARETTRIM]), "g");
				tok("CARET"), l[p.CARET] = "^" + l[p.LONECARET] + l[p.XRANGEPLAIN] + "$", tok("CARETLOOSE"), l[p.CARETLOOSE] = "^" + l[p.LONECARET] + l[p.XRANGEPLAINLOOSE] + "$", tok("COMPARATORLOOSE"), l[p.COMPARATORLOOSE] = "^" + l[p.GTLT] + "\\s*(" + l[p.LOOSEPLAIN] + ")$|^$", tok("COMPARATOR"), l[p.COMPARATOR] = "^" + l[p.GTLT] + "\\s*(" + l[p.FULLPLAIN] + ")$|^$", tok("COMPARATORTRIM"), l[p.COMPARATORTRIM] = "(\\s*)" + l[p.GTLT] + "\\s*(" + l[p.LOOSEPLAIN] + "|" + l[p.XRANGEPLAIN] + ")", o[p.COMPARATORTRIM] = new RegExp(l[p.COMPARATORTRIM], "g"), a[p.COMPARATORTRIM] = new RegExp(makeSafeRe(l[p.COMPARATORTRIM]), "g");
				tok("HYPHENRANGE"), l[p.HYPHENRANGE] = "^\\s*(" + l[p.XRANGEPLAIN] + ")\\s+-\\s+(" + l[p.XRANGEPLAIN] + ")\\s*$", tok("HYPHENRANGELOOSE"), l[p.HYPHENRANGELOOSE] = "^\\s*(" + l[p.XRANGEPLAINLOOSE] + ")\\s+-\\s+(" + l[p.XRANGEPLAINLOOSE] + ")\\s*$", tok("STAR"), l[p.STAR] = "(<|>)?=?\\s*\\*";
				for (var h = 0; h < c; h++) r(h, l[h]), o[h] || (o[h] = new RegExp(l[h]), a[h] = new RegExp(makeSafeRe(l[h])));
				function parse(e, t) {
					if (t && "object" == typeof t || (t = {
						loose: !!t,
						includePrerelease: !1
					}), e instanceof SemVer) return e;
					if ("string" != typeof e) return null;
					if (e.length > n) return null;
					if (!(t.loose ? a[p.LOOSE] : a[p.FULL]).test(e)) return null;
					try {
						return new SemVer(e, t);
					} catch (e) {
						return null;
					}
				}
				function SemVer(e, t) {
					if (t && "object" == typeof t || (t = {
						loose: !!t,
						includePrerelease: !1
					}), e instanceof SemVer) {
						if (e.loose === t.loose) return e;
						e = e.version;
					} else if ("string" != typeof e) throw new TypeError("Invalid Version: " + e);
					if (e.length > n) throw new TypeError("version is longer than " + n + " characters");
					if (!(this instanceof SemVer)) return new SemVer(e, t);
					r("SemVer", e, t), this.options = t, this.loose = !!t.loose;
					var i = e.trim().match(t.loose ? a[p.LOOSE] : a[p.FULL]);
					if (!i) throw new TypeError("Invalid Version: " + e);
					if (this.raw = e, this.major = +i[1], this.minor = +i[2], this.patch = +i[3], this.major > s || this.major < 0) throw new TypeError("Invalid major version");
					if (this.minor > s || this.minor < 0) throw new TypeError("Invalid minor version");
					if (this.patch > s || this.patch < 0) throw new TypeError("Invalid patch version");
					i[4] ? this.prerelease = i[4].split(".").map(function(e) {
						if (/^[0-9]+$/.test(e)) {
							var t = +e;
							if (t >= 0 && t < s) return t;
						}
						return e;
					}) : this.prerelease = [], this.build = i[5] ? i[5].split(".") : [], this.format();
				}
				t.parse = parse, t.valid = function(e, t) {
					var r = parse(e, t);
					return r ? r.version : null;
				}, t.clean = function(e, t) {
					var r = parse(e.trim().replace(/^[=v]+/, ""), t);
					return r ? r.version : null;
				}, t.SemVer = SemVer, SemVer.prototype.format = function() {
					return this.version = this.major + "." + this.minor + "." + this.patch, this.prerelease.length && (this.version += "-" + this.prerelease.join(".")), this.version;
				}, SemVer.prototype.toString = function() {
					return this.version;
				}, SemVer.prototype.compare = function(e) {
					return r("SemVer.compare", this.version, this.options, e), e instanceof SemVer || (e = new SemVer(e, this.options)), this.compareMain(e) || this.comparePre(e);
				}, SemVer.prototype.compareMain = function(e) {
					return e instanceof SemVer || (e = new SemVer(e, this.options)), compareIdentifiers(this.major, e.major) || compareIdentifiers(this.minor, e.minor) || compareIdentifiers(this.patch, e.patch);
				}, SemVer.prototype.comparePre = function(e) {
					if (e instanceof SemVer || (e = new SemVer(e, this.options)), this.prerelease.length && !e.prerelease.length) return -1;
					if (!this.prerelease.length && e.prerelease.length) return 1;
					if (!this.prerelease.length && !e.prerelease.length) return 0;
					var t = 0;
					do {
						var n = this.prerelease[t], s = e.prerelease[t];
						if (r("prerelease compare", t, n, s), void 0 === n && void 0 === s) return 0;
						if (void 0 === s) return 1;
						if (void 0 === n) return -1;
						if (n !== s) return compareIdentifiers(n, s);
					} while (++t);
				}, SemVer.prototype.compareBuild = function(e) {
					e instanceof SemVer || (e = new SemVer(e, this.options));
					var t = 0;
					do {
						var n = this.build[t], s = e.build[t];
						if (r("prerelease compare", t, n, s), void 0 === n && void 0 === s) return 0;
						if (void 0 === s) return 1;
						if (void 0 === n) return -1;
						if (n !== s) return compareIdentifiers(n, s);
					} while (++t);
				}, SemVer.prototype.inc = function(e, t) {
					switch (e) {
						case "premajor":
							this.prerelease.length = 0, this.patch = 0, this.minor = 0, this.major++, this.inc("pre", t);
							break;
						case "preminor":
							this.prerelease.length = 0, this.patch = 0, this.minor++, this.inc("pre", t);
							break;
						case "prepatch":
							this.prerelease.length = 0, this.inc("patch", t), this.inc("pre", t);
							break;
						case "prerelease":
							0 === this.prerelease.length && this.inc("patch", t), this.inc("pre", t);
							break;
						case "major":
							0 === this.minor && 0 === this.patch && 0 !== this.prerelease.length || this.major++, this.minor = 0, this.patch = 0, this.prerelease = [];
							break;
						case "minor":
							0 === this.patch && 0 !== this.prerelease.length || this.minor++, this.patch = 0, this.prerelease = [];
							break;
						case "patch":
							0 === this.prerelease.length && this.patch++, this.prerelease = [];
							break;
						case "pre":
							if (0 === this.prerelease.length) this.prerelease = [0];
							else {
								for (var r = this.prerelease.length; --r >= 0;) "number" == typeof this.prerelease[r] && (this.prerelease[r]++, r = -2);
								-1 === r && this.prerelease.push(0);
							}
							t && (this.prerelease[0] === t ? isNaN(this.prerelease[1]) && (this.prerelease = [t, 0]) : this.prerelease = [t, 0]);
							break;
						default: throw new Error("invalid increment argument: " + e);
					}
					return this.format(), this.raw = this.version, this;
				}, t.inc = function(e, t, r, n) {
					"string" == typeof r && (n = r, r = void 0);
					try {
						return new SemVer(e, r).inc(t, n).version;
					} catch (e) {
						return null;
					}
				}, t.diff = function(e, t) {
					if (eq(e, t)) return null;
					var r = parse(e), n = parse(t), s = "";
					if (r.prerelease.length || n.prerelease.length) {
						s = "pre";
						var i = "prerelease";
					}
					for (var o in r) if (("major" === o || "minor" === o || "patch" === o) && r[o] !== n[o]) return s + o;
					return i;
				}, t.compareIdentifiers = compareIdentifiers;
				var m = /^[0-9]+$/;
				function compareIdentifiers(e, t) {
					var r = m.test(e), n = m.test(t);
					return r && n && (e = +e, t = +t), e === t ? 0 : r && !n ? -1 : n && !r ? 1 : e < t ? -1 : 1;
				}
				function compare(e, t, r) {
					return new SemVer(e, r).compare(new SemVer(t, r));
				}
				function gt(e, t, r) {
					return compare(e, t, r) > 0;
				}
				function lt(e, t, r) {
					return compare(e, t, r) < 0;
				}
				function eq(e, t, r) {
					return 0 === compare(e, t, r);
				}
				function neq(e, t, r) {
					return 0 !== compare(e, t, r);
				}
				function gte(e, t, r) {
					return compare(e, t, r) >= 0;
				}
				function lte(e, t, r) {
					return compare(e, t, r) <= 0;
				}
				function cmp(e, t, r, n) {
					switch (t) {
						case "===": return "object" == typeof e && (e = e.version), "object" == typeof r && (r = r.version), e === r;
						case "!==": return "object" == typeof e && (e = e.version), "object" == typeof r && (r = r.version), e !== r;
						case "":
						case "=":
						case "==": return eq(e, r, n);
						case "!=": return neq(e, r, n);
						case ">": return gt(e, r, n);
						case ">=": return gte(e, r, n);
						case "<": return lt(e, r, n);
						case "<=": return lte(e, r, n);
						default: throw new TypeError("Invalid operator: " + t);
					}
				}
				function Comparator(e, t) {
					if (t && "object" == typeof t || (t = {
						loose: !!t,
						includePrerelease: !1
					}), e instanceof Comparator) {
						if (e.loose === !!t.loose) return e;
						e = e.value;
					}
					if (!(this instanceof Comparator)) return new Comparator(e, t);
					e = e.trim().split(/\s+/).join(" "), r("comparator", e, t), this.options = t, this.loose = !!t.loose, this.parse(e), this.semver === f ? this.value = "" : this.value = this.operator + this.semver.version, r("comp", this);
				}
				t.rcompareIdentifiers = function(e, t) {
					return compareIdentifiers(t, e);
				}, t.major = function(e, t) {
					return new SemVer(e, t).major;
				}, t.minor = function(e, t) {
					return new SemVer(e, t).minor;
				}, t.patch = function(e, t) {
					return new SemVer(e, t).patch;
				}, t.compare = compare, t.compareLoose = function(e, t) {
					return compare(e, t, !0);
				}, t.compareBuild = function(e, t, r) {
					var n = new SemVer(e, r), s = new SemVer(t, r);
					return n.compare(s) || n.compareBuild(s);
				}, t.rcompare = function(e, t, r) {
					return compare(t, e, r);
				}, t.sort = function(e, r) {
					return e.sort(function(e, n) {
						return t.compareBuild(e, n, r);
					});
				}, t.rsort = function(e, r) {
					return e.sort(function(e, n) {
						return t.compareBuild(n, e, r);
					});
				}, t.gt = gt, t.lt = lt, t.eq = eq, t.neq = neq, t.gte = gte, t.lte = lte, t.cmp = cmp, t.Comparator = Comparator;
				var f = {};
				function Range(e, t) {
					if (t && "object" == typeof t || (t = {
						loose: !!t,
						includePrerelease: !1
					}), e instanceof Range) return e.loose === !!t.loose && e.includePrerelease === !!t.includePrerelease ? e : new Range(e.raw, t);
					if (e instanceof Comparator) return new Range(e.value, t);
					if (!(this instanceof Range)) return new Range(e, t);
					if (this.options = t, this.loose = !!t.loose, this.includePrerelease = !!t.includePrerelease, this.raw = e.trim().split(/\s+/).join(" "), this.set = this.raw.split("||").map(function(e) {
						return this.parseRange(e.trim());
					}, this).filter(function(e) {
						return e.length;
					}), !this.set.length) throw new TypeError("Invalid SemVer Range: " + this.raw);
					this.format();
				}
				function isSatisfiable(e, t) {
					for (var r = !0, n = e.slice(), s = n.pop(); r && n.length;) r = n.every(function(e) {
						return s.intersects(e, t);
					}), s = n.pop();
					return r;
				}
				function isX(e) {
					return !e || "x" === e.toLowerCase() || "*" === e;
				}
				function hyphenReplace(e, t, r, n, s, i, o, a, l, p, c, u, d) {
					return ((t = isX(r) ? "" : isX(n) ? ">=" + r + ".0.0" : isX(s) ? ">=" + r + "." + n + ".0" : ">=" + t) + " " + (a = isX(l) ? "" : isX(p) ? "<" + (+l + 1) + ".0.0" : isX(c) ? "<" + l + "." + (+p + 1) + ".0" : u ? "<=" + l + "." + p + "." + c + "-" + u : "<=" + a)).trim();
				}
				function testSet(e, t, n) {
					for (var s = 0; s < e.length; s++) if (!e[s].test(t)) return !1;
					if (t.prerelease.length && !n.includePrerelease) {
						for (s = 0; s < e.length; s++) if (r(e[s].semver), e[s].semver !== f && e[s].semver.prerelease.length > 0) {
							var i = e[s].semver;
							if (i.major === t.major && i.minor === t.minor && i.patch === t.patch) return !0;
						}
						return !1;
					}
					return !0;
				}
				function satisfies(e, t, r) {
					try {
						t = new Range(t, r);
					} catch (e) {
						return !1;
					}
					return t.test(e);
				}
				function outside(e, t, r, n) {
					var s, i, o, a, l;
					switch (e = new SemVer(e, n), t = new Range(t, n), r) {
						case ">":
							s = gt, i = lte, o = lt, a = ">", l = ">=";
							break;
						case "<":
							s = lt, i = gte, o = gt, a = "<", l = "<=";
							break;
						default: throw new TypeError("Must provide a hilo val of \"<\" or \">\"");
					}
					if (satisfies(e, t, n)) return !1;
					for (var p = 0; p < t.set.length; ++p) {
						var c = t.set[p], u = null, d = null;
						if (c.forEach(function(e) {
							e.semver === f && (e = new Comparator(">=0.0.0")), u = u || e, d = d || e, s(e.semver, u.semver, n) ? u = e : o(e.semver, d.semver, n) && (d = e);
						}), u.operator === a || u.operator === l) return !1;
						if ((!d.operator || d.operator === a) && i(e, d.semver)) return !1;
						if (d.operator === l && o(e, d.semver)) return !1;
					}
					return !0;
				}
				Comparator.prototype.parse = function(e) {
					var t = this.options.loose ? a[p.COMPARATORLOOSE] : a[p.COMPARATOR], r = e.match(t);
					if (!r) throw new TypeError("Invalid comparator: " + e);
					this.operator = void 0 !== r[1] ? r[1] : "", "=" === this.operator && (this.operator = ""), r[2] ? this.semver = new SemVer(r[2], this.options.loose) : this.semver = f;
				}, Comparator.prototype.toString = function() {
					return this.value;
				}, Comparator.prototype.test = function(e) {
					if (r("Comparator.test", e, this.options.loose), this.semver === f || e === f) return !0;
					if ("string" == typeof e) try {
						e = new SemVer(e, this.options);
					} catch (e) {
						return !1;
					}
					return cmp(e, this.operator, this.semver, this.options);
				}, Comparator.prototype.intersects = function(e, t) {
					if (!(e instanceof Comparator)) throw new TypeError("a Comparator is required");
					var r;
					if (t && "object" == typeof t || (t = {
						loose: !!t,
						includePrerelease: !1
					}), "" === this.operator) return "" === this.value || (r = new Range(e.value, t), satisfies(this.value, r, t));
					if ("" === e.operator) return "" === e.value || (r = new Range(this.value, t), satisfies(e.semver, r, t));
					var n = !(">=" !== this.operator && ">" !== this.operator || ">=" !== e.operator && ">" !== e.operator), s = !("<=" !== this.operator && "<" !== this.operator || "<=" !== e.operator && "<" !== e.operator), i = this.semver.version === e.semver.version, o = !(">=" !== this.operator && "<=" !== this.operator || ">=" !== e.operator && "<=" !== e.operator), a = cmp(this.semver, "<", e.semver, t) && (">=" === this.operator || ">" === this.operator) && ("<=" === e.operator || "<" === e.operator), l = cmp(this.semver, ">", e.semver, t) && ("<=" === this.operator || "<" === this.operator) && (">=" === e.operator || ">" === e.operator);
					return n || s || i && o || a || l;
				}, t.Range = Range, Range.prototype.format = function() {
					return this.range = this.set.map(function(e) {
						return e.join(" ").trim();
					}).join("||").trim(), this.range;
				}, Range.prototype.toString = function() {
					return this.range;
				}, Range.prototype.parseRange = function(e) {
					var t = this.options.loose, n = t ? a[p.HYPHENRANGELOOSE] : a[p.HYPHENRANGE];
					e = e.replace(n, hyphenReplace), r("hyphen replace", e), e = e.replace(a[p.COMPARATORTRIM], "$1$2$3"), r("comparator trim", e, a[p.COMPARATORTRIM]), e = (e = (e = e.replace(a[p.TILDETRIM], "$1~")).replace(a[p.CARETTRIM], "$1^")).split(/\s+/).join(" ");
					var s = t ? a[p.COMPARATORLOOSE] : a[p.COMPARATOR], i = e.split(" ").map(function(e) {
						return function(e, t) {
							return r("comp", e, t), e = function(e, t) {
								return e.trim().split(/\s+/).map(function(e) {
									return function(e, t) {
										r("caret", e, t);
										var n = t.loose ? a[p.CARETLOOSE] : a[p.CARET];
										return e.replace(n, function(t, n, s, i, o) {
											var a;
											return r("caret", e, t, n, s, i, o), isX(n) ? a = "" : isX(s) ? a = ">=" + n + ".0.0 <" + (+n + 1) + ".0.0" : isX(i) ? a = "0" === n ? ">=" + n + "." + s + ".0 <" + n + "." + (+s + 1) + ".0" : ">=" + n + "." + s + ".0 <" + (+n + 1) + ".0.0" : o ? (r("replaceCaret pr", o), a = "0" === n ? "0" === s ? ">=" + n + "." + s + "." + i + "-" + o + " <" + n + "." + s + "." + (+i + 1) : ">=" + n + "." + s + "." + i + "-" + o + " <" + n + "." + (+s + 1) + ".0" : ">=" + n + "." + s + "." + i + "-" + o + " <" + (+n + 1) + ".0.0") : (r("no pr"), a = "0" === n ? "0" === s ? ">=" + n + "." + s + "." + i + " <" + n + "." + s + "." + (+i + 1) : ">=" + n + "." + s + "." + i + " <" + n + "." + (+s + 1) + ".0" : ">=" + n + "." + s + "." + i + " <" + (+n + 1) + ".0.0"), r("caret return", a), a;
										});
									}(e, t);
								}).join(" ");
							}(e, t), r("caret", e), e = function(e, t) {
								return e.trim().split(/\s+/).map(function(e) {
									return function(e, t) {
										var n = t.loose ? a[p.TILDELOOSE] : a[p.TILDE];
										return e.replace(n, function(t, n, s, i, o) {
											var a;
											return r("tilde", e, t, n, s, i, o), isX(n) ? a = "" : isX(s) ? a = ">=" + n + ".0.0 <" + (+n + 1) + ".0.0" : isX(i) ? a = ">=" + n + "." + s + ".0 <" + n + "." + (+s + 1) + ".0" : o ? (r("replaceTilde pr", o), a = ">=" + n + "." + s + "." + i + "-" + o + " <" + n + "." + (+s + 1) + ".0") : a = ">=" + n + "." + s + "." + i + " <" + n + "." + (+s + 1) + ".0", r("tilde return", a), a;
										});
									}(e, t);
								}).join(" ");
							}(e, t), r("tildes", e), e = function(e, t) {
								return r("replaceXRanges", e, t), e.split(/\s+/).map(function(e) {
									return function(e, t) {
										e = e.trim();
										var n = t.loose ? a[p.XRANGELOOSE] : a[p.XRANGE];
										return e.replace(n, function(n, s, i, o, a, l) {
											r("xRange", e, n, s, i, o, a, l);
											var p = isX(i), c = p || isX(o), u = c || isX(a), d = u;
											return "=" === s && d && (s = ""), l = t.includePrerelease ? "-0" : "", p ? n = ">" === s || "<" === s ? "<0.0.0-0" : "*" : s && d ? (c && (o = 0), a = 0, ">" === s ? (s = ">=", c ? (i = +i + 1, o = 0, a = 0) : (o = +o + 1, a = 0)) : "<=" === s && (s = "<", c ? i = +i + 1 : o = +o + 1), n = s + i + "." + o + "." + a + l) : c ? n = ">=" + i + ".0.0" + l + " <" + (+i + 1) + ".0.0" + l : u && (n = ">=" + i + "." + o + ".0" + l + " <" + i + "." + (+o + 1) + ".0" + l), r("xRange return", n), n;
										});
									}(e, t);
								}).join(" ");
							}(e, t), r("xrange", e), e = function(e, t) {
								return r("replaceStars", e, t), e.trim().replace(a[p.STAR], "");
							}(e, t), r("stars", e), e;
						}(e, this.options);
					}, this).join(" ").split(/\s+/);
					return this.options.loose && (i = i.filter(function(e) {
						return !!e.match(s);
					})), i = i.map(function(e) {
						return new Comparator(e, this.options);
					}, this);
				}, Range.prototype.intersects = function(e, t) {
					if (!(e instanceof Range)) throw new TypeError("a Range is required");
					return this.set.some(function(r) {
						return isSatisfiable(r, t) && e.set.some(function(e) {
							return isSatisfiable(e, t) && r.every(function(r) {
								return e.every(function(e) {
									return r.intersects(e, t);
								});
							});
						});
					});
				}, t.toComparators = function(e, t) {
					return new Range(e, t).set.map(function(e) {
						return e.map(function(e) {
							return e.value;
						}).join(" ").trim().split(" ");
					});
				}, Range.prototype.test = function(e) {
					if (!e) return !1;
					if ("string" == typeof e) try {
						e = new SemVer(e, this.options);
					} catch (e) {
						return !1;
					}
					for (var t = 0; t < this.set.length; t++) if (testSet(this.set[t], e, this.options)) return !0;
					return !1;
				}, t.satisfies = satisfies, t.maxSatisfying = function(e, t, r) {
					var n = null, s = null;
					try {
						var i = new Range(t, r);
					} catch (e) {
						return null;
					}
					return e.forEach(function(e) {
						i.test(e) && (n && -1 !== s.compare(e) || (s = new SemVer(n = e, r)));
					}), n;
				}, t.minSatisfying = function(e, t, r) {
					var n = null, s = null;
					try {
						var i = new Range(t, r);
					} catch (e) {
						return null;
					}
					return e.forEach(function(e) {
						i.test(e) && (n && 1 !== s.compare(e) || (s = new SemVer(n = e, r)));
					}), n;
				}, t.minVersion = function(e, t) {
					e = new Range(e, t);
					var r = new SemVer("0.0.0");
					if (e.test(r)) return r;
					if (r = new SemVer("0.0.0-0"), e.test(r)) return r;
					r = null;
					for (var n = 0; n < e.set.length; ++n) e.set[n].forEach(function(e) {
						var t = new SemVer(e.semver.version);
						switch (e.operator) {
							case ">": 0 === t.prerelease.length ? t.patch++ : t.prerelease.push(0), t.raw = t.format();
							case "":
							case ">=":
								r && !gt(r, t) || (r = t);
								break;
							case "<":
							case "<=": break;
							default: throw new Error("Unexpected operation: " + e.operator);
						}
					});
					if (r && e.test(r)) return r;
					return null;
				}, t.validRange = function(e, t) {
					try {
						return new Range(e, t).range || "*";
					} catch (e) {
						return null;
					}
				}, t.ltr = function(e, t, r) {
					return outside(e, t, "<", r);
				}, t.gtr = function(e, t, r) {
					return outside(e, t, ">", r);
				}, t.outside = outside, t.prerelease = function(e, t) {
					var r = parse(e, t);
					return r && r.prerelease.length ? r.prerelease : null;
				}, t.intersects = function(e, t, r) {
					return e = new Range(e, r), t = new Range(t, r), e.intersects(t);
				}, t.coerce = function(e, t) {
					if (e instanceof SemVer) return e;
					"number" == typeof e && (e = String(e));
					if ("string" != typeof e) return null;
					var r = null;
					if ((t = t || {}).rtl) {
						for (var n; (n = a[p.COERCERTL].exec(e)) && (!r || r.index + r[0].length !== e.length);) r && n.index + n[0].length === r.index + r[0].length || (r = n), a[p.COERCERTL].lastIndex = n.index + n[1].length + n[2].length;
						a[p.COERCERTL].lastIndex = -1;
					} else r = e.match(a[p.COERCE]);
					if (null === r) return null;
					return parse(r[2] + "." + (r[3] || "0") + "." + (r[4] || "0"), t);
				};
			},
			"./node_modules/.pnpm/supports-color@7.2.0/node_modules/supports-color/index.js": function(e, t, r) {
				"use strict";
				const n = r("os"), s = r("tty"), i = r("./node_modules/.pnpm/has-flag@4.0.0/node_modules/has-flag/index.js"), { env: o } = process;
				let a;
				function translateLevel(e) {
					return 0 !== e && {
						level: e,
						hasBasic: !0,
						has256: e >= 2,
						has16m: e >= 3
					};
				}
				function supportsColor(e, t) {
					if (0 === a) return 0;
					if (i("color=16m") || i("color=full") || i("color=truecolor")) return 3;
					if (i("color=256")) return 2;
					if (e && !t && void 0 === a) return 0;
					const r = a || 0;
					if ("dumb" === o.TERM) return r;
					if ("win32" === process.platform) {
						const e = n.release().split(".");
						return Number(e[0]) >= 10 && Number(e[2]) >= 10586 ? Number(e[2]) >= 14931 ? 3 : 2 : 1;
					}
					if ("CI" in o) return [
						"TRAVIS",
						"CIRCLECI",
						"APPVEYOR",
						"GITLAB_CI",
						"GITHUB_ACTIONS",
						"BUILDKITE"
					].some((e) => e in o) || "codeship" === o.CI_NAME ? 1 : r;
					if ("TEAMCITY_VERSION" in o) return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(o.TEAMCITY_VERSION) ? 1 : 0;
					if ("truecolor" === o.COLORTERM) return 3;
					if ("TERM_PROGRAM" in o) {
						const e = parseInt((o.TERM_PROGRAM_VERSION || "").split(".")[0], 10);
						switch (o.TERM_PROGRAM) {
							case "iTerm.app": return e >= 3 ? 3 : 2;
							case "Apple_Terminal": return 2;
						}
					}
					return /-256(color)?$/i.test(o.TERM) ? 2 : /^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(o.TERM) || "COLORTERM" in o ? 1 : r;
				}
				i("no-color") || i("no-colors") || i("color=false") || i("color=never") ? a = 0 : (i("color") || i("colors") || i("color=true") || i("color=always")) && (a = 1), "FORCE_COLOR" in o && (a = "true" === o.FORCE_COLOR ? 1 : "false" === o.FORCE_COLOR ? 0 : 0 === o.FORCE_COLOR.length ? 1 : Math.min(parseInt(o.FORCE_COLOR, 10), 3)), e.exports = {
					supportsColor: function(e) {
						return translateLevel(supportsColor(e, e && e.isTTY));
					},
					stdout: translateLevel(supportsColor(!0, s.isatty(1))),
					stderr: translateLevel(supportsColor(!0, s.isatty(2)))
				};
			},
			assert: function(e) {
				"use strict";
				e.exports = __require("assert");
			},
			fs: function(e) {
				"use strict";
				e.exports = __require("fs");
			},
			module: function(e) {
				"use strict";
				e.exports = __require("module");
			},
			os: function(e) {
				"use strict";
				e.exports = __require("os");
			},
			path: function(e) {
				"use strict";
				e.exports = __require("path");
			},
			process: function(e) {
				"use strict";
				e.exports = __require("process");
			},
			tty: function(e) {
				"use strict";
				e.exports = __require("tty");
			},
			url: function(e) {
				"use strict";
				e.exports = __require("url");
			},
			util: function(e) {
				"use strict";
				e.exports = __require("util");
			},
			v8: function(e) {
				"use strict";
				e.exports = __require("v8");
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/caching.js": function(e, t, r) {
				"use strict";
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.assertSimpleType = assertSimpleType, t.makeStrongCache = makeStrongCache, t.makeStrongCacheSync = function(e) {
					return synchronize(makeStrongCache(e));
				}, t.makeWeakCache = makeWeakCache, t.makeWeakCacheSync = function(e) {
					return synchronize(makeWeakCache(e));
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/async.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/util.js");
				const synchronize = (e) => _gensync()(e).sync;
				function* genTrue() {
					return !0;
				}
				function makeWeakCache(e) {
					return makeCachedFunction(WeakMap, e);
				}
				function makeStrongCache(e) {
					return makeCachedFunction(Map, e);
				}
				function makeCachedFunction(e, t) {
					const r = new e(), i = new e(), o = new e();
					return function* (e, a) {
						const l = yield* (0, n.isAsync)(), p = l ? i : r, c = yield* function* (e, t, r, s, i) {
							const o = yield* getCachedValue(t, s, i);
							if (o.valid) return o;
							if (e) {
								const e = yield* getCachedValue(r, s, i);
								if (e.valid) return {
									valid: !0,
									value: yield* (0, n.waitFor)(e.value.promise)
								};
							}
							return {
								valid: !1,
								value: null
							};
						}(l, p, o, e, a);
						if (c.valid) return c.value;
						const u = new CacheConfigurator(a), d = t(e, u);
						let h, m;
						return m = (0, s.isIterableIterator)(d) ? yield* (0, n.onFirstPause)(d, () => {
							h = function(e, t, r) {
								const n = new Lock();
								return updateFunctionCache(t, e, r, n), n;
							}(u, o, e);
						}) : d, updateFunctionCache(p, u, e, m), h && (o.delete(e), h.release(m)), m;
					};
				}
				function* getCachedValue(e, t, r) {
					const n = e.get(t);
					if (n) {
						for (const { value: e, valid: t } of n) if (yield* t(r)) return {
							valid: !0,
							value: e
						};
					}
					return {
						valid: !1,
						value: null
					};
				}
				function updateFunctionCache(e, t, r, n) {
					t.configured() || t.forever();
					let s = e.get(r);
					switch (t.deactivate(), t.mode()) {
						case "forever":
							s = [{
								value: n,
								valid: genTrue
							}], e.set(r, s);
							break;
						case "invalidate":
							s = [{
								value: n,
								valid: t.validator()
							}], e.set(r, s);
							break;
						case "valid": s ? s.push({
							value: n,
							valid: t.validator()
						}) : (s = [{
							value: n,
							valid: t.validator()
						}], e.set(r, s));
					}
				}
				class CacheConfigurator {
					constructor(e) {
						this._active = !0, this._never = !1, this._forever = !1, this._invalidate = !1, this._configured = !1, this._pairs = [], this._data = void 0, this._data = e;
					}
					simple() {
						return function(e) {
							function cacheFn(t) {
								if ("boolean" != typeof t) return e.using(() => assertSimpleType(t()));
								t ? e.forever() : e.never();
							}
							return cacheFn.forever = () => e.forever(), cacheFn.never = () => e.never(), cacheFn.using = (t) => e.using(() => assertSimpleType(t())), cacheFn.invalidate = (t) => e.invalidate(() => assertSimpleType(t())), cacheFn;
						}(this);
					}
					mode() {
						return this._never ? "never" : this._forever ? "forever" : this._invalidate ? "invalidate" : "valid";
					}
					forever() {
						if (!this._active) throw new Error("Cannot change caching after evaluation has completed.");
						if (this._never) throw new Error("Caching has already been configured with .never()");
						this._forever = !0, this._configured = !0;
					}
					never() {
						if (!this._active) throw new Error("Cannot change caching after evaluation has completed.");
						if (this._forever) throw new Error("Caching has already been configured with .forever()");
						this._never = !0, this._configured = !0;
					}
					using(e) {
						if (!this._active) throw new Error("Cannot change caching after evaluation has completed.");
						if (this._never || this._forever) throw new Error("Caching has already been configured with .never or .forever()");
						this._configured = !0;
						const t = e(this._data), r = (0, n.maybeAsync)(e, "You appear to be using an async cache handler, but Babel has been called synchronously");
						return (0, n.isThenable)(t) ? t.then((e) => (this._pairs.push([e, r]), e)) : (this._pairs.push([t, r]), t);
					}
					invalidate(e) {
						return this._invalidate = !0, this.using(e);
					}
					validator() {
						const e = this._pairs;
						return function* (t) {
							for (const [r, n] of e) if (r !== (yield* n(t))) return !1;
							return !0;
						};
					}
					deactivate() {
						this._active = !1;
					}
					configured() {
						return this._configured;
					}
				}
				function assertSimpleType(e) {
					if ((0, n.isThenable)(e)) throw new Error("You appear to be using an async cache handler, which your current version of Babel does not support. We may add support for this in the future, but if you're on the most recent version of @babel/core and still seeing this error, then you'll need to synchronously handle your caching logic.");
					if (null != e && "string" != typeof e && "boolean" != typeof e && "number" != typeof e) throw new Error("Cache keys must be either string, boolean, number, null, or undefined.");
					return e;
				}
				class Lock {
					constructor() {
						this.released = !1, this.promise = void 0, this._resolve = void 0, this.promise = new Promise((e) => {
							this._resolve = e;
						});
					}
					release(e) {
						this.released = !0, this._resolve(e);
					}
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/config-chain.js": function(e, t, r) {
				"use strict";
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				function _debug() {
					const e = r("./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/index.js");
					return _debug = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.buildPresetChain = function* (e, t) {
					const r = yield* d(e, t);
					return r ? {
						plugins: dedupDescriptors(r.plugins),
						presets: dedupDescriptors(r.presets),
						options: r.options.map((e) => normalizeOptions(e)),
						files: /* @__PURE__ */ new Set()
					} : null;
				}, t.buildPresetChainWalker = void 0, t.buildRootChain = function* (e, t) {
					let r, n;
					const o = new i.ConfigPrinter(), a = yield* v({
						options: e,
						dirname: t.cwd
					}, t, void 0, o);
					if (!a) return null;
					const p = yield* o.output();
					let c;
					"string" == typeof e.configFile ? c = yield* (0, l.loadConfig)(e.configFile, t.cwd, t.envName, t.caller) : !1 !== e.configFile && (c = yield* (0, l.findRootConfig)(t.root, t.envName, t.caller));
					let { babelrc: u, babelrcRoots: d } = e, h = t.cwd;
					const m = emptyChain(), f = new i.ConfigPrinter();
					if (c) {
						const e = b(c), n = yield* loadFileChain(e, t, void 0, f);
						if (!n) return null;
						r = yield* f.output(), void 0 === u && (u = e.options.babelrc), void 0 === d && (h = e.dirname, d = e.options.babelrcRoots), mergeChain(m, n);
					}
					let y, x, E = !1;
					const T = emptyChain();
					if ((!0 === u || void 0 === u) && "string" == typeof t.filename) {
						const e = yield* (0, l.findPackageData)(t.filename);
						if (e && function(e, t, r, n) {
							if ("boolean" == typeof r) return r;
							const i = e.root;
							if (void 0 === r) return t.directories.includes(i);
							let o = r;
							Array.isArray(o) || (o = [o]);
							if (o = o.map((e) => "string" == typeof e ? _path().resolve(n, e) : e), 1 === o.length && o[0] === i) return t.directories.includes(i);
							return o.some((r) => ("string" == typeof r && (r = (0, s.default)(r, n)), t.directories.some((t) => matchPattern(r, n, t, e))));
						}(t, e, d, h)) {
							if ({ignore: y, config: x} = yield* (0, l.findRelativeConfig)(e, t.envName, t.caller), y && T.files.add(y.filepath), y && shouldIgnore(t, y.ignore, null, y.dirname) && (E = !0), x && !E) {
								const e = g(x), r = new i.ConfigPrinter(), s = yield* loadFileChain(e, t, void 0, r);
								s ? (n = yield* r.output(), mergeChain(T, s)) : E = !0;
							}
							x && E && T.files.add(x.filepath);
						}
					}
					t.showConfig && console.log(`Babel configs on "${t.filename}" (ascending priority):\n` + [
						r,
						n,
						p
					].filter((e) => !!e).join("\n\n") + "\n-----End Babel configs-----");
					const S = mergeChain(mergeChain(mergeChain(emptyChain(), m), T), a);
					return {
						plugins: E ? [] : dedupDescriptors(S.plugins),
						presets: E ? [] : dedupDescriptors(S.presets),
						options: E ? [] : S.options.map((e) => normalizeOptions(e)),
						fileHandling: E ? "ignored" : "transpile",
						ignore: y || void 0,
						babelrc: x || void 0,
						config: c || void 0,
						files: S.files
					};
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/options.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/pattern-to-regex.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/printer.js"), o = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/rewrite-stack-trace.js"), a = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/config-error.js"), l = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/index.js"), p = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/caching.js"), c = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/config-descriptors.js");
				const u = _debug()("babel:config:config-chain");
				const d = t.buildPresetChainWalker = makeChainWalker({
					root: (e) => h(e),
					env: (e, t) => m(e)(t),
					overrides: (e, t) => f(e)(t),
					overridesEnv: (e, t, r) => y(e)(t)(r),
					createLogger: () => () => {}
				}), h = (0, p.makeWeakCacheSync)((e) => buildRootDescriptors(e, e.alias, c.createUncachedDescriptors)), m = (0, p.makeWeakCacheSync)((e) => (0, p.makeStrongCacheSync)((t) => buildEnvDescriptors(e, e.alias, c.createUncachedDescriptors, t))), f = (0, p.makeWeakCacheSync)((e) => (0, p.makeStrongCacheSync)((t) => buildOverrideDescriptors(e, e.alias, c.createUncachedDescriptors, t))), y = (0, p.makeWeakCacheSync)((e) => (0, p.makeStrongCacheSync)((t) => (0, p.makeStrongCacheSync)((r) => buildOverrideEnvDescriptors(e, e.alias, c.createUncachedDescriptors, t, r))));
				const b = (0, p.makeWeakCacheSync)((e) => ({
					filepath: e.filepath,
					dirname: e.dirname,
					options: (0, n.validate)("configfile", e.options, e.filepath)
				})), g = (0, p.makeWeakCacheSync)((e) => ({
					filepath: e.filepath,
					dirname: e.dirname,
					options: (0, n.validate)("babelrcfile", e.options, e.filepath)
				})), x = (0, p.makeWeakCacheSync)((e) => ({
					filepath: e.filepath,
					dirname: e.dirname,
					options: (0, n.validate)("extendsfile", e.options, e.filepath)
				})), v = makeChainWalker({
					root: (e) => buildRootDescriptors(e, "base", c.createCachedDescriptors),
					env: (e, t) => buildEnvDescriptors(e, "base", c.createCachedDescriptors, t),
					overrides: (e, t) => buildOverrideDescriptors(e, "base", c.createCachedDescriptors, t),
					overridesEnv: (e, t, r) => buildOverrideEnvDescriptors(e, "base", c.createCachedDescriptors, t, r),
					createLogger: (e, t, r) => function(e, t, r) {
						var n;
						if (!r) return () => {};
						return r.configure(t.showConfig, i.ChainFormatter.Programmatic, { callerName: null == (n = t.caller) ? void 0 : n.name });
					}(0, t, r)
				}), E = makeChainWalker({
					root: (e) => T(e),
					env: (e, t) => S(e)(t),
					overrides: (e, t) => P(e)(t),
					overridesEnv: (e, t, r) => _(e)(t)(r),
					createLogger: (e, t, r) => function(e, t, r) {
						if (!r) return () => {};
						return r.configure(t.showConfig, i.ChainFormatter.Config, { filepath: e });
					}(e.filepath, t, r)
				});
				function* loadFileChain(e, t, r, n) {
					const s = yield* E(e, t, r, n);
					return s?.files.add(e.filepath), s;
				}
				const T = (0, p.makeWeakCacheSync)((e) => buildRootDescriptors(e, e.filepath, c.createUncachedDescriptors)), S = (0, p.makeWeakCacheSync)((e) => (0, p.makeStrongCacheSync)((t) => buildEnvDescriptors(e, e.filepath, c.createUncachedDescriptors, t))), P = (0, p.makeWeakCacheSync)((e) => (0, p.makeStrongCacheSync)((t) => buildOverrideDescriptors(e, e.filepath, c.createUncachedDescriptors, t))), _ = (0, p.makeWeakCacheSync)((e) => (0, p.makeStrongCacheSync)((t) => (0, p.makeStrongCacheSync)((r) => buildOverrideEnvDescriptors(e, e.filepath, c.createUncachedDescriptors, t, r))));
				function buildRootDescriptors({ dirname: e, options: t }, r, n) {
					return n(e, t, r);
				}
				function buildEnvDescriptors({ dirname: e, options: t }, r, n, s) {
					var i;
					const o = null == (i = t.env) ? void 0 : i[s];
					return o ? n(e, o, `${r}.env["${s}"]`) : null;
				}
				function buildOverrideDescriptors({ dirname: e, options: t }, r, n, s) {
					var i;
					const o = null == (i = t.overrides) ? void 0 : i[s];
					if (!o) throw new Error("Assertion failure - missing override");
					return n(e, o, `${r}.overrides[${s}]`);
				}
				function buildOverrideEnvDescriptors({ dirname: e, options: t }, r, n, s, i) {
					var o, a;
					const l = null == (o = t.overrides) ? void 0 : o[s];
					if (!l) throw new Error("Assertion failure - missing override");
					const p = null == (a = l.env) ? void 0 : a[i];
					return p ? n(e, p, `${r}.overrides[${s}].env["${i}"]`) : null;
				}
				function makeChainWalker({ root: e, env: t, overrides: r, overridesEnv: n, createLogger: s }) {
					return function* (i, o, a = /* @__PURE__ */ new Set(), l) {
						const { dirname: p } = i, c = [], u = e(i);
						if (configIsApplicable(u, p, o, i.filepath)) {
							c.push({
								config: u,
								envName: void 0,
								index: void 0
							});
							const e = t(i, o.envName);
							e && configIsApplicable(e, p, o, i.filepath) && c.push({
								config: e,
								envName: o.envName,
								index: void 0
							}), (u.options.overrides || []).forEach((e, t) => {
								const s = r(i, t);
								if (configIsApplicable(s, p, o, i.filepath)) {
									c.push({
										config: s,
										index: t,
										envName: void 0
									});
									const e = n(i, t, o.envName);
									e && configIsApplicable(e, p, o, i.filepath) && c.push({
										config: e,
										index: t,
										envName: o.envName
									});
								}
							});
						}
						if (c.some(({ config: { options: { ignore: e, only: t } } }) => shouldIgnore(o, e, t, p))) return null;
						const d = emptyChain(), h = s(i, o, l);
						for (const { config: e, index: t, envName: r } of c) {
							if (!(yield* mergeExtendsChain(d, e.options, p, o, a, l))) return null;
							h(e, t, r), yield* mergeChainOpts(d, e);
						}
						return d;
					};
				}
				function* mergeExtendsChain(e, t, r, n, s, i) {
					if (void 0 === t.extends) return !0;
					const o = yield* (0, l.loadConfig)(t.extends, r, n.envName, n.caller);
					if (s.has(o)) throw new Error(`Configuration cycle detected loading ${o.filepath}.\nFile already loaded following the config chain:\n` + Array.from(s, (e) => ` - ${e.filepath}`).join("\n"));
					s.add(o);
					const a = yield* loadFileChain(x(o), n, s, i);
					return s.delete(o), !!a && (mergeChain(e, a), !0);
				}
				function mergeChain(e, t) {
					e.options.push(...t.options), e.plugins.push(...t.plugins), e.presets.push(...t.presets);
					for (const r of t.files) e.files.add(r);
					return e;
				}
				function* mergeChainOpts(e, { options: t, plugins: r, presets: n }) {
					return e.options.push(t), e.plugins.push(...yield* r()), e.presets.push(...yield* n()), e;
				}
				function emptyChain() {
					return {
						options: [],
						presets: [],
						plugins: [],
						files: /* @__PURE__ */ new Set()
					};
				}
				function normalizeOptions(e) {
					const t = Object.assign({}, e);
					return delete t.extends, delete t.env, delete t.overrides, delete t.plugins, delete t.presets, delete t.passPerPreset, delete t.ignore, delete t.only, delete t.test, delete t.include, delete t.exclude, hasOwnProperty.call(t, "sourceMap") && (t.sourceMaps = t.sourceMap, delete t.sourceMap), t;
				}
				function dedupDescriptors(e) {
					const t = /* @__PURE__ */ new Map(), r = [];
					for (const n of e) if ("function" == typeof n.value) {
						const e = n.value;
						let s = t.get(e);
						s || (s = /* @__PURE__ */ new Map(), t.set(e, s));
						let i = s.get(n.name);
						i ? i.value = n : (i = { value: n }, r.push(i), n.ownPass || s.set(n.name, i));
					} else r.push({ value: n });
					return r.reduce((e, t) => (e.push(t.value), e), []);
				}
				function configIsApplicable({ options: e }, t, r, n) {
					return (void 0 === e.test || configFieldIsApplicable(r, e.test, t, n)) && (void 0 === e.include || configFieldIsApplicable(r, e.include, t, n)) && (void 0 === e.exclude || !configFieldIsApplicable(r, e.exclude, t, n));
				}
				function configFieldIsApplicable(e, t, r, n) {
					return matchesPatterns(e, Array.isArray(t) ? t : [t], r, n);
				}
				function ignoreListReplacer(e, t) {
					return t instanceof RegExp ? String(t) : t;
				}
				function shouldIgnore(e, t, r, n) {
					if (t && matchesPatterns(e, t, n)) {
						var s;
						const r = `No config is applied to "${null != (s = e.filename) ? s : "(unknown)"}" because it matches one of \`ignore: ${JSON.stringify(t, ignoreListReplacer)}\` from "${n}"`;
						return u(r), e.showConfig && console.log(r), !0;
					}
					if (r && !matchesPatterns(e, r, n)) {
						var i;
						const t = `No config is applied to "${null != (i = e.filename) ? i : "(unknown)"}" because it fails to match one of \`only: ${JSON.stringify(r, ignoreListReplacer)}\` from "${n}"`;
						return u(t), e.showConfig && console.log(t), !0;
					}
					return !1;
				}
				function matchesPatterns(e, t, r, n) {
					return t.some((t) => matchPattern(t, r, e.filename, e, n));
				}
				function matchPattern(e, t, r, n, i) {
					if ("function" == typeof e) return !!(0, o.endHiddenCallStack)(e)(r, {
						dirname: t,
						envName: n.envName,
						caller: n.caller
					});
					if ("string" != typeof r) throw new a.default("Configuration contains string/RegExp pattern, but no filename was passed to Babel", i);
					return "string" == typeof e && (e = (0, s.default)(e, t)), e.test(r);
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/config-descriptors.js": function(e, t, r) {
				"use strict";
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.createCachedDescriptors = function(e, t, r) {
					const { plugins: n, presets: s, passPerPreset: i } = t;
					return {
						options: optionsWithResolvedBrowserslistConfigFile(t, e),
						plugins: n ? () => u(n, e)(r) : () => handlerOf([]),
						presets: s ? () => p(s, e)(r)(!!i) : () => handlerOf([])
					};
				}, t.createDescriptor = createDescriptor, t.createUncachedDescriptors = function(e, t, r) {
					return {
						options: optionsWithResolvedBrowserslistConfigFile(t, e),
						plugins: (0, n.once)(() => createPluginDescriptors(t.plugins || [], e, r)),
						presets: (0, n.once)(() => createPresetDescriptors(t.presets || [], e, r, !!t.passPerPreset))
					};
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/functional.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/index.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/item.js"), o = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/caching.js"), a = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/resolve-targets.js");
				function* handlerOf(e) {
					return e;
				}
				function optionsWithResolvedBrowserslistConfigFile(e, t) {
					return "string" == typeof e.browserslistConfigFile && (e.browserslistConfigFile = (0, a.resolveBrowserslistConfigFile)(e.browserslistConfigFile, t)), e;
				}
				const l = /* @__PURE__ */ new WeakMap(), p = (0, o.makeWeakCacheSync)((e, t) => {
					const r = t.using((e) => e);
					return (0, o.makeStrongCacheSync)((t) => (0, o.makeStrongCache)(function* (n) {
						return (yield* createPresetDescriptors(e, r, t, n)).map((e) => loadCachedDescriptor(l, e));
					}));
				}), c = /* @__PURE__ */ new WeakMap(), u = (0, o.makeWeakCacheSync)((e, t) => {
					const r = t.using((e) => e);
					return (0, o.makeStrongCache)(function* (t) {
						return (yield* createPluginDescriptors(e, r, t)).map((e) => loadCachedDescriptor(c, e));
					});
				}), d = {};
				function loadCachedDescriptor(e, t) {
					const { value: r, options: n = d } = t;
					if (!1 === n) return t;
					let s = e.get(r);
					s || (s = /* @__PURE__ */ new WeakMap(), e.set(r, s));
					let i = s.get(n);
					if (i || (i = [], s.set(n, i)), !i.includes(t)) {
						const e = i.filter((e) => {
							return n = t, (r = e).name === n.name && r.value === n.value && r.options === n.options && r.dirname === n.dirname && r.alias === n.alias && r.ownPass === n.ownPass && (null == (s = r.file) ? void 0 : s.request) === (null == (i = n.file) ? void 0 : i.request) && (null == (o = r.file) ? void 0 : o.resolved) === (null == (a = n.file) ? void 0 : a.resolved);
							var r, n, s, i, o, a;
						});
						if (e.length > 0) return e[0];
						i.push(t);
					}
					return t;
				}
				function* createPresetDescriptors(e, t, r, n) {
					return yield* createDescriptors("preset", e, t, r, n);
				}
				function* createPluginDescriptors(e, t, r) {
					return yield* createDescriptors("plugin", e, t, r);
				}
				function* createDescriptors(e, t, r, n, s) {
					const i = yield* _gensync().all(t.map((t, i) => createDescriptor(t, r, {
						type: e,
						alias: `${n}$${i}`,
						ownPass: !!s
					})));
					return function(e) {
						const t = /* @__PURE__ */ new Map();
						for (const r of e) {
							if ("function" != typeof r.value) continue;
							let n = t.get(r.value);
							if (n || (n = /* @__PURE__ */ new Set(), t.set(r.value, n)), n.has(r.name)) {
								const t = e.filter((e) => e.value === r.value);
								throw new Error([
									"Duplicate plugin/preset detected.",
									"If you'd like to use two separate instances of a plugin,",
									"they need separate names, e.g.",
									"",
									"  plugins: [",
									"    ['some-plugin', {}],",
									"    ['some-plugin', {}, 'some unique name'],",
									"  ]",
									"",
									"Duplicates detected are:",
									`${JSON.stringify(t, null, 2)}`
								].join("\n"));
							}
							n.add(r.name);
						}
					}(i), i;
				}
				function* createDescriptor(e, t, { type: r, alias: n, ownPass: o }) {
					const a = (0, i.getItemDescriptor)(e);
					if (a) return a;
					let l, p, c, u = e;
					Array.isArray(u) && (3 === u.length ? [u, p, l] = u : [u, p] = u);
					let d = null;
					if ("string" == typeof u) {
						if ("string" != typeof r) throw new Error("To resolve a string-based item, the type of item must be given");
						const e = "plugin" === r ? s.loadPlugin : s.loadPreset, n = u;
						({filepath: d, value: u} = yield* e(u, t)), c = {
							request: n,
							resolved: d
						};
					}
					if (!u) throw new Error(`Unexpected falsy value: ${String(u)}`);
					if ("object" == typeof u && u.__esModule) {
						if (!u.default) throw new Error("Must export a default export when using ES6 modules.");
						u = u.default;
					}
					if ("object" != typeof u && "function" != typeof u) throw new Error(`Unsupported format: ${typeof u}. Expected an object or a function.`);
					if (null !== d && "object" == typeof u && u) throw new Error(`Plugin/Preset files are not allowed to export objects, only functions. In ${d}`);
					return {
						name: l,
						alias: d || n,
						value: u,
						options: p,
						dirname: t,
						ownPass: o,
						file: c
					};
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/configuration.js": function(e, t, r) {
				"use strict";
				function _debug() {
					const e = r("./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/index.js");
					return _debug = function() {
						return e;
					}, e;
				}
				function _fs() {
					const e = r("fs");
					return _fs = function() {
						return e;
					}, e;
				}
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				function _json() {
					const e = r("./node_modules/.pnpm/json5@2.2.3/node_modules/json5/dist/index.mjs");
					return _json = function() {
						return e;
					}, e;
				}
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.ROOT_CONFIG_FILENAMES = void 0, t.findConfigUpwards = function(e) {
					let t = e;
					for (;;) {
						for (const e of h) if (_fs().existsSync(_path().join(t, e))) return t;
						const e = _path().dirname(t);
						if (t === e) break;
						t = e;
					}
					return null;
				}, t.findRelativeConfig = function* (e, t, r) {
					let n = null, s = null;
					const i = _path().dirname(e.filepath);
					for (const a of e.directories) {
						var o;
						if (!n) n = yield* loadOneConfig(m, a, t, r, (null == (o = e.pkg) ? void 0 : o.dirname) === a ? g(e.pkg) : null);
						if (!s) s = yield* v(_path().join(a, f)), s && d("Found ignore %o from %o.", s.filepath, i);
					}
					return {
						config: n,
						ignore: s
					};
				}, t.findRootConfig = function(e, t, r) {
					return loadOneConfig(h, e, t, r);
				}, t.loadConfig = function* (e, t, n, s) {
					const i = (a = process.versions.node, p = "8.9", a = a.split("."), p = p.split("."), +a[0] > +p[0] || a[0] == p[0] && +a[1] >= +p[1] ? r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files sync recursive").resolve : (e, { paths: [t] }, n = r("module")) => {
						let s = n._findPath(e, n._nodeModulePaths(t).concat(t));
						if (s) return s;
						throw s = /* @__PURE__ */ new Error(`Cannot resolve module '${e}'`), s.code = "MODULE_NOT_FOUND", s;
					})(e, { paths: [t] }), o = yield* readConfig(i, n, s);
					var a, p;
					if (!o) throw new l.default("Config file contains no configuration data", i);
					return d("Loaded config %o from %o.", e, t), o;
				}, t.resolveShowConfigPath = function* (e) {
					const t = process.env.BABEL_SHOW_CONFIG_FOR;
					if (null != t) {
						const r = _path().resolve(e, t);
						if (!(yield* p.stat(r)).isFile()) throw new Error(`${r}: BABEL_SHOW_CONFIG_FOR must refer to a regular file, directories are not supported.`);
						return r;
					}
					return null;
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/caching.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/helpers/config-api.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/utils.js"), o = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/module-types.js"), a = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/pattern-to-regex.js"), l = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/config-error.js"), p = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/fs.js");
				r("module");
				var c = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/rewrite-stack-trace.js"), u = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/async.js");
				const d = _debug()("babel:config:loading:files:configuration"), h = t.ROOT_CONFIG_FILENAMES = [
					"babel.config.js",
					"babel.config.cjs",
					"babel.config.mjs",
					"babel.config.json",
					"babel.config.cts",
					"babel.config.ts",
					"babel.config.mts"
				], m = [
					".babelrc",
					".babelrc.js",
					".babelrc.cjs",
					".babelrc.mjs",
					".babelrc.json",
					".babelrc.cts"
				], f = ".babelignore", y = (0, n.makeWeakCache)(function* (e, t) {
					return yield* [], {
						options: (0, c.endHiddenCallStack)(e)((0, s.makeConfigAPI)(t)),
						cacheNeedsConfiguration: !t.configured()
					};
				});
				function* readConfigCode(e, t) {
					if (!_fs().existsSync(e)) return null;
					let r = yield* (0, o.default)(e, (yield* (0, u.isAsync)()) ? "auto" : "require", "You appear to be using a native ECMAScript module configuration file, which is only supported when running Babel asynchronously or when using the Node.js `--experimental-require-module` flag.", "You appear to be using a configuration file that contains top-level await, which is only supported when running Babel asynchronously."), n = !1;
					if ("function" == typeof r && ({options: r, cacheNeedsConfiguration: n} = yield* y(r, t)), !r || "object" != typeof r || Array.isArray(r)) throw new l.default("Configuration should be an exported JavaScript object.", e);
					if ("function" == typeof r.then) throw null == r.catch || r.catch(() => {}), new l.default("You appear to be using an async configuration, which your current version of Babel does not support. We may add support for this in the future, but if you're on the most recent version of @babel/core and still seeing this error, then you'll need to synchronously return your config.", e);
					return n && function(e) {
						throw new l.default("Caching was left unconfigured. Babel's plugins, presets, and .babelrc.js files can be configured\nfor various types of caching, using the first param of their handler functions:\n\nmodule.exports = function(api) {\n  // The API exposes the following:\n\n  // Cache the returned value forever and don't call this function again.\n  api.cache(true);\n\n  // Don't cache at all. Not recommended because it will be very slow.\n  api.cache(false);\n\n  // Cached based on the value of some function. If this function returns a value different from\n  // a previously-encountered value, the plugins will re-evaluate.\n  var env = api.cache(() => process.env.NODE_ENV);\n\n  // If testing for a specific env, we recommend specifics to avoid instantiating a plugin for\n  // any possible NODE_ENV value that might come up during plugin execution.\n  var isProd = api.cache(() => process.env.NODE_ENV === \"production\");\n\n  // .cache(fn) will perform a linear search though instances to find the matching plugin based\n  // based on previous instantiated plugins. If you want to recreate the plugin and discard the\n  // previous instance whenever something changes, you may use:\n  var isProd = api.cache.invalidate(() => process.env.NODE_ENV === \"production\");\n\n  // Note, we also expose the following more-verbose versions of the above examples:\n  api.cache.forever(); // api.cache(true)\n  api.cache.never();   // api.cache(false)\n  api.cache.using(fn); // api.cache(fn)\n\n  // Return the value that will be cached.\n  return { };\n};", e);
					}(e), function(e, t) {
						let r = b.get(e);
						r || b.set(e, r = /* @__PURE__ */ new Map());
						let n = r.get(t);
						n || (n = {
							filepath: t,
							dirname: _path().dirname(t),
							options: e
						}, r.set(t, n));
						return n;
					}(r, e);
				}
				const b = /* @__PURE__ */ new WeakMap();
				const g = (0, n.makeWeakCacheSync)((e) => {
					const t = e.options.babel;
					if (void 0 === t) return null;
					if ("object" != typeof t || Array.isArray(t) || null === t) throw new l.default(".babel property must be an object", e.filepath);
					return {
						filepath: e.filepath,
						dirname: e.dirname,
						options: t
					};
				}), x = (0, i.makeStaticFileCache)((e, t) => {
					let r;
					try {
						r = _json().parse(t);
					} catch (t) {
						throw new l.default(`Error while parsing config - ${t.message}`, e);
					}
					if (!r) throw new l.default("No config detected", e);
					if ("object" != typeof r) throw new l.default("Config returned typeof " + typeof r, e);
					if (Array.isArray(r)) throw new l.default("Expected config object but found array", e);
					return delete r.$schema, {
						filepath: e,
						dirname: _path().dirname(e),
						options: r
					};
				}), v = (0, i.makeStaticFileCache)((e, t) => {
					const r = _path().dirname(e), n = t.split("\n").map((e) => e.replace(/#.*$/, "").trim()).filter(Boolean);
					for (const t of n) if ("!" === t[0]) throw new l.default("Negation of file paths is not supported.", e);
					return {
						filepath: e,
						dirname: _path().dirname(e),
						ignore: n.map((e) => (0, a.default)(e, r))
					};
				});
				function* loadOneConfig(e, t, r, n, s = null) {
					const i = (yield* _gensync().all(e.map((e) => readConfig(_path().join(t, e), r, n)))).reduce((e, r) => {
						if (r && e) throw new l.default(`Multiple configuration files found. Please remove one:\n - ${_path().basename(e.filepath)}\n - ${r.filepath}\nfrom ${t}`);
						return r || e;
					}, s);
					return i && d("Found configuration %o from %o.", i.filepath, t), i;
				}
				function readConfig(e, t, r) {
					switch (_path().extname(e)) {
						case ".js":
						case ".cjs":
						case ".mjs":
						case ".ts":
						case ".cts":
						case ".mts": return readConfigCode(e, {
							envName: t,
							caller: r
						});
						default: return x(e);
					}
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/import.cjs": function(e, t, r) {
				e.exports = function(e) {
					return r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files lazy recursive")(e);
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), Object.defineProperty(t, "ROOT_CONFIG_FILENAMES", {
					enumerable: !0,
					get: function() {
						return s.ROOT_CONFIG_FILENAMES;
					}
				}), Object.defineProperty(t, "findConfigUpwards", {
					enumerable: !0,
					get: function() {
						return s.findConfigUpwards;
					}
				}), Object.defineProperty(t, "findPackageData", {
					enumerable: !0,
					get: function() {
						return n.findPackageData;
					}
				}), Object.defineProperty(t, "findRelativeConfig", {
					enumerable: !0,
					get: function() {
						return s.findRelativeConfig;
					}
				}), Object.defineProperty(t, "findRootConfig", {
					enumerable: !0,
					get: function() {
						return s.findRootConfig;
					}
				}), Object.defineProperty(t, "loadConfig", {
					enumerable: !0,
					get: function() {
						return s.loadConfig;
					}
				}), Object.defineProperty(t, "loadPlugin", {
					enumerable: !0,
					get: function() {
						return i.loadPlugin;
					}
				}), Object.defineProperty(t, "loadPreset", {
					enumerable: !0,
					get: function() {
						return i.loadPreset;
					}
				}), Object.defineProperty(t, "resolvePlugin", {
					enumerable: !0,
					get: function() {
						return i.resolvePlugin;
					}
				}), Object.defineProperty(t, "resolvePreset", {
					enumerable: !0,
					get: function() {
						return i.resolvePreset;
					}
				}), Object.defineProperty(t, "resolveShowConfigPath", {
					enumerable: !0,
					get: function() {
						return s.resolveShowConfigPath;
					}
				});
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/package.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/configuration.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/plugins.js");
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/module-types.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function* (e, t, r, s) {
					let o;
					const a = _path().extname(e), l = ".ts" === a || ".cts" === a || ".mts" === a, p = h[hasOwnProperty.call(h, a) ? a : ".js"];
					switch (`${t} ${p}`) {
						case "require cjs":
						case "auto cjs": return l ? ensureTsSupport(e, a, () => loadCjsDefault(e)) : loadCjsDefault(e, arguments[2]);
						case "auto unknown":
						case "require unknown":
						case "require esm": try {
							return l ? ensureTsSupport(e, a, () => loadCjsDefault(e)) : loadCjsDefault(e, arguments[2]);
						} catch (t) {
							if ("ERR_REQUIRE_ASYNC_MODULE" === t.code || "ERR_REQUIRE_CYCLE_MODULE" === t.code && m.has(e)) {
								if (m.add(e), !(null != o ? o : o = yield* (0, n.isAsync)())) throw new i.default(s, e);
							} else if ("ERR_REQUIRE_ESM" !== t.code && "esm" !== p) throw t;
						}
						case "auto esm":
							if (null != o ? o : o = yield* (0, n.isAsync)()) {
								const t = l ? ensureTsSupport(e, a, () => c(e)) : c(e);
								return (yield* (0, n.waitFor)(t)).default;
							}
							throw l ? new i.default(tsNotSupportedError(a), e) : new i.default(r, e);
						default: throw new Error("Internal Babel error: unreachable code.");
					}
				}, t.supportsESM = void 0;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/async.js");
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				function _url() {
					const e = r("url");
					return _url = function() {
						return e;
					}, e;
				}
				function _semver() {
					const e = r("./node_modules/.pnpm/semver@6.3.1/node_modules/semver/semver.js");
					return _semver = function() {
						return e;
					}, e;
				}
				function _debug() {
					const e = r("./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/index.js");
					return _debug = function() {
						return e;
					}, e;
				}
				r("module");
				var s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/rewrite-stack-trace.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/config-error.js"), o = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transform-file.js");
				function asyncGeneratorStep(e, t, r, n, s, i, o) {
					try {
						var a = e[i](o), l = a.value;
					} catch (e) {
						r(e);
						return;
					}
					a.done ? t(l) : Promise.resolve(l).then(n, s);
				}
				const a = _debug()("babel:config:loading:files:module-types");
				try {
					var l = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/import.cjs");
				} catch (e) {}
				t.supportsESM = _semver().satisfies(process.versions.node, "^12.17 || >=13.2");
				const p = /* @__PURE__ */ new Set();
				function loadCjsDefault(e) {
					if (p.has(e)) return a("Auto-ignoring usage of config %o.", e), {};
					let t;
					try {
						p.add(e), t = (0, s.endHiddenCallStack)(r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files sync recursive"))(e);
					} finally {
						p.delete(e);
					}
					return null == t || !t.__esModule && "Module" !== t[Symbol.toStringTag] ? t : t.default || (arguments[1] ? t : void 0);
				}
				const c = (0, s.endHiddenCallStack)((u = function* (e) {
					const t = (0, _url().pathToFileURL)(e).toString() + "?import";
					if (!l) throw new i.default("Internal error: Native ECMAScript modules aren't supported by this platform.\n", e);
					return yield l(t);
				}, d = function() {
					var e = this, t = arguments;
					return new Promise(function(r, n) {
						var s = u.apply(e, t);
						function _next(e) {
							asyncGeneratorStep(s, r, n, _next, _throw, "next", e);
						}
						function _throw(e) {
							asyncGeneratorStep(s, r, n, _next, _throw, "throw", e);
						}
						_next(void 0);
					});
				}, function(e) {
					return d.apply(this, arguments);
				}));
				var u, d;
				const tsNotSupportedError = (e) => `You are using a ${e} config file, but Babel only supports transpiling .cts configs. Either:\n- Use a .cts config file\n- Update to Node.js 23.6.0, which has native TypeScript support\n- Install tsx to transpile ${e} files on the fly`, h = {
					".js": "unknown",
					".mjs": "esm",
					".cjs": "cjs",
					".ts": "unknown",
					".mts": "esm",
					".cts": "cjs"
				}, m = /* @__PURE__ */ new Set();
				function ensureTsSupport(e, t, n) {
					if (process.features.typescript || (void 0)[".ts"] || (void 0)[".cts"] || (void 0)[".mts"]) return n();
					if (".cts" !== t) throw new i.default(tsNotSupportedError(t), e);
					const s = {
						babelrc: !1,
						configFile: !1,
						sourceType: "unambiguous",
						sourceMaps: "inline",
						sourceFileName: _path().basename(e),
						presets: [[getTSPreset(e), Object.assign({
							onlyRemoveTypeImports: !0,
							optimizeConstEnums: !0
						}, { allowDeclareFields: !0 })]]
					};
					let handler = function(e, t) {
						if (handler && t.endsWith(".cts")) try {
							return e._compile((0, o.transformFileSync)(t, Object.assign({}, s, { filename: t })).code, t);
						} catch (e) {
							const t = r("./node_modules/.pnpm/@babel+preset-typescript@7.27.1_@babel+core@7.28.4/node_modules/@babel/preset-typescript/package.json");
							throw _semver().lt(t.version, "7.21.4") && console.error("`.cts` configuration file failed to load, please try to update `@babel/preset-typescript`."), e;
						}
						return (void 0)[".js"](e, t);
					};
					(void 0)[t] = handler;
					try {
						return n();
					} finally {
						(void 0)[t] === handler && delete (void 0)[t], handler = void 0;
					}
				}
				function getTSPreset(e) {
					try {
						return r("./node_modules/.pnpm/@babel+preset-typescript@7.27.1_@babel+core@7.28.4/node_modules/@babel/preset-typescript/lib/index.js");
					} catch (t) {
						if ("MODULE_NOT_FOUND" !== t.code) throw t;
						let r = "You appear to be using a .cts file as Babel configuration, but the `@babel/preset-typescript` package was not found: please install it!";
						throw process.versions.pnp && (r += "\nIf you are using Yarn Plug'n'Play, you may also need to add the following configuration to your .yarnrc.yml file:\n\npackageExtensions:\n	\"@babel/core@*\":\n		peerDependencies:\n			\"@babel/preset-typescript\": \"*\"\n"), new i.default(r, e);
					}
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/package.js": function(e, t, r) {
				"use strict";
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.findPackageData = function* (e) {
					let t = null;
					const r = [];
					let n = !0, s = _path().dirname(e);
					for (; !t && "node_modules" !== _path().basename(s);) {
						r.push(s), t = yield* o(_path().join(s, i));
						const e = _path().dirname(s);
						if (s === e) {
							n = !1;
							break;
						}
						s = e;
					}
					return {
						filepath: e,
						directories: r,
						pkg: t,
						isPackage: n
					};
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/utils.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/config-error.js");
				const i = "package.json", o = (0, n.makeStaticFileCache)((e, t) => {
					let r;
					try {
						r = JSON.parse(t);
					} catch (t) {
						throw new s.default(`Error while parsing JSON - ${t.message}`, e);
					}
					if (!r) throw new Error(`${e}: No config detected`);
					if ("object" != typeof r) throw new s.default("Config returned typeof " + typeof r, e);
					if (Array.isArray(r)) throw new s.default("Expected config object but found array", e);
					return {
						filepath: e,
						dirname: _path().dirname(e),
						options: r
					};
				});
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/plugins.js": function(e, t, r) {
				"use strict";
				function _debug() {
					const e = r("./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/index.js");
					return _debug = function() {
						return e;
					}, e;
				}
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.loadPlugin = function* (e, t) {
					const { filepath: r, loader: s } = f(e, t, yield* (0, n.isAsync)()), i = yield* requireModule("plugin", s, r);
					return o("Loaded plugin %o from %o.", e, t), {
						filepath: r,
						value: i
					};
				}, t.loadPreset = function* (e, t) {
					const { filepath: r, loader: s } = y(e, t, yield* (0, n.isAsync)()), i = yield* requireModule("preset", s, r);
					return o("Loaded preset %o from %o.", e, t), {
						filepath: r,
						value: i
					};
				}, t.resolvePreset = t.resolvePlugin = void 0;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/async.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/module-types.js");
				function _url() {
					const e = r("url");
					return _url = function() {
						return e;
					}, e;
				}
				var i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/vendor/import-meta-resolve.js");
				function _fs() {
					const e = r("fs");
					return _fs = function() {
						return e;
					}, e;
				}
				r("module");
				const o = _debug()("babel:config:loading:files:plugins"), a = /^module:/, l = /^(?!@|module:|[^/]+\/|babel-plugin-)/, p = /^(?!@|module:|[^/]+\/|babel-preset-)/, c = /^(@babel\/)(?!plugin-|[^/]+\/)/, u = /^(@babel\/)(?!preset-|[^/]+\/)/, d = /^(@(?!babel\/)[^/]+\/)(?![^/]*babel-plugin(?:-|\/|$)|[^/]+\/)/, h = /^(@(?!babel\/)[^/]+\/)(?![^/]*babel-preset(?:-|\/|$)|[^/]+\/)/, m = /^(@(?!babel$)[^/]+)$/, f = t.resolvePlugin = resolveStandardizedName.bind(null, "plugin"), y = t.resolvePreset = resolveStandardizedName.bind(null, "preset");
				function standardizeName(e, t) {
					if (_path().isAbsolute(t)) return t;
					const r = "preset" === e;
					return t.replace(r ? p : l, `babel-${e}-`).replace(r ? u : c, `$1${e}-`).replace(r ? h : d, `$1babel-${e}-`).replace(m, `$1/babel-${e}`).replace(a, "");
				}
				function* resolveAlternativesHelper(e, t) {
					const r = standardizeName(e, t), { error: n, value: s } = yield r;
					if (!n) return s;
					if ("MODULE_NOT_FOUND" !== n.code) throw n;
					r === t || (yield t).error || (n.message += `\n- If you want to resolve "${t}", use "module:${t}"`), (yield standardizeName(e, "@babel/" + t)).error || (n.message += `\n- Did you mean "@babel/${t}"?`);
					const i = "preset" === e ? "plugin" : "preset";
					if ((yield standardizeName(i, t)).error || (n.message += `\n- Did you accidentally pass a ${i} as a ${e}?`), "plugin" === e) {
						const e = r.replace("-proposal-", "-transform-");
						e === r || (yield e).error || (n.message += `\n- Did you mean "${e}"?`);
					}
					throw n.message += "\n\nMake sure that all the Babel plugins and presets you are using\nare defined as dependencies or devDependencies in your package.json\nfile. It's possible that the missing plugin is loaded by a preset\nyou are using that forgot to add the plugin to its dependencies: you\ncan workaround this problem by explicitly adding the missing package\nto your top-level package.json.\n", n;
				}
				function tryRequireResolve(e, t) {
					try {
						return t ? {
							error: null,
							value: (n = process.versions.node, s = "8.9", n = n.split("."), s = s.split("."), +n[0] > +s[0] || n[0] == s[0] && +n[1] >= +s[1] ? r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files sync recursive").resolve : (e, { paths: [t] }, n = r("module")) => {
								let s = n._findPath(e, n._nodeModulePaths(t).concat(t));
								if (s) return s;
								throw s = /* @__PURE__ */ new Error(`Cannot resolve module '${e}'`), s.code = "MODULE_NOT_FOUND", s;
							})(e, { paths: [t] })
						} : {
							error: null,
							value: r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files sync recursive").resolve(e)
						};
					} catch (e) {
						return {
							error: e,
							value: null
						};
					}
					var n, s;
				}
				function tryImportMetaResolve(e, t) {
					try {
						return {
							error: null,
							value: (0, i.resolve)(e, t)
						};
					} catch (e) {
						return {
							error: e,
							value: null
						};
					}
				}
				function resolveStandardizedNameForRequire(e, t, r) {
					const n = resolveAlternativesHelper(e, t);
					let s = n.next();
					for (; !s.done;) s = n.next(tryRequireResolve(s.value, r));
					return {
						loader: "require",
						filepath: s.value
					};
				}
				function resolveStandardizedName(e, t, r, n) {
					if (!s.supportsESM || !n) return resolveStandardizedNameForRequire(e, t, r);
					try {
						const n = function(e, t, r) {
							const n = (0, _url().pathToFileURL)(_path().join(r, "./babel-virtual-resolve-base.js")).href, s = resolveAlternativesHelper(e, t);
							let i = s.next();
							for (; !i.done;) i = s.next(tryImportMetaResolve(i.value, n));
							return {
								loader: "auto",
								filepath: (0, _url().fileURLToPath)(i.value)
							};
						}(e, t, r);
						if (!(0, _fs().existsSync)(n.filepath)) throw Object.assign(/* @__PURE__ */ new Error(`Could not resolve "${t}" in file ${r}.`), { type: "MODULE_NOT_FOUND" });
						return n;
					} catch (n) {
						try {
							return resolveStandardizedNameForRequire(e, t, r);
						} catch (e) {
							if ("MODULE_NOT_FOUND" === n.type) throw n;
							if ("MODULE_NOT_FOUND" === e.type) throw e;
							throw n;
						}
					}
				}
				var b = /* @__PURE__ */ new Set();
				function* requireModule(e, t, r) {
					if (!(yield* (0, n.isAsync)()) && b.has(r)) throw new Error(`Reentrant ${e} detected trying to load "${r}". This module is not ignored and is trying to load itself while compiling itself, leading to a dependency cycle. We recommend adding it to your "ignore" list in your babelrc, or to a .babelignore.`);
					try {
						return b.add(r), yield* (0, s.default)(r, t, `You appear to be using a native ECMAScript module ${e}, which is only supported when running Babel asynchronously or when using the Node.js \`--experimental-require-module\` flag.`, `You appear to be using a ${e} that contains top-level await, which is only supported when running Babel asynchronously.`, !0);
					} catch (e) {
						throw e.message = `[BABEL]: ${e.message} (While processing: ${r})`, e;
					} finally {
						b.delete(r);
					}
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/utils.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.makeStaticFileCache = function(e) {
					return (0, n.makeStrongCache)(function* (t, r) {
						return null === r.invalidate(() => function(e) {
							if (!_fs2().existsSync(e)) return null;
							try {
								return +_fs2().statSync(e).mtime;
							} catch (e) {
								if ("ENOENT" !== e.code && "ENOTDIR" !== e.code) throw e;
							}
							return null;
						}(t)) ? null : e(t, yield* s.readFile(t, "utf8"));
					});
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/caching.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/fs.js");
				function _fs2() {
					const e = r("fs");
					return _fs2 = function() {
						return e;
					}, e;
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/full.js": function(e, t, r) {
				"use strict";
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/async.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/util.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), o = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/plugin.js"), a = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/item.js"), l = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/config-chain.js"), p = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/helpers/deep-array.js");
				function _traverse() {
					const e = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js");
					return _traverse = function() {
						return e;
					}, e;
				}
				var c = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/caching.js"), u = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/options.js"), d = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/plugins.js"), h = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/helpers/config-api.js"), m = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/partial.js"), f = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/config-error.js");
				t.default = _gensync()(function* (e) {
					var t;
					const r = yield* (0, m.default)(e);
					if (!r) return null;
					const { options: n, context: i, fileHandling: o } = r;
					if ("ignored" === o) return null;
					const l = {}, { plugins: c, presets: d } = n;
					if (!c || !d) throw new Error("Assertion failure - plugins and presets exist");
					const h = Object.assign({}, i, { targets: n.targets }), toDescriptor = (e) => {
						const t = (0, a.getItemDescriptor)(e);
						if (!t) throw new Error("Assertion failure - must be config item");
						return t;
					}, f = d.map(toDescriptor), y = c.map(toDescriptor), b = [[]], g = [], x = [];
					if (yield* enhanceError(i, function* recursePresetDescriptors(e, t) {
						const r = [];
						for (let s = 0; s < e.length; s++) {
							const i = e[s];
							if (!1 !== i.options) {
								try {
									var n = yield* loadPresetDescriptor(i, h);
								} catch (t) {
									throw "BABEL_UNKNOWN_OPTION" === t.code && (0, u.checkNoUnwrappedItemOptionPairs)(e, s, "preset", t), t;
								}
								x.push(n.externalDependencies), i.ownPass ? r.push({
									preset: n.chain,
									pass: []
								}) : r.unshift({
									preset: n.chain,
									pass: t
								});
							}
						}
						if (r.length > 0) {
							b.splice(1, 0, ...r.map((e) => e.pass).filter((e) => e !== t));
							for (const { preset: e, pass: t } of r) {
								if (!e) return !0;
								t.push(...e.plugins);
								if (yield* recursePresetDescriptors(e.presets, t)) return !0;
								e.options.forEach((e) => {
									(0, s.mergeOptions)(l, e);
								});
							}
						}
					})(f, b[0])) return null;
					const E = l;
					(0, s.mergeOptions)(E, n);
					const T = Object.assign({}, h, { assumptions: null != (t = E.assumptions) ? t : {} });
					return yield* enhanceError(i, function* () {
						b[0].unshift(...y);
						for (const t of b) {
							const r = [];
							g.push(r);
							for (let n = 0; n < t.length; n++) {
								const s = t[n];
								if (!1 !== s.options) {
									try {
										var e = yield* loadPluginDescriptor(s, T);
									} catch (e) {
										throw "BABEL_UNKNOWN_PLUGIN_PROPERTY" === e.code && (0, u.checkNoUnwrappedItemOptionPairs)(t, n, "plugin", e), e;
									}
									r.push(e), x.push(e.externalDependencies);
								}
							}
						}
					})(), E.plugins = g[0], E.presets = g.slice(1).filter((e) => e.length > 0).map((e) => ({ plugins: e })), E.passPerPreset = E.presets.length > 0, {
						options: E,
						passes: g,
						externalDependencies: (0, p.finalize)(x)
					};
				});
				function enhanceError(e, t) {
					return function* (r, n) {
						try {
							return yield* t(r, n);
						} catch (t) {
							var s;
							if (!/^\[BABEL\]/.test(t.message)) t.message = `[BABEL] ${null != (s = e.filename) ? s : "unknown file"}: ${t.message}`;
							throw t;
						}
					};
				}
				const makeDescriptorLoader = (e) => (0, c.makeWeakCache)(function* ({ value: t, options: r, dirname: s, alias: o }, a) {
					if (!1 === r) throw new Error("Assertion failure");
					r = r || {};
					const l = [];
					let c = t;
					if ("function" == typeof t) {
						const p = (0, n.maybeAsync)(t, "You appear to be using an async plugin/preset, but Babel has been called synchronously"), u = Object.assign({}, i, e(a, l));
						try {
							c = yield* p(u, r, s);
						} catch (e) {
							throw o && (e.message += ` (While processing: ${JSON.stringify(o)})`), e;
						}
					}
					if (!c || "object" != typeof c) throw new Error("Plugin/Preset did not return an object.");
					if ((0, n.isThenable)(c)) throw yield* [], /* @__PURE__ */ new Error(`You appear to be using a promise as a plugin, which your current version of Babel does not support. If you're using a published plugin, you may need to upgrade your @babel/core version. As an alternative, you can prefix the promise with "await". (While processing: ${JSON.stringify(o)})`);
					if (l.length > 0 && (!a.configured() || "forever" === a.mode())) {
						let e = `A plugin/preset has external untracked dependencies (${l[0]}), but the cache `;
						throw a.configured() ? e += " has been configured to never be invalidated. " : e += "has not been configured to be invalidated when the external dependencies change. ", e += `Plugins/presets should configure their cache to be invalidated when the external dependencies change, for example using \`api.cache.invalidate(() => statSync(filepath).mtimeMs)\` or \`api.cache.never()\`\n(While processing: ${JSON.stringify(o)})`, new Error(e);
					}
					return {
						value: c,
						options: r,
						dirname: s,
						alias: o,
						externalDependencies: (0, p.finalize)(l)
					};
				}), y = makeDescriptorLoader(h.makePluginAPI), b = makeDescriptorLoader(h.makePresetAPI), g = (0, c.makeWeakCache)(function* ({ value: e, options: t, dirname: r, alias: s, externalDependencies: i }, a) {
					const l = (0, d.validatePluginObject)(e), c = Object.assign({}, l);
					if (c.visitor && (c.visitor = _traverse().default.explode(Object.assign({}, c.visitor))), c.inherits) {
						const e = {
							name: void 0,
							alias: `${s}$inherits`,
							value: c.inherits,
							options: t,
							dirname: r
						}, o = yield* (0, n.forwardAsync)(loadPluginDescriptor, (t) => a.invalidate((r) => t(e, r)));
						c.pre = chainMaybeAsync(o.pre, c.pre), c.post = chainMaybeAsync(o.post, c.post), c.manipulateOptions = chainMaybeAsync(o.manipulateOptions, c.manipulateOptions), c.visitor = _traverse().default.visitors.merge([o.visitor || {}, c.visitor || {}]), o.externalDependencies.length > 0 && (i = 0 === i.length ? o.externalDependencies : (0, p.finalize)([i, o.externalDependencies]));
					}
					return new o.default(c, t, s, i);
				});
				function* loadPluginDescriptor(e, t) {
					if (e.value instanceof o.default) {
						if (e.options) throw new Error("Passed options to an existing Plugin instance will not work.");
						return e.value;
					}
					return yield* g(yield* y(e, t), t);
				}
				const needsFilename = (e) => e && "function" != typeof e, validateIfOptionNeedsFilename = (e, t) => {
					if (needsFilename(e.test) || needsFilename(e.include) || needsFilename(e.exclude)) {
						const e = t.name ? `"${t.name}"` : "/* your preset */";
						throw new f.default([
							`Preset ${e} requires a filename to be set when babel is called directly,`,
							"```",
							`babel.transformSync(code, { filename: 'file.ts', presets: [${e}] });`,
							"```",
							"See https://babeljs.io/docs/en/options#filename for more information."
						].join("\n"));
					}
				}, validatePreset = (e, t, r) => {
					if (!t.filename) {
						var n;
						const { options: t } = e;
						validateIfOptionNeedsFilename(t, r), null == (n = t.overrides) || n.forEach((e) => validateIfOptionNeedsFilename(e, r));
					}
				}, x = (0, c.makeWeakCacheSync)(({ value: e, dirname: t, alias: r, externalDependencies: n }) => ({
					options: (0, u.validate)("preset", e),
					alias: r,
					dirname: t,
					externalDependencies: n
				}));
				function* loadPresetDescriptor(e, t) {
					const r = x(yield* b(e, t));
					return validatePreset(r, t, e), {
						chain: yield* (0, l.buildPresetChain)(r, t),
						externalDependencies: r.externalDependencies
					};
				}
				function chainMaybeAsync(e, t) {
					return e ? t ? function(...r) {
						const n = e.apply(this, r);
						return n && "function" == typeof n.then ? n.then(() => t.apply(this, r)) : t.apply(this, r);
					} : e : t;
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/helpers/config-api.js": function(e, t, r) {
				"use strict";
				function _semver() {
					const e = r("./node_modules/.pnpm/semver@6.3.1/node_modules/semver/semver.js");
					return _semver = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.makeConfigAPI = makeConfigAPI, t.makePluginAPI = function(e, t) {
					return Object.assign({}, makePresetAPI(e, t), { assumption: (t) => e.using((e) => e.assumptions[t]) });
				}, t.makePresetAPI = makePresetAPI;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/caching.js");
				function makeConfigAPI(e) {
					return {
						version: n.version,
						cache: e.simple(),
						env: (t) => e.using((e) => void 0 === t ? e.envName : "function" == typeof t ? (0, s.assertSimpleType)(t(e.envName)) : (Array.isArray(t) ? t : [t]).some((t) => {
							if ("string" != typeof t) throw new Error("Unexpected non-string value");
							return t === e.envName;
						})),
						async: () => !1,
						caller: (t) => e.using((e) => (0, s.assertSimpleType)(t(e.caller))),
						assertVersion
					};
				}
				function makePresetAPI(e, t) {
					return Object.assign({}, makeConfigAPI(e), {
						targets: () => JSON.parse(e.using((e) => JSON.stringify(e.targets))),
						addExternalDependency: (e) => {
							t.push(e);
						}
					});
				}
				function assertVersion(e) {
					if ("number" == typeof e) {
						if (!Number.isInteger(e)) throw new Error("Expected string or integer value.");
						e = `^${e}.0.0-0`;
					}
					if ("string" != typeof e) throw new Error("Expected string or integer value.");
					if ("*" === e || _semver().satisfies(n.version, e)) return;
					const t = Error.stackTraceLimit;
					"number" == typeof t && t < 25 && (Error.stackTraceLimit = 25);
					const r = /* @__PURE__ */ new Error(`Requires Babel "${e}", but was loaded with "${n.version}". If you are sure you have a compatible version of @babel/core, it is likely that something in your build process is loading the wrong version. Inspect the stack trace of this error to look for the first entry that doesn't mention "@babel/core" or "babel-core" to see what is calling Babel.`);
					throw "number" == typeof t && (Error.stackTraceLimit = t), Object.assign(r, {
						code: "BABEL_VERSION_UNSUPPORTED",
						version: n.version,
						range: e
					});
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/helpers/deep-array.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.finalize = function(e) {
					return Object.freeze(e);
				}, t.flattenToSet = function(e) {
					const t = /* @__PURE__ */ new Set(), r = [e];
					for (; r.length > 0;) for (const e of r.pop()) Array.isArray(e) ? r.push(e) : t.add(e);
					return t;
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/helpers/environment.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.getEnv = function(e = "development") {
					return process.env.BABEL_ENV || process.env.NODE_ENV || e;
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/index.js": function(e, t, r) {
				"use strict";
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.createConfigItem = function(e, t, r) {
					if (void 0 !== r) (0, o.beginHiddenCallStack)(p.errback)(e, t, r);
					else {
						if ("function" != typeof t) return createConfigItemSync(e, t);
						(0, o.beginHiddenCallStack)(p.errback)(e, void 0, r);
					}
				}, t.createConfigItemAsync = function(...e) {
					return (0, o.beginHiddenCallStack)(p.async)(...e);
				}, t.createConfigItemSync = createConfigItemSync, Object.defineProperty(t, "default", {
					enumerable: !0,
					get: function() {
						return n.default;
					}
				}), t.loadOptions = function(e, t) {
					if (void 0 !== t) (0, o.beginHiddenCallStack)(l.errback)(e, t);
					else {
						if ("function" != typeof e) return loadOptionsSync(e);
						(0, o.beginHiddenCallStack)(l.errback)(void 0, e);
					}
				}, t.loadOptionsAsync = function(...e) {
					return (0, o.beginHiddenCallStack)(l.async)(...e);
				}, t.loadOptionsSync = loadOptionsSync, t.loadPartialConfig = function(e, t) {
					if (void 0 !== t) (0, o.beginHiddenCallStack)(a.errback)(e, t);
					else {
						if ("function" != typeof e) return loadPartialConfigSync(e);
						(0, o.beginHiddenCallStack)(a.errback)(void 0, e);
					}
				}, t.loadPartialConfigAsync = function(...e) {
					return (0, o.beginHiddenCallStack)(a.async)(...e);
				}, t.loadPartialConfigSync = loadPartialConfigSync;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/full.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/partial.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/item.js"), o = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/rewrite-stack-trace.js");
				const a = _gensync()(s.loadPartialConfig);
				function loadPartialConfigSync(...e) {
					return (0, o.beginHiddenCallStack)(a.sync)(...e);
				}
				const l = _gensync()(function* (e) {
					var t;
					const r = yield* (0, n.default)(e);
					return null != (t = null == r ? void 0 : r.options) ? t : null;
				});
				function loadOptionsSync(...e) {
					return (0, o.beginHiddenCallStack)(l.sync)(...e);
				}
				const p = _gensync()(i.createConfigItem);
				function createConfigItemSync(...e) {
					return (0, o.beginHiddenCallStack)(p.sync)(...e);
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/item.js": function(e, t, r) {
				"use strict";
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.createConfigItem = function* (e, { dirname: t = ".", type: r } = {}) {
					return createItemFromDescriptor(yield* (0, n.createDescriptor)(e, _path().resolve(t), {
						type: r,
						alias: "programmatic item"
					}));
				}, t.createItemFromDescriptor = createItemFromDescriptor, t.getItemDescriptor = function(e) {
					if (null != e && e[s]) return e._descriptor;
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/config-descriptors.js");
				function createItemFromDescriptor(e) {
					return new ConfigItem(e);
				}
				const s = Symbol.for("@babel/core@7 - ConfigItem");
				class ConfigItem {
					constructor(e) {
						this._descriptor = void 0, this[s] = !0, this.value = void 0, this.options = void 0, this.dirname = void 0, this.name = void 0, this.file = void 0, this._descriptor = e, Object.defineProperty(this, "_descriptor", { enumerable: !1 }), Object.defineProperty(this, s, { enumerable: !1 }), this.value = this._descriptor.value, this.options = this._descriptor.options, this.dirname = this._descriptor.dirname, this.name = this._descriptor.name, this.file = this._descriptor.file ? {
							request: this._descriptor.file.request,
							resolved: this._descriptor.file.resolved
						} : void 0, Object.freeze(this);
					}
				}
				Object.freeze(ConfigItem.prototype);
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/partial.js": function(e, t, r) {
				"use strict";
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = loadPrivatePartialConfig, t.loadPartialConfig = function* (e) {
					let t = !1;
					if ("object" == typeof e && null !== e && !Array.isArray(e)) {
						var r = e;
						({showIgnoredFiles: t} = r), e = function(e, t) {
							if (null == e) return {};
							var r = {};
							for (var n in e) if ({}.hasOwnProperty.call(e, n)) {
								if (-1 !== t.indexOf(n)) continue;
								r[n] = e[n];
							}
							return r;
						}(r, u);
					}
					const s = yield* loadPrivatePartialConfig(e);
					if (!s) return null;
					const { options: i, babelrc: o, ignore: a, config: l, fileHandling: p, files: c } = s;
					if ("ignored" === p && !t) return null;
					return (i.plugins || []).forEach((e) => {
						if (e.value instanceof n.default) throw new Error("Passing cached plugin instances is not supported in babel.loadPartialConfig()");
					}), new PartialConfig(i, o ? o.filepath : void 0, a ? a.filepath : void 0, l ? l.filepath : void 0, p, c);
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/plugin.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/util.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/item.js"), o = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/config-chain.js"), a = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/helpers/environment.js"), l = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/options.js"), p = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/index.js"), c = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/resolve-targets.js");
				const u = ["showIgnoredFiles"];
				function* loadPrivatePartialConfig(e) {
					if (null != e && ("object" != typeof e || Array.isArray(e))) throw new Error("Babel options must be an object, null, or undefined");
					const t = e ? (0, l.validate)("arguments", e) : {}, { envName: r = (0, a.getEnv)(), cwd: n = ".", root: u = ".", rootMode: d = "root", caller: h, cloneInputAst: m = !0 } = t, f = _path().resolve(n), y = function(e, t) {
						switch (t) {
							case "root": return e;
							case "upward-optional": {
								const t = (0, p.findConfigUpwards)(e);
								return null === t ? e : t;
							}
							case "upward": {
								const t = (0, p.findConfigUpwards)(e);
								if (null !== t) return t;
								throw Object.assign(/* @__PURE__ */ new Error(`Babel was run with rootMode:"upward" but a root could not be found when searching upward from "${e}".\nOne of the following config files must be in the directory tree: "${p.ROOT_CONFIG_FILENAMES.join(", ")}".`), {
									code: "BABEL_ROOT_NOT_FOUND",
									dirname: e
								});
							}
							default: throw new Error("Assertion failure - unknown rootMode value.");
						}
					}(_path().resolve(f, u), d), b = "string" == typeof t.filename ? _path().resolve(n, t.filename) : void 0, g = {
						filename: b,
						cwd: f,
						root: y,
						envName: r,
						caller: h,
						showConfig: (yield* (0, p.resolveShowConfigPath)(f)) === b
					}, x = yield* (0, o.buildRootChain)(t, g);
					if (!x) return null;
					const v = { assumptions: {} };
					x.options.forEach((e) => {
						(0, s.mergeOptions)(v, e);
					});
					return {
						options: Object.assign({}, v, {
							targets: (0, c.resolveTargets)(v, y),
							cloneInputAst: m,
							babelrc: !1,
							configFile: !1,
							browserslistConfigFile: !1,
							passPerPreset: !1,
							envName: g.envName,
							cwd: g.cwd,
							root: g.root,
							rootMode: "root",
							filename: "string" == typeof g.filename ? g.filename : void 0,
							plugins: x.plugins.map((e) => (0, i.createItemFromDescriptor)(e)),
							presets: x.presets.map((e) => (0, i.createItemFromDescriptor)(e))
						}),
						context: g,
						fileHandling: x.fileHandling,
						ignore: x.ignore,
						babelrc: x.babelrc,
						config: x.config,
						files: x.files
					};
				}
				class PartialConfig {
					constructor(e, t, r, n, s, i) {
						this.options = void 0, this.babelrc = void 0, this.babelignore = void 0, this.config = void 0, this.fileHandling = void 0, this.files = void 0, this.options = e, this.babelignore = r, this.babelrc = t, this.config = n, this.fileHandling = s, this.files = i, Object.freeze(this);
					}
					hasFilesystemConfig() {
						return void 0 !== this.babelrc || void 0 !== this.config;
					}
				}
				Object.freeze(PartialConfig.prototype);
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/pattern-to-regex.js": function(e, t, r) {
				"use strict";
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					const r = _path().resolve(t, e).split(_path().sep);
					return new RegExp(["^", ...r.map((e, t) => {
						const c = t === r.length - 1;
						return "**" === e ? c ? p : l : "*" === e ? c ? a : o : 0 === e.indexOf("*.") ? i + escapeRegExp(e.slice(1)) + (c ? s : n) : escapeRegExp(e) + (c ? s : n);
					})].join(""));
				};
				const n = `\\${_path().sep}`, s = `(?:${n}|$)`, i = `[^${n}]+`, o = `(?:${i}${n})`, a = `(?:${i}${s})`, l = `${o}*?`, p = `${o}*?${a}?`;
				function escapeRegExp(e) {
					return e.replace(/[|\\{}()[\]^$+*?.]/g, "\\$&");
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/plugin.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/helpers/deep-array.js");
				t.default = class {
					constructor(e, t, r, s = (0, n.finalize)([])) {
						this.key = void 0, this.manipulateOptions = void 0, this.post = void 0, this.pre = void 0, this.visitor = void 0, this.parserOverride = void 0, this.generatorOverride = void 0, this.options = void 0, this.externalDependencies = void 0, this.key = e.name || r, this.manipulateOptions = e.manipulateOptions, this.post = e.post, this.pre = e.pre, this.visitor = e.visitor || {}, this.parserOverride = e.parserOverride, this.generatorOverride = e.generatorOverride, this.options = t, this.externalDependencies = s;
					}
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/printer.js": function(e, t, r) {
				"use strict";
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.ConfigPrinter = t.ChainFormatter = void 0;
				const n = t.ChainFormatter = {
					Programmatic: 0,
					Config: 1
				}, s = {
					title(e, t, r) {
						let s = "";
						return e === n.Programmatic ? (s = "programmatic options", t && (s += " from " + t)) : s = "config " + r, s;
					},
					loc(e, t) {
						let r = "";
						return null != e && (r += `.overrides[${e}]`), null != t && (r += `.env["${t}"]`), r;
					},
					*optionsAndDescriptors(e) {
						const t = Object.assign({}, e.options);
						delete t.overrides, delete t.env;
						const r = [...yield* e.plugins()];
						r.length && (t.plugins = r.map((e) => descriptorToConfig(e)));
						const n = [...yield* e.presets()];
						return n.length && (t.presets = [...n].map((e) => descriptorToConfig(e))), JSON.stringify(t, void 0, 2);
					}
				};
				function descriptorToConfig(e) {
					var t;
					let r = null == (t = e.file) ? void 0 : t.request;
					return r ?? ("object" == typeof e.value ? r = e.value : "function" == typeof e.value && (r = `[Function: ${e.value.toString().slice(0, 50)} ... ]`)), r ?? (r = "[Unknown]"), void 0 === e.options ? r : null == e.name ? [r, e.options] : [
						r,
						e.options,
						e.name
					];
				}
				class ConfigPrinter {
					constructor() {
						this._stack = [];
					}
					configure(e, t, { callerName: r, filepath: n }) {
						return e ? (e, s, i) => {
							this._stack.push({
								type: t,
								callerName: r,
								filepath: n,
								content: e,
								index: s,
								envName: i
							});
						} : () => {};
					}
					static *format(e) {
						let t = s.title(e.type, e.callerName, e.filepath);
						const r = s.loc(e.index, e.envName);
						r && (t += ` ${r}`);
						return `${t}\n${yield* s.optionsAndDescriptors(e.content)}`;
					}
					*output() {
						if (0 === this._stack.length) return "";
						return (yield* _gensync().all(this._stack.map((e) => ConfigPrinter.format(e)))).join("\n\n");
					}
				}
				t.ConfigPrinter = ConfigPrinter;
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/resolve-targets.js": function(e, t, r) {
				"use strict";
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				function _helperCompilationTargets() {
					const e = r("./stubs/helper-compilation-targets.mjs");
					return _helperCompilationTargets = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.resolveBrowserslistConfigFile = function(e, t) {
					return _path().resolve(t, e);
				}, t.resolveTargets = function(e, t) {
					const r = e.targets;
					let n;
					"string" == typeof r || Array.isArray(r) ? n = { browsers: r } : r && (n = "esmodules" in r ? Object.assign({}, r, { esmodules: "intersect" }) : r);
					const { browserslistConfigFile: s } = e;
					let i, o = !1;
					"string" == typeof s ? i = s : o = !1 === s;
					return (0, _helperCompilationTargets().default)(n, {
						ignoreBrowserslistConfig: o,
						configFile: i,
						configPath: t,
						browserslistEnv: e.browserslistEnv
					});
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/util.js": function(e, t) {
				"use strict";
				function mergeDefaultFields(e, t) {
					for (const r of Object.keys(t)) {
						const n = t[r];
						void 0 !== n && (e[r] = n);
					}
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.isIterableIterator = function(e) {
					return !!e && "function" == typeof e.next && "function" == typeof e[Symbol.iterator];
				}, t.mergeOptions = function(e, t) {
					for (const r of Object.keys(t)) if ("parserOpts" !== r && "generatorOpts" !== r && "assumptions" !== r || !t[r]) {
						const n = t[r];
						void 0 !== n && (e[r] = n);
					} else {
						const n = t[r];
						mergeDefaultFields(e[r] || (e[r] = {}), n);
					}
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/option-assertions.js": function(e, t, r) {
				"use strict";
				function _helperCompilationTargets() {
					const e = r("./stubs/helper-compilation-targets.mjs");
					return _helperCompilationTargets = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.access = access, t.assertArray = assertArray, t.assertAssumptions = function(e, t) {
					if (void 0 === t) return;
					if ("object" != typeof t || null === t) throw new Error(`${msg(e)} must be an object or undefined.`);
					let r = e;
					do
						r = r.parent;
					while ("root" !== r.type);
					const s = "preset" === r.source;
					for (const r of Object.keys(t)) {
						const i = access(e, r);
						if (!n.assumptionsNames.has(r)) throw new Error(`${msg(i)} is not a supported assumption.`);
						if ("boolean" != typeof t[r]) throw new Error(`${msg(i)} must be a boolean.`);
						if (s && !1 === t[r]) throw new Error(`${msg(i)} cannot be set to 'false' inside presets.`);
					}
					return t;
				}, t.assertBabelrcSearch = function(e, t) {
					if (void 0 === t || "boolean" == typeof t) return t;
					if (Array.isArray(t)) t.forEach((t, r) => {
						if (!checkValidTest(t)) throw new Error(`${msg(access(e, r))} must be a string/Function/RegExp.`);
					});
					else if (!checkValidTest(t)) throw new Error(`${msg(e)} must be a undefined, a boolean, a string/Function/RegExp or an array of those, got ${JSON.stringify(t)}`);
					return t;
				}, t.assertBoolean = assertBoolean, t.assertCallerMetadata = function(e, t) {
					const r = assertObject(e, t);
					if (r) {
						if ("string" != typeof r.name) throw new Error(`${msg(e)} set but does not contain "name" property string`);
						for (const t of Object.keys(r)) {
							const n = access(e, t), s = r[t];
							if (null != s && "boolean" != typeof s && "string" != typeof s && "number" != typeof s) throw new Error(`${msg(n)} must be null, undefined, a boolean, a string, or a number.`);
						}
					}
					return t;
				}, t.assertCompact = function(e, t) {
					if (void 0 !== t && "boolean" != typeof t && "auto" !== t) throw new Error(`${msg(e)} must be a boolean, "auto", or undefined`);
					return t;
				}, t.assertConfigApplicableTest = function(e, t) {
					if (void 0 === t) return t;
					if (Array.isArray(t)) t.forEach((t, r) => {
						if (!checkValidTest(t)) throw new Error(`${msg(access(e, r))} must be a string/Function/RegExp.`);
					});
					else if (!checkValidTest(t)) throw new Error(`${msg(e)} must be a string/Function/RegExp, or an array of those`);
					return t;
				}, t.assertConfigFileSearch = function(e, t) {
					if (void 0 !== t && "boolean" != typeof t && "string" != typeof t) throw new Error(`${msg(e)} must be a undefined, a boolean, a string, got ${JSON.stringify(t)}`);
					return t;
				}, t.assertFunction = function(e, t) {
					if (void 0 !== t && "function" != typeof t) throw new Error(`${msg(e)} must be a function, or undefined`);
					return t;
				}, t.assertIgnoreList = function(e, t) {
					const r = assertArray(e, t);
					return r?.forEach((t, r) => function(e, t) {
						if ("string" != typeof t && "function" != typeof t && !(t instanceof RegExp)) throw new Error(`${msg(e)} must be an array of string/Function/RegExp values, or undefined`);
						return t;
					}(access(e, r), t)), r;
				}, t.assertInputSourceMap = function(e, t) {
					if (void 0 !== t && "boolean" != typeof t && ("object" != typeof t || !t)) throw new Error(`${msg(e)} must be a boolean, object, or undefined`);
					return t;
				}, t.assertObject = assertObject, t.assertPluginList = function(e, t) {
					const r = assertArray(e, t);
					r && r.forEach((t, r) => function(e, t) {
						if (Array.isArray(t)) {
							if (0 === t.length) throw new Error(`${msg(e)} must include an object`);
							if (t.length > 3) throw new Error(`${msg(e)} may only be a two-tuple or three-tuple`);
							if (assertPluginTarget(access(e, 0), t[0]), t.length > 1) {
								const r = t[1];
								if (void 0 !== r && !1 !== r && ("object" != typeof r || Array.isArray(r) || null === r)) throw new Error(`${msg(access(e, 1))} must be an object, false, or undefined`);
							}
							if (3 === t.length) {
								const r = t[2];
								if (void 0 !== r && "string" != typeof r) throw new Error(`${msg(access(e, 2))} must be a string, or undefined`);
							}
						} else assertPluginTarget(e, t);
						return t;
					}(access(e, r), t));
					return r;
				}, t.assertRootMode = function(e, t) {
					if (void 0 !== t && "root" !== t && "upward" !== t && "upward-optional" !== t) throw new Error(`${msg(e)} must be a "root", "upward", "upward-optional" or undefined`);
					return t;
				}, t.assertSourceMaps = function(e, t) {
					if (void 0 !== t && "boolean" != typeof t && "inline" !== t && "both" !== t) throw new Error(`${msg(e)} must be a boolean, "inline", "both", or undefined`);
					return t;
				}, t.assertSourceType = function(e, t) {
					if (void 0 !== t && "module" !== t && "commonjs" !== t && "script" !== t && "unambiguous" !== t) throw new Error(`${msg(e)} must be "module", "commonjs", "script", "unambiguous", or undefined`);
					return t;
				}, t.assertString = function(e, t) {
					if (void 0 !== t && "string" != typeof t) throw new Error(`${msg(e)} must be a string, or undefined`);
					return t;
				}, t.assertTargets = function(e, t) {
					if ((0, _helperCompilationTargets().isBrowsersQueryValid)(t)) return t;
					if ("object" != typeof t || !t || Array.isArray(t)) throw new Error(`${msg(e)} must be a string, an array of strings or an object`);
					const r = access(e, "browsers"), n = access(e, "esmodules");
					assertBrowsersList(r, t.browsers), assertBoolean(n, t.esmodules);
					for (const r of Object.keys(t)) {
						const n = t[r], s = access(e, r);
						if ("esmodules" === r) assertBoolean(s, n);
						else if ("browsers" === r) assertBrowsersList(s, n);
						else {
							if (!hasOwnProperty.call(_helperCompilationTargets().TargetNames, r)) {
								const e = Object.keys(_helperCompilationTargets().TargetNames).join(", ");
								throw new Error(`${msg(s)} is not a valid target. Supported targets are ${e}`);
							}
							assertBrowserVersion(s, n);
						}
					}
					return t;
				}, t.msg = msg;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/options.js");
				function msg(e) {
					switch (e.type) {
						case "root": return "";
						case "env": return `${msg(e.parent)}.env["${e.name}"]`;
						case "overrides": return `${msg(e.parent)}.overrides[${e.index}]`;
						case "option": return `${msg(e.parent)}.${e.name}`;
						case "access": return `${msg(e.parent)}[${JSON.stringify(e.name)}]`;
						default: throw new Error(`Assertion failure: Unknown type ${e.type}`);
					}
				}
				function access(e, t) {
					return {
						type: "access",
						name: t,
						parent: e
					};
				}
				function assertBoolean(e, t) {
					if (void 0 !== t && "boolean" != typeof t) throw new Error(`${msg(e)} must be a boolean, or undefined`);
					return t;
				}
				function assertObject(e, t) {
					if (void 0 !== t && ("object" != typeof t || Array.isArray(t) || !t)) throw new Error(`${msg(e)} must be an object, or undefined`);
					return t;
				}
				function assertArray(e, t) {
					if (null != t && !Array.isArray(t)) throw new Error(`${msg(e)} must be an array, or undefined`);
					return t;
				}
				function checkValidTest(e) {
					return "string" == typeof e || "function" == typeof e || e instanceof RegExp;
				}
				function assertPluginTarget(e, t) {
					if (("object" != typeof t || !t) && "string" != typeof t && "function" != typeof t) throw new Error(`${msg(e)} must be a string, object, function`);
					return t;
				}
				function assertBrowsersList(e, t) {
					if (void 0 !== t && !(0, _helperCompilationTargets().isBrowsersQueryValid)(t)) throw new Error(`${msg(e)} must be undefined, a string or an array of strings`);
				}
				function assertBrowserVersion(e, t) {
					if (("number" != typeof t || Math.round(t) !== t) && "string" != typeof t) throw new Error(`${msg(e)} must be a string or an integer number`);
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/options.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.assumptionsNames = void 0, t.checkNoUnwrappedItemOptionPairs = function(e, t, r, n) {
					if (0 === t) return;
					const s = e[t - 1], i = e[t];
					s.file && void 0 === s.options && "object" == typeof i.value && (n.message += `\n- Maybe you meant to use\n"${r}s": [\n  ["${s.file.request}", ${JSON.stringify(i.value, void 0, 2)}]\n]\nTo be a valid ${r}, its name and options should be wrapped in a pair of brackets`);
				}, t.validate = function(e, t, r) {
					try {
						return validateNested({
							type: "root",
							source: e
						}, t);
					} catch (e) {
						const t = new i.default(e.message, r);
						throw e.code && (t.code = e.code), t;
					}
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/removed.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/option-assertions.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/config-error.js");
				const o = {
					cwd: s.assertString,
					root: s.assertString,
					rootMode: s.assertRootMode,
					configFile: s.assertConfigFileSearch,
					caller: s.assertCallerMetadata,
					filename: s.assertString,
					filenameRelative: s.assertString,
					code: s.assertBoolean,
					ast: s.assertBoolean,
					cloneInputAst: s.assertBoolean,
					envName: s.assertString
				}, a = {
					babelrc: s.assertBoolean,
					babelrcRoots: s.assertBabelrcSearch
				}, l = {
					extends: s.assertString,
					ignore: s.assertIgnoreList,
					only: s.assertIgnoreList,
					targets: s.assertTargets,
					browserslistConfigFile: s.assertConfigFileSearch,
					browserslistEnv: s.assertString
				}, p = {
					inputSourceMap: s.assertInputSourceMap,
					presets: s.assertPluginList,
					plugins: s.assertPluginList,
					passPerPreset: s.assertBoolean,
					assumptions: s.assertAssumptions,
					env: function(e, t) {
						if ("env" === e.parent.type) throw new Error(`${(0, s.msg)(e)} is not allowed inside of another .env block`);
						const r = e.parent, n = (0, s.assertObject)(e, t);
						if (n) for (const t of Object.keys(n)) {
							const i = (0, s.assertObject)((0, s.access)(e, t), n[t]);
							if (!i) continue;
							validateNested({
								type: "env",
								name: t,
								parent: r
							}, i);
						}
						return n;
					},
					overrides: function(e, t) {
						if ("env" === e.parent.type) throw new Error(`${(0, s.msg)(e)} is not allowed inside an .env block`);
						if ("overrides" === e.parent.type) throw new Error(`${(0, s.msg)(e)} is not allowed inside an .overrides block`);
						const r = e.parent, n = (0, s.assertArray)(e, t);
						if (n) for (const [t, i] of n.entries()) {
							const n = (0, s.access)(e, t), o = (0, s.assertObject)(n, i);
							if (!o) throw new Error(`${(0, s.msg)(n)} must be an object`);
							validateNested({
								type: "overrides",
								index: t,
								parent: r
							}, o);
						}
						return n;
					},
					test: s.assertConfigApplicableTest,
					include: s.assertConfigApplicableTest,
					exclude: s.assertConfigApplicableTest,
					retainLines: s.assertBoolean,
					comments: s.assertBoolean,
					shouldPrintComment: s.assertFunction,
					compact: s.assertCompact,
					minified: s.assertBoolean,
					auxiliaryCommentBefore: s.assertString,
					auxiliaryCommentAfter: s.assertString,
					sourceType: s.assertSourceType,
					wrapPluginVisitorMethod: s.assertFunction,
					highlightCode: s.assertBoolean,
					sourceMaps: s.assertSourceMaps,
					sourceMap: s.assertSourceMaps,
					sourceFileName: s.assertString,
					sourceRoot: s.assertString,
					parserOpts: s.assertObject,
					generatorOpts: s.assertObject
				};
				Object.assign(p, {
					getModuleId: s.assertFunction,
					moduleRoot: s.assertString,
					moduleIds: s.assertBoolean,
					moduleId: s.assertString
				});
				t.assumptionsNames = new Set([
					"arrayLikeIsIterable",
					"constantReexports",
					"constantSuper",
					"enumerableModuleMeta",
					"ignoreFunctionLength",
					"ignoreToPrimitiveHint",
					"iterableIsArray",
					"mutableTemplateObject",
					"noClassCalls",
					"noDocumentAll",
					"noIncompleteNsImportDetection",
					"noNewArrows",
					"noUninitializedPrivateFieldAccess",
					"objectRestNoSymbols",
					"privateFieldsAsSymbols",
					"privateFieldsAsProperties",
					"pureGetters",
					"setClassMethods",
					"setComputedProperties",
					"setPublicClassFields",
					"setSpreadProperties",
					"skipForOfIteratorClosing",
					"superIsCallableConstructor"
				]);
				function getSource(e) {
					return "root" === e.type ? e.source : getSource(e.parent);
				}
				function validateNested(e, t) {
					const r = getSource(e);
					return function(e) {
						if (hasOwnProperty.call(e, "sourceMap") && hasOwnProperty.call(e, "sourceMaps")) throw new Error(".sourceMap is an alias for .sourceMaps, cannot use both");
					}(t), Object.keys(t).forEach((n) => {
						const i = {
							type: "option",
							name: n,
							parent: e
						};
						if ("preset" === r && l[n]) throw new Error(`${(0, s.msg)(i)} is not allowed in preset options`);
						if ("arguments" !== r && o[n]) throw new Error(`${(0, s.msg)(i)} is only allowed in root programmatic options`);
						if ("arguments" !== r && "configfile" !== r && a[n]) {
							if ("babelrcfile" === r || "extendsfile" === r) throw new Error(`${(0, s.msg)(i)} is not allowed in .babelrc or "extends"ed files, only in root programmatic options, or babel.config.js/config file options`);
							throw new Error(`${(0, s.msg)(i)} is only allowed in root programmatic options, or babel.config.js/config file options`);
						}
						(p[n] || l[n] || a[n] || o[n] || throwUnknownError)(i, t[n]);
					}), t;
				}
				function throwUnknownError(e) {
					const t = e.name;
					if (n.default[t]) {
						const { message: r, version: i = 5 } = n.default[t];
						throw new Error(`Using removed Babel ${i} option: ${(0, s.msg)(e)} - ${r}`);
					}
					{
						const t = /* @__PURE__ */ new Error(`Unknown option: ${(0, s.msg)(e)}. Check out https://babeljs.io/docs/en/babel-core/#options for more information about options.`);
						throw t.code = "BABEL_UNKNOWN_OPTION", t;
					}
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/plugins.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.validatePluginObject = function(e) {
					const t = {
						type: "root",
						source: "plugin"
					};
					return Object.keys(e).forEach((r) => {
						const n = s[r];
						if (!n) {
							const e = /* @__PURE__ */ new Error(`.${r} is not a valid Plugin property`);
							throw e.code = "BABEL_UNKNOWN_PLUGIN_PROPERTY", e;
						}
						n({
							type: "option",
							name: r,
							parent: t
						}, e[r]);
					}), e;
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/option-assertions.js");
				const s = {
					name: n.assertString,
					manipulateOptions: n.assertFunction,
					pre: n.assertFunction,
					post: n.assertFunction,
					inherits: n.assertFunction,
					visitor: function(e, t) {
						const r = (0, n.assertObject)(e, t);
						if (r && (Object.keys(r).forEach((e) => {
							"_exploded" !== e && "_verified" !== e && function(e, t) {
								if (t && "object" == typeof t) Object.keys(t).forEach((t) => {
									if ("enter" !== t && "exit" !== t) throw new Error(`.visitor["${e}"] may only have .enter and/or .exit handlers.`);
								});
								else if ("function" != typeof t) throw new Error(`.visitor["${e}"] must be a function`);
							}(e, r[e]);
						}), r.enter || r.exit)) throw new Error(`${(0, n.msg)(e)} cannot contain catch-all "enter" or "exit" handlers. Please target individual nodes.`);
						return r;
					},
					parserOverride: n.assertFunction,
					generatorOverride: n.assertFunction
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/validation/removed.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				t.default = {
					auxiliaryComment: { message: "Use `auxiliaryCommentBefore` or `auxiliaryCommentAfter`" },
					blacklist: { message: "Put the specific transforms you want in the `plugins` option" },
					breakConfig: { message: "This is not a necessary option in Babel 6" },
					experimental: { message: "Put the specific transforms you want in the `plugins` option" },
					externalHelpers: { message: "Use the `external-helpers` plugin instead. Check out http://babeljs.io/docs/plugins/external-helpers/" },
					extra: { message: "" },
					jsxPragma: { message: "use the `pragma` option in the `react-jsx` plugin. Check out http://babeljs.io/docs/plugins/transform-react-jsx/" },
					loose: { message: "Specify the `loose` option for the relevant plugin you are using or use a preset that sets the option." },
					metadataUsedHelpers: { message: "Not required anymore as this is enabled by default" },
					modules: { message: "Use the corresponding module transform plugin in the `plugins` option. Check out http://babeljs.io/docs/plugins/#modules" },
					nonStandard: { message: "Use the `react-jsx` and `flow-strip-types` plugins to support JSX and Flow. Also check out the react preset http://babeljs.io/docs/plugins/preset-react/" },
					optional: { message: "Put the specific transforms you want in the `plugins` option" },
					sourceMapName: { message: "The `sourceMapName` option has been removed because it makes more sense for the tooling that calls Babel to assign `map.file` themselves." },
					stage: { message: "Check out the corresponding stage-x presets http://babeljs.io/docs/plugins/#presets" },
					whitelist: { message: "Put the specific transforms you want in the `plugins` option" },
					resolveModuleSource: {
						version: 6,
						message: "Use `babel-plugin-module-resolver@3`'s 'resolvePath' options"
					},
					metadata: {
						version: 6,
						message: "Generated plugin metadata is always included in the output result"
					},
					sourceMapTarget: {
						version: 6,
						message: "The `sourceMapTarget` option has been removed because it makes more sense for the tooling that calls Babel to assign `map.file` themselves."
					}
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/config-error.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/rewrite-stack-trace.js");
				class ConfigError extends Error {
					constructor(e, t) {
						super(e), (0, n.expectedError)(this), t && (0, n.injectVirtualStackFrame)(this, t);
					}
				}
				t.default = ConfigError;
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/rewrite-stack-trace.js": function(e, t) {
				"use strict";
				var r;
				Object.defineProperty(t, "__esModule", { value: !0 }), t.beginHiddenCallStack = function(e) {
					return s ? Object.defineProperty(function(...t) {
						return setupPrepareStackTrace(), e(...t);
					}, "name", { value: o }) : e;
				}, t.endHiddenCallStack = function(e) {
					return s ? Object.defineProperty(function(...t) {
						return e(...t);
					}, "name", { value: i }) : e;
				}, t.expectedError = function(e) {
					if (!s) return;
					return a.add(e), e;
				}, t.injectVirtualStackFrame = function(e, t) {
					if (!s) return;
					let r = l.get(e);
					r || l.set(e, r = []);
					return r.push(function(e) {
						return Object.create({
							isNative: () => !1,
							isConstructor: () => !1,
							isToplevel: () => !0,
							getFileName: () => e,
							getLineNumber: () => {},
							getColumnNumber: () => {},
							getFunctionName: () => {},
							getMethodName: () => {},
							getTypeName: () => {},
							toString: () => e
						});
					}(t)), e;
				};
				const n = Function.call.bind(Error.prototype.toString), s = !!Error.captureStackTrace && !0 === (null == (r = Object.getOwnPropertyDescriptor(Error, "stackTraceLimit")) ? void 0 : r.writable), i = "startHiding - secret - don't use this - v1", o = "stopHiding - secret - don't use this - v1", a = /* @__PURE__ */ new WeakSet(), l = /* @__PURE__ */ new WeakMap();
				function setupPrepareStackTrace() {
					setupPrepareStackTrace = () => {};
					const { prepareStackTrace: e = defaultPrepareStackTrace } = Error;
					Error.stackTraceLimit && (Error.stackTraceLimit = Math.max(Error.stackTraceLimit, 50)), Error.prepareStackTrace = function(t, r) {
						let n = [];
						let s = a.has(t) ? "hiding" : "unknown";
						for (let e = 0; e < r.length; e++) {
							const a = r[e].getFunctionName();
							if (a === i) s = "hiding";
							else if (a === o) {
								if ("hiding" === s) s = "showing", l.has(t) && n.unshift(...l.get(t));
								else if ("unknown" === s) {
									n = r;
									break;
								}
							} else "hiding" !== s && n.push(r[e]);
						}
						return e(t, n);
					};
				}
				function defaultPrepareStackTrace(e, t) {
					return 0 === t.length ? n(e) : `${n(e)}\n    at ${t.join("\n    at ")}`;
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/async.js": function(e, t, r) {
				"use strict";
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				function asyncGeneratorStep(e, t, r, n, s, i, o) {
					try {
						var a = e[i](o), l = a.value;
					} catch (e) {
						r(e);
						return;
					}
					a.done ? t(l) : Promise.resolve(l).then(n, s);
				}
				function _asyncToGenerator(e) {
					return function() {
						var t = this, r = arguments;
						return new Promise(function(n, s) {
							var i = e.apply(t, r);
							function _next(e) {
								asyncGeneratorStep(i, n, s, _next, _throw, "next", e);
							}
							function _throw(e) {
								asyncGeneratorStep(i, n, s, _next, _throw, "throw", e);
							}
							_next(void 0);
						});
					};
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.forwardAsync = function(e, t) {
					const r = _gensync()(e);
					return s((e) => {
						const n = r[e];
						return t(n);
					});
				}, t.isAsync = void 0, t.isThenable = isThenable, t.maybeAsync = function(e, t) {
					return _gensync()({
						sync(...r) {
							const n = e.apply(this, r);
							if (isThenable(n)) throw new Error(t);
							return n;
						},
						async(...t) {
							return Promise.resolve(e.apply(this, t));
						}
					});
				}, t.waitFor = t.onFirstPause = void 0;
				const n = _gensync()(function* (e) {
					return yield* e;
				});
				t.isAsync = _gensync()({
					sync: () => !1,
					errback: (e) => e(null, !0)
				});
				const s = _gensync()({
					sync: (e) => e("sync"),
					async: (i = _asyncToGenerator(function* (e) {
						return e("async");
					}), function(e) {
						return i.apply(this, arguments);
					})
				});
				var i;
				t.onFirstPause = _gensync()({
					name: "onFirstPause",
					arity: 2,
					sync: function(e) {
						return n.sync(e);
					},
					errback: function(e, t, r) {
						let s = !1;
						n.errback(e, (e, t) => {
							s = !0, r(e, t);
						}), s || t();
					}
				}), t.waitFor = _gensync()({
					sync: (e) => e,
					async: (o = _asyncToGenerator(function* (e) {
						return e;
					}), function(e) {
						return o.apply(this, arguments);
					})
				});
				var o;
				function isThenable(e) {
					return !(!e || "object" != typeof e && "function" != typeof e || !e.then || "function" != typeof e.then);
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/fs.js": function(e, t, r) {
				"use strict";
				function _fs() {
					const e = r("fs");
					return _fs = function() {
						return e;
					}, e;
				}
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.stat = t.readFile = void 0;
				t.readFile = _gensync()({
					sync: _fs().readFileSync,
					errback: _fs().readFile
				}), t.stat = _gensync()({
					sync: _fs().statSync,
					errback: _fs().stat
				});
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/functional.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.once = function(e) {
					let t, r, s = !1;
					return function* () {
						if (!t) {
							if (r) return s = !0, yield* (0, n.waitFor)(r);
							if (yield* (0, n.isAsync)()) {
								let n, i;
								r = new Promise((e, t) => {
									n = e, i = t;
								});
								try {
									t = {
										ok: !0,
										value: yield* e()
									}, r = null, s && n(t.value);
								} catch (e) {
									t = {
										ok: !1,
										value: e
									}, r = null, s && i(e);
								}
							} else try {
								t = {
									ok: !0,
									value: yield* e()
								};
							} catch (e) {
								t = {
									ok: !1,
									value: e
								};
							}
						}
						if (t.ok) return t.value;
						throw t.value;
					};
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/async.js");
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.DEFAULT_EXTENSIONS = void 0, Object.defineProperty(t, "File", {
					enumerable: !0,
					get: function() {
						return n.default;
					}
				}), Object.defineProperty(t, "buildExternalHelpers", {
					enumerable: !0,
					get: function() {
						return s.default;
					}
				}), Object.defineProperty(t, "createConfigItem", {
					enumerable: !0,
					get: function() {
						return a.createConfigItem;
					}
				}), Object.defineProperty(t, "createConfigItemAsync", {
					enumerable: !0,
					get: function() {
						return a.createConfigItemAsync;
					}
				}), Object.defineProperty(t, "createConfigItemSync", {
					enumerable: !0,
					get: function() {
						return a.createConfigItemSync;
					}
				}), Object.defineProperty(t, "getEnv", {
					enumerable: !0,
					get: function() {
						return o.getEnv;
					}
				}), Object.defineProperty(t, "loadOptions", {
					enumerable: !0,
					get: function() {
						return a.loadOptions;
					}
				}), Object.defineProperty(t, "loadOptionsAsync", {
					enumerable: !0,
					get: function() {
						return a.loadOptionsAsync;
					}
				}), Object.defineProperty(t, "loadOptionsSync", {
					enumerable: !0,
					get: function() {
						return a.loadOptionsSync;
					}
				}), Object.defineProperty(t, "loadPartialConfig", {
					enumerable: !0,
					get: function() {
						return a.loadPartialConfig;
					}
				}), Object.defineProperty(t, "loadPartialConfigAsync", {
					enumerable: !0,
					get: function() {
						return a.loadPartialConfigAsync;
					}
				}), Object.defineProperty(t, "loadPartialConfigSync", {
					enumerable: !0,
					get: function() {
						return a.loadPartialConfigSync;
					}
				}), Object.defineProperty(t, "parse", {
					enumerable: !0,
					get: function() {
						return u.parse;
					}
				}), Object.defineProperty(t, "parseAsync", {
					enumerable: !0,
					get: function() {
						return u.parseAsync;
					}
				}), Object.defineProperty(t, "parseSync", {
					enumerable: !0,
					get: function() {
						return u.parseSync;
					}
				}), t.resolvePreset = t.resolvePlugin = void 0, Object.defineProperty(t, "template", {
					enumerable: !0,
					get: function() {
						return _template().default;
					}
				}), Object.defineProperty(t, "tokTypes", {
					enumerable: !0,
					get: function() {
						return _parser().tokTypes;
					}
				}), Object.defineProperty(t, "transform", {
					enumerable: !0,
					get: function() {
						return l.transform;
					}
				}), Object.defineProperty(t, "transformAsync", {
					enumerable: !0,
					get: function() {
						return l.transformAsync;
					}
				}), Object.defineProperty(t, "transformFile", {
					enumerable: !0,
					get: function() {
						return p.transformFile;
					}
				}), Object.defineProperty(t, "transformFileAsync", {
					enumerable: !0,
					get: function() {
						return p.transformFileAsync;
					}
				}), Object.defineProperty(t, "transformFileSync", {
					enumerable: !0,
					get: function() {
						return p.transformFileSync;
					}
				}), Object.defineProperty(t, "transformFromAst", {
					enumerable: !0,
					get: function() {
						return c.transformFromAst;
					}
				}), Object.defineProperty(t, "transformFromAstAsync", {
					enumerable: !0,
					get: function() {
						return c.transformFromAstAsync;
					}
				}), Object.defineProperty(t, "transformFromAstSync", {
					enumerable: !0,
					get: function() {
						return c.transformFromAstSync;
					}
				}), Object.defineProperty(t, "transformSync", {
					enumerable: !0,
					get: function() {
						return l.transformSync;
					}
				}), Object.defineProperty(t, "traverse", {
					enumerable: !0,
					get: function() {
						return _traverse().default;
					}
				}), t.version = t.types = void 0;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/file/file.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/tools/build-external-helpers.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/files/index.js"), o = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/helpers/environment.js");
				function _types() {
					const e = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
					return _types = function() {
						return e;
					}, e;
				}
				function _parser() {
					const e = r("./node_modules/.pnpm/@babel+parser@7.28.4/node_modules/@babel/parser/lib/index.js");
					return _parser = function() {
						return e;
					}, e;
				}
				function _traverse() {
					const e = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js");
					return _traverse = function() {
						return e;
					}, e;
				}
				function _template() {
					const e = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/index.js");
					return _template = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "types", {
					enumerable: !0,
					get: function() {
						return _types();
					}
				});
				var a = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/index.js"), l = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transform.js"), p = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transform-file.js"), c = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transform-ast.js"), u = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/parse.js");
				t.version = "7.28.4";
				t.resolvePlugin = (e, t) => i.resolvePlugin(e, t, !1).filepath;
				t.resolvePreset = (e, t) => i.resolvePreset(e, t, !1).filepath;
				t.DEFAULT_EXTENSIONS = Object.freeze([
					".js",
					".jsx",
					".es6",
					".es",
					".mjs",
					".cjs"
				]);
				t.OptionManager = class {
					init(e) {
						return (0, a.loadOptionsSync)(e);
					}
				}, t.Plugin = function(e) {
					throw new Error(`The (${e}) Babel 5 plugin is being run with an unsupported Babel version.`);
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/parse.js": function(e, t, r) {
				"use strict";
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.parse = void 0, t.parseAsync = function(...e) {
					return (0, o.beginHiddenCallStack)(a.async)(...e);
				}, t.parseSync = function(...e) {
					return (0, o.beginHiddenCallStack)(a.sync)(...e);
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/index.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/parser/index.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/normalize-opts.js"), o = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/rewrite-stack-trace.js");
				const a = _gensync()(function* (e, t) {
					const r = yield* (0, n.default)(t);
					return null === r ? null : yield* (0, s.default)(r.passes, (0, i.default)(r), e);
				});
				t.parse = function(e, t, r) {
					if ("function" == typeof t && (r = t, t = void 0), void 0 === r) return (0, o.beginHiddenCallStack)(a.sync)(e, t);
					(0, o.beginHiddenCallStack)(a.errback)(e, t, r);
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/parser/index.js": function(e, t, r) {
				"use strict";
				function _parser() {
					const e = r("./node_modules/.pnpm/@babel+parser@7.28.4/node_modules/@babel/parser/lib/index.js");
					return _parser = function() {
						return e;
					}, e;
				}
				function _codeFrame() {
					const e = r("./stubs/babel-codeframe.mjs");
					return _codeFrame = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function* (e, { parserOpts: t, highlightCode: r = !0, filename: s = "unknown" }, i) {
					try {
						const r = [];
						for (const n of e) for (const e of n) {
							const { parserOverride: n } = e;
							if (n) {
								const e = n(i, t, _parser().parse);
								void 0 !== e && r.push(e);
							}
						}
						if (0 === r.length) return (0, _parser().parse)(i, t);
						if (1 === r.length) {
							if (yield* [], "function" == typeof r[0].then) throw new Error("You appear to be using an async parser plugin, which your current version of Babel does not support. If you're using a published plugin, you may need to upgrade your @babel/core version.");
							return r[0];
						}
						throw new Error("More than one plugin attempted to override parsing.");
					} catch (e) {
						"BABEL_PARSER_SOURCETYPE_MODULE_REQUIRED" === e.code && (e.message += "\nConsider renaming the file to '.mjs', or setting sourceType:module or sourceType:unambiguous in your Babel config for this file.");
						const { loc: t, missingPlugin: o } = e;
						if (t) {
							const a = (0, _codeFrame().codeFrameColumns)(i, { start: {
								line: t.line,
								column: t.column + 1
							} }, { highlightCode: r });
							e.message = o ? `${s}: ` + (0, n.default)(o[0], t, a, s) : `${s}: ${e.message}\n\n` + a, e.code = "BABEL_PARSE_ERROR";
						}
						throw e;
					}
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/parser/util/missing-plugin-helper.js");
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/parser/util/missing-plugin-helper.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, n, s) {
					let i = `Support for the experimental syntax '${e}' isn't currently enabled (${t.line}:${t.column + 1}):\n\n` + n;
					const o = r[e];
					if (o) {
						const { syntax: e, transform: t } = o;
						if (e) {
							const r = getNameURLCombination(e);
							if (t) i += `\n\nAdd ${getNameURLCombination(t)} to the '${t.name.startsWith("@babel/plugin") ? "plugins" : "presets"}' section of your Babel config to enable transformation.\nIf you want to leave it as-is, add ${r} to the 'plugins' section to enable parsing.`;
							else i += `\n\nAdd ${r} to the 'plugins' section of your Babel config to enable parsing.`;
						}
					}
					return i += `\n\nIf you already added the plugin for this syntax to your config, it's possible that your config isn't being loaded.\nYou can re-run Babel with the BABEL_SHOW_CONFIG_FOR environment variable to show the loaded configuration:\n\tnpx cross-env BABEL_SHOW_CONFIG_FOR=${s === "unknown" ? "<name of the input file>" : s} <your build command>\nSee https://babeljs.io/docs/configuration#print-effective-configs for more info.\n`, i;
				};
				const r = {
					asyncDoExpressions: { syntax: {
						name: "@babel/plugin-syntax-async-do-expressions",
						url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-async-do-expressions"
					} },
					decimal: { syntax: {
						name: "@babel/plugin-syntax-decimal",
						url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-decimal"
					} },
					decorators: {
						syntax: {
							name: "@babel/plugin-syntax-decorators",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-decorators"
						},
						transform: {
							name: "@babel/plugin-proposal-decorators",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-decorators"
						}
					},
					doExpressions: {
						syntax: {
							name: "@babel/plugin-syntax-do-expressions",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-do-expressions"
						},
						transform: {
							name: "@babel/plugin-proposal-do-expressions",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-do-expressions"
						}
					},
					exportDefaultFrom: {
						syntax: {
							name: "@babel/plugin-syntax-export-default-from",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-export-default-from"
						},
						transform: {
							name: "@babel/plugin-proposal-export-default-from",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-export-default-from"
						}
					},
					flow: {
						syntax: {
							name: "@babel/plugin-syntax-flow",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-flow"
						},
						transform: {
							name: "@babel/preset-flow",
							url: "https://github.com/babel/babel/tree/main/packages/babel-preset-flow"
						}
					},
					functionBind: {
						syntax: {
							name: "@babel/plugin-syntax-function-bind",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-function-bind"
						},
						transform: {
							name: "@babel/plugin-proposal-function-bind",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-function-bind"
						}
					},
					functionSent: {
						syntax: {
							name: "@babel/plugin-syntax-function-sent",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-function-sent"
						},
						transform: {
							name: "@babel/plugin-proposal-function-sent",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-function-sent"
						}
					},
					jsx: {
						syntax: {
							name: "@babel/plugin-syntax-jsx",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-jsx"
						},
						transform: {
							name: "@babel/preset-react",
							url: "https://github.com/babel/babel/tree/main/packages/babel-preset-react"
						}
					},
					pipelineOperator: {
						syntax: {
							name: "@babel/plugin-syntax-pipeline-operator",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-pipeline-operator"
						},
						transform: {
							name: "@babel/plugin-proposal-pipeline-operator",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-pipeline-operator"
						}
					},
					recordAndTuple: { syntax: {
						name: "@babel/plugin-syntax-record-and-tuple",
						url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-record-and-tuple"
					} },
					throwExpressions: {
						syntax: {
							name: "@babel/plugin-syntax-throw-expressions",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-throw-expressions"
						},
						transform: {
							name: "@babel/plugin-proposal-throw-expressions",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-proposal-throw-expressions"
						}
					},
					typescript: {
						syntax: {
							name: "@babel/plugin-syntax-typescript",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-typescript"
						},
						transform: {
							name: "@babel/preset-typescript",
							url: "https://github.com/babel/babel/tree/main/packages/babel-preset-typescript"
						}
					}
				};
				Object.assign(r, {
					asyncGenerators: {
						syntax: {
							name: "@babel/plugin-syntax-async-generators",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-async-generators"
						},
						transform: {
							name: "@babel/plugin-transform-async-generator-functions",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-async-generator-functions"
						}
					},
					classProperties: {
						syntax: {
							name: "@babel/plugin-syntax-class-properties",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-class-properties"
						},
						transform: {
							name: "@babel/plugin-transform-class-properties",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-class-properties"
						}
					},
					classPrivateProperties: {
						syntax: {
							name: "@babel/plugin-syntax-class-properties",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-class-properties"
						},
						transform: {
							name: "@babel/plugin-transform-class-properties",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-class-properties"
						}
					},
					classPrivateMethods: {
						syntax: {
							name: "@babel/plugin-syntax-class-properties",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-class-properties"
						},
						transform: {
							name: "@babel/plugin-transform-private-methods",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-private-methods"
						}
					},
					classStaticBlock: {
						syntax: {
							name: "@babel/plugin-syntax-class-static-block",
							url: "https://github.com/babel/babel/tree/HEAD/packages/babel-plugin-syntax-class-static-block"
						},
						transform: {
							name: "@babel/plugin-transform-class-static-block",
							url: "https://github.com/babel/babel/tree/HEAD/packages/babel-plugin-transform-class-static-block"
						}
					},
					dynamicImport: { syntax: {
						name: "@babel/plugin-syntax-dynamic-import",
						url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-dynamic-import"
					} },
					exportNamespaceFrom: {
						syntax: {
							name: "@babel/plugin-syntax-export-namespace-from",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-export-namespace-from"
						},
						transform: {
							name: "@babel/plugin-transform-export-namespace-from",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-export-namespace-from"
						}
					},
					importAssertions: { syntax: {
						name: "@babel/plugin-syntax-import-assertions",
						url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-import-assertions"
					} },
					importAttributes: { syntax: {
						name: "@babel/plugin-syntax-import-attributes",
						url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-import-attributes"
					} },
					importMeta: { syntax: {
						name: "@babel/plugin-syntax-import-meta",
						url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-import-meta"
					} },
					logicalAssignment: {
						syntax: {
							name: "@babel/plugin-syntax-logical-assignment-operators",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-logical-assignment-operators"
						},
						transform: {
							name: "@babel/plugin-transform-logical-assignment-operators",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-logical-assignment-operators"
						}
					},
					moduleStringNames: { syntax: {
						name: "@babel/plugin-syntax-module-string-names",
						url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-module-string-names"
					} },
					numericSeparator: {
						syntax: {
							name: "@babel/plugin-syntax-numeric-separator",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-numeric-separator"
						},
						transform: {
							name: "@babel/plugin-transform-numeric-separator",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-numeric-separator"
						}
					},
					nullishCoalescingOperator: {
						syntax: {
							name: "@babel/plugin-syntax-nullish-coalescing-operator",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-nullish-coalescing-operator"
						},
						transform: {
							name: "@babel/plugin-transform-nullish-coalescing-operator",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-nullish-coalescing-opearator"
						}
					},
					objectRestSpread: {
						syntax: {
							name: "@babel/plugin-syntax-object-rest-spread",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-object-rest-spread"
						},
						transform: {
							name: "@babel/plugin-transform-object-rest-spread",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-object-rest-spread"
						}
					},
					optionalCatchBinding: {
						syntax: {
							name: "@babel/plugin-syntax-optional-catch-binding",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-optional-catch-binding"
						},
						transform: {
							name: "@babel/plugin-transform-optional-catch-binding",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-optional-catch-binding"
						}
					},
					optionalChaining: {
						syntax: {
							name: "@babel/plugin-syntax-optional-chaining",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-optional-chaining"
						},
						transform: {
							name: "@babel/plugin-transform-optional-chaining",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-optional-chaining"
						}
					},
					privateIn: {
						syntax: {
							name: "@babel/plugin-syntax-private-property-in-object",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-syntax-private-property-in-object"
						},
						transform: {
							name: "@babel/plugin-transform-private-property-in-object",
							url: "https://github.com/babel/babel/tree/main/packages/babel-plugin-transform-private-property-in-object"
						}
					},
					regexpUnicodeSets: {
						syntax: {
							name: "@babel/plugin-syntax-unicode-sets-regex",
							url: "https://github.com/babel/babel/blob/main/packages/babel-plugin-syntax-unicode-sets-regex/README.md"
						},
						transform: {
							name: "@babel/plugin-transform-unicode-sets-regex",
							url: "https://github.com/babel/babel/blob/main/packages/babel-plugin-proposalunicode-sets-regex/README.md"
						}
					}
				});
				const getNameURLCombination = ({ name: e, url: t }) => `${e} (${t})`;
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/tools/build-external-helpers.js": function(e, t, r) {
				"use strict";
				function helpers() {
					const e = r("./node_modules/.pnpm/@babel+helpers@7.28.4/node_modules/@babel/helpers/lib/index.js");
					return helpers = function() {
						return e;
					}, e;
				}
				function _generator() {
					const e = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/index.js");
					return _generator = function() {
						return e;
					}, e;
				}
				function _template() {
					const e = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/index.js");
					return _template = function() {
						return e;
					}, e;
				}
				function _t() {
					const e = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
					return _t = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t = "global") {
					let r;
					const n = {
						global: buildGlobal,
						module: buildModule,
						umd: buildUmd,
						var: buildVar
					}[t];
					if (!n) throw new Error(`Unsupported output type ${t}`);
					r = n(e);
					return (0, _generator().default)(r).code;
				};
				const { arrayExpression: n, assignmentExpression: s, binaryExpression: i, blockStatement: o, callExpression: a, cloneNode: l, conditionalExpression: p, exportNamedDeclaration: c, exportSpecifier: u, expressionStatement: d, functionExpression: h, identifier: m, memberExpression: f, objectExpression: y, program: b, stringLiteral: g, unaryExpression: x, variableDeclaration: v, variableDeclarator: E } = _t(), buildUmdWrapper = (e) => _template().default.statement`
    (function (root, factory) {
      if (typeof define === "function" && define.amd) {
        define(AMD_ARGUMENTS, factory);
      } else if (typeof exports === "object") {
        factory(COMMON_ARGUMENTS);
      } else {
        factory(BROWSER_ARGUMENTS);
      }
    })(UMD_ROOT, function (FACTORY_PARAMETERS) {
      FACTORY_BODY
    });
  `(e);
				function buildGlobal(e) {
					const t = m("babelHelpers"), r = [], l = b([d(a(h(null, [m("global")], o(r)), [p(i("===", x("typeof", m("global")), g("undefined")), m("self"), m("global"))]))]);
					return r.push(v("var", [E(t, s("=", f(m("global"), t), y([])))])), buildHelpers(r, t, e), l;
				}
				function buildModule(e) {
					const t = [], r = buildHelpers(t, null, e);
					return t.unshift(c(null, Object.keys(r).map((e) => u(l(r[e]), m(e))))), b(t, [], "module");
				}
				function buildUmd(e) {
					const t = m("babelHelpers"), r = [];
					return r.push(v("var", [E(t, m("global"))])), buildHelpers(r, t, e), b([buildUmdWrapper({
						FACTORY_PARAMETERS: m("global"),
						BROWSER_ARGUMENTS: s("=", f(m("root"), t), y([])),
						COMMON_ARGUMENTS: m("exports"),
						AMD_ARGUMENTS: n([g("exports")]),
						FACTORY_BODY: r,
						UMD_ROOT: m("this")
					})]);
				}
				function buildVar(e) {
					const t = m("babelHelpers"), r = [];
					r.push(v("var", [E(t, y([]))]));
					const n = b(r);
					return buildHelpers(r, t, e), r.push(d(t)), n;
				}
				function buildHelpers(e, t, r) {
					const getHelperReference = (e) => t ? f(t, m(e)) : m(`_${e}`), n = {};
					return helpers().list.forEach(function(i) {
						if (r && !r.includes(i)) return;
						const o = n[i] = getHelperReference(i), { nodes: a } = helpers().get(i, getHelperReference, t ? null : `_${i}`, [], t ? (e, t, r) => {
							r((e) => s("=", o, e)), e.body.push(d(s("=", o, m(t))));
						} : null);
						e.push(...a);
					}), n;
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transform-ast.js": function(e, t, r) {
				"use strict";
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.transformFromAst = void 0, t.transformFromAstAsync = function(...e) {
					return (0, i.beginHiddenCallStack)(o.async)(...e);
				}, t.transformFromAstSync = function(...e) {
					return (0, i.beginHiddenCallStack)(o.sync)(...e);
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/index.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/index.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/rewrite-stack-trace.js");
				const o = _gensync()(function* (e, t, r) {
					const i = yield* (0, n.default)(r);
					if (null === i) return null;
					if (!e) throw new Error("No AST given");
					return yield* (0, s.run)(i, t, e);
				});
				t.transformFromAst = function(e, t, r, n) {
					let s, a;
					if ("function" == typeof r ? (a = r, s = void 0) : (s = r, a = n), void 0 === a) return (0, i.beginHiddenCallStack)(o.sync)(e, t, s);
					(0, i.beginHiddenCallStack)(o.errback)(e, t, s, a);
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transform-file.js": function(e, t, r) {
				"use strict";
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.transformFile = function(...e) {
					o.errback(...e);
				}, t.transformFileAsync = function(...e) {
					return o.async(...e);
				}, t.transformFileSync = function(...e) {
					return o.sync(...e);
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/index.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/index.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/fs.js");
				const o = _gensync()(function* (e, t) {
					const r = Object.assign({}, t, { filename: e }), o = yield* (0, n.default)(r);
					if (null === o) return null;
					const a = yield* i.readFile(e, "utf8");
					return yield* (0, s.run)(o, a);
				});
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transform.js": function(e, t, r) {
				"use strict";
				function _gensync() {
					const e = r("./node_modules/.pnpm/gensync@1.0.0-beta.2/node_modules/gensync/index.js");
					return _gensync = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.transform = void 0, t.transformAsync = function(...e) {
					return (0, i.beginHiddenCallStack)(o.async)(...e);
				}, t.transformSync = function(...e) {
					return (0, i.beginHiddenCallStack)(o.sync)(...e);
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/index.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/index.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/errors/rewrite-stack-trace.js");
				const o = _gensync()(function* (e, t) {
					const r = yield* (0, n.default)(t);
					return null === r ? null : yield* (0, s.run)(r, e);
				});
				t.transform = function(e, t, r) {
					let n, s;
					if ("function" == typeof t ? (s = t, n = void 0) : (n = t, s = r), void 0 === s) return (0, i.beginHiddenCallStack)(o.sync)(e, n);
					(0, i.beginHiddenCallStack)(o.errback)(e, n, s);
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/block-hoist-plugin.js": function(e, t, r) {
				"use strict";
				function _traverse() {
					const e = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js");
					return _traverse = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function() {
					s || (s = new n.default(Object.assign({}, i, { visitor: _traverse().default.explode(i.visitor) }), {}));
					return s;
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/plugin.js");
				let s;
				const i = {
					name: "internal.blockHoist",
					visitor: {
						Block: { exit({ node: e }) {
							e.body = performHoisting(e.body);
						} },
						SwitchCase: { exit({ node: e }) {
							e.consequent = performHoisting(e.consequent);
						} }
					}
				};
				function performHoisting(e) {
					let t = Math.pow(2, 30) - 1, r = !1;
					for (let n = 0; n < e.length; n++) {
						const s = priority(e[n]);
						if (s > t) {
							r = !0;
							break;
						}
						t = s;
					}
					return r ? function(e) {
						const t = Object.create(null);
						for (let r = 0; r < e.length; r++) {
							const n = e[r], s = priority(n);
							(t[s] || (t[s] = [])).push(n);
						}
						const r = Object.keys(t).map((e) => +e).sort((e, t) => t - e);
						let n = 0;
						for (const s of r) {
							const r = t[s];
							for (const t of r) e[n++] = t;
						}
						return e;
					}(e.slice()) : e;
				}
				function priority(e) {
					const t = null == e ? void 0 : e._blockHoist;
					return null == t ? 1 : !0 === t ? 2 : t;
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/file/babel-7-helpers.cjs": function(e, t, r) {
				t.getModuleName = () => r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/index.js").getModuleName;
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/file/file.js": function(e, t, r) {
				"use strict";
				function helpers() {
					const e = r("./node_modules/.pnpm/@babel+helpers@7.28.4/node_modules/@babel/helpers/lib/index.js");
					return helpers = function() {
						return e;
					}, e;
				}
				function _traverse() {
					const e = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js");
					return _traverse = function() {
						return e;
					}, e;
				}
				function _codeFrame() {
					const e = r("./stubs/babel-codeframe.mjs");
					return _codeFrame = function() {
						return e;
					}, e;
				}
				function _t() {
					const e = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
					return _t = function() {
						return e;
					}, e;
				}
				function _semver() {
					const e = r("./node_modules/.pnpm/semver@6.3.1/node_modules/semver/semver.js");
					return _semver = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/file/babel-7-helpers.cjs");
				const { cloneNode: s, interpreterDirective: i } = _t(), o = { enter(e, t) {
					const r = e.node.loc;
					r && (t.loc = r, e.stop());
				} };
				class File {
					constructor(e, { code: t, ast: r, inputMap: n }) {
						this._map = /* @__PURE__ */ new Map(), this.opts = void 0, this.declarations = {}, this.path = void 0, this.ast = void 0, this.scope = void 0, this.metadata = {}, this.code = "", this.inputMap = void 0, this.hub = {
							file: this,
							getCode: () => this.code,
							getScope: () => this.scope,
							addHelper: this.addHelper.bind(this),
							buildError: this.buildCodeFrameError.bind(this)
						}, this.opts = e, this.code = t, this.ast = r, this.inputMap = n, this.path = _traverse().NodePath.get({
							hub: this.hub,
							parentPath: null,
							parent: this.ast,
							container: this.ast,
							key: "program"
						}).setContext(), this.scope = this.path.scope;
					}
					get shebang() {
						const { interpreter: e } = this.path.node;
						return e ? e.value : "";
					}
					set shebang(e) {
						e ? this.path.get("interpreter").replaceWith(i(e)) : this.path.get("interpreter").remove();
					}
					set(e, t) {
						if ("helpersNamespace" === e) throw new Error("Babel 7.0.0-beta.56 has dropped support for the 'helpersNamespace' utility.If you are using @babel/plugin-external-helpers you will need to use a newer version than the one you currently have installed. If you have your own implementation, you'll want to explore using 'helperGenerator' alongside 'file.availableHelper()'.");
						this._map.set(e, t);
					}
					get(e) {
						return this._map.get(e);
					}
					has(e) {
						return this._map.has(e);
					}
					availableHelper(e, t) {
						if (helpers().isInternal(e)) return !1;
						let r;
						try {
							r = helpers().minVersion(e);
						} catch (e) {
							if ("BABEL_HELPER_UNKNOWN" !== e.code) throw e;
							return !1;
						}
						return "string" != typeof t || (_semver().valid(t) && (t = `^${t}`), !_semver().intersects(`<${r}`, t) && !_semver().intersects(">=8.0.0", t));
					}
					addHelper(e) {
						if (helpers().isInternal(e)) throw new Error("Cannot use internal helper " + e);
						return this._addHelper(e);
					}
					_addHelper(e) {
						const t = this.declarations[e];
						if (t) return s(t);
						const r = this.get("helperGenerator");
						if (r) {
							const t = r(e);
							if (t) return t;
						}
						helpers().minVersion(e);
						const n = this.declarations[e] = this.scope.generateUidIdentifier(e), i = {};
						for (const t of helpers().getDependencies(e)) i[t] = this._addHelper(t);
						const { nodes: o, globals: a } = helpers().get(e, (e) => i[e], n.name, Object.keys(this.scope.getAllBindings()));
						a.forEach((e) => {
							this.path.scope.hasBinding(e, !0) && this.path.scope.rename(e);
						}), o.forEach((e) => {
							e._compact = !0;
						});
						const l = this.path.unshiftContainer("body", o);
						for (const e of l) e.isVariableDeclaration() && this.scope.registerDeclaration(e);
						return n;
					}
					buildCodeFrameError(e, t, r = SyntaxError) {
						let n = null == e ? void 0 : e.loc;
						if (!n && e) {
							const r = { loc: null };
							(0, _traverse().default)(e, o, this.scope, r), n = r.loc;
							let s = "This is an error on an internal node. Probably an internal error.";
							n && (s += " Location has been estimated."), t += ` (${s})`;
						}
						if (n) {
							const { highlightCode: e = !0 } = this.opts;
							t += "\n" + (0, _codeFrame().codeFrameColumns)(this.code, {
								start: {
									line: n.start.line,
									column: n.start.column + 1
								},
								end: n.end && n.start.line === n.end.line ? {
									line: n.end.line,
									column: n.end.column + 1
								} : void 0
							}, { highlightCode: e });
						}
						return new r(t);
					}
				}
				t.default = File, File.prototype.addImport = function() {
					throw new Error("This API has been removed. If you're looking for this functionality in Babel 7, you should import the '@babel/helper-module-imports' module and use the functions exposed  from that module, such as 'addNamed' or 'addDefault'.");
				}, File.prototype.addTemplateObject = function() {
					throw new Error("This function has been moved into the template literal transform itself.");
				}, File.prototype.getModuleName = function() {
					return n.getModuleName()(this.opts, this.opts);
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/file/generate.js": function(e, t, r) {
				"use strict";
				function _convertSourceMap() {
					const e = r("./node_modules/.pnpm/convert-source-map@2.0.0/node_modules/convert-source-map/index.js");
					return _convertSourceMap = function() {
						return e;
					}, e;
				}
				function _generator() {
					const e = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/index.js");
					return _generator = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					const { opts: r, ast: s, code: i, inputMap: o } = t, { generatorOpts: a } = r;
					a.inputSourceMap = null == o ? void 0 : o.toObject();
					const l = [];
					for (const t of e) for (const e of t) {
						const { generatorOverride: t } = e;
						if (t) {
							const e = t(s, a, i, _generator().default);
							void 0 !== e && l.push(e);
						}
					}
					let p;
					if (0 === l.length) p = (0, _generator().default)(s, a, i);
					else {
						if (1 !== l.length) throw new Error("More than one plugin attempted to override codegen.");
						if (p = l[0], "function" == typeof p.then) throw new Error("You appear to be using an async codegen plugin, which your current version of Babel does not support. If you're using a published plugin, you may need to upgrade your @babel/core version.");
					}
					let { code: c, decodedMap: u = p.map } = p;
					p.__mergedMap ? u = Object.assign({}, p.map) : u && (u = o ? (0, n.default)(o.toObject(), u, a.sourceFileName) : p.map);
					"inline" !== r.sourceMaps && "both" !== r.sourceMaps || (c += "\n" + _convertSourceMap().fromObject(u).toComment());
					"inline" === r.sourceMaps && (u = null);
					return {
						outputCode: c,
						outputMap: u
					};
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/file/merge-map.js");
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/file/merge-map.js": function(e, t, r) {
				"use strict";
				function _remapping() {
					const e = r("./node_modules/.pnpm/@jridgewell+remapping@2.3.5/node_modules/@jridgewell/remapping/dist/remapping.umd.js");
					return _remapping = function() {
						return e;
					}, e;
				}
				function rootless(e) {
					return Object.assign({}, e, { sourceRoot: null });
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					const n = r.replace(/\\/g, "/");
					let s = !1;
					const i = _remapping()(rootless(t), (t, r) => t !== n || s ? null : (s = !0, r.source = "", rootless(e)));
					"string" == typeof e.sourceRoot && (i.sourceRoot = e.sourceRoot);
					return Object.assign({}, i);
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/index.js": function(e, t, r) {
				"use strict";
				function _traverse() {
					const e = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js");
					return _traverse = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.run = function* (e, t, r) {
					const c = yield* (0, o.default)(e.passes, (0, i.default)(e), t, r), u = c.opts;
					try {
						yield* function* (e, t) {
							const r = yield* (0, p.isAsync)();
							for (const i of t) {
								const t = [], o = [], a = [];
								for (const l of i.concat([(0, s.default)()])) {
									const s = new n.default(e, l.key, l.options, r);
									t.push([l, s]), o.push(s), a.push(l.visitor);
								}
								for (const [r, n] of t) if (r.pre) yield* (0, p.maybeAsync)(r.pre, "You appear to be using an async plugin/preset, but Babel has been called synchronously").call(n, e);
								const l = _traverse().default.visitors.merge(a, o, e.opts.wrapPluginVisitorMethod);
								(0, _traverse().default)(e.ast, l, e.scope);
								for (const [r, n] of t) if (r.post) yield* (0, p.maybeAsync)(r.post, "You appear to be using an async plugin/preset, but Babel has been called synchronously").call(n, e);
							}
						}(c, e.passes);
					} catch (e) {
						var d;
						throw e.message = `${null != (d = u.filename) ? d : "unknown file"}: ${e.message}`, e.code || (e.code = "BABEL_TRANSFORM_ERROR"), e;
					}
					let h, m;
					try {
						!1 !== u.code && ({outputCode: h, outputMap: m} = (0, a.default)(e.passes, c));
					} catch (e) {
						var f;
						throw e.message = `${null != (f = u.filename) ? f : "unknown file"}: ${e.message}`, e.code || (e.code = "BABEL_GENERATE_ERROR"), e;
					}
					return {
						metadata: c.metadata,
						options: u,
						ast: !0 === u.ast ? c.ast : null,
						code: void 0 === h ? null : h,
						map: void 0 === m ? null : m,
						sourceType: c.ast.program.sourceType,
						externalDependencies: (0, l.flattenToSet)(e.externalDependencies)
					};
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/plugin-pass.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/block-hoist-plugin.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/normalize-opts.js"), o = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/normalize-file.js"), a = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/file/generate.js"), l = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/config/helpers/deep-array.js"), p = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/gensync-utils/async.js");
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/normalize-file.js": function(e, t, r) {
				"use strict";
				function _fs() {
					const e = r("fs");
					return _fs = function() {
						return e;
					}, e;
				}
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				function _debug() {
					const e = r("./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/index.js");
					return _debug = function() {
						return e;
					}, e;
				}
				function _t() {
					const e = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
					return _t = function() {
						return e;
					}, e;
				}
				function _convertSourceMap() {
					const e = r("./node_modules/.pnpm/convert-source-map@2.0.0/node_modules/convert-source-map/index.js");
					return _convertSourceMap = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function* (e, t, r, a) {
					if (r = `${r || ""}`, a) {
						if ("Program" === a.type) a = o(a, [], []);
						else if ("File" !== a.type) throw new Error("AST root must be a Program or File node");
						t.cloneInputAst && (a = (0, i.default)(a));
					} else a = yield* (0, s.default)(e, t, r);
					let u = null;
					if (!1 !== t.inputSourceMap) {
						if ("object" == typeof t.inputSourceMap && (u = _convertSourceMap().fromObject(t.inputSourceMap)), !u) {
							const e = extractComments(p, a);
							if (e) try {
								u = _convertSourceMap().fromComment("//" + e);
							} catch (e) {
								l("discarding unknown inline input sourcemap");
							}
						}
						if (!u) {
							const e = extractComments(c, a);
							if ("string" == typeof t.filename && e) try {
								const r = c.exec(e), n = _fs().readFileSync(_path().resolve(_path().dirname(t.filename), r[1]), "utf8");
								u = _convertSourceMap().fromJSON(n);
							} catch (e) {
								l("discarding unknown file input sourcemap", e);
							}
							else e && l("discarding un-loadable file input sourcemap");
						}
					}
					return new n.default(t, {
						code: r,
						ast: a,
						inputMap: u
					});
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/file/file.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/parser/index.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/util/clone-deep.js");
				const { file: o, traverseFast: a } = _t(), l = _debug()("babel:transform:file"), p = /^[@#]\s+sourceMappingURL=data:(?:application|text)\/json;(?:charset[:=]\S+?;)?base64,.*$/, c = /^[@#][ \t]+sourceMappingURL=([^\s'"`]+)[ \t]*$/;
				function extractCommentsFromList(e, t, r) {
					return t && (t = t.filter(({ value: t }) => !e.test(t) || (r = t, !1))), [t, r];
				}
				function extractComments(e, t) {
					let r = null;
					return a(t, (t) => {
						[t.leadingComments, r] = extractCommentsFromList(e, t.leadingComments, r), [t.innerComments, r] = extractCommentsFromList(e, t.innerComments, r), [t.trailingComments, r] = extractCommentsFromList(e, t.trailingComments, r);
					}), r;
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/normalize-opts.js": function(e, t, r) {
				"use strict";
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					const { filename: t, cwd: r, filenameRelative: n = "string" == typeof t ? _path().relative(r, t) : "unknown", sourceType: s = "module", inputSourceMap: i, sourceMaps: o = !!i, sourceRoot: a = e.options.moduleRoot, sourceFileName: l = _path().basename(n), comments: p = !0, compact: c = "auto" } = e.options, u = e.options, d = Object.assign({}, u, {
						parserOpts: Object.assign({
							sourceType: ".mjs" === _path().extname(n) ? "module" : s,
							sourceFileName: t,
							plugins: []
						}, u.parserOpts),
						generatorOpts: Object.assign({
							filename: t,
							auxiliaryCommentBefore: u.auxiliaryCommentBefore,
							auxiliaryCommentAfter: u.auxiliaryCommentAfter,
							retainLines: u.retainLines,
							comments: p,
							shouldPrintComment: u.shouldPrintComment,
							compact: c,
							minified: u.minified,
							sourceMaps: !!o,
							sourceRoot: a,
							sourceFileName: l
						}, u.generatorOpts)
					});
					for (const t of e.passes) for (const e of t) e.manipulateOptions && e.manipulateOptions(d, d.parserOpts);
					return d;
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/plugin-pass.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				class PluginPass {
					constructor(e, t, r, n) {
						this._map = /* @__PURE__ */ new Map(), this.key = void 0, this.file = void 0, this.opts = void 0, this.cwd = void 0, this.filename = void 0, this.isAsync = void 0, this.key = t, this.file = e, this.opts = r || {}, this.cwd = e.opts.cwd, this.filename = e.opts.filename, this.isAsync = n;
					}
					set(e, t) {
						this._map.set(e, t);
					}
					get(e) {
						return this._map.get(e);
					}
					availableHelper(e, t) {
						return this.file.availableHelper(e, t);
					}
					addHelper(e) {
						return this.file.addHelper(e);
					}
					buildCodeFrameError(e, t, r) {
						return this.file.buildCodeFrameError(e, t, r);
					}
				}
				t.default = PluginPass, PluginPass.prototype.getModuleName = function() {
					return this.file.getModuleName();
				}, PluginPass.prototype.addImport = function() {
					this.file.addImport();
				};
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/transformation/util/clone-deep.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					if ("object" != typeof e) return e;
					try {
						return deepClone(e, /* @__PURE__ */ new Map(), !0);
					} catch (t) {
						return structuredClone(e);
					}
				};
				const r = /* @__PURE__ */ new Set();
				let n = 0;
				function deepClone(e, t, s) {
					if (null !== e) {
						if (s) {
							if (t.has(e)) return t.get(e);
						} else if (++n > 250) {
							if (r.has(e)) throw n = 0, r.clear(), /* @__PURE__ */ new Error("Babel-deepClone: Cycles are not allowed in AST");
							r.add(e);
						}
						let i;
						if (Array.isArray(e)) {
							i = new Array(e.length), s && t.set(e, i);
							for (let r = 0; r < e.length; r++) i[r] = "object" != typeof e[r] ? e[r] : deepClone(e[r], t, s);
						} else {
							i = {}, s && t.set(e, i);
							const r = Object.keys(e);
							for (let n = 0; n < r.length; n++) {
								const o = r[n];
								i[o] = "object" != typeof e[o] ? e[o] : deepClone(e[o], t, s || "leadingComments" === o || "innerComments" === o || "trailingComments" === o || "extra" === o);
							}
						}
						return s || n-- > 250 && r.delete(e), i;
					}
					return e;
				}
			},
			"./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/vendor/import-meta-resolve.js": function(e, t, r) {
				"use strict";
				function _assert() {
					const e = r("assert");
					return _assert = function() {
						return e;
					}, e;
				}
				function _fs() {
					const e = _interopRequireWildcard(r("fs"), !0);
					return _fs = function() {
						return e;
					}, e;
				}
				function _process() {
					const e = r("process");
					return _process = function() {
						return e;
					}, e;
				}
				function _url() {
					const e = r("url");
					return _url = function() {
						return e;
					}, e;
				}
				function _path() {
					const e = r("path");
					return _path = function() {
						return e;
					}, e;
				}
				function _module() {
					const e = r("module");
					return _module = function() {
						return e;
					}, e;
				}
				function _v() {
					const e = r("v8");
					return _v = function() {
						return e;
					}, e;
				}
				function _util() {
					const e = r("util");
					return _util = function() {
						return e;
					}, e;
				}
				function _interopRequireWildcard(e, t) {
					if ("function" == typeof WeakMap) var r = /* @__PURE__ */ new WeakMap(), n = /* @__PURE__ */ new WeakMap();
					return (_interopRequireWildcard = function(e, t) {
						if (!t && e && e.__esModule) return e;
						var s, i, o = {
							__proto__: null,
							default: e
						};
						if (null === e || "object" != typeof e && "function" != typeof e) return o;
						if (s = t ? n : r) {
							if (s.has(e)) return s.get(e);
							s.set(e, o);
						}
						for (const t in e) "default" !== t && {}.hasOwnProperty.call(e, t) && ((i = (s = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, t)) && (i.get || i.set) ? s(o, t, i) : o[t] = e[t]);
						return o;
					})(e, t);
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.moduleResolve = moduleResolve, t.resolve = function(e, t) {
					if (!t) throw new Error("Please pass `parent`: `import-meta-resolve` cannot ponyfill that");
					try {
						return function(e, t = {}) {
							const { parentURL: r } = t;
							let n, s, i;
							if (_assert()(void 0 !== r, "expected `parentURL` to be defined"), function(e) {
								if (void 0 === e) return;
								if ("string" != typeof e && (t = e, !Boolean(t && "object" == typeof t && "href" in t && "string" == typeof t.href && "protocol" in t && "string" == typeof t.protocol && t.href && t.protocol))) throw new o.ERR_INVALID_ARG_TYPE("parentURL", ["string", "URL"], e);
								var t;
							}(r), r) try {
								n = new (_url()).URL(r);
							} catch (e) {}
							try {
								if (s = shouldBeTreatedAsRelativeOrAbsolutePath(e) ? new (_url()).URL(e, n) : new (_url()).URL(e), i = s.protocol, "data:" === i) return {
									url: s.href,
									format: null
								};
							} catch (e) {}
							const a = function(e, t, r) {
								if (r) {
									const n = r.protocol;
									if ("http:" === n || "https:" === n) {
										if (shouldBeTreatedAsRelativeOrAbsolutePath(e)) {
											const n = null == t ? void 0 : t.protocol;
											if (n && "https:" !== n && "http:" !== n) throw new E(e, r, "remote imports cannot import from a local location.");
											return { url: (null == t ? void 0 : t.href) || "" };
										}
										if (_module().builtinModules.includes(e)) throw new E(e, r, "remote imports cannot import from a local location.");
										throw new E(e, r, "only relative and absolute specifiers are supported.");
									}
								}
							}(e, s, n);
							if (a) return a;
							void 0 === i && s && (i = s.protocol);
							if ("node:" === i) return { url: e };
							if (s && "node:" === s.protocol) return { url: e };
							const l = function(e) {
								if (void 0 !== e && e !== g) {
									if (!Array.isArray(e)) throw new b("conditions", e, "expected an array");
									return new Set(e);
								}
								return x;
							}(t.conditions), p = moduleResolve(e, new (_url()).URL(r), l, !1);
							return {
								url: p.href,
								format: defaultGetFormatWithoutErrors(p, { parentURL: r })
							};
						}(e, { parentURL: t }).url;
					} catch (e) {
						const t = e;
						if (("ERR_UNSUPPORTED_DIR_IMPORT" === t.code || "ERR_MODULE_NOT_FOUND" === t.code) && "string" == typeof t.url) return t.url;
						throw e;
					}
				};
				const n = {}.hasOwnProperty, s = /^([A-Z][a-z\d]*)+$/, i = new Set([
					"string",
					"function",
					"number",
					"object",
					"Function",
					"Object",
					"boolean",
					"bigint",
					"symbol"
				]), o = {};
				function formatList(e, t = "and") {
					return e.length < 3 ? e.join(` ${t} `) : `${e.slice(0, -1).join(", ")}, ${t} ${e[e.length - 1]}`;
				}
				const a = /* @__PURE__ */ new Map();
				let l;
				function createError(e, t, r) {
					return a.set(e, t), function(e, t) {
						return NodeError;
						function NodeError(...r) {
							const n = Error.stackTraceLimit;
							isErrorStackTraceLimitWritable() && (Error.stackTraceLimit = 0);
							const s = new e();
							isErrorStackTraceLimitWritable() && (Error.stackTraceLimit = n);
							const i = function(e, t, r) {
								const n = a.get(e);
								if (_assert()(void 0 !== n, "expected `message` to be found"), "function" == typeof n) return _assert()(n.length <= t.length, `Code: ${e}; The provided arguments length (${t.length}) does not match the required ones (${n.length}).`), Reflect.apply(n, r, t);
								const s = /%[dfijoOs]/g;
								let i = 0;
								for (; null !== s.exec(n);) i++;
								return _assert()(i === t.length, `Code: ${e}; The provided arguments length (${t.length}) does not match the required ones (${i}).`), 0 === t.length ? n : (t.unshift(n), Reflect.apply(_util().format, null, t));
							}(t, r, s);
							return Object.defineProperties(s, {
								message: {
									value: i,
									enumerable: !1,
									writable: !0,
									configurable: !0
								},
								toString: {
									value() {
										return `${this.name} [${t}]: ${this.message}`;
									},
									enumerable: !1,
									writable: !0,
									configurable: !0
								}
							}), p(s), s.code = t, s;
						}
					}(r, e);
				}
				function isErrorStackTraceLimitWritable() {
					try {
						if (_v().startupSnapshot.isBuildingSnapshot()) return !1;
					} catch (e) {}
					const e = Object.getOwnPropertyDescriptor(Error, "stackTraceLimit");
					return void 0 === e ? Object.isExtensible(Error) : n.call(e, "writable") && void 0 !== e.writable ? e.writable : void 0 !== e.set;
				}
				o.ERR_INVALID_ARG_TYPE = createError("ERR_INVALID_ARG_TYPE", (e, t, r) => {
					_assert()("string" == typeof e, "'name' must be a string"), Array.isArray(t) || (t = [t]);
					let n = "The ";
					if (e.endsWith(" argument")) n += `${e} `;
					else {
						const t = e.includes(".") ? "property" : "argument";
						n += `"${e}" ${t} `;
					}
					n += "must be ";
					const o = [], a = [], l = [];
					for (const e of t) _assert()("string" == typeof e, "All expected entries have to be of type string"), i.has(e) ? o.push(e.toLowerCase()) : null === s.exec(e) ? (_assert()("object" !== e, "The value \"object\" should be written as \"Object\""), l.push(e)) : a.push(e);
					if (a.length > 0) {
						const e = o.indexOf("object");
						-1 !== e && (o.slice(e, 1), a.push("Object"));
					}
					return o.length > 0 && (n += `${o.length > 1 ? "one of type" : "of type"} ${formatList(o, "or")}`, (a.length > 0 || l.length > 0) && (n += " or ")), a.length > 0 && (n += `an instance of ${formatList(a, "or")}`, l.length > 0 && (n += " or ")), l.length > 0 && (l.length > 1 ? n += `one of ${formatList(l, "or")}` : (l[0].toLowerCase() !== l[0] && (n += "an "), n += `${l[0]}`)), n += `. Received ${function(e) {
						if (null == e) return String(e);
						if ("function" == typeof e && e.name) return `function ${e.name}`;
						if ("object" == typeof e) return e.constructor && e.constructor.name ? `an instance of ${e.constructor.name}` : `${(0, _util().inspect)(e, { depth: -1 })}`;
						let t = (0, _util().inspect)(e, { colors: !1 });
						t.length > 28 && (t = `${t.slice(0, 25)}...`);
						return `type ${typeof e} (${t})`;
					}(r)}`, n;
				}, TypeError), o.ERR_INVALID_MODULE_SPECIFIER = createError("ERR_INVALID_MODULE_SPECIFIER", (e, t, r = void 0) => `Invalid module "${e}" ${t}${r ? ` imported from ${r}` : ""}`, TypeError), o.ERR_INVALID_PACKAGE_CONFIG = createError("ERR_INVALID_PACKAGE_CONFIG", (e, t, r) => `Invalid package config ${e}${t ? ` while importing ${t}` : ""}${r ? `. ${r}` : ""}`, Error), o.ERR_INVALID_PACKAGE_TARGET = createError("ERR_INVALID_PACKAGE_TARGET", (e, t, r, n = !1, s = void 0) => {
					const i = "string" == typeof r && !n && r.length > 0 && !r.startsWith("./");
					return "." === t ? (_assert()(!1 === n), `Invalid "exports" main target ${JSON.stringify(r)} defined in the package config ${e}package.json${s ? ` imported from ${s}` : ""}${i ? "; targets must start with \"./\"" : ""}`) : `Invalid "${n ? "imports" : "exports"}" target ${JSON.stringify(r)} defined for '${t}' in the package config ${e}package.json${s ? ` imported from ${s}` : ""}${i ? "; targets must start with \"./\"" : ""}`;
				}, Error), o.ERR_MODULE_NOT_FOUND = createError("ERR_MODULE_NOT_FOUND", (e, t, r = !1) => `Cannot find ${r ? "module" : "package"} '${e}' imported from ${t}`, Error), o.ERR_NETWORK_IMPORT_DISALLOWED = createError("ERR_NETWORK_IMPORT_DISALLOWED", "import of '%s' by %s is not supported: %s", Error), o.ERR_PACKAGE_IMPORT_NOT_DEFINED = createError("ERR_PACKAGE_IMPORT_NOT_DEFINED", (e, t, r) => `Package import specifier "${e}" is not defined${t ? ` in package ${t}package.json` : ""} imported from ${r}`, TypeError), o.ERR_PACKAGE_PATH_NOT_EXPORTED = createError("ERR_PACKAGE_PATH_NOT_EXPORTED", (e, t, r = void 0) => "." === t ? `No "exports" main defined in ${e}package.json${r ? ` imported from ${r}` : ""}` : `Package subpath '${t}' is not defined by "exports" in ${e}package.json${r ? ` imported from ${r}` : ""}`, Error), o.ERR_UNSUPPORTED_DIR_IMPORT = createError("ERR_UNSUPPORTED_DIR_IMPORT", "Directory import '%s' is not supported resolving ES modules imported from %s", Error), o.ERR_UNSUPPORTED_RESOLVE_REQUEST = createError("ERR_UNSUPPORTED_RESOLVE_REQUEST", "Failed to resolve module specifier \"%s\" from \"%s\": Invalid relative URL or base scheme is not hierarchical.", TypeError), o.ERR_UNKNOWN_FILE_EXTENSION = createError("ERR_UNKNOWN_FILE_EXTENSION", (e, t) => `Unknown file extension "${e}" for ${t}`, TypeError), o.ERR_INVALID_ARG_VALUE = createError("ERR_INVALID_ARG_VALUE", (e, t, r = "is invalid") => {
					let n = (0, _util().inspect)(t);
					n.length > 128 && (n = `${n.slice(0, 128)}...`);
					return `The ${e.includes(".") ? "property" : "argument"} '${e}' ${r}. Received ${n}`;
				}, TypeError);
				const p = function(e) {
					const t = "__node_internal_" + e.name;
					return Object.defineProperty(e, "name", { value: t }), e;
				}(function(e) {
					const t = isErrorStackTraceLimitWritable();
					return t && (l = Error.stackTraceLimit, Error.stackTraceLimit = Number.POSITIVE_INFINITY), Error.captureStackTrace(e), t && (Error.stackTraceLimit = l), e;
				});
				const c = {}.hasOwnProperty, { ERR_INVALID_PACKAGE_CONFIG: u } = o, d = /* @__PURE__ */ new Map();
				function read(e, { base: t, specifier: r }) {
					const n = d.get(e);
					if (n) return n;
					let s;
					try {
						s = _fs().default.readFileSync(_path().toNamespacedPath(e), "utf8");
					} catch (e) {
						const t = e;
						if ("ENOENT" !== t.code) throw t;
					}
					const i = {
						exists: !1,
						pjsonPath: e,
						main: void 0,
						name: void 0,
						type: "none",
						exports: void 0,
						imports: void 0
					};
					if (void 0 !== s) {
						let n;
						try {
							n = JSON.parse(s);
						} catch (n) {
							const s = n, i = new u(e, (t ? `"${r}" from ` : "") + (0, _url().fileURLToPath)(t || r), s.message);
							throw i.cause = s, i;
						}
						i.exists = !0, c.call(n, "name") && "string" == typeof n.name && (i.name = n.name), c.call(n, "main") && "string" == typeof n.main && (i.main = n.main), c.call(n, "exports") && (i.exports = n.exports), c.call(n, "imports") && (i.imports = n.imports), !c.call(n, "type") || "commonjs" !== n.type && "module" !== n.type || (i.type = n.type);
					}
					return d.set(e, i), i;
				}
				function getPackageScopeConfig(e) {
					let t = new URL("package.json", e);
					for (;;) {
						if (t.pathname.endsWith("node_modules/package.json")) break;
						const r = read((0, _url().fileURLToPath)(t), { specifier: e });
						if (r.exists) return r;
						const n = t;
						if (t = new URL("../package.json", t), t.pathname === n.pathname) break;
					}
					return {
						pjsonPath: (0, _url().fileURLToPath)(t),
						exists: !1,
						type: "none"
					};
				}
				function getPackageType(e) {
					return getPackageScopeConfig(e).type;
				}
				const { ERR_UNKNOWN_FILE_EXTENSION: h } = o, m = {}.hasOwnProperty, f = {
					__proto__: null,
					".cjs": "commonjs",
					".js": "module",
					".json": "json",
					".mjs": "module"
				};
				const y = {
					__proto__: null,
					"data:": function(e) {
						const { 1: t } = /^([^/]+\/[^;,]+)[^,]*?(;base64)?,/.exec(e.pathname) || [
							null,
							null,
							null
						];
						return function(e) {
							return e && /\s*(text|application)\/javascript\s*(;\s*charset=utf-?8\s*)?/i.test(e) ? "module" : "application/json" === e ? "json" : null;
						}(t);
					},
					"file:": function(e, t, r) {
						const n = function(e) {
							const t = e.pathname;
							let r = t.length;
							for (; r--;) {
								const e = t.codePointAt(r);
								if (47 === e) return "";
								if (46 === e) return 47 === t.codePointAt(r - 1) ? "" : t.slice(r);
							}
							return "";
						}(e);
						if (".js" === n) {
							const t = getPackageType(e);
							return "none" !== t ? t : "commonjs";
						}
						if ("" === n) {
							const t = getPackageType(e);
							return "none" === t || "commonjs" === t ? "commonjs" : "module";
						}
						const s = f[n];
						if (s) return s;
						if (r) return;
						throw new h(n, (0, _url().fileURLToPath)(e));
					},
					"http:": getHttpProtocolModuleFormat,
					"https:": getHttpProtocolModuleFormat,
					"node:": () => "builtin"
				};
				function getHttpProtocolModuleFormat() {}
				function defaultGetFormatWithoutErrors(e, t) {
					const r = e.protocol;
					return m.call(y, r) && y[r](e, t, !0) || null;
				}
				const { ERR_INVALID_ARG_VALUE: b } = o, g = Object.freeze(["node", "import"]), x = new Set(g);
				const v = RegExp.prototype[Symbol.replace], { ERR_NETWORK_IMPORT_DISALLOWED: E, ERR_INVALID_MODULE_SPECIFIER: T, ERR_INVALID_PACKAGE_CONFIG: S, ERR_INVALID_PACKAGE_TARGET: P, ERR_MODULE_NOT_FOUND: _, ERR_PACKAGE_IMPORT_NOT_DEFINED: A, ERR_PACKAGE_PATH_NOT_EXPORTED: C, ERR_UNSUPPORTED_DIR_IMPORT: w, ERR_UNSUPPORTED_RESOLVE_REQUEST: I } = o, D = {}.hasOwnProperty, k = /(^|\\|\/)((\.|%2e)(\.|%2e)?|(n|%6e|%4e)(o|%6f|%4f)(d|%64|%44)(e|%65|%45)(_|%5f)(m|%6d|%4d)(o|%6f|%4f)(d|%64|%44)(u|%75|%55)(l|%6c|%4c)(e|%65|%45)(s|%73|%53))?(\\|\/|$)/i, N = /(^|\\|\/)((\.|%2e)(\.|%2e)?|(n|%6e|%4e)(o|%6f|%4f)(d|%64|%44)(e|%65|%45)(_|%5f)(m|%6d|%4d)(o|%6f|%4f)(d|%64|%44)(u|%75|%55)(l|%6c|%4c)(e|%65|%45)(s|%73|%53))(\\|\/|$)/i, O = /^\.|%|\\/, j = /\*/g, F = /%2f|%5c/i, L = /* @__PURE__ */ new Set(), M = /[/\\]{2}/;
				function emitInvalidSegmentDeprecation(e, t, r, n, s, i, o) {
					if (_process().noDeprecation) return;
					const a = (0, _url().fileURLToPath)(n), l = null !== M.exec(o ? e : t);
					_process().emitWarning(`Use of deprecated ${l ? "double slash" : "leading or trailing slash matching"} resolving "${e}" for module request "${t}" ${t === r ? "" : `matched to "${r}" `}in the "${s ? "imports" : "exports"}" field module resolution of the package at ${a}${i ? ` imported from ${(0, _url().fileURLToPath)(i)}` : ""}.`, "DeprecationWarning", "DEP0166");
				}
				function emitLegacyIndexDeprecation(e, t, r, n) {
					if (_process().noDeprecation) return;
					if ("module" !== defaultGetFormatWithoutErrors(e, { parentURL: r.href })) return;
					const s = (0, _url().fileURLToPath)(e.href), i = (0, _url().fileURLToPath)(new (_url()).URL(".", t)), o = (0, _url().fileURLToPath)(r);
					n ? _path().resolve(i, n) !== s && _process().emitWarning(`Package ${i} has a "main" field set to "${n}", excluding the full filename and extension to the resolved file at "${s.slice(i.length)}", imported from ${o}.\n Automatic extension resolution of the "main" field is deprecated for ES modules.`, "DeprecationWarning", "DEP0151") : _process().emitWarning(`No "main" or "exports" field defined in the package.json for ${i} resolving the main entry point "${s.slice(i.length)}", imported from ${o}.\nDefault "index" lookups for the main are deprecated for ES modules.`, "DeprecationWarning", "DEP0151");
				}
				function tryStatSync(e) {
					try {
						return (0, _fs().statSync)(e);
					} catch (e) {}
				}
				function fileExists(e) {
					const t = (0, _fs().statSync)(e, { throwIfNoEntry: !1 }), r = t ? t.isFile() : void 0;
					return null != r && r;
				}
				function legacyMainResolve(e, t, r) {
					let n;
					if (void 0 !== t.main) {
						if (n = new (_url()).URL(t.main, e), fileExists(n)) return n;
						const s = [
							`./${t.main}.js`,
							`./${t.main}.json`,
							`./${t.main}.node`,
							`./${t.main}/index.js`,
							`./${t.main}/index.json`,
							`./${t.main}/index.node`
						];
						let i = -1;
						for (; ++i < s.length && (n = new (_url()).URL(s[i], e), !fileExists(n));) n = void 0;
						if (n) return emitLegacyIndexDeprecation(n, e, r, t.main), n;
					}
					const s = [
						"./index.js",
						"./index.json",
						"./index.node"
					];
					let i = -1;
					for (; ++i < s.length && (n = new (_url()).URL(s[i], e), !fileExists(n));) n = void 0;
					if (n) return emitLegacyIndexDeprecation(n, e, r, t.main), n;
					throw new _((0, _url().fileURLToPath)(new (_url()).URL(".", e)), (0, _url().fileURLToPath)(r));
				}
				function exportsNotFound(e, t, r) {
					return new C((0, _url().fileURLToPath)(new (_url()).URL(".", t)), e, r && (0, _url().fileURLToPath)(r));
				}
				function invalidPackageTarget(e, t, r, n, s) {
					return t = "object" == typeof t && null !== t ? JSON.stringify(t, null, "") : `${t}`, new P((0, _url().fileURLToPath)(new (_url()).URL(".", r)), e, t, n, s && (0, _url().fileURLToPath)(s));
				}
				function resolvePackageTargetString(e, t, r, n, s, i, o, a, l) {
					if ("" !== t && !i && "/" !== e[e.length - 1]) throw invalidPackageTarget(r, e, n, o, s);
					if (!e.startsWith("./")) {
						if (o && !e.startsWith("../") && !e.startsWith("/")) {
							let r = !1;
							try {
								new (_url()).URL(e), r = !0;
							} catch (e) {}
							if (!r) return packageResolve(i ? v.call(j, e, () => t) : e + t, n, l);
						}
						throw invalidPackageTarget(r, e, n, o, s);
					}
					if (null !== k.exec(e.slice(2))) {
						if (null !== N.exec(e.slice(2))) throw invalidPackageTarget(r, e, n, o, s);
						if (!a) {
							const a = i ? r.replace("*", () => t) : r + t;
							emitInvalidSegmentDeprecation(i ? v.call(j, e, () => t) : e, a, r, n, o, s, !0);
						}
					}
					const p = new (_url()).URL(e, n), c = p.pathname, u = new (_url()).URL(".", n).pathname;
					if (!c.startsWith(u)) throw invalidPackageTarget(r, e, n, o, s);
					if ("" === t) return p;
					if (null !== k.exec(t)) {
						const l = i ? r.replace("*", () => t) : r + t;
						if (null === N.exec(t)) {
							if (!a) emitInvalidSegmentDeprecation(i ? v.call(j, e, () => t) : e, l, r, n, o, s, !1);
						} else (function(e, t, r, n, s) {
							throw new T(e, `request is not a valid match in pattern "${t}" for the "${n ? "imports" : "exports"}" resolution of ${(0, _url().fileURLToPath)(r)}`, s && (0, _url().fileURLToPath)(s));
						})(l, r, n, o, s);
					}
					return i ? new (_url()).URL(v.call(j, p.href, () => t)) : new (_url()).URL(t, p);
				}
				function isArrayIndex(e) {
					const t = Number(e);
					return `${t}` === e && t >= 0 && t < 4294967295;
				}
				function resolvePackageTarget(e, t, r, n, s, i, o, a, l) {
					if ("string" == typeof t) return resolvePackageTargetString(t, r, n, e, s, i, o, a, l);
					if (Array.isArray(t)) {
						const p = t;
						if (0 === p.length) return null;
						let c, u = -1;
						for (; ++u < p.length;) {
							const t = p[u];
							let d;
							try {
								d = resolvePackageTarget(e, t, r, n, s, i, o, a, l);
							} catch (e) {
								if (c = e, "ERR_INVALID_PACKAGE_TARGET" === e.code) continue;
								throw e;
							}
							if (void 0 !== d) {
								if (null !== d) return d;
								c = null;
							}
						}
						if (null == c) return null;
						throw c;
					}
					if ("object" == typeof t && null !== t) {
						const p = Object.getOwnPropertyNames(t);
						let c = -1;
						for (; ++c < p.length;) if (isArrayIndex(p[c])) throw new S((0, _url().fileURLToPath)(e), s, "\"exports\" cannot contain numeric property keys.");
						for (c = -1; ++c < p.length;) {
							const u = p[c];
							if ("default" === u || l && l.has(u)) {
								const p = resolvePackageTarget(e, t[u], r, n, s, i, o, a, l);
								if (void 0 === p) continue;
								return p;
							}
						}
						return null;
					}
					if (null === t) return null;
					throw invalidPackageTarget(n, t, e, o, s);
				}
				function emitTrailingSlashPatternDeprecation(e, t, r) {
					if (_process().noDeprecation) return;
					const n = (0, _url().fileURLToPath)(t);
					L.has(n + "|" + e) || (L.add(n + "|" + e), _process().emitWarning(`Use of deprecated trailing slash pattern mapping "${e}" in the "exports" field module resolution of the package at ${n}${r ? ` imported from ${(0, _url().fileURLToPath)(r)}` : ""}. Mapping specifiers ending in "/" is no longer supported.`, "DeprecationWarning", "DEP0155"));
				}
				function packageExportsResolve(e, t, r, n, s) {
					let i = r.exports;
					if (function(e, t, r) {
						if ("string" == typeof e || Array.isArray(e)) return !0;
						if ("object" != typeof e || null === e) return !1;
						const n = Object.getOwnPropertyNames(e);
						let s = !1, i = 0, o = -1;
						for (; ++o < n.length;) {
							const e = n[o], a = "" === e || "." !== e[0];
							if (0 === i++) s = a;
							else if (s !== a) throw new S((0, _url().fileURLToPath)(t), r, "\"exports\" cannot contain some keys starting with '.' and some not. The exports object must either be an object of package subpath keys or an object of main entry condition name keys only.");
						}
						return s;
					}(i, e, n) && (i = { ".": i }), D.call(i, t) && !t.includes("*") && !t.endsWith("/")) {
						const r = resolvePackageTarget(e, i[t], "", t, n, !1, !1, !1, s);
						if (null == r) throw exportsNotFound(t, e, n);
						return r;
					}
					let o = "", a = "";
					const l = Object.getOwnPropertyNames(i);
					let p = -1;
					for (; ++p < l.length;) {
						const r = l[p], s = r.indexOf("*");
						if (-1 !== s && t.startsWith(r.slice(0, s))) {
							t.endsWith("/") && emitTrailingSlashPatternDeprecation(t, e, n);
							const i = r.slice(s + 1);
							t.length >= r.length && t.endsWith(i) && 1 === patternKeyCompare(o, r) && r.lastIndexOf("*") === s && (o = r, a = t.slice(s, t.length - i.length));
						}
					}
					if (o) {
						const r = resolvePackageTarget(e, i[o], a, o, n, !0, !1, t.endsWith("/"), s);
						if (null == r) throw exportsNotFound(t, e, n);
						return r;
					}
					throw exportsNotFound(t, e, n);
				}
				function patternKeyCompare(e, t) {
					const r = e.indexOf("*"), n = t.indexOf("*"), s = -1 === r ? e.length : r + 1, i = -1 === n ? t.length : n + 1;
					return s > i ? -1 : i > s || -1 === r ? 1 : -1 === n || e.length > t.length ? -1 : t.length > e.length ? 1 : 0;
				}
				function packageImportsResolve(e, t, r) {
					if ("#" === e || e.startsWith("#/") || e.endsWith("/")) throw new T(e, "is not a valid internal imports specifier name", (0, _url().fileURLToPath)(t));
					let n;
					const s = getPackageScopeConfig(t);
					if (s.exists) {
						n = (0, _url().pathToFileURL)(s.pjsonPath);
						const i = s.imports;
						if (i) if (D.call(i, e) && !e.includes("*")) {
							const s = resolvePackageTarget(n, i[e], "", e, t, !1, !0, !1, r);
							if (null != s) return s;
						} else {
							let s = "", o = "";
							const a = Object.getOwnPropertyNames(i);
							let l = -1;
							for (; ++l < a.length;) {
								const t = a[l], r = t.indexOf("*");
								if (-1 !== r && e.startsWith(t.slice(0, -1))) {
									const n = t.slice(r + 1);
									e.length >= t.length && e.endsWith(n) && 1 === patternKeyCompare(s, t) && t.lastIndexOf("*") === r && (s = t, o = e.slice(r, e.length - n.length));
								}
							}
							if (s) {
								const e = resolvePackageTarget(n, i[s], o, s, t, !0, !0, !1, r);
								if (null != e) return e;
							}
						}
					}
					throw function(e, t, r) {
						return new A(e, t && (0, _url().fileURLToPath)(new (_url()).URL(".", t)), (0, _url().fileURLToPath)(r));
					}(e, n, t);
				}
				function packageResolve(e, t, r) {
					if (_module().builtinModules.includes(e)) return new (_url()).URL("node:" + e);
					const { packageName: n, packageSubpath: s, isScoped: i } = function(e, t) {
						let r = e.indexOf("/"), n = !0, s = !1;
						"@" === e[0] && (s = !0, -1 === r || 0 === e.length ? n = !1 : r = e.indexOf("/", r + 1));
						const i = -1 === r ? e : e.slice(0, r);
						if (null !== O.exec(i) && (n = !1), !n) throw new T(e, "is not a valid package name", (0, _url().fileURLToPath)(t));
						return {
							packageName: i,
							packageSubpath: "." + (-1 === r ? "" : e.slice(r)),
							isScoped: s
						};
					}(e, t), o = getPackageScopeConfig(t);
					if (o.exists) {
						const e = (0, _url().pathToFileURL)(o.pjsonPath);
						if (o.name === n && void 0 !== o.exports && null !== o.exports) return packageExportsResolve(e, s, o, t, r);
					}
					let a, l = new (_url()).URL("./node_modules/" + n + "/package.json", t), p = (0, _url().fileURLToPath)(l);
					do {
						const o = tryStatSync(p.slice(0, -13));
						if (!o || !o.isDirectory()) {
							a = p, l = new (_url()).URL((i ? "../../../../node_modules/" : "../../../node_modules/") + n + "/package.json", l), p = (0, _url().fileURLToPath)(l);
							continue;
						}
						const c = read(p, {
							base: t,
							specifier: e
						});
						return void 0 !== c.exports && null !== c.exports ? packageExportsResolve(l, s, c, t, r) : "." === s ? legacyMainResolve(l, c, t) : new (_url()).URL(s, l);
					} while (p.length !== a.length);
					throw new _(n, (0, _url().fileURLToPath)(t), !1);
				}
				function shouldBeTreatedAsRelativeOrAbsolutePath(e) {
					return "" !== e && ("/" === e[0] || function(e) {
						if ("." === e[0]) {
							if (1 === e.length || "/" === e[1]) return !0;
							if ("." === e[1] && (2 === e.length || "/" === e[2])) return !0;
						}
						return !1;
					}(e));
				}
				function moduleResolve(e, t, r, n) {
					const s = t.protocol, i = "data:" === s || "http:" === s || "https:" === s;
					let o;
					if (shouldBeTreatedAsRelativeOrAbsolutePath(e)) try {
						o = new (_url()).URL(e, t);
					} catch (r) {
						const n = new I(e, t);
						throw n.cause = r, n;
					}
					else if ("file:" === s && "#" === e[0]) o = packageImportsResolve(e, t, r);
					else try {
						o = new (_url()).URL(e);
					} catch (n) {
						if (i && !_module().builtinModules.includes(e)) {
							const r = new I(e, t);
							throw r.cause = n, r;
						}
						o = packageResolve(e, t, r);
					}
					return _assert()(void 0 !== o, "expected to be defined"), "file:" !== o.protocol ? o : function(e, t, r) {
						if (null !== F.exec(e.pathname)) throw new T(e.pathname, "must not include encoded \"/\" or \"\\\" characters", (0, _url().fileURLToPath)(t));
						let n;
						try {
							n = (0, _url().fileURLToPath)(e);
						} catch (r) {
							const n = r;
							throw Object.defineProperty(n, "input", { value: String(e) }), Object.defineProperty(n, "module", { value: String(t) }), n;
						}
						const s = tryStatSync(n.endsWith("/") ? n.slice(-1) : n);
						if (s && s.isDirectory()) {
							const r = new w(n, (0, _url().fileURLToPath)(t));
							throw r.url = String(e), r;
						}
						if (!s || !s.isFile()) {
							const r = new _(n || e.pathname, t && (0, _url().fileURLToPath)(t), !0);
							throw r.url = String(e), r;
						}
						if (!r) {
							const t = (0, _fs().realpathSync)(n), { search: r, hash: s } = e;
							(e = (0, _url().pathToFileURL)(t + (n.endsWith(_path().sep) ? "/" : ""))).search = r, e.hash = s;
						}
						return e;
					}(o, t, n);
				}
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/buffer.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				t.default = class {
					constructor(e, t) {
						this._map = null, this._buf = "", this._str = "", this._appendCount = 0, this._last = 0, this._queue = [], this._queueCursor = 0, this._canMarkIdName = !0, this._indentChar = "", this._fastIndentations = [], this._position = {
							line: 1,
							column: 0
						}, this._sourcePosition = {
							identifierName: void 0,
							identifierNamePos: void 0,
							line: void 0,
							column: void 0,
							filename: void 0
						}, this._map = e, this._indentChar = t;
						for (let e = 0; e < 64; e++) this._fastIndentations.push(t.repeat(e));
						this._allocQueue();
					}
					_allocQueue() {
						const e = this._queue;
						for (let t = 0; t < 16; t++) e.push({
							char: 0,
							repeat: 1,
							line: void 0,
							column: void 0,
							identifierName: void 0,
							identifierNamePos: void 0,
							filename: ""
						});
					}
					_pushQueue(e, t, r, n, s) {
						const i = this._queueCursor;
						i === this._queue.length && this._allocQueue();
						const o = this._queue[i];
						o.char = e, o.repeat = t, o.line = r, o.column = n, o.filename = s, this._queueCursor++;
					}
					_popQueue() {
						if (0 === this._queueCursor) throw new Error("Cannot pop from empty queue");
						return this._queue[--this._queueCursor];
					}
					get() {
						this._flush();
						const e = this._map, t = {
							code: (this._buf + this._str).trimRight(),
							decodedMap: null == e ? void 0 : e.getDecoded(),
							get __mergedMap() {
								return this.map;
							},
							get map() {
								const r = e ? e.get() : null;
								return t.map = r, r;
							},
							set map(e) {
								Object.defineProperty(t, "map", {
									value: e,
									writable: !0
								});
							},
							get rawMappings() {
								const r = null == e ? void 0 : e.getRawMappings();
								return t.rawMappings = r, r;
							},
							set rawMappings(e) {
								Object.defineProperty(t, "rawMappings", {
									value: e,
									writable: !0
								});
							}
						};
						return t;
					}
					append(e, t) {
						this._flush(), this._append(e, this._sourcePosition, t);
					}
					appendChar(e) {
						this._flush(), this._appendChar(e, 1, this._sourcePosition);
					}
					queue(e) {
						if (10 === e) for (; 0 !== this._queueCursor;) {
							const e = this._queue[this._queueCursor - 1].char;
							if (32 !== e && 9 !== e) break;
							this._queueCursor--;
						}
						const t = this._sourcePosition;
						this._pushQueue(e, 1, t.line, t.column, t.filename);
					}
					queueIndentation(e) {
						0 !== e && this._pushQueue(-1, e, void 0, void 0, void 0);
					}
					_flush() {
						const e = this._queueCursor, t = this._queue;
						for (let r = 0; r < e; r++) {
							const e = t[r];
							this._appendChar(e.char, e.repeat, e);
						}
						this._queueCursor = 0;
					}
					_appendChar(e, t, r) {
						if (this._last = e, -1 === e) {
							const e = this._fastIndentations[t];
							this._str += void 0 !== e ? e : t > 1 ? this._indentChar.repeat(t) : this._indentChar;
						} else this._str += t > 1 ? String.fromCharCode(e).repeat(t) : String.fromCharCode(e);
						10 !== e ? (this._mark(r.line, r.column, r.identifierName, r.identifierNamePos, r.filename), this._position.column += t) : (this._position.line++, this._position.column = 0), this._canMarkIdName && (r.identifierName = void 0, r.identifierNamePos = void 0);
					}
					_append(e, t, r) {
						const n = e.length, s = this._position;
						if (this._last = e.charCodeAt(n - 1), ++this._appendCount > 4096 ? (this._str, this._buf += this._str, this._str = e, this._appendCount = 0) : this._str += e, !r && !this._map) return void (s.column += n);
						const { column: i, identifierName: o, identifierNamePos: a, filename: l } = t;
						let p = t.line;
						null == o && null == a || !this._canMarkIdName || (t.identifierName = void 0, t.identifierNamePos = void 0);
						let c = e.indexOf("\n"), u = 0;
						for (0 !== c && this._mark(p, i, o, a, l); -1 !== c;) s.line++, s.column = 0, u = c + 1, u < n && void 0 !== p && this._mark(++p, 0, null, null, l), c = e.indexOf("\n", u);
						s.column += n - u;
					}
					_mark(e, t, r, n, s) {
						var i;
						null == (i = this._map) || i.mark(this._position, e, t, r, n, s);
					}
					removeTrailingNewline() {
						const e = this._queueCursor;
						0 !== e && 10 === this._queue[e - 1].char && this._queueCursor--;
					}
					removeLastSemicolon() {
						const e = this._queueCursor;
						0 !== e && 59 === this._queue[e - 1].char && this._queueCursor--;
					}
					getLastChar() {
						const e = this._queueCursor;
						return 0 !== e ? this._queue[e - 1].char : this._last;
					}
					getNewlineCount() {
						const e = this._queueCursor;
						let t = 0;
						if (0 === e) return 10 === this._last ? 1 : 0;
						for (let r = e - 1; r >= 0 && 10 === this._queue[r].char; r--) t++;
						return t === e && 10 === this._last ? t + 1 : t;
					}
					endsWithCharAndNewline() {
						const e = this._queue, t = this._queueCursor;
						if (0 !== t) {
							if (10 !== e[t - 1].char) return;
							return t > 1 ? e[t - 2].char : this._last;
						}
					}
					hasContent() {
						return 0 !== this._queueCursor || !!this._last;
					}
					exactSource(e, t) {
						if (!this._map) return void t();
						this.source("start", e);
						const r = e.identifierName, n = this._sourcePosition;
						r && (this._canMarkIdName = !1, n.identifierName = r), t(), r && (this._canMarkIdName = !0, n.identifierName = void 0, n.identifierNamePos = void 0), this.source("end", e);
					}
					source(e, t) {
						this._map && this._normalizePosition(e, t, 0);
					}
					sourceWithOffset(e, t, r) {
						this._map && this._normalizePosition(e, t, r);
					}
					_normalizePosition(e, t, r) {
						const n = t[e], s = this._sourcePosition;
						n && (s.line = n.line, s.column = Math.max(n.column + r, 0), s.filename = t.filename);
					}
					getCurrentColumn() {
						const e = this._queue, t = this._queueCursor;
						let r = -1, n = 0;
						for (let s = 0; s < t; s++) {
							const t = e[s];
							10 === t.char && (r = n), n += t.repeat;
						}
						return -1 === r ? this._position.column + n : n - 1 - r;
					}
					getCurrentLine() {
						let e = 0;
						const t = this._queue;
						for (let r = 0; r < this._queueCursor; r++) 10 === t[r].char && e++;
						return this._position.line + e;
					}
				};
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/base.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.BlockStatement = function(e) {
					var t;
					this.tokenChar(123);
					const r = this.enterDelimited(), n = null == (t = e.directives) ? void 0 : t.length;
					if (n) {
						var s;
						const t = e.body.length ? 2 : 1;
						this.printSequence(e.directives, !0, t), null != (s = e.directives[n - 1].trailingComments) && s.length || this.newline(t);
					}
					this.printSequence(e.body, !0), r(), this.rightBrace(e);
				}, t.Directive = function(e) {
					this.print(e.value), this.semicolon();
				}, t.DirectiveLiteral = function(e) {
					const t = this.getPossibleRaw(e);
					if (!this.format.minified && void 0 !== t) return void this.token(t);
					const { value: s } = e;
					if (n.test(s)) {
						if (r.test(s)) throw new Error("Malformed AST: it is not possible to print a directive containing both unescaped single and double quotes.");
						this.token(`'${s}'`);
					} else this.token(`"${s}"`);
				}, t.File = function(e) {
					e.program && this.print(e.program.interpreter);
					this.print(e.program);
				}, t.InterpreterDirective = function(e) {
					this.token(`#!${e.value}`), this.newline(1, !0);
				}, t.Placeholder = function(e) {
					this.token("%%"), this.print(e.name), this.token("%%"), "Statement" === e.expectedNode && this.semicolon();
				}, t.Program = function(e) {
					var t;
					this.noIndentInnerCommentsHere(), this.printInnerComments();
					const r = null == (t = e.directives) ? void 0 : t.length;
					if (r) {
						var n;
						const t = e.body.length ? 2 : 1;
						this.printSequence(e.directives, void 0, t), null != (n = e.directives[r - 1].trailingComments) && n.length || this.newline(t);
					}
					this.printSequence(e.body);
				};
				const r = /(?:^|[^\\])(?:\\\\)*'/, n = /(?:^|[^\\])(?:\\\\)*"/;
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/classes.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.ClassAccessorProperty = function(e) {
					var t;
					this.printJoin(e.decorators);
					const r = null == (t = e.key.loc) || null == (t = t.end) ? void 0 : t.line;
					r && this.catchUp(r);
					this.tsPrintClassMemberModifiers(e), this.word("accessor", !0), this.space(), e.computed ? (this.tokenChar(91), this.print(e.key), this.tokenChar(93)) : (this._variance(e), this.print(e.key));
					e.optional && this.tokenChar(63);
					e.definite && this.tokenChar(33);
					this.print(e.typeAnnotation), e.value && (this.space(), this.tokenChar(61), this.space(), this.print(e.value));
					this.semicolon();
				}, t.ClassBody = function(e) {
					if (this.tokenChar(123), 0 === e.body.length) this.tokenChar(125);
					else {
						this.newline();
						const t = function(e, t) {
							if (!e.tokenMap || null == t.start || null == t.end) return null;
							const r = e.tokenMap.getIndexes(t);
							if (!r) return null;
							let n = 1, s = 0, i = 0;
							const advanceNextLocIndex = () => {
								for (; i < t.body.length && null == t.body[i].start;) i++;
							};
							return advanceNextLocIndex(), (o) => {
								i <= o && (i = o + 1, advanceNextLocIndex());
								const a = i === t.body.length ? t.end : t.body[i].start;
								let l;
								for (; n < r.length && e.tokenMap.matchesOriginal(l = e._tokens[r[n]], ";") && l.start < a;) e.token(";", void 0, s++), n++;
							};
						}(this, e);
						t?.(-1);
						const r = this.enterDelimited();
						this.printJoin(e.body, !0, !0, t, !0), r(), this.endsWith(10) || this.newline(), this.rightBrace(e);
					}
				}, t.ClassExpression = t.ClassDeclaration = function(e, t) {
					(s(t) || i(t)) && this._shouldPrintDecoratorsBeforeExport(t) || this.printJoin(e.decorators);
					e.declare && (this.word("declare"), this.space());
					e.abstract && (this.word("abstract"), this.space());
					this.word("class"), e.id && (this.space(), this.print(e.id));
					this.print(e.typeParameters), e.superClass && (this.space(), this.word("extends"), this.space(), this.print(e.superClass), this.print(e.superTypeParameters));
					e.implements && (this.space(), this.word("implements"), this.space(), this.printList(e.implements));
					this.space(), this.print(e.body);
				}, t.ClassMethod = function(e) {
					this._classMethodHead(e), this.space(), this.print(e.body);
				}, t.ClassPrivateMethod = function(e) {
					this._classMethodHead(e), this.space(), this.print(e.body);
				}, t.ClassPrivateProperty = function(e) {
					this.printJoin(e.decorators), this.tsPrintClassMemberModifiers(e), this.print(e.key), e.optional && this.tokenChar(63);
					e.definite && this.tokenChar(33);
					this.print(e.typeAnnotation), e.value && (this.space(), this.tokenChar(61), this.space(), this.print(e.value));
					this.semicolon();
				}, t.ClassProperty = function(e) {
					if (this.printJoin(e.decorators), !e.static && !this.format.preserveFormat) {
						var t;
						const r = null == (t = e.key.loc) || null == (t = t.end) ? void 0 : t.line;
						r && this.catchUp(r);
					}
					this.tsPrintClassMemberModifiers(e), e.computed ? (this.tokenChar(91), this.print(e.key), this.tokenChar(93)) : (this._variance(e), this.print(e.key));
					e.optional && this.tokenChar(63);
					e.definite && this.tokenChar(33);
					this.print(e.typeAnnotation), e.value && (this.space(), this.tokenChar(61), this.space(), this.print(e.value));
					this.semicolon();
				}, t.StaticBlock = function(e) {
					this.word("static"), this.space(), this.tokenChar(123), 0 === e.body.length ? this.tokenChar(125) : (this.newline(), this.printSequence(e.body, !0), this.rightBrace(e));
				}, t._classMethodHead = function(e) {
					if (this.printJoin(e.decorators), !this.format.preserveFormat) {
						var t;
						const r = null == (t = e.key.loc) || null == (t = t.end) ? void 0 : t.line;
						r && this.catchUp(r);
					}
					this.tsPrintClassMemberModifiers(e), this._methodHead(e);
				};
				const { isExportDefaultDeclaration: s, isExportNamedDeclaration: i } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/deprecated.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.addDeprecatedGenerators = function(e) {
					Object.assign(e.prototype, {
						Noop() {},
						TSExpressionWithTypeArguments(e) {
							this.print(e.expression), this.print(e.typeParameters);
						},
						DecimalLiteral(e) {
							const t = this.getPossibleRaw(e);
							this.format.minified || void 0 === t ? this.word(e.value + "m") : this.word(t);
						}
					});
				};
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/expressions.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.LogicalExpression = t.BinaryExpression = t.AssignmentExpression = function(e) {
					this.print(e.left), this.space(), "in" === e.operator || "instanceof" === e.operator ? this.word(e.operator) : (this.token(e.operator), this._endsWithDiv = "/" === e.operator);
					this.space(), this.print(e.right);
				}, t.AssignmentPattern = function(e) {
					this.print(e.left), ("Identifier" === e.left.type || p(e.left)) && (e.left.optional && this.tokenChar(63), this.print(e.left.typeAnnotation));
					this.space(), this.tokenChar(61), this.space(), this.print(e.right);
				}, t.AwaitExpression = function(e) {
					this.word("await"), this.space(), this.print(e.argument);
				}, t.BindExpression = function(e) {
					this.print(e.object), this.token("::"), this.print(e.callee);
				}, t.CallExpression = function(e) {
					this.print(e.callee), this.print(e.typeArguments), this.print(e.typeParameters), this.tokenChar(40);
					const t = this.enterDelimited();
					this.printList(e.arguments, this.shouldPrintTrailingComma(")")), t(), this.rightParens(e);
				}, t.ConditionalExpression = function(e) {
					this.print(e.test), this.space(), this.tokenChar(63), this.space(), this.print(e.consequent), this.space(), this.tokenChar(58), this.space(), this.print(e.alternate);
				}, t.Decorator = function(e) {
					this.tokenChar(64), this.print(e.expression), this.newline();
				}, t.DoExpression = function(e) {
					e.async && (this.word("async", !0), this.space());
					this.word("do"), this.space(), this.print(e.body);
				}, t.EmptyStatement = function() {
					this.semicolon(!0);
				}, t.ExpressionStatement = function(e) {
					this.tokenContext |= s.TokenContext.expressionStatement, this.print(e.expression), this.semicolon();
				}, t.Import = function() {
					this.word("import");
				}, t.MemberExpression = function(e) {
					if (this.print(e.object), !e.computed && a(e.property)) throw new TypeError("Got a MemberExpression for MemberExpression property");
					let t = e.computed;
					o(e.property) && "number" == typeof e.property.value && (t = !0);
					if (t) {
						const t = this.enterDelimited();
						this.tokenChar(91), this.print(e.property), this.tokenChar(93), t();
					} else this.tokenChar(46), this.print(e.property);
				}, t.MetaProperty = function(e) {
					this.print(e.meta), this.tokenChar(46), this.print(e.property);
				}, t.ModuleExpression = function(e) {
					this.word("module", !0), this.space(), this.tokenChar(123), this.indent();
					const { body: t } = e;
					(t.body.length || t.directives.length) && this.newline();
					this.print(t), this.dedent(), this.rightBrace(e);
				}, t.NewExpression = function(e, t) {
					if (this.word("new"), this.space(), this.print(e.callee), this.format.minified && 0 === e.arguments.length && !e.optional && !i(t, { callee: e }) && !a(t) && !l(t)) return;
					this.print(e.typeArguments), this.print(e.typeParameters), e.optional && this.token("?.");
					if (0 === e.arguments.length && this.tokenMap && !this.tokenMap.endMatches(e, ")")) return;
					this.tokenChar(40);
					const r = this.enterDelimited();
					this.printList(e.arguments, this.shouldPrintTrailingComma(")")), r(), this.rightParens(e);
				}, t.OptionalCallExpression = function(e) {
					this.print(e.callee), this.print(e.typeParameters), e.optional && this.token("?.");
					this.print(e.typeArguments), this.tokenChar(40);
					const t = this.enterDelimited();
					this.printList(e.arguments), t(), this.rightParens(e);
				}, t.OptionalMemberExpression = function(e) {
					let { computed: t } = e;
					const { optional: r, property: n } = e;
					if (this.print(e.object), !t && a(n)) throw new TypeError("Got a MemberExpression for MemberExpression property");
					o(n) && "number" == typeof n.value && (t = !0);
					r && this.token("?.");
					t ? (this.tokenChar(91), this.print(n), this.tokenChar(93)) : (r || this.tokenChar(46), this.print(n));
				}, t.ParenthesizedExpression = function(e) {
					this.tokenChar(40);
					const t = this.enterDelimited();
					this.print(e.expression), t(), this.rightParens(e);
				}, t.PrivateName = function(e) {
					this.tokenChar(35), this.print(e.id);
				}, t.SequenceExpression = function(e) {
					this.printList(e.expressions);
				}, t.Super = function() {
					this.word("super");
				}, t.ThisExpression = function() {
					this.word("this");
				}, t.UnaryExpression = function(e) {
					const { operator: t } = e;
					"void" === t || "delete" === t || "typeof" === t || "throw" === t ? (this.word(t), this.space()) : this.token(t);
					this.print(e.argument);
				}, t.UpdateExpression = function(e) {
					e.prefix ? (this.token(e.operator), this.print(e.argument)) : (this.print(e.argument, !0), this.token(e.operator));
				}, t.V8IntrinsicIdentifier = function(e) {
					this.tokenChar(37), this.word(e.name);
				}, t.YieldExpression = function(e) {
					e.delegate ? (this.word("yield", !0), this.tokenChar(42), e.argument && (this.space(), this.print(e.argument))) : e.argument ? (this.word("yield", !0), this.space(), this.print(e.argument)) : this.word("yield");
				}, t._shouldPrintDecoratorsBeforeExport = function(e) {
					if ("boolean" == typeof this.format.decoratorsBeforeExport) return this.format.decoratorsBeforeExport;
					return "number" == typeof e.start && e.start === e.declaration.start;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/node/index.js");
				const { isCallExpression: i, isLiteral: o, isMemberExpression: a, isNewExpression: l, isPattern: p } = n;
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/flow.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.AnyTypeAnnotation = function() {
					this.word("any");
				}, t.ArrayTypeAnnotation = function(e) {
					this.print(e.elementType, !0), this.tokenChar(91), this.tokenChar(93);
				}, t.BooleanLiteralTypeAnnotation = function(e) {
					this.word(e.value ? "true" : "false");
				}, t.BooleanTypeAnnotation = function() {
					this.word("boolean");
				}, t.DeclareClass = function(e, t) {
					a(t) || (this.word("declare"), this.space());
					this.word("class"), this.space(), this._interfaceish(e);
				}, t.DeclareExportAllDeclaration = function(e) {
					this.word("declare"), this.space(), s.ExportAllDeclaration.call(this, e);
				}, t.DeclareExportDeclaration = function(e) {
					this.word("declare"), this.space(), this.word("export"), this.space(), e.default && (this.word("default"), this.space());
					FlowExportDeclaration.call(this, e);
				}, t.DeclareFunction = function(e, t) {
					a(t) || (this.word("declare"), this.space());
					this.word("function"), this.space(), this.print(e.id), this.print(e.id.typeAnnotation.typeAnnotation), e.predicate && (this.space(), this.print(e.predicate));
					this.semicolon();
				}, t.DeclareInterface = function(e) {
					this.word("declare"), this.space(), this.InterfaceDeclaration(e);
				}, t.DeclareModule = function(e) {
					this.word("declare"), this.space(), this.word("module"), this.space(), this.print(e.id), this.space(), this.print(e.body);
				}, t.DeclareModuleExports = function(e) {
					this.word("declare"), this.space(), this.word("module"), this.tokenChar(46), this.word("exports"), this.print(e.typeAnnotation);
				}, t.DeclareOpaqueType = function(e, t) {
					a(t) || (this.word("declare"), this.space());
					this.OpaqueType(e);
				}, t.DeclareTypeAlias = function(e) {
					this.word("declare"), this.space(), this.TypeAlias(e);
				}, t.DeclareVariable = function(e, t) {
					a(t) || (this.word("declare"), this.space());
					this.word("var"), this.space(), this.print(e.id), this.print(e.id.typeAnnotation), this.semicolon();
				}, t.DeclaredPredicate = function(e) {
					this.tokenChar(37), this.word("checks"), this.tokenChar(40), this.print(e.value), this.tokenChar(41);
				}, t.EmptyTypeAnnotation = function() {
					this.word("empty");
				}, t.EnumBooleanBody = function(e) {
					const { explicitType: t } = e;
					enumExplicitType(this, "boolean", t), enumBody(this, e);
				}, t.EnumBooleanMember = function(e) {
					enumInitializedMember(this, e);
				}, t.EnumDeclaration = function(e) {
					const { id: t, body: r } = e;
					this.word("enum"), this.space(), this.print(t), this.print(r);
				}, t.EnumDefaultedMember = function(e) {
					const { id: t } = e;
					this.print(t), this.tokenChar(44);
				}, t.EnumNumberBody = function(e) {
					const { explicitType: t } = e;
					enumExplicitType(this, "number", t), enumBody(this, e);
				}, t.EnumNumberMember = function(e) {
					enumInitializedMember(this, e);
				}, t.EnumStringBody = function(e) {
					const { explicitType: t } = e;
					enumExplicitType(this, "string", t), enumBody(this, e);
				}, t.EnumStringMember = function(e) {
					enumInitializedMember(this, e);
				}, t.EnumSymbolBody = function(e) {
					enumExplicitType(this, "symbol", !0), enumBody(this, e);
				}, t.ExistsTypeAnnotation = function() {
					this.tokenChar(42);
				}, t.FunctionTypeAnnotation = function(e, t) {
					this.print(e.typeParameters), this.tokenChar(40), e.this && (this.word("this"), this.tokenChar(58), this.space(), this.print(e.this.typeAnnotation), (e.params.length || e.rest) && (this.tokenChar(44), this.space()));
					this.printList(e.params), e.rest && (e.params.length && (this.tokenChar(44), this.space()), this.token("..."), this.print(e.rest));
					this.tokenChar(41);
					const r = null == t ? void 0 : t.type;
					null != r && ("ObjectTypeCallProperty" === r || "ObjectTypeInternalSlot" === r || "DeclareFunction" === r || "ObjectTypeProperty" === r && t.method) ? this.tokenChar(58) : (this.space(), this.token("=>"));
					this.space(), this.print(e.returnType);
				}, t.FunctionTypeParam = function(e) {
					this.print(e.name), e.optional && this.tokenChar(63);
					e.name && (this.tokenChar(58), this.space());
					this.print(e.typeAnnotation);
				}, t.IndexedAccessType = function(e) {
					this.print(e.objectType, !0), this.tokenChar(91), this.print(e.indexType), this.tokenChar(93);
				}, t.InferredPredicate = function() {
					this.tokenChar(37), this.word("checks");
				}, t.InterfaceDeclaration = function(e) {
					this.word("interface"), this.space(), this._interfaceish(e);
				}, t.GenericTypeAnnotation = t.ClassImplements = t.InterfaceExtends = function(e) {
					this.print(e.id), this.print(e.typeParameters, !0);
				}, t.InterfaceTypeAnnotation = function(e) {
					var t;
					this.word("interface"), null != (t = e.extends) && t.length && (this.space(), this.word("extends"), this.space(), this.printList(e.extends));
					this.space(), this.print(e.body);
				}, t.IntersectionTypeAnnotation = function(e) {
					this.printJoin(e.types, void 0, void 0, andSeparator);
				}, t.MixedTypeAnnotation = function() {
					this.word("mixed");
				}, t.NullLiteralTypeAnnotation = function() {
					this.word("null");
				}, t.NullableTypeAnnotation = function(e) {
					this.tokenChar(63), this.print(e.typeAnnotation);
				}, Object.defineProperty(t, "NumberLiteralTypeAnnotation", {
					enumerable: !0,
					get: function() {
						return o.NumericLiteral;
					}
				}), t.NumberTypeAnnotation = function() {
					this.word("number");
				}, t.ObjectTypeAnnotation = function(e) {
					e.exact ? this.token("{|") : this.tokenChar(123);
					const t = [
						...e.properties,
						...e.callProperties || [],
						...e.indexers || [],
						...e.internalSlots || []
					];
					t.length && (this.newline(), this.space(), this.printJoin(t, !0, !0, void 0, void 0, function(e) {
						if (e && !t[0]) return 1;
					}, () => {
						(1 !== t.length || e.inexact) && (this.tokenChar(44), this.space());
					}), this.space());
					e.inexact && (this.indent(), this.token("..."), t.length && this.newline(), this.dedent());
					e.exact ? this.token("|}") : this.tokenChar(125);
				}, t.ObjectTypeCallProperty = function(e) {
					e.static && (this.word("static"), this.space());
					this.print(e.value);
				}, t.ObjectTypeIndexer = function(e) {
					e.static && (this.word("static"), this.space());
					this._variance(e), this.tokenChar(91), e.id && (this.print(e.id), this.tokenChar(58), this.space());
					this.print(e.key), this.tokenChar(93), this.tokenChar(58), this.space(), this.print(e.value);
				}, t.ObjectTypeInternalSlot = function(e) {
					e.static && (this.word("static"), this.space());
					this.tokenChar(91), this.tokenChar(91), this.print(e.id), this.tokenChar(93), this.tokenChar(93), e.optional && this.tokenChar(63);
					e.method || (this.tokenChar(58), this.space());
					this.print(e.value);
				}, t.ObjectTypeProperty = function(e) {
					e.proto && (this.word("proto"), this.space());
					e.static && (this.word("static"), this.space());
					"get" !== e.kind && "set" !== e.kind || (this.word(e.kind), this.space());
					this._variance(e), this.print(e.key), e.optional && this.tokenChar(63);
					e.method || (this.tokenChar(58), this.space());
					this.print(e.value);
				}, t.ObjectTypeSpreadProperty = function(e) {
					this.token("..."), this.print(e.argument);
				}, t.OpaqueType = function(e) {
					this.word("opaque"), this.space(), this.word("type"), this.space(), this.print(e.id), this.print(e.typeParameters), e.supertype && (this.tokenChar(58), this.space(), this.print(e.supertype));
					e.impltype && (this.space(), this.tokenChar(61), this.space(), this.print(e.impltype));
					this.semicolon();
				}, t.OptionalIndexedAccessType = function(e) {
					this.print(e.objectType), e.optional && this.token("?.");
					this.tokenChar(91), this.print(e.indexType), this.tokenChar(93);
				}, t.QualifiedTypeIdentifier = function(e) {
					this.print(e.qualification), this.tokenChar(46), this.print(e.id);
				}, Object.defineProperty(t, "StringLiteralTypeAnnotation", {
					enumerable: !0,
					get: function() {
						return o.StringLiteral;
					}
				}), t.StringTypeAnnotation = function() {
					this.word("string");
				}, t.SymbolTypeAnnotation = function() {
					this.word("symbol");
				}, t.ThisTypeAnnotation = function() {
					this.word("this");
				}, t.TupleTypeAnnotation = function(e) {
					this.tokenChar(91), this.printList(e.types), this.tokenChar(93);
				}, t.TypeAlias = function(e) {
					this.word("type"), this.space(), this.print(e.id), this.print(e.typeParameters), this.space(), this.tokenChar(61), this.space(), this.print(e.right), this.semicolon();
				}, t.TypeAnnotation = function(e, t) {
					this.tokenChar(58), this.space(), "ArrowFunctionExpression" === t.type ? this.tokenContext |= i.TokenContext.arrowFlowReturnType : e.optional && this.tokenChar(63);
					this.print(e.typeAnnotation);
				}, t.TypeCastExpression = function(e) {
					this.tokenChar(40), this.print(e.expression), this.print(e.typeAnnotation), this.tokenChar(41);
				}, t.TypeParameter = function(e) {
					this._variance(e), this.word(e.name), e.bound && this.print(e.bound);
					e.default && (this.space(), this.tokenChar(61), this.space(), this.print(e.default));
				}, t.TypeParameterDeclaration = t.TypeParameterInstantiation = function(e) {
					this.tokenChar(60), this.printList(e.params), this.tokenChar(62);
				}, t.TypeofTypeAnnotation = function(e) {
					this.word("typeof"), this.space(), this.print(e.argument);
				}, t.UnionTypeAnnotation = function(e) {
					this.printJoin(e.types, void 0, void 0, orSeparator);
				}, t.Variance = function(e) {
					"plus" === e.kind ? this.tokenChar(43) : this.tokenChar(45);
				}, t.VoidTypeAnnotation = function() {
					this.word("void");
				}, t._interfaceish = function(e) {
					var t;
					this.print(e.id), this.print(e.typeParameters), null != (t = e.extends) && t.length && (this.space(), this.word("extends"), this.space(), this.printList(e.extends));
					if ("DeclareClass" === e.type) {
						var r, n;
						null != (r = e.mixins) && r.length && (this.space(), this.word("mixins"), this.space(), this.printList(e.mixins)), null != (n = e.implements) && n.length && (this.space(), this.word("implements"), this.space(), this.printList(e.implements));
					}
					this.space(), this.print(e.body);
				}, t._variance = function(e) {
					var t;
					const r = null == (t = e.variance) ? void 0 : t.kind;
					null != r && ("plus" === r ? this.tokenChar(43) : "minus" === r && this.tokenChar(45));
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/modules.js"), i = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/node/index.js"), o = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/types.js");
				const { isDeclareExportDeclaration: a, isStatement: l } = n;
				function enumExplicitType(e, t, r) {
					r && (e.space(), e.word("of"), e.space(), e.word(t)), e.space();
				}
				function enumBody(e, t) {
					const { members: r } = t;
					e.token("{"), e.indent(), e.newline();
					for (const t of r) e.print(t), e.newline();
					t.hasUnknownMembers && (e.token("..."), e.newline()), e.dedent(), e.token("}");
				}
				function enumInitializedMember(e, t) {
					e.print(t.id), e.space(), e.token("="), e.space(), e.print(t.init), e.token(",");
				}
				function FlowExportDeclaration(e) {
					if (e.declaration) {
						const t = e.declaration;
						this.print(t), l(t) || this.semicolon();
					} else this.tokenChar(123), e.specifiers.length && (this.space(), this.printList(e.specifiers), this.space()), this.tokenChar(125), e.source && (this.space(), this.word("from"), this.space(), this.print(e.source)), this.semicolon();
				}
				function andSeparator(e) {
					this.space(), this.token("&", !1, e), this.space();
				}
				function orSeparator(e) {
					this.space(), this.token("|", !1, e), this.space();
				}
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 });
				var n = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/template-literals.js");
				Object.keys(n).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === n[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return n[e];
						}
					}));
				});
				var s = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/expressions.js");
				Object.keys(s).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === s[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return s[e];
						}
					}));
				});
				var i = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/statements.js");
				Object.keys(i).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === i[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return i[e];
						}
					}));
				});
				var o = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/classes.js");
				Object.keys(o).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === o[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return o[e];
						}
					}));
				});
				var a = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/methods.js");
				Object.keys(a).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === a[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return a[e];
						}
					}));
				});
				var l = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/modules.js");
				Object.keys(l).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === l[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return l[e];
						}
					}));
				});
				var p = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/types.js");
				Object.keys(p).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === p[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return p[e];
						}
					}));
				});
				var c = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/flow.js");
				Object.keys(c).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === c[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return c[e];
						}
					}));
				});
				var u = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/base.js");
				Object.keys(u).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === u[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return u[e];
						}
					}));
				});
				var d = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/jsx.js");
				Object.keys(d).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === d[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return d[e];
						}
					}));
				});
				var h = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/typescript.js");
				Object.keys(h).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === h[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return h[e];
						}
					}));
				});
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/jsx.js": function(e, t) {
				"use strict";
				function spaceSeparator() {
					this.space();
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.JSXAttribute = function(e) {
					this.print(e.name), e.value && (this.tokenChar(61), this.print(e.value));
				}, t.JSXClosingElement = function(e) {
					this.tokenChar(60), this.tokenChar(47), this.print(e.name), this.tokenChar(62);
				}, t.JSXClosingFragment = function() {
					this.token("</"), this.tokenChar(62);
				}, t.JSXElement = function(e) {
					const t = e.openingElement;
					if (this.print(t), t.selfClosing) return;
					this.indent();
					for (const t of e.children) this.print(t);
					this.dedent(), this.print(e.closingElement);
				}, t.JSXEmptyExpression = function() {
					this.printInnerComments();
				}, t.JSXExpressionContainer = function(e) {
					this.tokenChar(123), this.print(e.expression), this.rightBrace(e);
				}, t.JSXFragment = function(e) {
					this.print(e.openingFragment), this.indent();
					for (const t of e.children) this.print(t);
					this.dedent(), this.print(e.closingFragment);
				}, t.JSXIdentifier = function(e) {
					this.word(e.name);
				}, t.JSXMemberExpression = function(e) {
					this.print(e.object), this.tokenChar(46), this.print(e.property);
				}, t.JSXNamespacedName = function(e) {
					this.print(e.namespace), this.tokenChar(58), this.print(e.name);
				}, t.JSXOpeningElement = function(e) {
					this.tokenChar(60), this.print(e.name), e.typeArguments && this.print(e.typeArguments);
					this.print(e.typeParameters), e.attributes.length > 0 && (this.space(), this.printJoin(e.attributes, void 0, void 0, spaceSeparator));
					e.selfClosing && (this.space(), this.tokenChar(47));
					this.tokenChar(62);
				}, t.JSXOpeningFragment = function() {
					this.tokenChar(60), this.tokenChar(62);
				}, t.JSXSpreadAttribute = function(e) {
					this.tokenChar(123), this.token("..."), this.print(e.argument), this.rightBrace(e);
				}, t.JSXSpreadChild = function(e) {
					this.tokenChar(123), this.token("..."), this.print(e.expression), this.rightBrace(e);
				}, t.JSXText = function(e) {
					const t = this.getPossibleRaw(e);
					void 0 !== t ? this.token(t, !0) : this.token(e.value, !0);
				};
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/methods.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.ArrowFunctionExpression = function(e, t) {
					e.async && (this.word("async", !0), this.space());
					this._shouldPrintArrowParamsParens(e) ? this._params(e, void 0, t) : this.print(e.params[0], !0);
					this._predicate(e, !0), this.space(), this.printInnerComments(), this.token("=>"), this.space(), this.tokenContext |= s.TokenContext.arrowBody, this.print(e.body);
				}, t.FunctionDeclaration = t.FunctionExpression = function(e, t) {
					this._functionHead(e, t), this.space(), this.print(e.body);
				}, t._functionHead = function(e, t) {
					e.async && (this.word("async"), this.format.preserveFormat || (this._endsWithInnerRaw = !1), this.space());
					this.word("function"), e.generator && (this.format.preserveFormat || (this._endsWithInnerRaw = !1), this.tokenChar(42));
					this.space(), e.id && this.print(e.id);
					this._params(e, e.id, t), "TSDeclareFunction" !== e.type && this._predicate(e);
				}, t._methodHead = function(e) {
					const t = e.kind, r = e.key;
					"get" !== t && "set" !== t || (this.word(t), this.space());
					e.async && (this.word("async", !0), this.space());
					"method" !== t && "init" !== t || e.generator && this.tokenChar(42);
					e.computed ? (this.tokenChar(91), this.print(r), this.tokenChar(93)) : this.print(r);
					e.optional && this.tokenChar(63);
					this._params(e, e.computed && "StringLiteral" !== e.key.type ? void 0 : e.key, void 0);
				}, t._param = function(e) {
					this.printJoin(e.decorators), this.print(e), e.optional && this.tokenChar(63);
					this.print(e.typeAnnotation);
				}, t._parameters = function(e, t) {
					const r = this.enterDelimited(), n = this.shouldPrintTrailingComma(t), s = e.length;
					for (let t = 0; t < s; t++) this._param(e[t]), (n || t < s - 1) && (this.token(",", null, t), this.space());
					this.token(t), r();
				}, t._params = function(e, t, r) {
					this.print(e.typeParameters);
					const n = _getFuncIdName.call(this, t, r);
					n && this.sourceIdentifierName(n.name, n.pos);
					this.tokenChar(40), this._parameters(e.params, ")");
					const s = "ArrowFunctionExpression" === e.type;
					this.print(e.returnType, s), this._noLineTerminator = s;
				}, t._predicate = function(e, t) {
					e.predicate && (e.returnType || this.tokenChar(58), this.space(), this.print(e.predicate, t));
				}, t._shouldPrintArrowParamsParens = function(e) {
					var t, r;
					if (1 !== e.params.length) return !0;
					if (e.typeParameters || e.returnType || e.predicate) return !0;
					const n = e.params[0];
					if (!i(n) || n.typeAnnotation || n.optional || null != (t = n.leadingComments) && t.length || null != (r = n.trailingComments) && r.length) return !0;
					if (this.tokenMap) {
						if (null == e.loc) return !0;
						if (null !== this.tokenMap.findMatching(e, "(")) return !0;
						const t = this.tokenMap.findMatching(e, "=>");
						return null == (null == t ? void 0 : t.loc) || t.loc.start.line !== e.loc.start.line;
					}
					return !!this.format.retainLines;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/node/index.js");
				const { isIdentifier: i } = n;
				function _getFuncIdName(e, t) {
					let r, n = e;
					if (!n && t) {
						const e = t.type;
						"VariableDeclarator" === e ? n = t.id : "AssignmentExpression" === e || "AssignmentPattern" === e ? n = t.left : "ObjectProperty" === e || "ClassProperty" === e ? t.computed && "StringLiteral" !== t.key.type || (n = t.key) : "ClassPrivateProperty" !== e && "ClassAccessorProperty" !== e || (n = t.key);
					}
					if (n) {
						var s, i;
						if ("Identifier" === n.type) r = {
							pos: null == (s = n.loc) ? void 0 : s.start,
							name: (null == (i = n.loc) ? void 0 : i.identifierName) || n.name
						};
						else if ("PrivateName" === n.type) {
							var o;
							r = {
								pos: null == (o = n.loc) ? void 0 : o.start,
								name: "#" + n.id.name
							};
						} else if ("StringLiteral" === n.type) {
							var a;
							r = {
								pos: null == (a = n.loc) ? void 0 : a.start,
								name: n.value
							};
						}
						return r;
					}
				}
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/modules.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.ExportAllDeclaration = function(e) {
					var t, r;
					this.word("export"), this.space(), "type" === e.exportKind && (this.word("type"), this.space());
					this.tokenChar(42), this.space(), this.word("from"), this.space(), null != (t = e.attributes) && t.length || null != (r = e.assertions) && r.length ? (this.print(e.source, !0), this.space(), this._printAttributes(e, !1)) : this.print(e.source);
					this.semicolon();
				}, t.ExportDefaultDeclaration = function(e) {
					maybePrintDecoratorsBeforeExport(this, e), this.word("export"), this.noIndentInnerCommentsHere(), this.space(), this.word("default"), this.space(), this.tokenContext |= s.TokenContext.exportDefault;
					const t = e.declaration;
					this.print(t), c(t) || this.semicolon();
				}, t.ExportDefaultSpecifier = function(e) {
					this.print(e.exported);
				}, t.ExportNamedDeclaration = function(e) {
					if (maybePrintDecoratorsBeforeExport(this, e), this.word("export"), this.space(), e.declaration) {
						const t = e.declaration;
						this.print(t), c(t) || this.semicolon();
					} else {
						"type" === e.exportKind && (this.word("type"), this.space());
						const n = e.specifiers.slice(0);
						let s = !1;
						for (;;) {
							const e = n[0];
							if (!o(e) && !a(e)) break;
							s = !0, this.print(n.shift()), n.length && (this.tokenChar(44), this.space());
						}
						let i = !1;
						var t, r;
						if ((n.length || !n.length && !s) && (i = !0, this.tokenChar(123), n.length && (this.space(), this.printList(n, this.shouldPrintTrailingComma("}")), this.space()), this.tokenChar(125)), e.source) this.space(), this.word("from"), this.space(), null != (t = e.attributes) && t.length || null != (r = e.assertions) && r.length ? (this.print(e.source, !0), this.space(), this._printAttributes(e, i)) : this.print(e.source);
						this.semicolon();
					}
				}, t.ExportNamespaceSpecifier = function(e) {
					this.tokenChar(42), this.space(), this.word("as"), this.space(), this.print(e.exported);
				}, t.ExportSpecifier = function(e) {
					"type" === e.exportKind && (this.word("type"), this.space());
					this.print(e.local), e.exported && e.local.name !== e.exported.name && (this.space(), this.word("as"), this.space(), this.print(e.exported));
				}, t.ImportAttribute = function(e) {
					this.print(e.key), this.tokenChar(58), this.space(), this.print(e.value);
				}, t.ImportDeclaration = function(e) {
					var t, r;
					this.word("import"), this.space();
					const n = "type" === e.importKind || "typeof" === e.importKind;
					n ? (this.noIndentInnerCommentsHere(), this.word(e.importKind), this.space()) : e.module ? (this.noIndentInnerCommentsHere(), this.word("module"), this.space()) : e.phase && (this.noIndentInnerCommentsHere(), this.word(e.phase), this.space());
					const s = e.specifiers.slice(0), i = !!s.length;
					for (; i;) {
						const e = s[0];
						if (!l(e) && !p(e)) break;
						this.print(s.shift()), s.length && (this.tokenChar(44), this.space());
					}
					let o = !1;
					s.length ? (o = !0, this.tokenChar(123), this.space(), this.printList(s, this.shouldPrintTrailingComma("}")), this.space(), this.tokenChar(125)) : n && !i && (o = !0, this.tokenChar(123), this.tokenChar(125));
					(i || n) && (this.space(), this.word("from"), this.space());
					null != (t = e.attributes) && t.length || null != (r = e.assertions) && r.length ? (this.print(e.source, !0), this.space(), this._printAttributes(e, o)) : this.print(e.source);
					this.semicolon();
				}, t.ImportDefaultSpecifier = function(e) {
					this.print(e.local);
				}, t.ImportExpression = function(e) {
					this.word("import"), e.phase && (this.tokenChar(46), this.word(e.phase));
					this.tokenChar(40);
					const t = this.shouldPrintTrailingComma(")");
					this.print(e.source), null != e.options && (this.tokenChar(44), this.space(), this.print(e.options));
					t && this.tokenChar(44);
					this.rightParens(e);
				}, t.ImportNamespaceSpecifier = function(e) {
					this.tokenChar(42), this.space(), this.word("as"), this.space(), this.print(e.local);
				}, t.ImportSpecifier = function(e) {
					"type" !== e.importKind && "typeof" !== e.importKind || (this.word(e.importKind), this.space());
					this.print(e.imported), e.local && e.local.name !== e.imported.name && (this.space(), this.word("as"), this.space(), this.print(e.local));
				}, t._printAttributes = function(e, t) {
					var r;
					const { importAttributesKeyword: n } = this.format, { attributes: s, assertions: i } = e;
					s && !n && e.extra && (e.extra.deprecatedAssertSyntax || e.extra.deprecatedWithLegacySyntax) && !u && (u = !0, console.warn("You are using import attributes, without specifying the desired output syntax.\nPlease specify the \"importAttributesKeyword\" generator option, whose value can be one of:\n - \"with\"        : `import { a } from \"b\" with { type: \"json\" };`\n - \"assert\"      : `import { a } from \"b\" assert { type: \"json\" };`\n - \"with-legacy\" : `import { a } from \"b\" with type: \"json\";`\n"));
					const o = "assert" === n || !n && i;
					if (this.word(o ? "assert" : "with"), this.space(), !o && ("with-legacy" === n || !n && null != (r = e.extra) && r.deprecatedWithLegacySyntax)) return void this.printList(s || i);
					const a = t ? 1 : 0;
					this.token("{", null, a), this.space(), this.printList(s || i, this.shouldPrintTrailingComma("}")), this.space(), this.token("}", null, a);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/node/index.js");
				const { isClassDeclaration: i, isExportDefaultSpecifier: o, isExportNamespaceSpecifier: a, isImportDefaultSpecifier: l, isImportNamespaceSpecifier: p, isStatement: c } = n;
				let u = !1;
				function maybePrintDecoratorsBeforeExport(e, t) {
					i(t.declaration) && e._shouldPrintDecoratorsBeforeExport(t) && e.printJoin(t.declaration.decorators);
				}
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/statements.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.BreakStatement = function(e) {
					this.word("break"), printStatementAfterKeyword(this, e.label);
				}, t.CatchClause = function(e) {
					this.word("catch"), this.space(), e.param && (this.tokenChar(40), this.print(e.param), this.print(e.param.typeAnnotation), this.tokenChar(41), this.space());
					this.print(e.body);
				}, t.ContinueStatement = function(e) {
					this.word("continue"), printStatementAfterKeyword(this, e.label);
				}, t.DebuggerStatement = function() {
					this.word("debugger"), this.semicolon();
				}, t.DoWhileStatement = function(e) {
					this.word("do"), this.space(), this.print(e.body), this.space(), this.word("while"), this.space(), this.tokenChar(40), this.print(e.test), this.tokenChar(41), this.semicolon();
				}, t.ForOfStatement = t.ForInStatement = void 0, t.ForStatement = function(e) {
					this.word("for"), this.space(), this.tokenChar(40);
					{
						const t = this.enterForStatementInit();
						this.print(e.init), t();
					}
					this.tokenChar(59), e.test && (this.space(), this.print(e.test));
					this.token(";", !1, 1), e.update && (this.space(), this.print(e.update));
					this.tokenChar(41), this.printBlock(e);
				}, t.IfStatement = function(e) {
					this.word("if"), this.space(), this.tokenChar(40), this.print(e.test), this.tokenChar(41), this.space();
					const t = e.alternate && o(getLastStatement(e.consequent));
					t && (this.tokenChar(123), this.newline(), this.indent());
					this.printAndIndentOnComments(e.consequent), t && (this.dedent(), this.newline(), this.tokenChar(125));
					e.alternate && (this.endsWith(125) && this.space(), this.word("else"), this.space(), this.printAndIndentOnComments(e.alternate));
				}, t.LabeledStatement = function(e) {
					this.print(e.label), this.tokenChar(58), this.space(), this.print(e.body);
				}, t.ReturnStatement = function(e) {
					this.word("return"), printStatementAfterKeyword(this, e.argument);
				}, t.SwitchCase = function(e) {
					e.test ? (this.word("case"), this.space(), this.print(e.test), this.tokenChar(58)) : (this.word("default"), this.tokenChar(58));
					e.consequent.length && (this.newline(), this.printSequence(e.consequent, !0));
				}, t.SwitchStatement = function(e) {
					this.word("switch"), this.space(), this.tokenChar(40), this.print(e.discriminant), this.tokenChar(41), this.space(), this.tokenChar(123), this.printSequence(e.cases, !0, void 0, function(t, r) {
						if (!t && e.cases[e.cases.length - 1] === r) return -1;
					}), this.rightBrace(e);
				}, t.ThrowStatement = function(e) {
					this.word("throw"), printStatementAfterKeyword(this, e.argument);
				}, t.TryStatement = function(e) {
					this.word("try"), this.space(), this.print(e.block), this.space(), e.handlers ? this.print(e.handlers[0]) : this.print(e.handler);
					e.finalizer && (this.space(), this.word("finally"), this.space(), this.print(e.finalizer));
				}, t.VariableDeclaration = function(e, t) {
					e.declare && (this.word("declare"), this.space());
					const { kind: r } = e;
					"await using" === r ? (this.word("await"), this.space(), this.word("using", !0)) : this.word(r, "using" === r);
					this.space();
					let n = !1;
					if (!s(t)) for (const t of e.declarations) t.init && (n = !0);
					if (this.printList(e.declarations, void 0, void 0, e.declarations.length > 1, n ? function(e) {
						this.token(",", !1, e), this.newline();
					} : void 0), s(t)) {
						if (i(t)) {
							if (t.init === e) return;
						} else if (t.left === e) return;
					}
					this.semicolon();
				}, t.VariableDeclarator = function(e) {
					this.print(e.id), e.definite && this.tokenChar(33);
					this.print(e.id.typeAnnotation), e.init && (this.space(), this.tokenChar(61), this.space(), this.print(e.init));
				}, t.WhileStatement = function(e) {
					this.word("while"), this.space(), this.tokenChar(40), this.print(e.test), this.tokenChar(41), this.printBlock(e);
				}, t.WithStatement = function(e) {
					this.word("with"), this.space(), this.tokenChar(40), this.print(e.object), this.tokenChar(41), this.printBlock(e);
				};
				const { isFor: s, isForStatement: i, isIfStatement: o, isStatement: a } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
				function getLastStatement(e) {
					const { body: t } = e;
					return !1 === a(t) ? e : getLastStatement(t);
				}
				function ForXStatement(e) {
					this.word("for"), this.space();
					const t = "ForOfStatement" === e.type;
					t && e.await && (this.word("await"), this.space()), this.noIndentInnerCommentsHere(), this.tokenChar(40);
					{
						const r = this.enterForXStatementInit(t);
						this.print(e.left), r?.();
					}
					this.space(), this.word(t ? "of" : "in"), this.space(), this.print(e.right), this.tokenChar(41), this.printBlock(e);
				}
				t.ForInStatement = ForXStatement, t.ForOfStatement = ForXStatement;
				function printStatementAfterKeyword(e, t) {
					t && (e.space(), e.printTerminatorless(t)), e.semicolon();
				}
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/template-literals.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.TaggedTemplateExpression = function(e) {
					this.print(e.tag), this.print(e.typeParameters), this.print(e.quasi);
				}, t.TemplateElement = function() {
					throw new Error("TemplateElement printing is handled in TemplateLiteral");
				}, t.TemplateLiteral = function(e) {
					this._printTemplate(e, e.expressions);
				}, t._printTemplate = function(e, t) {
					const r = e.quasis;
					let n = "`";
					for (let s = 0; s < r.length - 1; s++) if (n += r[s].value.raw, this.token(n + "${", !0), this.print(t[s]), n = "}", this.tokenMap) {
						const t = this.tokenMap.findMatching(e, "}", s);
						t && this._catchUpTo(t.loc.start);
					}
					n += r[r.length - 1].value.raw, this.token(n + "`", !0);
				};
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/types.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.ArgumentPlaceholder = function() {
					this.tokenChar(63);
				}, t.ArrayPattern = t.ArrayExpression = function(e) {
					const t = e.elements, r = t.length;
					this.tokenChar(91);
					const n = this.enterDelimited();
					for (let e = 0; e < t.length; e++) {
						const n = t[e];
						n ? (e > 0 && this.space(), this.print(n), (e < r - 1 || this.shouldPrintTrailingComma("]")) && this.token(",", !1, e)) : this.token(",", !1, e);
					}
					n(), this.tokenChar(93);
				}, t.BigIntLiteral = function(e) {
					const t = this.getPossibleRaw(e);
					if (!this.format.minified && void 0 !== t) return void this.word(t);
					this.word(e.value + "n");
				}, t.BooleanLiteral = function(e) {
					this.word(e.value ? "true" : "false");
				}, t.Identifier = function(e) {
					var t;
					this.sourceIdentifierName((null == (t = e.loc) ? void 0 : t.identifierName) || e.name), this.word(this.tokenMap ? this._getRawIdentifier(e) : e.name);
				}, t.NullLiteral = function() {
					this.word("null");
				}, t.NumericLiteral = function(e) {
					const t = this.getPossibleRaw(e), r = this.format.jsescOption, n = e.value, i = n + "";
					r.numbers ? this.number(s(n, r), n) : null == t ? this.number(i, n) : this.format.minified ? this.number(t.length < i.length ? t : i, n) : this.number(t, n);
				}, t.ObjectPattern = t.ObjectExpression = function(e) {
					const t = e.properties;
					if (this.tokenChar(123), t.length) {
						const e = this.enterDelimited();
						this.space(), this.printList(t, this.shouldPrintTrailingComma("}"), !0, !0), this.space(), e();
					}
					this.sourceWithOffset("end", e.loc, -1), this.tokenChar(125);
				}, t.ObjectMethod = function(e) {
					this.printJoin(e.decorators), this._methodHead(e), this.space(), this.print(e.body);
				}, t.ObjectProperty = function(e) {
					if (this.printJoin(e.decorators), e.computed) this.tokenChar(91), this.print(e.key), this.tokenChar(93);
					else {
						if (i(e.value) && o(e.key) && e.key.name === e.value.left.name) return void this.print(e.value);
						if (this.print(e.key), e.shorthand && o(e.key) && o(e.value) && e.key.name === e.value.name) return;
					}
					this.tokenChar(58), this.space(), this.print(e.value);
				}, t.PipelineBareFunction = function(e) {
					this.print(e.callee);
				}, t.PipelinePrimaryTopicReference = function() {
					this.tokenChar(35);
				}, t.PipelineTopicExpression = function(e) {
					this.print(e.expression);
				}, t.RecordExpression = function(e) {
					const t = e.properties;
					let r, n;
					if ("bar" === this.format.recordAndTupleSyntaxType) r = "{|", n = "|}";
					else {
						if ("hash" !== this.format.recordAndTupleSyntaxType && null != this.format.recordAndTupleSyntaxType) throw new Error(`The "recordAndTupleSyntaxType" generator option must be "bar" or "hash" (${JSON.stringify(this.format.recordAndTupleSyntaxType)} received).`);
						r = "#{", n = "}";
					}
					this.token(r), t.length && (this.space(), this.printList(t, this.shouldPrintTrailingComma(n), !0, !0), this.space());
					this.token(n);
				}, t.RegExpLiteral = function(e) {
					this.word(`/${e.pattern}/${e.flags}`);
				}, t.SpreadElement = t.RestElement = function(e) {
					this.token("..."), this.print(e.argument);
				}, t.StringLiteral = function(e) {
					const t = this.getPossibleRaw(e);
					if (!this.format.minified && void 0 !== t) return void this.token(t);
					const r = s(e.value, this.format.jsescOption);
					this.token(r);
				}, t.TopicReference = function() {
					const { topicToken: e } = this.format;
					if (!p.has(e)) {
						const t = JSON.stringify(e), r = Array.from(p, (e) => JSON.stringify(e));
						throw new Error(`The "topicToken" generator option must be one of ${r.join(", ")} (${t} received instead).`);
					}
					this.token(e);
				}, t.TupleExpression = function(e) {
					const t = e.elements, r = t.length;
					let n, s;
					if ("bar" === this.format.recordAndTupleSyntaxType) n = "[|", s = "|]";
					else {
						if ("hash" !== this.format.recordAndTupleSyntaxType) throw new Error(`${this.format.recordAndTupleSyntaxType} is not a valid recordAndTuple syntax type`);
						n = "#[", s = "]";
					}
					this.token(n);
					for (let e = 0; e < t.length; e++) {
						const n = t[e];
						n && (e > 0 && this.space(), this.print(n), (e < r - 1 || this.shouldPrintTrailingComma(s)) && this.token(",", !1, e));
					}
					this.token(s);
				}, t.VoidPattern = function() {
					this.word("void");
				}, t._getRawIdentifier = function(e) {
					if (e === a) return l;
					a = e;
					const { name: t } = e, r = this.tokenMap.find(e, (e) => e.value === t);
					if (r) return l = this._originalCode.slice(r.start, r.end), l;
					return l = e.name;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = r("./node_modules/.pnpm/jsesc@3.1.0/node_modules/jsesc/jsesc.js");
				const { isAssignmentPattern: i, isIdentifier: o } = n;
				let a = null, l = "";
				const p = new Set([
					"^^",
					"@@",
					"^",
					"%",
					"#"
				]);
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/typescript.js": function(e, t) {
				"use strict";
				function maybePrintTrailingCommaOrSemicolon(e, t) {
					e.tokenMap && t.start && t.end ? e.tokenMap.endMatches(t, ",") ? e.token(",") : e.tokenMap.endMatches(t, ";") && e.semicolon() : e.semicolon();
				}
				function tsPrintUnionOrIntersectionType(e, t, r) {
					var n;
					let s = 0;
					null != (n = e.tokenMap) && n.startMatches(t, r) && (s = 1, e.token(r)), e.printJoin(t.types, void 0, void 0, function(e) {
						this.space(), this.token(r, null, e + s), this.space();
					});
				}
				function tokenIfPlusMinus(e, t) {
					!0 !== t && e.token(t);
				}
				function TSEnumBody(e) {
					printBraced(this, e, () => {
						var t;
						return this.printList(e.members, null == (t = this.shouldPrintTrailingComma("}")) || t, !0, !0);
					});
				}
				function printBraced(e, t, r) {
					e.token("{");
					const n = e.enterDelimited();
					r(), n(), e.rightBrace(t);
				}
				function printModifiersList(e, t, r) {
					var n;
					const s = /* @__PURE__ */ new Set();
					for (const e of r) e && s.add(e);
					null == (n = e.tokenMap) || n.find(t, (t) => {
						if (s.has(t.value)) return e.token(t.value), e.space(), s.delete(t.value), 0 === s.size;
					});
					for (const t of s) e.word(t), e.space();
				}
				Object.defineProperty(t, "__esModule", { value: !0 }), t.TSAnyKeyword = function() {
					this.word("any");
				}, t.TSArrayType = function(e) {
					this.print(e.elementType, !0), this.tokenChar(91), this.tokenChar(93);
				}, t.TSSatisfiesExpression = t.TSAsExpression = function(e) {
					const { type: t, expression: r, typeAnnotation: n } = e;
					this.print(r, !0), this.space(), this.word("TSAsExpression" === t ? "as" : "satisfies"), this.space(), this.print(n);
				}, t.TSBigIntKeyword = function() {
					this.word("bigint");
				}, t.TSBooleanKeyword = function() {
					this.word("boolean");
				}, t.TSCallSignatureDeclaration = function(e) {
					this.tsPrintSignatureDeclarationBase(e), maybePrintTrailingCommaOrSemicolon(this, e);
				}, t.TSInterfaceHeritage = t.TSClassImplements = function(e) {
					this.print(e.expression), this.print(e.typeArguments);
				}, t.TSConditionalType = function(e) {
					this.print(e.checkType), this.space(), this.word("extends"), this.space(), this.print(e.extendsType), this.space(), this.tokenChar(63), this.space(), this.print(e.trueType), this.space(), this.tokenChar(58), this.space(), this.print(e.falseType);
				}, t.TSConstructSignatureDeclaration = function(e) {
					this.word("new"), this.space(), this.tsPrintSignatureDeclarationBase(e), maybePrintTrailingCommaOrSemicolon(this, e);
				}, t.TSConstructorType = function(e) {
					e.abstract && (this.word("abstract"), this.space());
					this.word("new"), this.space(), this.tsPrintFunctionOrConstructorType(e);
				}, t.TSDeclareFunction = function(e, t) {
					e.declare && (this.word("declare"), this.space());
					this._functionHead(e, t), this.semicolon();
				}, t.TSDeclareMethod = function(e) {
					this._classMethodHead(e), this.semicolon();
				}, t.TSEnumBody = TSEnumBody, t.TSEnumDeclaration = function(e) {
					const { declare: t, const: r, id: n } = e;
					t && (this.word("declare"), this.space());
					r && (this.word("const"), this.space());
					this.word("enum"), this.space(), this.print(n), this.space(), TSEnumBody.call(this, e);
				}, t.TSEnumMember = function(e) {
					const { id: t, initializer: r } = e;
					this.print(t), r && (this.space(), this.tokenChar(61), this.space(), this.print(r));
				}, t.TSExportAssignment = function(e) {
					this.word("export"), this.space(), this.tokenChar(61), this.space(), this.print(e.expression), this.semicolon();
				}, t.TSExternalModuleReference = function(e) {
					this.token("require("), this.print(e.expression), this.tokenChar(41);
				}, t.TSFunctionType = function(e) {
					this.tsPrintFunctionOrConstructorType(e);
				}, t.TSImportEqualsDeclaration = function(e) {
					const { id: t, moduleReference: r } = e;
					e.isExport && (this.word("export"), this.space());
					this.word("import"), this.space(), this.print(t), this.space(), this.tokenChar(61), this.space(), this.print(r), this.semicolon();
				}, t.TSImportType = function(e) {
					const { argument: t, qualifier: r, options: n } = e;
					this.word("import"), this.tokenChar(40), this.print(t), n && (this.tokenChar(44), this.print(n));
					this.tokenChar(41), r && (this.tokenChar(46), this.print(r));
					const s = e.typeParameters;
					s && this.print(s);
				}, t.TSIndexSignature = function(e) {
					const { readonly: t, static: r } = e;
					r && (this.word("static"), this.space());
					t && (this.word("readonly"), this.space());
					this.tokenChar(91), this._parameters(e.parameters, "]"), this.print(e.typeAnnotation), maybePrintTrailingCommaOrSemicolon(this, e);
				}, t.TSIndexedAccessType = function(e) {
					this.print(e.objectType, !0), this.tokenChar(91), this.print(e.indexType), this.tokenChar(93);
				}, t.TSInferType = function(e) {
					this.word("infer"), this.print(e.typeParameter);
				}, t.TSInstantiationExpression = function(e) {
					this.print(e.expression), this.print(e.typeParameters);
				}, t.TSInterfaceBody = function(e) {
					printBraced(this, e, () => this.printJoin(e.body, !0, !0));
				}, t.TSInterfaceDeclaration = function(e) {
					const { declare: t, id: r, typeParameters: n, extends: s, body: i } = e;
					t && (this.word("declare"), this.space());
					this.word("interface"), this.space(), this.print(r), this.print(n), null != s && s.length && (this.space(), this.word("extends"), this.space(), this.printList(s));
					this.space(), this.print(i);
				}, t.TSIntersectionType = function(e) {
					tsPrintUnionOrIntersectionType(this, e, "&");
				}, t.TSIntrinsicKeyword = function() {
					this.word("intrinsic");
				}, t.TSLiteralType = function(e) {
					this.print(e.literal);
				}, t.TSMappedType = function(e) {
					const { nameType: t, optional: r, readonly: n, typeAnnotation: s } = e;
					this.tokenChar(123);
					const i = this.enterDelimited();
					this.space(), n && (tokenIfPlusMinus(this, n), this.word("readonly"), this.space());
					this.tokenChar(91), this.word(e.typeParameter.name), this.space(), this.word("in"), this.space(), this.print(e.typeParameter.constraint), t && (this.space(), this.word("as"), this.space(), this.print(t));
					this.tokenChar(93), r && (tokenIfPlusMinus(this, r), this.tokenChar(63));
					s && (this.tokenChar(58), this.space(), this.print(s));
					this.space(), i(), this.tokenChar(125);
				}, t.TSMethodSignature = function(e) {
					const { kind: t } = e;
					"set" !== t && "get" !== t || (this.word(t), this.space());
					this.tsPrintPropertyOrMethodName(e), this.tsPrintSignatureDeclarationBase(e), maybePrintTrailingCommaOrSemicolon(this, e);
				}, t.TSModuleBlock = function(e) {
					printBraced(this, e, () => this.printSequence(e.body, !0));
				}, t.TSModuleDeclaration = function(e) {
					const { declare: t, id: r, kind: n } = e;
					t && (this.word("declare"), this.space());
					{
						if (e.global || (this.word(null != n ? n : "Identifier" === r.type ? "namespace" : "module"), this.space()), this.print(r), !e.body) return void this.semicolon();
						let t = e.body;
						for (; "TSModuleDeclaration" === t.type;) this.tokenChar(46), this.print(t.id), t = t.body;
						this.space(), this.print(t);
					}
				}, t.TSNamedTupleMember = function(e) {
					this.print(e.label), e.optional && this.tokenChar(63);
					this.tokenChar(58), this.space(), this.print(e.elementType);
				}, t.TSNamespaceExportDeclaration = function(e) {
					this.word("export"), this.space(), this.word("as"), this.space(), this.word("namespace"), this.space(), this.print(e.id), this.semicolon();
				}, t.TSNeverKeyword = function() {
					this.word("never");
				}, t.TSNonNullExpression = function(e) {
					this.print(e.expression), this.tokenChar(33);
				}, t.TSNullKeyword = function() {
					this.word("null");
				}, t.TSNumberKeyword = function() {
					this.word("number");
				}, t.TSObjectKeyword = function() {
					this.word("object");
				}, t.TSOptionalType = function(e) {
					this.print(e.typeAnnotation), this.tokenChar(63);
				}, t.TSParameterProperty = function(e) {
					e.accessibility && (this.word(e.accessibility), this.space());
					e.readonly && (this.word("readonly"), this.space());
					this._param(e.parameter);
				}, t.TSParenthesizedType = function(e) {
					this.tokenChar(40), this.print(e.typeAnnotation), this.tokenChar(41);
				}, t.TSPropertySignature = function(e) {
					const { readonly: t } = e;
					t && (this.word("readonly"), this.space());
					this.tsPrintPropertyOrMethodName(e), this.print(e.typeAnnotation), maybePrintTrailingCommaOrSemicolon(this, e);
				}, t.TSQualifiedName = function(e) {
					this.print(e.left), this.tokenChar(46), this.print(e.right);
				}, t.TSRestType = function(e) {
					this.token("..."), this.print(e.typeAnnotation);
				}, t.TSStringKeyword = function() {
					this.word("string");
				}, t.TSSymbolKeyword = function() {
					this.word("symbol");
				}, t.TSTemplateLiteralType = function(e) {
					this._printTemplate(e, e.types);
				}, t.TSThisType = function() {
					this.word("this");
				}, t.TSTupleType = function(e) {
					this.tokenChar(91), this.printList(e.elementTypes, this.shouldPrintTrailingComma("]")), this.tokenChar(93);
				}, t.TSTypeAliasDeclaration = function(e) {
					const { declare: t, id: r, typeParameters: n, typeAnnotation: s } = e;
					t && (this.word("declare"), this.space());
					this.word("type"), this.space(), this.print(r), this.print(n), this.space(), this.tokenChar(61), this.space(), this.print(s), this.semicolon();
				}, t.TSTypeAnnotation = function(e, t) {
					this.token("TSFunctionType" !== t.type && "TSConstructorType" !== t.type || t.typeAnnotation !== e ? ":" : "=>"), this.space(), e.optional && this.tokenChar(63);
					this.print(e.typeAnnotation);
				}, t.TSTypeAssertion = function(e) {
					const { typeAnnotation: t, expression: r } = e;
					this.tokenChar(60), this.print(t), this.tokenChar(62), this.space(), this.print(r);
				}, t.TSTypeLiteral = function(e) {
					printBraced(this, e, () => this.printJoin(e.members, !0, !0));
				}, t.TSTypeOperator = function(e) {
					this.word(e.operator), this.space(), this.print(e.typeAnnotation);
				}, t.TSTypeParameter = function(e) {
					e.const && (this.word("const"), this.space());
					e.in && (this.word("in"), this.space());
					e.out && (this.word("out"), this.space());
					this.word(e.name), e.constraint && (this.space(), this.word("extends"), this.space(), this.print(e.constraint));
					e.default && (this.space(), this.tokenChar(61), this.space(), this.print(e.default));
				}, t.TSTypeParameterDeclaration = t.TSTypeParameterInstantiation = function(e, t) {
					this.tokenChar(60);
					let r = "ArrowFunctionExpression" === t.type && 1 === e.params.length;
					this.tokenMap && null != e.start && null != e.end && (r && (r = !!this.tokenMap.find(e, (e) => this.tokenMap.matchesOriginal(e, ","))), r || (r = this.shouldPrintTrailingComma(">")));
					this.printList(e.params, r), this.tokenChar(62);
				}, t.TSTypePredicate = function(e) {
					e.asserts && (this.word("asserts"), this.space());
					this.print(e.parameterName), e.typeAnnotation && (this.space(), this.word("is"), this.space(), this.print(e.typeAnnotation.typeAnnotation));
				}, t.TSTypeQuery = function(e) {
					this.word("typeof"), this.space(), this.print(e.exprName);
					const t = e.typeParameters;
					t && this.print(t);
				}, t.TSTypeReference = function(e) {
					const t = e.typeParameters;
					this.print(e.typeName, !!t), this.print(t);
				}, t.TSUndefinedKeyword = function() {
					this.word("undefined");
				}, t.TSUnionType = function(e) {
					tsPrintUnionOrIntersectionType(this, e, "|");
				}, t.TSUnknownKeyword = function() {
					this.word("unknown");
				}, t.TSVoidKeyword = function() {
					this.word("void");
				}, t.tsPrintClassMemberModifiers = function(e) {
					const t = "ClassPrivateProperty" === e.type, r = "ClassAccessorProperty" === e.type || "ClassProperty" === e.type;
					printModifiersList(this, e, [r && e.declare && "declare", !t && e.accessibility]), e.static && (this.word("static"), this.space());
					printModifiersList(this, e, [
						!t && e.abstract && "abstract",
						!t && e.override && "override",
						(r || t) && e.readonly && "readonly"
					]);
				}, t.tsPrintFunctionOrConstructorType = function(e) {
					const { typeParameters: t } = e, r = e.parameters;
					this.print(t), this.tokenChar(40), this._parameters(r, ")"), this.space();
					const n = e.typeAnnotation;
					this.print(n);
				}, t.tsPrintPropertyOrMethodName = function(e) {
					e.computed && this.tokenChar(91);
					this.print(e.key), e.computed && this.tokenChar(93);
					e.optional && this.tokenChar(63);
				}, t.tsPrintSignatureDeclarationBase = function(e) {
					const { typeParameters: t } = e, r = e.parameters;
					this.print(t), this.tokenChar(40), this._parameters(r, ")");
					const n = e.typeAnnotation;
					this.print(n);
				};
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0, t.generate = generate;
				var n = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/source-map.js"), s = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/printer.js");
				function normalizeOptions(e, t, r) {
					if (t.experimental_preserveFormat) {
						if ("string" != typeof e) throw new Error("`experimental_preserveFormat` requires the original `code` to be passed to @babel/generator as a string");
						if (!t.retainLines) throw new Error("`experimental_preserveFormat` requires `retainLines` to be set to `true`");
						if (t.compact && "auto" !== t.compact) throw new Error("`experimental_preserveFormat` is not compatible with the `compact` option");
						if (t.minified) throw new Error("`experimental_preserveFormat` is not compatible with the `minified` option");
						if (t.jsescOption) throw new Error("`experimental_preserveFormat` is not compatible with the `jsescOption` option");
						if (!Array.isArray(r.tokens)) throw new Error("`experimental_preserveFormat` requires the AST to have attached the token of the input code. Make sure to enable the `tokens: true` parser option.");
					}
					const n = {
						auxiliaryCommentBefore: t.auxiliaryCommentBefore,
						auxiliaryCommentAfter: t.auxiliaryCommentAfter,
						shouldPrintComment: t.shouldPrintComment,
						preserveFormat: t.experimental_preserveFormat,
						retainLines: t.retainLines,
						retainFunctionParens: t.retainFunctionParens,
						comments: null == t.comments || t.comments,
						compact: t.compact,
						minified: t.minified,
						concise: t.concise,
						indent: {
							adjustMultilineComment: !0,
							style: "  "
						},
						jsescOption: Object.assign({
							quotes: "double",
							wrap: !0,
							minimal: !1
						}, t.jsescOption),
						topicToken: t.topicToken,
						importAttributesKeyword: t.importAttributesKeyword
					};
					var s;
					n.decoratorsBeforeExport = t.decoratorsBeforeExport, n.jsescOption.json = t.jsonCompatibleStrings, n.recordAndTupleSyntaxType = null != (s = t.recordAndTupleSyntaxType) ? s : "hash", n.minified ? (n.compact = !0, n.shouldPrintComment = n.shouldPrintComment || (() => n.comments)) : n.shouldPrintComment = n.shouldPrintComment || ((e) => n.comments || e.includes("@license") || e.includes("@preserve")), "auto" === n.compact && (n.compact = "string" == typeof e && e.length > 5e5, n.compact && console.error(`[BABEL] Note: The code generator has deoptimised the styling of ${t.filename} as it exceeds the max of 500KB.`)), (n.compact || n.preserveFormat) && (n.indent.adjustMultilineComment = !1);
					const { auxiliaryCommentBefore: i, auxiliaryCommentAfter: o, shouldPrintComment: a } = n;
					return i && !a(i) && (n.auxiliaryCommentBefore = void 0), o && !a(o) && (n.auxiliaryCommentAfter = void 0), n;
				}
				function generate(e, t = {}, r) {
					const i = normalizeOptions(r, t, e), o = t.sourceMaps ? new n.default(t, r) : null;
					return new s.default(i, o, e.tokens, "string" == typeof r ? r : null).generate(e);
				}
				t.CodeGenerator = class {
					constructor(e, t = {}, r) {
						this._ast = void 0, this._format = void 0, this._map = void 0, this._ast = e, this._format = normalizeOptions(r, t, e), this._map = t.sourceMaps ? new n.default(t, r) : null;
					}
					generate() {
						return new s.default(this._format, this._map).generate(this._ast);
					}
				};
				t.default = generate;
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/node/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.TokenContext = void 0, t.isLastChild = function(e, t) {
					const r = a[e.type];
					for (let n = r.length - 1; n >= 0; n--) {
						const s = e[r[n]];
						if (s === t) return !0;
						if (Array.isArray(s)) {
							let e = s.length - 1;
							for (; e >= 0 && null === s[e];) e--;
							return e >= 0 && s[e] === t;
						}
						if (s) return !1;
					}
					return !1;
				}, t.needsParens = function(e, t, r, n) {
					var s;
					if (!t) return !1;
					if (d(t) && t.callee === e && isOrHasCallExpression(e)) return !0;
					if (p(t)) return !(isDecoratorMemberExpression(e) || l(e) && isDecoratorMemberExpression(e.callee) || h(e));
					return null == (s = m.get(e.type)) ? void 0 : s(e, t, r, n);
				}, t.needsWhitespace = needsWhitespace, t.needsWhitespaceAfter = function(e, t) {
					return needsWhitespace(e, t, 2);
				}, t.needsWhitespaceBefore = function(e, t) {
					return needsWhitespace(e, t, 1);
				};
				var n = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/node/whitespace.js"), s = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/node/parentheses.js");
				const { FLIPPED_ALIAS_KEYS: o, VISITOR_KEYS: a, isCallExpression: l, isDecorator: p, isExpressionStatement: c, isMemberExpression: u, isNewExpression: d, isParenthesizedExpression: h } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
				t.TokenContext = {
					normal: 0,
					expressionStatement: 1,
					arrowBody: 2,
					exportDefault: 4,
					arrowFlowReturnType: 8,
					forInitHead: 16,
					forInHead: 32,
					forOfHead: 64,
					forInOrInitHeadAccumulate: 128,
					forInOrInitHeadAccumulatePassThroughMask: 128
				};
				function expandAliases(e) {
					const t = /* @__PURE__ */ new Map();
					function add(e, r) {
						const n = t.get(e);
						t.set(e, n ? function(e, t, s, i) {
							var o;
							return null != (o = n(e, t, s, i)) ? o : r(e, t, s, i);
						} : r);
					}
					for (const t of Object.keys(e)) {
						const r = o[t];
						if (r) for (const n of r) add(n, e[t]);
						else add(t, e[t]);
					}
					return t;
				}
				const m = expandAliases(s), f = expandAliases(n.nodes);
				function isOrHasCallExpression(e) {
					return !!l(e) || u(e) && isOrHasCallExpression(e.object);
				}
				function needsWhitespace(e, t, r) {
					var n;
					if (!e) return !1;
					c(e) && (e = e.expression);
					const s = null == (n = f.get(e.type)) ? void 0 : n(e, t);
					return "number" == typeof s && 0 !== (s & r);
				}
				function isDecoratorMemberExpression(e) {
					switch (e.type) {
						case "Identifier": return !0;
						case "MemberExpression": return !e.computed && "Identifier" === e.property.type && isDecoratorMemberExpression(e.object);
						default: return !1;
					}
				}
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/node/parentheses.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.AssignmentExpression = function(e, t, r) {
					return !(!needsParenBeforeExpressionBrace(r) || !u(e.left)) || ConditionalExpression(e, t);
				}, t.Binary = Binary, t.BinaryExpression = function(e, t, r) {
					return "in" === e.operator && Boolean(r & s.TokenContext.forInOrInitHeadAccumulate);
				}, t.ClassExpression = function(e, t, r) {
					return Boolean(r & (s.TokenContext.expressionStatement | s.TokenContext.exportDefault));
				}, t.ArrowFunctionExpression = t.ConditionalExpression = ConditionalExpression, t.DoExpression = function(e, t, r) {
					return !e.async && Boolean(r & s.TokenContext.expressionStatement);
				}, t.FunctionExpression = function(e, t, r) {
					return Boolean(r & (s.TokenContext.expressionStatement | s.TokenContext.exportDefault));
				}, t.FunctionTypeAnnotation = function(e, t, r) {
					const n = t.type;
					return "UnionTypeAnnotation" === n || "IntersectionTypeAnnotation" === n || "ArrayTypeAnnotation" === n || Boolean(r & s.TokenContext.arrowFlowReturnType);
				}, t.Identifier = function(e, t, r, n) {
					var i;
					const o = t.type;
					if (null != (i = e.extra) && i.parenthesized && "AssignmentExpression" === o && t.left === e) {
						const e = t.right.type;
						if (("FunctionExpression" === e || "ClassExpression" === e) && null == t.right.id) return !0;
					}
					if (n && n(e) !== e.name) return !1;
					if ("let" === e.name) return !!((c(t, {
						object: e,
						computed: !0
					}) || d(t, {
						object: e,
						computed: !0,
						optional: !1
					})) && r & (s.TokenContext.expressionStatement | s.TokenContext.forInitHead | s.TokenContext.forInHead)) || Boolean(r & s.TokenContext.forOfHead);
					return "async" === e.name && l(t, {
						left: e,
						await: !1
					});
				}, t.LogicalExpression = function(e, t) {
					const r = t.type;
					if (isTSTypeExpression(r)) return !0;
					if ("LogicalExpression" !== r) return !1;
					switch (e.operator) {
						case "||": return "??" === t.operator || "&&" === t.operator;
						case "&&": return "??" === t.operator;
						case "??": return "??" !== t.operator;
					}
				}, t.NullableTypeAnnotation = function(e, t) {
					return i(t);
				}, t.ObjectExpression = function(e, t, r) {
					return needsParenBeforeExpressionBrace(r);
				}, t.OptionalIndexedAccessType = function(e, t) {
					return p(t) && t.objectType === e;
				}, t.OptionalCallExpression = t.OptionalMemberExpression = function(e, t) {
					return a(t) && t.callee === e || c(t) && t.object === e;
				}, t.SequenceExpression = function(e, t) {
					const r = t.type;
					if ("SequenceExpression" === r || "ParenthesizedExpression" === r || "MemberExpression" === r && t.property === e || "OptionalMemberExpression" === r && t.property === e || "TemplateLiteral" === r) return !1;
					if ("ClassDeclaration" === r) return !0;
					if ("ForOfStatement" === r) return t.right === e;
					if ("ExportDefaultDeclaration" === r) return !0;
					return !m(t);
				}, t.TSSatisfiesExpression = t.TSAsExpression = function(e, t) {
					if (("AssignmentExpression" === t.type || "AssignmentPattern" === t.type) && t.left === e) return !0;
					if ("BinaryExpression" === t.type && ("|" === t.operator || "&" === t.operator) && e === t.left) return !0;
					return Binary(e, t);
				}, t.TSConditionalType = function(e, t) {
					const r = t.type;
					if ("TSArrayType" === r || "TSIndexedAccessType" === r && t.objectType === e || "TSOptionalType" === r || "TSTypeOperator" === r || "TSTypeParameter" === r) return !0;
					if (("TSIntersectionType" === r || "TSUnionType" === r) && t.types[0] === e) return !0;
					if ("TSConditionalType" === r && (t.checkType === e || t.extendsType === e)) return !0;
					return !1;
				}, t.TSConstructorType = t.TSFunctionType = function(e, t) {
					const r = t.type;
					return "TSIntersectionType" === r || "TSUnionType" === r || "TSTypeOperator" === r || "TSOptionalType" === r || "TSArrayType" === r || "TSIndexedAccessType" === r && t.objectType === e || "TSConditionalType" === r && (t.checkType === e || t.extendsType === e);
				}, t.TSInferType = function(e, t) {
					const r = t.type;
					if ("TSArrayType" === r || "TSIndexedAccessType" === r && t.objectType === e || "TSOptionalType" === r) return !0;
					if (e.typeParameter.constraint && ("TSIntersectionType" === r || "TSUnionType" === r) && t.types[0] === e) return !0;
					return !1;
				}, t.TSInstantiationExpression = function(e, t) {
					const r = t.type;
					return ("CallExpression" === r || "OptionalCallExpression" === r || "NewExpression" === r || "TSInstantiationExpression" === r) && !!t.typeParameters;
				}, t.TSIntersectionType = function(e, t) {
					const r = t.type;
					return "TSTypeOperator" === r || "TSArrayType" === r || "TSIndexedAccessType" === r && t.objectType === e || "TSOptionalType" === r;
				}, t.UnaryLike = t.TSTypeAssertion = UnaryLike, t.TSTypeOperator = function(e, t) {
					const r = t.type;
					return "TSArrayType" === r || "TSIndexedAccessType" === r && t.objectType === e || "TSOptionalType" === r;
				}, t.TSUnionType = function(e, t) {
					const r = t.type;
					return "TSIntersectionType" === r || "TSTypeOperator" === r || "TSArrayType" === r || "TSIndexedAccessType" === r && t.objectType === e || "TSOptionalType" === r;
				}, t.IntersectionTypeAnnotation = t.UnionTypeAnnotation = function(e, t) {
					const r = t.type;
					return "ArrayTypeAnnotation" === r || "NullableTypeAnnotation" === r || "IntersectionTypeAnnotation" === r || "UnionTypeAnnotation" === r;
				}, t.UpdateExpression = function(e, t) {
					return hasPostfixPart(e, t) || isClassExtendsClause(e, t);
				}, t.AwaitExpression = t.YieldExpression = function(e, t) {
					const r = t.type;
					return "BinaryExpression" === r || "LogicalExpression" === r || "UnaryExpression" === r || "SpreadElement" === r || hasPostfixPart(e, t) || "AwaitExpression" === r && h(e) || "ConditionalExpression" === r && e === t.test || isClassExtendsClause(e, t) || isTSTypeExpression(r);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/node/index.js");
				const { isArrayTypeAnnotation: i, isBinaryExpression: o, isCallExpression: a, isForOfStatement: l, isIndexedAccessType: p, isMemberExpression: c, isObjectPattern: u, isOptionalMemberExpression: d, isYieldExpression: h, isStatement: m } = n, f = new Map([
					["||", 0],
					["??", 0],
					["|>", 0],
					["&&", 1],
					["|", 2],
					["^", 3],
					["&", 4],
					["==", 5],
					["===", 5],
					["!=", 5],
					["!==", 5],
					["<", 6],
					[">", 6],
					["<=", 6],
					[">=", 6],
					["in", 6],
					["instanceof", 6],
					[">>", 7],
					["<<", 7],
					[">>>", 7],
					["+", 8],
					["-", 8],
					["*", 9],
					["/", 9],
					["%", 9],
					["**", 10]
				]);
				function getBinaryPrecedence(e, t) {
					return "BinaryExpression" === t || "LogicalExpression" === t ? f.get(e.operator) : "TSAsExpression" === t || "TSSatisfiesExpression" === t ? f.get("in") : void 0;
				}
				function isTSTypeExpression(e) {
					return "TSAsExpression" === e || "TSSatisfiesExpression" === e || "TSTypeAssertion" === e;
				}
				const isClassExtendsClause = (e, t) => {
					const r = t.type;
					return ("ClassDeclaration" === r || "ClassExpression" === r) && t.superClass === e;
				}, hasPostfixPart = (e, t) => {
					const r = t.type;
					return ("MemberExpression" === r || "OptionalMemberExpression" === r) && t.object === e || ("CallExpression" === r || "OptionalCallExpression" === r || "NewExpression" === r) && t.callee === e || "TaggedTemplateExpression" === r && t.tag === e || "TSNonNullExpression" === r;
				};
				function needsParenBeforeExpressionBrace(e) {
					return Boolean(e & (s.TokenContext.expressionStatement | s.TokenContext.arrowBody));
				}
				function Binary(e, t) {
					const r = t.type;
					if ("BinaryExpression" === e.type && "**" === e.operator && "BinaryExpression" === r && "**" === t.operator) return t.left === e;
					if (isClassExtendsClause(e, t)) return !0;
					if (hasPostfixPart(e, t) || "UnaryExpression" === r || "SpreadElement" === r || "AwaitExpression" === r) return !0;
					const n = getBinaryPrecedence(t, r);
					if (null != n) {
						const s = getBinaryPrecedence(e, e.type);
						if (n === s && "BinaryExpression" === r && t.right === e || n > s) return !0;
					}
				}
				function UnaryLike(e, t) {
					return hasPostfixPart(e, t) || o(t) && "**" === t.operator && t.left === e || isClassExtendsClause(e, t);
				}
				function ConditionalExpression(e, t) {
					const r = t.type;
					return !!("UnaryExpression" === r || "SpreadElement" === r || "BinaryExpression" === r || "LogicalExpression" === r || "ConditionalExpression" === r && t.test === e || "AwaitExpression" === r || isTSTypeExpression(r)) || UnaryLike(e, t);
				}
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/node/whitespace.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.nodes = void 0;
				const { FLIPPED_ALIAS_KEYS: s, isArrayExpression: i, isAssignmentExpression: o, isBinary: a, isBlockStatement: l, isCallExpression: p, isFunction: c, isIdentifier: u, isLiteral: d, isMemberExpression: h, isObjectExpression: m, isOptionalCallExpression: f, isOptionalMemberExpression: y, isStringLiteral: b } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
				function crawlInternal(e, t) {
					return e ? (h(e) || y(e) ? (crawlInternal(e.object, t), e.computed && crawlInternal(e.property, t)) : a(e) || o(e) ? (crawlInternal(e.left, t), crawlInternal(e.right, t)) : p(e) || f(e) ? (t.hasCall = !0, crawlInternal(e.callee, t)) : c(e) ? t.hasFunction = !0 : u(e) && (t.hasHelper = t.hasHelper || e.callee && isHelper(e.callee)), t) : t;
				}
				function crawl(e) {
					return crawlInternal(e, {
						hasCall: !1,
						hasFunction: !1,
						hasHelper: !1
					});
				}
				function isHelper(e) {
					return !!e && (h(e) ? isHelper(e.object) || isHelper(e.property) : u(e) ? "require" === e.name || 95 === e.name.charCodeAt(0) : p(e) ? isHelper(e.callee) : !(!a(e) && !o(e)) && (u(e.left) && isHelper(e.left) || isHelper(e.right)));
				}
				function isType(e) {
					return d(e) || m(e) || i(e) || u(e) || h(e);
				}
				const g = t.nodes = {
					AssignmentExpression(e) {
						const t = crawl(e.right);
						if (t.hasCall && t.hasHelper || t.hasFunction) return t.hasFunction ? 3 : 2;
					},
					SwitchCase: (e, t) => (e.consequent.length || t.cases[0] === e ? 1 : 0) | (e.consequent.length || t.cases[t.cases.length - 1] !== e ? 0 : 2),
					LogicalExpression(e) {
						if (c(e.left) || c(e.right)) return 2;
					},
					Literal(e) {
						if (b(e) && "use strict" === e.value) return 2;
					},
					CallExpression(e) {
						if (c(e.callee) || isHelper(e)) return 3;
					},
					OptionalCallExpression(e) {
						if (c(e.callee)) return 3;
					},
					VariableDeclaration(e) {
						for (let t = 0; t < e.declarations.length; t++) {
							const r = e.declarations[t];
							let n = isHelper(r.id) && !isType(r.init);
							if (!n && r.init) {
								const e = crawl(r.init);
								n = isHelper(r.init) && e.hasCall || e.hasFunction;
							}
							if (n) return 3;
						}
					},
					IfStatement(e) {
						if (l(e.consequent)) return 3;
					}
				};
				g.ObjectProperty = g.ObjectTypeProperty = g.ObjectMethod = function(e, t) {
					if (t.properties[0] === e) return 1;
				}, g.ObjectTypeCallProperty = function(e, t) {
					var r;
					if (t.callProperties[0] === e && (null == (r = t.properties) || !r.length)) return 1;
				}, g.ObjectTypeIndexer = function(e, t) {
					var r, n;
					if (!(t.indexers[0] !== e || null != (r = t.properties) && r.length || null != (n = t.callProperties) && n.length)) return 1;
				}, g.ObjectTypeInternalSlot = function(e, t) {
					var r, n, s;
					if (!(t.internalSlots[0] !== e || null != (r = t.properties) && r.length || null != (n = t.callProperties) && n.length || null != (s = t.indexers) && s.length)) return 1;
				}, [
					["Function", !0],
					["Class", !0],
					["Loop", !0],
					["LabeledStatement", !0],
					["SwitchStatement", !0],
					["TryStatement", !0]
				].forEach(function([e, t]) {
					[e].concat(s[e] || []).forEach(function(e) {
						const r = t ? 3 : 0;
						g[e] = () => r;
					});
				});
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/printer.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/buffer.js"), s = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/node/index.js"), i = s, o = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), a = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/token-map.js"), l = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/index.js"), p = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/generators/deprecated.js");
				const { isExpression: c, isFunction: u, isStatement: d, isClassBody: h, isTSInterfaceBody: m, isTSEnumMember: f } = o, y = /e/i, b = /\.0+$/, g = /[\n\r\u2028\u2029]/, x = /[\n\r\u2028\u2029]|\*\//;
				function commentIsNewline(e) {
					return "CommentLine" === e.type || g.test(e.value);
				}
				const { needsParens: v } = i;
				class Printer {
					constructor(e, t, r, i) {
						this.tokenContext = s.TokenContext.normal, this._tokens = null, this._originalCode = null, this._currentNode = null, this._indent = 0, this._indentRepeat = 0, this._insideAux = !1, this._noLineTerminator = !1, this._noLineTerminatorAfterNode = null, this._printAuxAfterOnNextUserNode = !1, this._printedComments = /* @__PURE__ */ new Set(), this._endsWithInteger = !1, this._endsWithWord = !1, this._endsWithDiv = !1, this._lastCommentLine = 0, this._endsWithInnerRaw = !1, this._indentInnerComments = !0, this.tokenMap = null, this._boundGetRawIdentifier = this._getRawIdentifier.bind(this), this._printSemicolonBeforeNextNode = -1, this._printSemicolonBeforeNextToken = -1, this.format = e, this._tokens = r, this._originalCode = i, this._indentRepeat = e.indent.style.length, this._inputMap = null == t ? void 0 : t._inputMap, this._buf = new n.default(t, e.indent.style[0]);
					}
					enterForStatementInit() {
						return this.tokenContext |= s.TokenContext.forInitHead | s.TokenContext.forInOrInitHeadAccumulate, () => this.tokenContext = s.TokenContext.normal;
					}
					enterForXStatementInit(e) {
						return e ? (this.tokenContext |= s.TokenContext.forOfHead, null) : (this.tokenContext |= s.TokenContext.forInHead | s.TokenContext.forInOrInitHeadAccumulate, () => this.tokenContext = s.TokenContext.normal);
					}
					enterDelimited() {
						const e = this.tokenContext, t = this._noLineTerminatorAfterNode;
						return e & s.TokenContext.forInOrInitHeadAccumulate || null !== t ? (this._noLineTerminatorAfterNode = null, this.tokenContext = s.TokenContext.normal, () => {
							this._noLineTerminatorAfterNode = t, this.tokenContext = e;
						}) : () => {};
					}
					generate(e) {
						return this.format.preserveFormat && (this.tokenMap = new a.TokenMap(e, this._tokens, this._originalCode)), this.print(e), this._maybeAddAuxComment(), this._buf.get();
					}
					indent() {
						const { format: e } = this;
						e.preserveFormat || e.compact || e.concise || this._indent++;
					}
					dedent() {
						const { format: e } = this;
						e.preserveFormat || e.compact || e.concise || this._indent--;
					}
					semicolon(e = !1) {
						if (this._maybeAddAuxComment(), e) return this._appendChar(59), void (this._noLineTerminator = !1);
						if (this.tokenMap) {
							const e = this._currentNode;
							if (null != e.start && null != e.end) {
								if (!this.tokenMap.endMatches(e, ";")) return void (this._printSemicolonBeforeNextNode = this._buf.getCurrentLine());
								const t = this.tokenMap.getIndexes(this._currentNode);
								this._catchUpTo(this._tokens[t[t.length - 1]].loc.start);
							}
						}
						this._queue(59), this._noLineTerminator = !1;
					}
					rightBrace(e) {
						this.format.minified && this._buf.removeLastSemicolon(), this.sourceWithOffset("end", e.loc, -1), this.tokenChar(125);
					}
					rightParens(e) {
						this.sourceWithOffset("end", e.loc, -1), this.tokenChar(41);
					}
					space(e = !1) {
						const { format: t } = this;
						if (!t.compact && !t.preserveFormat) {
							if (e) this._space();
							else if (this._buf.hasContent()) {
								const e = this.getLastChar();
								32 !== e && 10 !== e && this._space();
							}
						}
					}
					word(e, t = !1) {
						this.tokenContext &= s.TokenContext.forInOrInitHeadAccumulatePassThroughMask, this._maybePrintInnerComments(e), this._maybeAddAuxComment(), this.tokenMap && this._catchUpToCurrentToken(e), (this._endsWithWord || this._endsWithDiv && 47 === e.charCodeAt(0)) && this._space(), this._append(e, !1), this._endsWithWord = !0, this._noLineTerminator = t;
					}
					number(e, t) {
						this.word(e), this._endsWithInteger = Number.isInteger(t) && !function(e) {
							if (e.length > 2 && 48 === e.charCodeAt(0)) {
								const t = e.charCodeAt(1);
								return 98 === t || 111 === t || 120 === t;
							}
							return !1;
						}(e) && !y.test(e) && !b.test(e) && 46 !== e.charCodeAt(e.length - 1);
					}
					token(e, t = !1, r = 0) {
						this.tokenContext &= s.TokenContext.forInOrInitHeadAccumulatePassThroughMask, this._maybePrintInnerComments(e, r), this._maybeAddAuxComment(), this.tokenMap && this._catchUpToCurrentToken(e, r);
						const n = this.getLastChar(), i = e.charCodeAt(0);
						(33 === n && ("--" === e || 61 === i) || 43 === i && 43 === n || 45 === i && 45 === n || 46 === i && this._endsWithInteger) && this._space(), this._append(e, t), this._noLineTerminator = !1;
					}
					tokenChar(e) {
						this.tokenContext &= s.TokenContext.forInOrInitHeadAccumulatePassThroughMask;
						const t = String.fromCharCode(e);
						this._maybePrintInnerComments(t), this._maybeAddAuxComment(), this.tokenMap && this._catchUpToCurrentToken(t);
						const r = this.getLastChar();
						(43 === e && 43 === r || 45 === e && 45 === r || 46 === e && this._endsWithInteger) && this._space(), this._appendChar(e), this._noLineTerminator = !1;
					}
					newline(e = 1, t) {
						if (!(e <= 0)) {
							if (!t) {
								if (this.format.retainLines || this.format.compact) return;
								if (this.format.concise) return void this.space();
							}
							e > 2 && (e = 2), e -= this._buf.getNewlineCount();
							for (let t = 0; t < e; t++) this._newline();
						}
					}
					endsWith(e) {
						return this.getLastChar() === e;
					}
					getLastChar() {
						return this._buf.getLastChar();
					}
					endsWithCharAndNewline() {
						return this._buf.endsWithCharAndNewline();
					}
					removeTrailingNewline() {
						this._buf.removeTrailingNewline();
					}
					exactSource(e, t) {
						e ? (this._catchUp("start", e), this._buf.exactSource(e, t)) : t();
					}
					source(e, t) {
						t && (this._catchUp(e, t), this._buf.source(e, t));
					}
					sourceWithOffset(e, t, r) {
						t && !this.format.preserveFormat && (this._catchUp(e, t), this._buf.sourceWithOffset(e, t, r));
					}
					sourceIdentifierName(e, t) {
						if (!this._buf._canMarkIdName) return;
						const r = this._buf._sourcePosition;
						r.identifierNamePos = t, r.identifierName = e;
					}
					_space() {
						this._queue(32);
					}
					_newline() {
						this._queue(10);
					}
					_catchUpToCurrentToken(e, t = 0) {
						const r = this.tokenMap.findMatching(this._currentNode, e, t);
						r && this._catchUpTo(r.loc.start), -1 !== this._printSemicolonBeforeNextToken && this._printSemicolonBeforeNextToken === this._buf.getCurrentLine() && (this._buf.appendChar(59), this._endsWithWord = !1, this._endsWithInteger = !1, this._endsWithDiv = !1), this._printSemicolonBeforeNextToken = -1, this._printSemicolonBeforeNextNode = -1;
					}
					_append(e, t) {
						this._maybeIndent(e.charCodeAt(0)), this._buf.append(e, t), this._endsWithWord = !1, this._endsWithInteger = !1, this._endsWithDiv = !1;
					}
					_appendChar(e) {
						this._maybeIndent(e), this._buf.appendChar(e), this._endsWithWord = !1, this._endsWithInteger = !1, this._endsWithDiv = !1;
					}
					_queue(e) {
						this._maybeIndent(e), this._buf.queue(e), this._endsWithWord = !1, this._endsWithInteger = !1;
					}
					_maybeIndent(e) {
						this._indent && 10 !== e && this.endsWith(10) && this._buf.queueIndentation(this._getIndent());
					}
					_shouldIndent(e) {
						if (this._indent && 10 !== e && this.endsWith(10)) return !0;
					}
					catchUp(e) {
						if (!this.format.retainLines) return;
						const t = e - this._buf.getCurrentLine();
						for (let e = 0; e < t; e++) this._newline();
					}
					_catchUp(e, t) {
						const { format: r } = this;
						if (!r.preserveFormat) return void (r.retainLines && null != t && t[e] && this.catchUp(t[e].line));
						const n = null == t ? void 0 : t[e];
						null != n && this._catchUpTo(n);
					}
					_catchUpTo({ line: e, column: t, index: r }) {
						const n = e - this._buf.getCurrentLine();
						if (n > 0 && this._noLineTerminator) return;
						for (let e = 0; e < n; e++) this._newline();
						const s = n > 0 ? t : t - this._buf.getCurrentColumn();
						if (s > 0) {
							const e = this._originalCode ? this._originalCode.slice(r - s, r).replace(/[^\t\x0B\f \xA0\u1680\u2000-\u200A\u202F\u205F\u3000\uFEFF]/gu, " ") : " ".repeat(s);
							this._append(e, !1);
						}
					}
					_getIndent() {
						return this._indentRepeat * this._indent;
					}
					printTerminatorless(e) {
						this._noLineTerminator = !0, this.print(e);
					}
					print(e, t, r) {
						var n, o, a;
						if (!e) return;
						this._endsWithInnerRaw = !1;
						const l = e.type, p = this.format, u = p.concise;
						e._compact && (p.concise = !0);
						const d = this[l];
						if (void 0 === d) throw new ReferenceError(`unknown node of type ${JSON.stringify(l)} with constructor ${JSON.stringify(e.constructor.name)}`);
						const h = this._currentNode;
						this._currentNode = e, this.tokenMap && (this._printSemicolonBeforeNextToken = this._printSemicolonBeforeNextNode);
						const m = this._insideAux;
						this._insideAux = null == e.loc, this._maybeAddAuxComment(this._insideAux && !m);
						const f = null == (n = e.extra) ? void 0 : n.parenthesized;
						let y = f && p.preserveFormat || f && p.retainFunctionParens && "FunctionExpression" === l || v(e, h, this.tokenContext, p.preserveFormat ? this._boundGetRawIdentifier : void 0);
						if (!y && f && null != (o = e.leadingComments) && o.length && "CommentBlock" === e.leadingComments[0].type) switch (null == h ? void 0 : h.type) {
							case "ExpressionStatement":
							case "VariableDeclarator":
							case "AssignmentExpression":
							case "ReturnStatement": break;
							case "CallExpression":
							case "OptionalCallExpression":
							case "NewExpression": if (h.callee !== e) break;
							default: y = !0;
						}
						let b, g, x = !1;
						var E;
						(!y && this._noLineTerminator && (null != (a = e.leadingComments) && a.some(commentIsNewline) || this.format.retainLines && e.loc && e.loc.start.line > this._buf.getCurrentLine()) && (y = !0, x = !0), y) || (t || (t = h && this._noLineTerminatorAfterNode === h && i.isLastChild(h, e)), t && (null != (E = e.trailingComments) && E.some(commentIsNewline) ? c(e) && (y = !0) : (b = this._noLineTerminatorAfterNode, this._noLineTerminatorAfterNode = e)));
						y && (this.tokenChar(40), x && this.indent(), this._endsWithInnerRaw = !1, this.tokenContext & s.TokenContext.forInOrInitHeadAccumulate && (g = this.tokenContext, this.tokenContext = s.TokenContext.normal), b = this._noLineTerminatorAfterNode, this._noLineTerminatorAfterNode = null), this._lastCommentLine = 0, this._printLeadingComments(e, h);
						const T = "Program" === l || "File" === l ? null : e.loc;
						this.exactSource(T, d.bind(this, e, h)), y ? (this._printTrailingComments(e, h), x && (this.dedent(), this.newline()), this.tokenChar(41), this._noLineTerminator = t, g && (this.tokenContext = g)) : t && !this._noLineTerminator ? (this._noLineTerminator = !0, this._printTrailingComments(e, h)) : this._printTrailingComments(e, h, r), this._currentNode = h, p.concise = u, this._insideAux = m, void 0 !== b && (this._noLineTerminatorAfterNode = b), this._endsWithInnerRaw = !1;
					}
					_maybeAddAuxComment(e) {
						e && this._printAuxBeforeComment(), this._insideAux || this._printAuxAfterComment();
					}
					_printAuxBeforeComment() {
						if (this._printAuxAfterOnNextUserNode) return;
						this._printAuxAfterOnNextUserNode = !0;
						const e = this.format.auxiliaryCommentBefore;
						e && this._printComment({
							type: "CommentBlock",
							value: e
						}, 0);
					}
					_printAuxAfterComment() {
						if (!this._printAuxAfterOnNextUserNode) return;
						this._printAuxAfterOnNextUserNode = !1;
						const e = this.format.auxiliaryCommentAfter;
						e && this._printComment({
							type: "CommentBlock",
							value: e
						}, 0);
					}
					getPossibleRaw(e) {
						const t = e.extra;
						if (null != (null == t ? void 0 : t.raw) && null != t.rawValue && e.value === t.rawValue) return t.raw;
					}
					printJoin(e, t, r, n, s, i, o, a) {
						if (null == e || !e.length) return;
						if (null == r && this.format.retainLines) {
							var l;
							const t = null == (l = e[0].loc) ? void 0 : l.start.line;
							null != t && t !== this._buf.getCurrentLine() && (r = !0);
						}
						r && this.indent();
						const p = {
							addNewlines: i,
							nextNodeStartLine: 0
						}, c = null == n ? void 0 : n.bind(this), u = e.length;
						for (let r = 0; r < u; r++) {
							const n = e[r];
							var d;
							if (n) {
								if (t && this._printNewline(0 === r, p), this.print(n, void 0, a || 0), o?.(n, r), null != c && (r < u - 1 ? c(r, !1) : s && c(r, !0)), t) if (null != (d = n.trailingComments) && d.length || (this._lastCommentLine = 0), r + 1 === u) this.newline(1);
								else {
									var h;
									p.nextNodeStartLine = (null == (h = e[r + 1].loc) ? void 0 : h.start.line) || 0, this._printNewline(!0, p);
								}
							}
						}
						r && this.dedent();
					}
					printAndIndentOnComments(e) {
						const t = e.leadingComments && e.leadingComments.length > 0;
						t && this.indent(), this.print(e), t && this.dedent();
					}
					printBlock(e) {
						const t = e.body;
						"EmptyStatement" !== t.type && this.space(), this.print(t);
					}
					_printTrailingComments(e, t, r) {
						const { innerComments: n, trailingComments: s } = e;
						null != n && n.length && this._printComments(2, n, e, t, r), null != s && s.length && this._printComments(2, s, e, t, r);
					}
					_printLeadingComments(e, t) {
						const r = e.leadingComments;
						null != r && r.length && this._printComments(0, r, e, t);
					}
					_maybePrintInnerComments(e, t) {
						var r;
						this._endsWithInnerRaw && this.printInnerComments(null == (r = this.tokenMap) ? void 0 : r.findMatching(this._currentNode, e, t));
						this._endsWithInnerRaw = !0, this._indentInnerComments = !0;
					}
					printInnerComments(e) {
						const t = this._currentNode, r = t.innerComments;
						if (null == r || !r.length) return;
						const n = this.endsWith(32), s = this._indentInnerComments, i = this._printedComments.size;
						s && this.indent(), this._printComments(1, r, t, void 0, void 0, e), n && i !== this._printedComments.size && this.space(), s && this.dedent();
					}
					noIndentInnerCommentsHere() {
						this._indentInnerComments = !1;
					}
					printSequence(e, t, r, n) {
						this.printJoin(e, !0, null != t && t, void 0, void 0, n, void 0, r);
					}
					printList(e, t, r, n, s, i) {
						this.printJoin(e, r, n, null != s ? s : commaSeparator, t, void 0, i);
					}
					shouldPrintTrailingComma(e) {
						if (!this.tokenMap) return null;
						const t = this.tokenMap.findLastIndex(this._currentNode, (t) => this.tokenMap.matchesOriginal(t, e));
						return t <= 0 ? null : this.tokenMap.matchesOriginal(this._tokens[t - 1], ",");
					}
					_printNewline(e, t) {
						const r = this.format;
						if (r.retainLines || r.compact) return;
						if (r.concise) return void this.space();
						if (!e) return;
						const n = t.nextNodeStartLine, s = this._lastCommentLine;
						if (n > 0 && s > 0) {
							const e = n - s;
							if (e >= 0) return void this.newline(e || 1);
						}
						this._buf.hasContent() && this.newline(1);
					}
					_shouldPrintComment(e, t) {
						if (e.ignore) return 0;
						if (this._printedComments.has(e)) return 0;
						if (this._noLineTerminator && x.test(e.value)) return 2;
						if (t && this.tokenMap) {
							const r = this.tokenMap.find(this._currentNode, (t) => t.value === e.value);
							if (r && r.start > t.start) return 2;
						}
						return this._printedComments.add(e), this.format.shouldPrintComment(e.value) ? 1 : 0;
					}
					_printComment(e, t) {
						const r = this._noLineTerminator, n = "CommentBlock" === e.type, s = n && 1 !== t && !this._noLineTerminator;
						s && this._buf.hasContent() && 2 !== t && this.newline(1);
						const i = this.getLastChar();
						let o;
						if (91 !== i && 123 !== i && 40 !== i && this.space(), n) {
							if (o = `/*${e.value}*/`, this.format.indent.adjustMultilineComment) {
								var a;
								const t = null == (a = e.loc) ? void 0 : a.start.column;
								if (t) {
									const e = new RegExp("\\n\\s{1," + t + "}", "g");
									o = o.replace(e, "\n");
								}
								if (this.format.concise) o = o.replace(/\n(?!$)/g, "\n");
								else {
									let e = this.format.retainLines ? 0 : this._buf.getCurrentColumn();
									(this._shouldIndent(47) || this.format.retainLines) && (e += this._getIndent()), o = o.replace(/\n(?!$)/g, `\n${" ".repeat(e)}`);
								}
							}
						} else o = r ? `/*${e.value}*/` : `//${e.value}`;
						if (this._endsWithDiv && this._space(), this.tokenMap) {
							const { _printSemicolonBeforeNextToken: t, _printSemicolonBeforeNextNode: r } = this;
							this._printSemicolonBeforeNextToken = -1, this._printSemicolonBeforeNextNode = -1, this.source("start", e.loc), this._append(o, n), this._printSemicolonBeforeNextNode = r, this._printSemicolonBeforeNextToken = t;
						} else this.source("start", e.loc), this._append(o, n);
						n || r || this.newline(1, !0), s && 3 !== t && this.newline(1);
					}
					_printComments(e, t, r, n, s = 0, i) {
						const o = r.loc, a = t.length;
						let l = !!o;
						const p = l ? o.start.line : 0, c = l ? o.end.line : 0;
						let y = 0, b = 0;
						const x = this._noLineTerminator ? function() {} : this.newline.bind(this);
						for (let o = 0; o < a; o++) {
							const v = t[o], E = this._shouldPrintComment(v, i);
							if (2 === E) {
								l = !1;
								break;
							}
							if (l && v.loc && 1 === E) {
								const t = v.loc.start.line, r = v.loc.end.line;
								if (0 === e) {
									let e = 0;
									0 === o ? !this._buf.hasContent() || "CommentLine" !== v.type && t === r || (e = b = 1) : e = t - y, y = r, x(e), this._printComment(v, 1), o + 1 === a && (x(Math.max(p - y, b)), y = p);
								} else if (1 === e) {
									const e = t - (0 === o ? p : y);
									y = r, x(e), this._printComment(v, 1), o + 1 === a && (x(Math.min(1, c - y)), y = c);
								} else {
									const e = t - (0 === o ? c - s : y);
									y = r, x(e), this._printComment(v, 1);
								}
							} else {
								if (l = !1, 1 !== E) continue;
								if (1 === a) {
									const t = v.loc ? v.loc.start.line === v.loc.end.line : !g.test(v.value), s = t && !d(r) && !h(n) && !m(n) && !f(r);
									0 === e ? this._printComment(v, s && "ObjectExpression" !== r.type || t && u(n, { body: r }) ? 1 : 0) : s && 2 === e ? this._printComment(v, 1) : this._printComment(v, 0);
								} else 1 !== e || "ObjectExpression" === r.type && r.properties.length > 1 || "ClassBody" === r.type || "TSInterfaceBody" === r.type ? this._printComment(v, 0) : this._printComment(v, 0 === o ? 2 : o === a - 1 ? 3 : 0);
							}
						}
						2 === e && l && y && (this._lastCommentLine = y);
					}
				}
				Object.assign(Printer.prototype, l), (0, p.addDeprecatedGenerators)(Printer);
				t.default = Printer;
				function commaSeparator(e, t) {
					this.token(",", !1, e), t || this.space();
				}
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/source-map.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@jridgewell+gen-mapping@0.3.13/node_modules/@jridgewell/gen-mapping/dist/gen-mapping.umd.js"), s = r("./node_modules/.pnpm/@jridgewell+trace-mapping@0.3.31/node_modules/@jridgewell/trace-mapping/dist/trace-mapping.umd.js");
				t.default = class {
					constructor(e, t) {
						var r;
						this._map = void 0, this._rawMappings = void 0, this._sourceFileName = void 0, this._lastGenLine = 0, this._lastSourceLine = 0, this._lastSourceColumn = 0, this._inputMap = void 0;
						const i = this._map = new n.GenMapping({ sourceRoot: e.sourceRoot });
						if (this._sourceFileName = null == (r = e.sourceFileName) ? void 0 : r.replace(/\\/g, "/"), this._rawMappings = void 0, e.inputSourceMap) {
							this._inputMap = new s.TraceMap(e.inputSourceMap);
							const t = this._inputMap.resolvedSources;
							if (t.length) for (let e = 0; e < t.length; e++) {
								var o;
								(0, n.setSourceContent)(i, t[e], null == (o = this._inputMap.sourcesContent) ? void 0 : o[e]);
							}
						}
						if ("string" != typeof t || e.inputSourceMap) {
							if ("object" == typeof t) for (const e of Object.keys(t)) (0, n.setSourceContent)(i, e.replace(/\\/g, "/"), t[e]);
						} else (0, n.setSourceContent)(i, this._sourceFileName, t);
					}
					get() {
						return (0, n.toEncodedMap)(this._map);
					}
					getDecoded() {
						return (0, n.toDecodedMap)(this._map);
					}
					getRawMappings() {
						return this._rawMappings || (this._rawMappings = (0, n.allMappings)(this._map));
					}
					mark(e, t, r, i, o, a) {
						var l;
						let p;
						if (this._rawMappings = void 0, null != t) if (this._inputMap) {
							if (p = (0, s.originalPositionFor)(this._inputMap, {
								line: t,
								column: r
							}), !p.name && o) {
								const e = (0, s.originalPositionFor)(this._inputMap, o);
								e.name && (i = e.name);
							}
						} else p = {
							source: (null == a ? void 0 : a.replace(/\\/g, "/")) || this._sourceFileName,
							line: t,
							column: r
						};
						(0, n.maybeAddMapping)(this._map, {
							name: i,
							generated: e,
							source: null == (l = p) ? void 0 : l.source,
							original: p
						});
					}
				};
			},
			"./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/token-map.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.TokenMap = void 0;
				const { traverseFast: s, VISITOR_KEYS: i } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
				t.TokenMap = class {
					constructor(e, t, r) {
						this._tokens = void 0, this._source = void 0, this._nodesToTokenIndexes = /* @__PURE__ */ new Map(), this._nodesOccurrencesCountCache = /* @__PURE__ */ new Map(), this._tokensCache = /* @__PURE__ */ new Map(), this._tokens = t, this._source = r, s(e, (e) => {
							const t = this._getTokensIndexesOfNode(e);
							t.length > 0 && this._nodesToTokenIndexes.set(e, t);
						}), this._tokensCache = null;
					}
					has(e) {
						return this._nodesToTokenIndexes.has(e);
					}
					getIndexes(e) {
						return this._nodesToTokenIndexes.get(e);
					}
					find(e, t) {
						const r = this._nodesToTokenIndexes.get(e);
						if (r) for (let e = 0; e < r.length; e++) {
							const n = r[e], s = this._tokens[n];
							if (t(s, n)) return s;
						}
						return null;
					}
					findLastIndex(e, t) {
						const r = this._nodesToTokenIndexes.get(e);
						if (r) for (let e = r.length - 1; e >= 0; e--) {
							const n = r[e];
							if (t(this._tokens[n], n)) return n;
						}
						return -1;
					}
					findMatching(e, t, r = 0) {
						const n = this._nodesToTokenIndexes.get(e);
						if (n) {
							let s = 0;
							const i = r;
							if (i > 1) {
								const n = this._nodesOccurrencesCountCache.get(e);
								n && n.test === t && n.count < i && (s = n.i + 1, r -= n.count + 1);
							}
							for (; s < n.length; s++) {
								const o = this._tokens[n[s]];
								if (this.matchesOriginal(o, t)) {
									if (0 === r) return i > 0 && this._nodesOccurrencesCountCache.set(e, {
										test: t,
										count: i,
										i: s
									}), o;
									r--;
								}
							}
						}
						return null;
					}
					matchesOriginal(e, t) {
						return e.end - e.start === t.length && (null != e.value ? e.value === t : this._source.startsWith(t, e.start));
					}
					startMatches(e, t) {
						const r = this._nodesToTokenIndexes.get(e);
						if (!r) return !1;
						const n = this._tokens[r[0]];
						return n.start === e.start && this.matchesOriginal(n, t);
					}
					endMatches(e, t) {
						const r = this._nodesToTokenIndexes.get(e);
						if (!r) return !1;
						const n = this._tokens[r[r.length - 1]];
						return n.end === e.end && this.matchesOriginal(n, t);
					}
					_getTokensIndexesOfNode(e) {
						if (null == e.start || null == e.end) return [];
						const { first: t, last: r } = this._findTokensOfNode(e, 0, this._tokens.length - 1);
						let n = t;
						const s = function* (e) {
							if ("TemplateLiteral" === e.type) {
								yield e.quasis[0];
								for (let t = 1; t < e.quasis.length; t++) yield e.expressions[t - 1], yield e.quasis[t];
								return;
							}
							const t = i[e.type];
							for (const r of t) {
								const t = e[r];
								t && (Array.isArray(t) ? yield* t : yield t);
							}
						}(e);
						"ExportNamedDeclaration" !== e.type && "ExportDefaultDeclaration" !== e.type || !e.declaration || "ClassDeclaration" !== e.declaration.type || s.next();
						const o = [];
						for (const e of s) {
							if (null == e) continue;
							if (null == e.start || null == e.end) continue;
							const t = this._findTokensOfNode(e, n, r), s = t.first;
							for (let e = n; e < s; e++) o.push(e);
							n = t.last + 1;
						}
						for (let e = n; e <= r; e++) o.push(e);
						return o;
					}
					_findTokensOfNode(e, t, r) {
						const n = this._tokensCache.get(e);
						if (n) return n;
						const s = this._findFirstTokenOfNode(e.start, t, r), i = this._findLastTokenOfNode(e.end, s, r);
						return this._tokensCache.set(e, {
							first: s,
							last: i
						}), {
							first: s,
							last: i
						};
					}
					_findFirstTokenOfNode(e, t, r) {
						for (; t <= r;) {
							const n = r + t >> 1;
							if (e < this._tokens[n].start) r = n - 1;
							else {
								if (!(e > this._tokens[n].start)) return n;
								t = n + 1;
							}
						}
						return t;
					}
					_findLastTokenOfNode(e, t, r) {
						for (; t <= r;) {
							const n = r + t >> 1;
							if (e < this._tokens[n].end) r = n - 1;
							else {
								if (!(e > this._tokens[n].end)) return n;
								t = n + 1;
							}
						}
						return r;
					}
				};
			},
			"./node_modules/.pnpm/@babel+helper-annotate-as-pure@7.27.3/node_modules/@babel/helper-annotate-as-pure/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					const t = e.node || e;
					if (isPureAnnotated(t)) return;
					s(t, "leading", i);
				};
				const { addComment: s } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), i = "#__PURE__", isPureAnnotated = ({ leadingComments: e }) => !!e && e.some((e) => /[@#]__PURE__/.test(e.value));
			},
			"./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/decorators-2018-09.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.buildDecoratedClass = function(e, t, i, o) {
					const { node: a, scope: l } = t, p = l.generateUidIdentifier("initialize"), c = a.id && t.isDeclaration(), u = t.isInStrictMode(), { superClass: d } = a;
					a.type = "ClassDeclaration", a.id || (a.id = n.types.cloneNode(e));
					let h;
					d && (h = l.generateUidIdentifierBasedOnNode(a.superClass, "super"), a.superClass = h);
					const m = takeDecorators(a), f = n.types.arrayExpression(i.filter((e) => !e.node.abstract && "TSIndexSignature" !== e.node.type).map((e) => function(e, t, i, o) {
						const a = o.isClassMethod();
						if (o.isPrivate()) throw o.buildCodeFrameError(`Private ${a ? "methods" : "fields"} in decorated classes are not supported yet.`);
						if ("ClassAccessorProperty" === o.node.type) throw o.buildCodeFrameError("Accessor properties are not supported in 2018-09 decorator transform, please specify { \"version\": \"2021-12\" } instead.");
						if ("StaticBlock" === o.node.type) throw o.buildCodeFrameError("Static blocks are not supported in 2018-09 decorator transform, please specify { \"version\": \"2021-12\" } instead.");
						const { node: l, scope: p } = o;
						o.isTSDeclareMethod() || new s.default({
							methodPath: o,
							objectRef: t,
							superRef: i,
							file: e,
							refToPreserve: t
						}).replace();
						const c = [
							prop("kind", n.types.stringLiteral(n.types.isClassMethod(l) ? l.kind : "field")),
							prop("decorators", takeDecorators(l)),
							prop("static", l.static && n.types.booleanLiteral(!0)),
							prop("key", getKey(l))
						].filter(Boolean);
						if (a) o.ensureFunctionName ?? (o.ensureFunctionName = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js").NodePath.prototype.ensureFunctionName), o.ensureFunctionName(!1), c.push(prop("value", n.types.toExpression(o.node)));
						else n.types.isClassProperty(l) && l.value ? c.push((u = "value", d = n.template.statements.ast`return ${l.value}`, n.types.objectMethod("method", n.types.identifier(u), [], n.types.blockStatement(d)))) : c.push(prop("value", p.buildUndefinedNode()));
						var u, d;
						return o.remove(), n.types.objectExpression(c);
					}(o, a.id, h, e))), y = n.template.expression.ast`
    ${function(e) {
						return e.addHelper("decorate");
					}(o)}(
      ${m || n.types.nullLiteral()},
      function (${p}, ${d ? n.types.cloneNode(h) : null}) {
        ${a}
        return { F: ${n.types.cloneNode(a.id)}, d: ${f} };
      },
      ${d}
    )
  `;
					u || y.arguments[1].body.directives.push(n.types.directive(n.types.directiveLiteral("use strict")));
					let b = y, g = "arguments.1.body.body.0";
					c && (b = n.template.statement.ast`let ${e} = ${y}`, g = "declarations.0.init." + g);
					return {
						instanceNodes: [n.template.statement.ast`
        ${n.types.cloneNode(p)}(this)
      `],
						wrapClass: (e) => (e.replaceWith(b), e.get(g))
					};
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), s = r("./node_modules/.pnpm/@babel+helper-replace-supers@7.27.1_@babel+core@7.28.4/node_modules/@babel/helper-replace-supers/lib/index.js");
				function prop(e, t) {
					return t ? n.types.objectProperty(n.types.identifier(e), t) : null;
				}
				function takeDecorators(e) {
					let t;
					return e.decorators && e.decorators.length > 0 && (t = n.types.arrayExpression(e.decorators.map((e) => e.expression))), e.decorators = void 0, t;
				}
				function getKey(e) {
					return e.computed ? e.key : n.types.isIdentifier(e.key) ? n.types.stringLiteral(e.key.name) : n.types.stringLiteral(String(e.key.value));
				}
			},
			"./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/decorators.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.buildNamedEvaluationVisitor = buildNamedEvaluationVisitor, t.default = function({ assertVersion: e, assumption: t }, { loose: i }, c, y) {
					var b, g;
					e("2023-11" === c || "2023-05" === c || "2023-01" === c ? "^7.21.0" : "2021-12" === c ? "^7.16.0" : "^7.19.0");
					const x = /* @__PURE__ */ new WeakSet(), v = null != (b = t("constantSuper")) ? b : i, E = null != (g = t("ignoreFunctionLength")) ? g : i, T = buildNamedEvaluationVisitor(isDecoratedAnonymousClassExpression, visitClass);
					function visitClass(e, t, r) {
						var i;
						if (x.has(e)) return;
						const { node: y } = e;
						r ?? (r = null == (i = y.id) ? void 0 : i.name);
						const b = function(e, t, r, i, c, y, b) {
							var g;
							const x = e.get("body.body"), v = e.node.decorators;
							let E = !1, T = !1, S = !1;
							const P = function(e) {
								let t;
								return () => (t || (t = function(e) {
									const t = [], r = /* @__PURE__ */ new Set();
									return e.traverse({ PrivateName(e) {
										r.add(e.node.id.name);
									} }), () => {
										let e;
										do
											incrementId(t), e = String.fromCharCode(...t);
										while (r.has(e));
										return n.types.privateName(n.types.identifier(e));
									};
								}(e)), t());
							}(e), _ = [], A = e.scope.parent, memoiseExpression = (e, t, r) => {
								const s = generateLetUidIdentifier(A, t);
								return r.push(n.types.assignmentExpression("=", s, e)), n.types.cloneNode(s);
							};
							let C, w;
							const I = null == (g = e.node.id) ? void 0 : g.name, D = "object" == typeof c ? c : void 0, usesFunctionContextOrYieldAwait = (e) => {
								try {
									return n.types.traverseFast(e, (e) => {
										if (n.types.isThisExpression(e) || n.types.isSuper(e) || n.types.isYieldExpression(e) || n.types.isAwaitExpression(e) || n.types.isIdentifier(e, { name: "arguments" }) || I && n.types.isIdentifier(e, { name: I }) || n.types.isMetaProperty(e) && "import" !== e.meta.name) throw null;
									}), !1;
								} catch (e) {
									return !0;
								}
							}, k = [];
							for (const r of x) {
								if (!isClassDecoratableElementPath(r)) continue;
								const s = r.node;
								if (!s.static && n.types.isPrivateName(s.key) && k.push(s.key.id.name), isDecorated(s)) {
									switch (s.type) {
										case "ClassProperty":
											y.ClassProperty(r, t);
											break;
										case "ClassPrivateProperty":
											y.ClassPrivateProperty(r, t);
											break;
										case "ClassAccessorProperty": if (y.ClassAccessorProperty(r, t), "2023-11" === b) break;
										default: s.static ? w ?? (w = generateLetUidIdentifier(A, "initStatic")) : C ?? (C = generateLetUidIdentifier(A, "initProto"));
									}
									E = !0, S || (S = s.decorators.some(usesFunctionContextOrYieldAwait));
								} else if ("ClassAccessorProperty" === s.type) {
									y.ClassAccessorProperty(r, t);
									const { key: i, value: o, static: l, computed: p } = s, u = P(), d = generateClassProperty(u, o, l), h = r.get("key"), [m] = r.replaceWith(d);
									let f, g;
									p && !h.isConstantExpression() ? (f = (0, a.memoiseComputedKey)(createToPropertyKeyCall(t, i), A, A.generateUid("computedKey")), g = n.types.cloneNode(f.left)) : (f = n.types.cloneNode(i), g = n.types.cloneNode(i)), assignIdForAnonymousClass(e, c), addProxyAccessorsFor(e.node.id, m, f, g, u, p, l, b);
								}
								"computed" in r.node && r.node.computed && (T || (T = !A.isStatic(r.node.key)));
							}
							if (!v && !E) return e.node.id || "string" != typeof c || (e.node.id = n.types.identifier(c)), void (D && e.node.body.body.unshift(createStaticBlockFromExpressions([createSetFunctionNameCall(t, D)])));
							const N = [];
							let O;
							const j = /* @__PURE__ */ new Set();
							let F, L, M = null;
							function handleDecorators(e) {
								let t = !1, r = !1;
								const s = [];
								for (const i of e) {
									const { expression: e } = i;
									let o;
									"2023-11" !== b && "2023-05" !== b || !n.types.isMemberExpression(e) || (n.types.isSuper(e.object) ? o = n.types.thisExpression() : A.isStatic(e.object) ? o = n.types.cloneNode(e.object) : (M ?? (M = generateLetUidIdentifier(A, "obj")), o = n.types.assignmentExpression("=", n.types.cloneNode(M), e.object), e.object = n.types.cloneNode(M))), s.push(o), t || (t = !A.isStatic(e)), r || (r = usesFunctionContextOrYieldAwait(i));
								}
								return {
									hasSideEffects: t,
									usesFnContext: r,
									decoratorsThis: s
								};
							}
							const B = T || S || "2023-11" !== b;
							let R, U, V = !1, $ = 0, K = [], W = [];
							if (v) {
								F = generateLetUidIdentifier(A, "initClass"), V = e.isClassDeclaration(), {id: L, path: e} = function(e, t) {
									const r = e.node.id, s = e.scope;
									if ("ClassDeclaration" === e.type) {
										const t = r.name, i = s.generateUidIdentifierBasedOnNode(r), o = n.types.identifier(t);
										return s.rename(t, i.name), e.get("id").replaceWith(o), {
											id: n.types.cloneNode(i),
											path: e
										};
									}
									{
										let i;
										r ? (t = r.name, i = generateLetUidIdentifier(s.parent, t), s.rename(t, i.name)) : i = generateLetUidIdentifier(s.parent, "string" == typeof t ? t : "decorated_class");
										const o = n.types.classExpression("string" == typeof t ? n.types.identifier(t) : null, e.node.superClass, e.node.body), [a] = e.replaceWith(n.types.sequenceExpression([o, i]));
										return {
											id: n.types.cloneNode(i),
											path: a.get("expressions.0")
										};
									}
								}(e, c), e.node.decorators = null;
								const t = v.some(usesPrivateField), { hasSideEffects: r, usesFnContext: s, decoratorsThis: i } = handleDecorators(v), { haveThis: o, decs: l } = generateDecorationList(v, i, b);
								if ($ = o ? 1 : 0, K = l, (s || r && B || t) && (R = memoiseExpression(n.types.arrayExpression(K), "classDecs", _)), !E) for (const t of e.get("body.body")) {
									const { node: e } = t;
									if ("computed" in e && e.computed) if (t.isClassProperty({ static: !0 })) {
										if (!t.get("key").isConstantExpression()) {
											const t = e.key, r = (0, a.memoiseComputedKey)(t, A, A.generateUid("computedKey"));
											null != r && (e.key = n.types.cloneNode(r.left), W.push(r));
										}
									} else W.length > 0 && (prependExpressionsToComputedKey(W, t), W = []);
								}
							} else assignIdForAnonymousClass(e, c), L = n.types.cloneNode(e.node.id);
							let q = !1, H = [], z = [];
							if (E) {
								if (C) {
									const e = n.types.callExpression(n.types.cloneNode(C), [n.types.thisExpression()]);
									H.push(e);
								}
								for (const i of x) {
									if (!isClassDecoratableElementPath(i)) {
										z.length > 0 && i.isStaticBlock() && (prependExpressionsToStaticBlock(z, i), z = []);
										continue;
									}
									const { node: o } = i, h = o.decorators, m = !(null == h || !h.length), f = "computed" in o && o.computed;
									let y, g, x = "computedKey";
									if ("PrivateName" === o.key.type ? x = o.key.id.name : f || "Identifier" !== o.key.type || (x = o.key.name), m) {
										const { hasSideEffects: e, usesFnContext: t, decoratorsThis: r } = handleDecorators(h), { decs: s, haveThis: i } = generateDecorationList(h, r, b);
										g = i, y = 1 === s.length ? s[0] : n.types.arrayExpression(s), (t || e && B) && (y = memoiseExpression(y, x + "Decs", W));
									}
									if (f && !i.get("key").isConstantExpression()) {
										const e = o.key, r = (0, a.memoiseComputedKey)(m ? createToPropertyKeyCall(t, e) : e, A, A.generateUid("computedKey"));
										null != r && (v && i.isClassProperty({ static: !0 }) ? (o.key = n.types.cloneNode(r.left), W.push(r)) : o.key = r);
									}
									const { key: E, static: T } = o, S = "PrivateName" === E.type, _ = getElementKind(i);
									let C;
									if (S && !T && (m && (q = !0), !n.types.isClassPrivateProperty(o) && U || (U = E)), i.isClassMethod({ kind: "constructor" }) && (O = i), m) {
										let o, a;
										if (a = f ? getComputedKeyMemoiser(i.get("key")) : "PrivateName" === E.type ? n.types.stringLiteral(E.id.name) : "Identifier" === E.type ? n.types.stringLiteral(E.name) : n.types.cloneNode(E), _ === p) {
											const { value: t } = i.node, r = "2023-11" === b && T ? [] : [n.types.thisExpression()];
											t && r.push(n.types.cloneNode(t));
											const s = P(), a = generateLetUidIdentifier(A, `init_${x}`), l = generateClassProperty(s, n.types.callExpression(n.types.cloneNode(a), r), T), [p] = i.replaceWith(l);
											if (S) {
												o = extractProxyAccessorsFor(s, b);
												const e = generateLetUidIdentifier(A, `get_${x}`), t = generateLetUidIdentifier(A, `set_${x}`);
												addCallAccessorsFor(b, p, E, e, t, T), C = [
													a,
													e,
													t
												];
											} else assignIdForAnonymousClass(e, c), addProxyAccessorsFor(e.node.id, p, n.types.cloneNode(E), n.types.isAssignmentExpression(E) ? n.types.cloneNode(E.left) : n.types.cloneNode(E), s, f, T, b), C = [a];
										} else if (_ === l) {
											const e = generateLetUidIdentifier(A, `init_${x}`), t = i.get("value"), r = "2023-11" === b && T ? [] : [n.types.thisExpression()];
											t.node && r.push(t.node), t.replaceWith(n.types.callExpression(n.types.cloneNode(e), r)), C = [e], S && (o = extractProxyAccessorsFor(E, b));
										} else if (S) {
											const a = generateLetUidIdentifier(A, `call_${x}`);
											C = [a];
											if (new s.default({
												constantSuper: r,
												methodPath: i,
												objectRef: L,
												superRef: e.node.superClass,
												file: t.file,
												refToPreserve: L
											}).replace(), o = [createFunctionExpressionFromPrivateMethod(i.node)], _ === u || _ === d) movePrivateAccessor(i, n.types.cloneNode(E), n.types.cloneNode(a), T);
											else {
												const t = i.node;
												e.node.body.body.unshift(n.types.classPrivateProperty(E, n.types.cloneNode(a), [], t.static)), j.add(E.id.name), i.remove();
											}
										}
										N.push({
											kind: _,
											decoratorsArray: y,
											decoratorsHaveThis: g,
											name: a,
											isStatic: T,
											privateMethods: o,
											locals: C
										}), i.node && (i.node.decorators = null);
									}
									if (f && W.length > 0 && (v && i.isClassProperty({ static: !0 }) || (prependExpressionsToComputedKey(W, _ === p ? i.getNextSibling() : i), W = [])), H.length > 0 && !T && (_ === l || _ === p) && (prependExpressionsToFieldInitializer(H, i), H = []), z.length > 0 && T && (_ === l || _ === p) && (prependExpressionsToFieldInitializer(z, i), z = []), m && "2023-11" === b && (_ === l || _ === p)) {
										const e = generateLetUidIdentifier(A, `init_extra_${x}`);
										C.push(e);
										const t = n.types.callExpression(n.types.cloneNode(e), T ? [] : [n.types.thisExpression()]);
										T ? z.push(t) : H.push(t);
									}
								}
							}
							if (W.length > 0) {
								const t = e.get("body.body");
								let r;
								for (let e = t.length - 1; e >= 0; e--) {
									const s = t[e], i = s.node;
									if (i.computed) {
										if (v && n.types.isClassProperty(i, { static: !0 })) continue;
										r = s;
										break;
									}
								}
								null != r && (function(e, t) {
									const r = t.get("key"), s = getComputedKeyLastElement(r);
									if (s.isConstantExpression()) prependExpressionsToComputedKey(e, t);
									else {
										const i = r.scope.parent, o = (0, a.memoiseComputedKey)(s.node, i, i.generateUid("computedKey"));
										if (o) {
											const t = [...e, n.types.cloneNode(o.left)], r = s.parentPath;
											r.isSequenceExpression() ? r.pushContainer("expressions", t) : s.replaceWith(maybeSequenceExpression([n.types.cloneNode(o), ...t]));
										} else prependExpressionsToComputedKey(e, t);
									}
								}(W, r), W = []);
							}
							if (H.length > 0) {
								const t = !!e.node.superClass;
								O ? t ? function(e, t, r) {
									t.traverse({
										CallExpression: { exit(t) {
											if (!t.get("callee").isSuper()) return;
											const s = [t.node, ...e.map((e) => n.types.cloneNode(e))];
											t.isCompletionRecord() && s.push(n.types.thisExpression()), t.replaceWith(function(e, t) {
												if (t) {
													if (e.length >= 2 && isProtoInitCallExpression(e[1], t)) {
														const r = n.types.callExpression(n.types.cloneNode(t), [e[0]]);
														e.splice(0, 2, r);
													}
													e.length >= 2 && n.types.isThisExpression(e[e.length - 1]) && isProtoInitCallExpression(e[e.length - 2], t) && e.splice(e.length - 1, 1);
												}
												return maybeSequenceExpression(e);
											}(s, r)), t.skip();
										} },
										ClassMethod(e) {
											"constructor" === e.node.kind && e.skip();
										}
									});
								}(H, O, C) : function(e, t) {
									t.node.body.body.unshift(n.types.expressionStatement(maybeSequenceExpression(e)));
								}(H, O) : e.node.body.body.unshift(createConstructorFromExpressions(H, t)), H = [];
							}
							z.length > 0 && (e.node.body.body.push(createStaticBlockFromExpressions(z)), z = []);
							const G = (Y = N, [
								...Y.filter((e) => e.isStatic && e.kind >= p && e.kind <= d),
								...Y.filter((e) => !e.isStatic && e.kind >= p && e.kind <= d),
								...Y.filter((e) => e.isStatic && e.kind === l),
								...Y.filter((e) => !e.isStatic && e.kind === l)
							]), X = function(e, t) {
								return n.types.arrayExpression(e.map((e) => {
									let r = e.kind;
									return e.isStatic && (r += "2023-11" === t || "2023-05" === t ? m : h), e.decoratorsHaveThis && (r += f), n.types.arrayExpression([
										e.decoratorsArray,
										n.types.numericLiteral(r),
										e.name,
										...e.privateMethods || []
									]);
								}));
							}("2023-11" === b ? N : G, b), J = function(e) {
								const t = [];
								for (const r of e) {
									const { locals: e } = r;
									Array.isArray(e) ? t.push(...e) : void 0 !== e && t.push(e);
								}
								return t;
							}(G);
							var Y;
							C && J.push(C);
							w && J.push(w);
							const Q = [];
							let Z = !1;
							const ee = F && n.types.callExpression(n.types.cloneNode(F), []);
							let te = e;
							const re = e.node, ne = [];
							if (v) {
								Q.push(L, F);
								const o = [];
								if (e.get("body.body").forEach((a) => {
									if (a.isStaticBlock()) {
										if (hasInstancePrivateAccess(a, k)) {
											const e = memoiseExpression((l = a.node, n.types.functionExpression(null, [], n.types.blockStatement(l.body))), "staticBlock", ne);
											z.push(n.types.callExpression(n.types.memberExpression(e, n.types.identifier("call")), [n.types.thisExpression()]));
										} else z.push(function(e) {
											return n.types.callExpression(n.types.arrowFunctionExpression([], n.types.blockStatement(e.body)), []);
										}(a.node));
										a.remove();
									} else {
										var l;
										if ((a.isClassProperty() || a.isClassPrivateProperty()) && a.node.static) {
											const e = a.get("value");
											if (hasInstancePrivateAccess(e, k)) {
												const t = memoiseExpression(function(e) {
													return n.types.functionExpression(null, [], n.types.blockStatement([n.types.returnStatement(e)]));
												}(e.node), "fieldValue", ne);
												e.replaceWith(n.types.callExpression(n.types.memberExpression(t, n.types.identifier("call")), [n.types.thisExpression()]));
											}
											z.length > 0 && (prependExpressionsToFieldInitializer(z, a), z = []), a.node.static = !1, o.push(a.node), a.remove();
										} else if (a.isClassPrivateMethod({ static: !0 })) {
											if (hasInstancePrivateAccess(a, k)) {
												new s.default({
													constantSuper: r,
													methodPath: a,
													objectRef: L,
													superRef: e.node.superClass,
													file: t.file,
													refToPreserve: L
												}).replace();
												const o = memoiseExpression(createFunctionExpressionFromPrivateMethod(a.node), a.get("key.id").node.name, ne);
												i ? (a.node.params = [n.types.restElement(n.types.identifier("arg"))], a.node.body = n.types.blockStatement([n.types.returnStatement(n.types.callExpression(n.types.memberExpression(o, n.types.identifier("apply")), [n.types.thisExpression(), n.types.identifier("arg")]))])) : (a.node.params = a.node.params.map((e, t) => n.types.isRestElement(e) ? n.types.restElement(n.types.identifier("arg")) : n.types.identifier("_" + t)), a.node.body = n.types.blockStatement([n.types.returnStatement(n.types.callExpression(n.types.memberExpression(o, n.types.identifier("apply")), [n.types.thisExpression(), n.types.identifier("arguments")]))]));
											}
											a.node.static = !1, o.push(a.node), a.remove();
										}
									}
								}), o.length > 0 || z.length > 0) {
									const r = n.template.expression.ast`
        class extends ${t.addHelper("identity")} {}
      `;
									r.body.body = [n.types.classProperty(n.types.toExpression(re), void 0, void 0, void 0, !0, !0), ...o];
									const s = [], i = n.types.newExpression(r, []);
									z.length > 0 && s.push(...z), ee && (Z = !0, s.push(ee)), s.length > 0 ? (s.unshift(n.types.callExpression(n.types.super(), [n.types.cloneNode(L)])), r.body.body.push(createConstructorFromExpressions(s, !1))) : i.arguments.push(n.types.cloneNode(L));
									const [a] = e.replaceWith(i);
									te = a.get("callee").get("body").get("body.0.key");
								}
							}
							!Z && ee && e.node.body.body.push(n.types.staticBlock([n.types.expressionStatement(ee)]));
							let { superClass: se } = re;
							if (se && ("2023-11" === b || "2023-05" === b)) {
								const t = e.scope.maybeGenerateMemoised(se);
								t && (re.superClass = n.types.assignmentExpression("=", t, se), se = t);
							}
							const ie = n.types.staticBlock([]);
							re.body.body.unshift(ie);
							const oe = ie.body;
							if (W.length > 0) {
								const e = te.get("body.body");
								let t;
								for (const r of e) if ((r.isClassProperty() || r.isClassMethod()) && "constructor" !== r.node.kind) {
									t = r;
									break;
								}
								null != t ? (function(e) {
									const { node: t } = e;
									t.computed = !0, n.types.isIdentifier(t.key) && (t.key = n.types.stringLiteral(t.key.name));
								}(t), prependExpressionsToComputedKey(W, t)) : (re.body.body.unshift(n.types.classProperty(n.types.sequenceExpression([...W, n.types.stringLiteral("_")]), void 0, void 0, void 0, !0, !0)), oe.push(n.types.expressionStatement(n.types.unaryExpression("delete", n.types.memberExpression(n.types.thisExpression(), n.types.identifier("_")))))), W = [];
							}
							oe.push(n.types.expressionStatement(function(e, t, r, s, i, o, a, l, p, c) {
								let u, d;
								const h = [
									a ? createSetFunctionNameCall(p, a) : n.types.thisExpression(),
									s,
									r
								];
								"2023-11" !== c && h.splice(1, 2, r, s);
								if ("2021-12" === c || "2022-03" === c && !p.availableHelper("applyDecs2203R")) return u = n.types.arrayPattern([...e, ...t]), d = n.types.callExpression(p.addHelper("2021-12" === c ? "applyDecs" : "applyDecs2203"), h), n.types.assignmentExpression("=", u, d);
								"2022-03" === c ? d = n.types.callExpression(p.addHelper("applyDecs2203R"), h) : "2023-01" === c ? (o && h.push(createPrivateBrandCheckClosure(o)), d = n.types.callExpression(p.addHelper("applyDecs2301"), h)) : "2023-05" === c && ((o || l || 0 !== i.value) && h.push(i), o ? h.push(createPrivateBrandCheckClosure(o)) : l && h.push(n.types.unaryExpression("void", n.types.numericLiteral(0))), l && h.push(l), d = n.types.callExpression(p.addHelper("applyDecs2305"), h));
								"2023-11" === c && ((o || l || 0 !== i.value) && h.push(i), o ? h.push(createPrivateBrandCheckClosure(o)) : l && h.push(n.types.unaryExpression("void", n.types.numericLiteral(0))), l && h.push(l), d = n.types.callExpression(p.addHelper("applyDecs2311"), h));
								e.length > 0 ? t.length > 0 ? u = n.types.objectPattern([n.types.objectProperty(n.types.identifier("e"), n.types.arrayPattern(e)), n.types.objectProperty(n.types.identifier("c"), n.types.arrayPattern(t))]) : (u = n.types.arrayPattern(e), d = n.types.memberExpression(d, n.types.identifier("e"), !1, !1)) : (u = n.types.arrayPattern(t), d = n.types.memberExpression(d, n.types.identifier("c"), !1, !1));
								return n.types.assignmentExpression("=", u, d);
							}(J, Q, X, null != R ? R : n.types.arrayExpression(K), n.types.numericLiteral($), q ? U : null, D, n.types.cloneNode(se), t, b))), w && oe.push(n.types.expressionStatement(n.types.callExpression(n.types.cloneNode(w), [n.types.thisExpression()])));
							ne.length > 0 && oe.push(...ne.map((e) => n.types.expressionStatement(e)));
							if (e.insertBefore(_.map((e) => n.types.expressionStatement(e))), V) if (A.getBinding(L.name).constantViolations.length) {
								const t = A.generateUidIdentifier("t" + L.name), r = L;
								e.replaceWithMultiple([
									n.types.variableDeclaration("let", [n.types.variableDeclarator(n.types.cloneNode(r)), n.types.variableDeclarator(t)]),
									n.types.blockStatement([
										n.types.variableDeclaration("let", [n.types.variableDeclarator(n.types.cloneNode(L))]),
										e.node,
										n.types.expressionStatement(n.types.assignmentExpression("=", n.types.cloneNode(t), n.types.cloneNode(L)))
									]),
									n.types.expressionStatement(n.types.assignmentExpression("=", n.types.cloneNode(r), n.types.cloneNode(t)))
								]);
							} else e.insertBefore(n.types.variableDeclaration("let", [n.types.variableDeclarator(n.types.cloneNode(L))]));
							j.size > 0 && function(e, t) {
								const r = (0, o.privateNameVisitorFactory)({ PrivateName(e, t) {
									if (!t.privateNamesMap.has(e.node.id.name)) return;
									const r = e.parentPath, n = r.parentPath;
									if ("AssignmentExpression" === n.node.type && n.node.left === r.node || "UpdateExpression" === n.node.type || "RestElement" === n.node.type || "ArrayPattern" === n.node.type || "ObjectProperty" === n.node.type && n.node.value === r.node && "ObjectPattern" === n.parentPath.type || "ForOfStatement" === n.node.type && n.node.left === r.node) throw e.buildCodeFrameError(`Decorated private methods are read-only, but "#${e.node.id.name}" is updated via this expression.`);
								} }), n = /* @__PURE__ */ new Map();
								for (const e of t) n.set(e, null);
								e.traverse(r, { privateNamesMap: n });
							}(e, j);
							return e.scope.crawl(), e;
						}(e, t, v, E, r, T, c);
						b ? x.add(b) : x.add(e);
					}
					return {
						name: "proposal-decorators",
						inherits: y,
						visitor: Object.assign({
							ExportDefaultDeclaration(e, t) {
								const { declaration: s } = e.node;
								if ("ClassDeclaration" === (null == s ? void 0 : s.type) && isDecorated(s)) {
									const i = !s.id;
									e.splitExportDeclaration ?? (e.splitExportDeclaration = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js").NodePath.prototype.splitExportDeclaration);
									const o = e.splitExportDeclaration();
									i && visitClass(o, t, n.types.stringLiteral("default"));
								}
							},
							ExportNamedDeclaration(e) {
								const { declaration: t } = e.node;
								"ClassDeclaration" === (null == t ? void 0 : t.type) && isDecorated(t) && (e.splitExportDeclaration ?? (e.splitExportDeclaration = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js").NodePath.prototype.splitExportDeclaration), e.splitExportDeclaration());
							},
							Class(e, t) {
								visitClass(e, t, void 0);
							}
						}, T)
					};
				}, t.hasDecorators = function(e) {
					return hasOwnDecorators(e) || e.body.body.some(hasOwnDecorators);
				}, t.hasOwnDecorators = hasOwnDecorators;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), s = r("./node_modules/.pnpm/@babel+helper-replace-supers@7.27.1_@babel+core@7.28.4/node_modules/@babel/helper-replace-supers/lib/index.js"), i = r("./node_modules/.pnpm/@babel+helper-skip-transparent-expression-wrappers@7.27.1/node_modules/@babel/helper-skip-transparent-expression-wrappers/lib/index.js"), o = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/fields.js"), a = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/misc.js");
				function hasOwnDecorators(e) {
					var t;
					return !(null == (t = e.decorators) || !t.length);
				}
				function incrementId(e, t = e.length - 1) {
					if (-1 === t) return void e.unshift(65);
					const r = e[t];
					90 === r ? e[t] = 97 : 122 === r ? (e[t] = 65, incrementId(e, t - 1)) : e[t] = r + 1;
				}
				function generateClassProperty(e, t, r) {
					return "PrivateName" === e.type ? n.types.classPrivateProperty(e, t, void 0, r) : n.types.classProperty(e, t, void 0, void 0, r);
				}
				function assignIdForAnonymousClass(e, t) {
					e.node.id || (e.node.id = "string" == typeof t ? n.types.identifier(t) : e.scope.generateUidIdentifier("Class"));
				}
				function addProxyAccessorsFor(e, t, r, s, i, o, a, l) {
					const p = "2023-11" !== l && "2023-05" !== l || !a ? n.types.thisExpression() : e, c = n.types.blockStatement([n.types.returnStatement(n.types.memberExpression(n.types.cloneNode(p), n.types.cloneNode(i)))]), u = n.types.blockStatement([n.types.expressionStatement(n.types.assignmentExpression("=", n.types.memberExpression(n.types.cloneNode(p), n.types.cloneNode(i)), n.types.identifier("v")))]);
					let d, h;
					"PrivateName" === r.type ? (d = n.types.classPrivateMethod("get", r, [], c, a), h = n.types.classPrivateMethod("set", s, [n.types.identifier("v")], u, a)) : (d = n.types.classMethod("get", r, [], c, o, a), h = n.types.classMethod("set", s, [n.types.identifier("v")], u, o, a)), t.insertAfter(h), t.insertAfter(d);
				}
				function extractProxyAccessorsFor(e, t) {
					return "2023-11" !== t && "2023-05" !== t && "2023-01" !== t ? [n.template.expression.ast`
        function () {
          return this.${n.types.cloneNode(e)};
        }
      `, n.template.expression.ast`
        function (value) {
          this.${n.types.cloneNode(e)} = value;
        }
      `] : [n.template.expression.ast`
      o => o.${n.types.cloneNode(e)}
    `, n.template.expression.ast`
      (o, v) => o.${n.types.cloneNode(e)} = v
    `];
				}
				function getComputedKeyLastElement(e) {
					if ((e = (0, i.skipTransparentExprWrappers)(e)).isSequenceExpression()) {
						const t = e.get("expressions");
						return getComputedKeyLastElement(t[t.length - 1]);
					}
					return e;
				}
				function getComputedKeyMemoiser(e) {
					const t = getComputedKeyLastElement(e);
					if (t.isConstantExpression()) return n.types.cloneNode(e.node);
					if (t.isIdentifier() && e.scope.hasUid(t.node.name)) return n.types.cloneNode(e.node);
					if (t.isAssignmentExpression() && t.get("left").isIdentifier()) return n.types.cloneNode(t.node.left);
					throw new Error(`Internal Error: the computed key ${e.toString()} has not yet been memoised.`);
				}
				function prependExpressionsToComputedKey(e, t) {
					const r = t.get("key");
					r.isSequenceExpression() ? e.push(...r.node.expressions) : e.push(r.node), r.replaceWith(maybeSequenceExpression(e));
				}
				function prependExpressionsToFieldInitializer(e, t) {
					const r = t.get("value");
					r.node ? e.push(r.node) : e.length > 0 && (e[e.length - 1] = n.types.unaryExpression("void", e[e.length - 1])), r.replaceWith(maybeSequenceExpression(e));
				}
				function prependExpressionsToStaticBlock(e, t) {
					t.unshiftContainer("body", n.types.expressionStatement(maybeSequenceExpression(e)));
				}
				function isProtoInitCallExpression(e, t) {
					return n.types.isCallExpression(e) && n.types.isIdentifier(e.callee, { name: t.name });
				}
				function createConstructorFromExpressions(e, t) {
					const r = [n.types.expressionStatement(maybeSequenceExpression(e))];
					return t && r.unshift(n.types.expressionStatement(n.types.callExpression(n.types.super(), [n.types.spreadElement(n.types.identifier("args"))]))), n.types.classMethod("constructor", n.types.identifier("constructor"), t ? [n.types.restElement(n.types.identifier("args"))] : [], n.types.blockStatement(r));
				}
				function createStaticBlockFromExpressions(e) {
					return n.types.staticBlock([n.types.expressionStatement(maybeSequenceExpression(e))]);
				}
				const l = 0, p = 1, c = 2, u = 3, d = 4, h = 5, m = 8, f = 16;
				function getElementKind(e) {
					switch (e.node.type) {
						case "ClassProperty":
						case "ClassPrivateProperty": return l;
						case "ClassAccessorProperty": return p;
						case "ClassMethod":
						case "ClassPrivateMethod": return "get" === e.node.kind ? u : "set" === e.node.kind ? d : c;
					}
				}
				function generateDecorationList(e, t, r) {
					const s = e.length, i = t.some(Boolean), o = [];
					for (let a = 0; a < s; a++) "2023-11" !== r && "2023-05" !== r || !i || o.push(t[a] || n.types.unaryExpression("void", n.types.numericLiteral(0))), o.push(e[a].expression);
					return {
						haveThis: i,
						decs: o
					};
				}
				function addCallAccessorsFor(e, t, r, s, i, o) {
					t.insertAfter(n.types.classPrivateMethod("get", n.types.cloneNode(r), [], n.types.blockStatement([n.types.returnStatement(n.types.callExpression(n.types.cloneNode(s), "2023-11" === e && o ? [] : [n.types.thisExpression()]))]), o)), t.insertAfter(n.types.classPrivateMethod("set", n.types.cloneNode(r), [n.types.identifier("v")], n.types.blockStatement([n.types.expressionStatement(n.types.callExpression(n.types.cloneNode(i), "2023-11" === e && o ? [n.types.identifier("v")] : [n.types.thisExpression(), n.types.identifier("v")]))]), o));
				}
				function movePrivateAccessor(e, t, r, s) {
					let i, o;
					"set" === e.node.kind ? (i = [n.types.identifier("v")], o = [n.types.expressionStatement(n.types.callExpression(r, [n.types.thisExpression(), n.types.identifier("v")]))]) : (i = [], o = [n.types.returnStatement(n.types.callExpression(r, [n.types.thisExpression()]))]), e.replaceWith(n.types.classPrivateMethod(e.node.kind, n.types.cloneNode(t), i, n.types.blockStatement(o), s));
				}
				function isClassDecoratableElementPath(e) {
					const { type: t } = e;
					return "TSDeclareMethod" !== t && "TSIndexSignature" !== t && "StaticBlock" !== t;
				}
				function maybeSequenceExpression(e) {
					return 0 === e.length ? n.types.unaryExpression("void", n.types.numericLiteral(0)) : 1 === e.length ? e[0] : n.types.sequenceExpression(e);
				}
				function createFunctionExpressionFromPrivateMethod(e) {
					const { params: t, body: r, generator: s, async: i } = e;
					return n.types.functionExpression(void 0, t, r, s, i);
				}
				function createSetFunctionNameCall(e, t) {
					return n.types.callExpression(e.addHelper("setFunctionName"), [n.types.thisExpression(), t]);
				}
				function createToPropertyKeyCall(e, t) {
					return n.types.callExpression(e.addHelper("toPropertyKey"), [t]);
				}
				function createPrivateBrandCheckClosure(e) {
					return n.types.arrowFunctionExpression([n.types.identifier("_")], n.types.binaryExpression("in", n.types.cloneNode(e), n.types.identifier("_")));
				}
				function usesPrivateField(e) {
					try {
						return n.types.traverseFast(e, (e) => {
							if (n.types.isPrivateName(e)) throw null;
						}), !1;
					} catch (e) {
						return !0;
					}
				}
				function hasInstancePrivateAccess(e, t) {
					let r = !1;
					if (t.length > 0) {
						const n = (0, o.privateNameVisitorFactory)({ PrivateName(e, t) {
							t.privateNamesMap.has(e.node.id.name) && (r = !0, e.stop());
						} }), s = /* @__PURE__ */ new Map();
						for (const e of t) s.set(e, null);
						e.traverse(n, { privateNamesMap: s });
					}
					return r;
				}
				function isProtoKey(e) {
					return "Identifier" === e.type ? "__proto__" === e.name : "__proto__" === e.value;
				}
				function isDecorated(e) {
					return e.decorators && e.decorators.length > 0;
				}
				function shouldTransformElement(e) {
					switch (e.type) {
						case "ClassAccessorProperty": return !0;
						case "ClassMethod":
						case "ClassProperty":
						case "ClassPrivateMethod":
						case "ClassPrivateProperty": return isDecorated(e);
						default: return !1;
					}
				}
				function buildNamedEvaluationVisitor(e, t) {
					function handleComputedProperty(e, t, r) {
						switch (t.type) {
							case "StringLiteral": return n.types.stringLiteral(t.value);
							case "NumericLiteral":
							case "BigIntLiteral": {
								const r = t.value + "";
								return e.get("key").replaceWith(n.types.stringLiteral(r)), n.types.stringLiteral(r);
							}
							default: {
								const s = e.scope.maybeGenerateMemoised(t);
								return e.get("key").replaceWith(n.types.assignmentExpression("=", s, createToPropertyKeyCall(r, t))), n.types.cloneNode(s);
							}
						}
					}
					return {
						VariableDeclarator(r, n) {
							const s = r.node.id;
							if ("Identifier" === s.type) {
								const o = (0, i.skipTransparentExprWrappers)(r.get("init"));
								if (e(o)) {
									const e = s.name;
									t(o, n, e);
								}
							}
						},
						AssignmentExpression(r, n) {
							const s = r.node.left;
							if ("Identifier" === s.type) {
								const o = (0, i.skipTransparentExprWrappers)(r.get("right"));
								if (e(o)) switch (r.node.operator) {
									case "=":
									case "&&=":
									case "||=":
									case "??=": t(o, n, s.name);
								}
							}
						},
						AssignmentPattern(r, n) {
							const s = r.node.left;
							if ("Identifier" === s.type) {
								const o = (0, i.skipTransparentExprWrappers)(r.get("right"));
								if (e(o)) {
									const e = s.name;
									t(o, n, e);
								}
							}
						},
						ObjectExpression(r, s) {
							for (const o of r.get("properties")) {
								if (!o.isObjectProperty()) continue;
								const { node: r } = o, a = r.key, l = (0, i.skipTransparentExprWrappers)(o.get("value"));
								if (e(l)) {
									if (r.computed) t(l, s, handleComputedProperty(o, a, s));
									else if (!isProtoKey(a)) if ("Identifier" === a.type) t(l, s, a.name);
									else t(l, s, n.types.stringLiteral(a.value + ""));
								}
							}
						},
						ClassPrivateProperty(r, s) {
							const { node: o } = r, a = (0, i.skipTransparentExprWrappers)(r.get("value"));
							if (e(a)) t(a, s, n.types.stringLiteral("#" + o.key.id.name));
						},
						ClassAccessorProperty(r, s) {
							const { node: o } = r, a = o.key, l = (0, i.skipTransparentExprWrappers)(r.get("value"));
							if (e(l)) if (o.computed) t(l, s, handleComputedProperty(r, a, s));
							else if ("Identifier" === a.type) t(l, s, a.name);
							else if ("PrivateName" === a.type) t(l, s, n.types.stringLiteral("#" + a.id.name));
							else t(l, s, n.types.stringLiteral(a.value + ""));
						},
						ClassProperty(r, s) {
							const { node: o } = r, a = o.key, l = (0, i.skipTransparentExprWrappers)(r.get("value"));
							if (e(l)) if (o.computed) t(l, s, handleComputedProperty(r, a, s));
							else if ("Identifier" === a.type) t(l, s, a.name);
							else t(l, s, n.types.stringLiteral(a.value + ""));
						}
					};
				}
				function isDecoratedAnonymousClassExpression(e) {
					return e.isClassExpression({ id: null }) && (isDecorated(t = e.node) || t.body.body.some(shouldTransformElement));
					var t;
				}
				function generateLetUidIdentifier(e, t) {
					const r = e.generateUidIdentifier(t);
					return e.push({
						id: r,
						kind: "let"
					}), n.types.cloneNode(r);
				}
			},
			"./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/features.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.FEATURES = void 0, t.enableFeature = function(e, t, r) {
					hasFeature(e, t) && !canIgnoreLoose(e, t) || (e.set(o, e.get(o) | t), "#__internal__@babel/preset-env__prefer-true-but-false-is-ok-if-it-prevents-an-error" === r ? (setLoose(e, t, !0), e.set(l, e.get(l) | t)) : "#__internal__@babel/preset-env__prefer-false-but-true-is-ok-if-it-prevents-an-error" === r ? (setLoose(e, t, !1), e.set(l, e.get(l) | t)) : setLoose(e, t, r));
					let n;
					for (const [t, r] of i) {
						if (!hasFeature(e, t)) continue;
						if (canIgnoreLoose(e, t)) continue;
						const i = isLoose(e, t);
						if (n === !i) throw new Error("'loose' mode configuration must be the same for @babel/plugin-transform-class-properties, @babel/plugin-transform-private-methods and @babel/plugin-transform-private-property-in-object (when they are enabled).\n\n" + getBabelShowConfigForHint(e));
						n = i;
						var s = r;
					}
					if (void 0 !== n) for (const [t, r] of i) hasFeature(e, t) && isLoose(e, t) !== n && (setLoose(e, t, n), console.warn(`Though the "loose" option was set to "${!n}" in your @babel/preset-env config, it will not be used for ${r} since the "loose" mode option was set to "${n}" for ${s}.\nThe "loose" option must be the same for @babel/plugin-transform-class-properties, @babel/plugin-transform-private-methods and @babel/plugin-transform-private-property-in-object (when they are enabled): you can silence this warning by explicitly adding\n\t["${r}", { "loose": ${n} }]\nto the "plugins" section of your Babel config.\n\n` + getBabelShowConfigForHint(e)));
				}, t.isLoose = isLoose, t.shouldTransform = function(e, t) {
					let r = null, i = null, o = null, a = null, l = null;
					(0, n.hasOwnDecorators)(e.node) && (r = e.get("decorators.0"));
					for (const t of e.get("body.body")) !r && (0, n.hasOwnDecorators)(t.node) && (r = t.get("decorators.0")), !i && t.isClassProperty() && (i = t), !o && t.isClassPrivateProperty() && (o = t), !a && null != t.isClassPrivateMethod && t.isClassPrivateMethod() && (a = t), !l && null != t.isStaticBlock && t.isStaticBlock() && (l = t);
					if (r && o) throw o.buildCodeFrameError("Private fields in decorated classes are not supported yet.");
					if (r && a) throw a.buildCodeFrameError("Private methods in decorated classes are not supported yet.");
					if (r && !hasFeature(t, s.decorators)) throw e.buildCodeFrameError("Decorators are not enabled.\nIf you are using [\"@babel/plugin-proposal-decorators\", { \"version\": \"legacy\" }], make sure it comes *before* \"@babel/plugin-transform-class-properties\" and enable loose mode, like so:\n	[\"@babel/plugin-proposal-decorators\", { \"version\": \"legacy\" }]\n	[\"@babel/plugin-transform-class-properties\", { \"loose\": true }]");
					if (a && !hasFeature(t, s.privateMethods)) throw a.buildCodeFrameError("Class private methods are not enabled. Please add `@babel/plugin-transform-private-methods` to your configuration.");
					if ((i || o) && !hasFeature(t, s.fields) && !hasFeature(t, s.privateMethods)) throw e.buildCodeFrameError("Class fields are not enabled. Please add `@babel/plugin-transform-class-properties` to your configuration.");
					if (l && !hasFeature(t, s.staticBlocks)) throw e.buildCodeFrameError("Static class blocks are not enabled. Please add `@babel/plugin-transform-class-static-block` to your configuration.");
					if (r || a || l) return !0;
					if ((i || o) && hasFeature(t, s.fields)) return !0;
					return !1;
				};
				var n = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/decorators.js");
				const s = t.FEATURES = Object.freeze({
					fields: 2,
					privateMethods: 4,
					decorators: 8,
					privateIn: 16,
					staticBlocks: 32
				}), i = new Map([
					[s.fields, "@babel/plugin-transform-class-properties"],
					[s.privateMethods, "@babel/plugin-transform-private-methods"],
					[s.privateIn, "@babel/plugin-transform-private-property-in-object"]
				]), o = "@babel/plugin-class-features/featuresKey", a = "@babel/plugin-class-features/looseKey";
				var l = "@babel/plugin-class-features/looseLowPriorityKey/#__internal__@babel/preset-env__please-overwrite-loose-instead-of-throwing", canIgnoreLoose = function(e, t) {
					return !!(e.get(l) & t);
				};
				function getBabelShowConfigForHint(e) {
					let { filename: t } = e.opts;
					return t && "unknown" !== t || (t = "[name of the input file]"), `If you already set the same 'loose' mode for these plugins in your config, it's possible that they are enabled multiple times with different options.\nYou can re-run Babel with the BABEL_SHOW_CONFIG_FOR environment variable to show the loaded configuration:\n\tnpx cross-env BABEL_SHOW_CONFIG_FOR=${t} <your build command>\nSee https://babeljs.io/docs/configuration#print-effective-configs for more info.`;
				}
				function hasFeature(e, t) {
					return !!(e.get(o) & t);
				}
				function isLoose(e, t) {
					return !!(e.get(a) & t);
				}
				function setLoose(e, t, r) {
					r ? e.set(a, e.get(a) | t) : e.set(a, e.get(a) & ~t), e.set(l, e.get(l) & ~t);
				}
			},
			"./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/fields.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.buildCheckInRHS = buildCheckInRHS, t.buildFieldsInitNodes = function(e, t, r, s, o, a, l, p, u, d) {
					let h, m = 0;
					const f = [], y = [];
					let b = !1;
					const g = [];
					let x = null;
					const v = n.types.isIdentifier(t) ? () => t : () => (h ?? (h = r[0].scope.generateUidIdentifierBasedOnNode(t)), h), E = null != e ? e : r[0].scope.generateUidIdentifier((null == d ? void 0 : d.name) || "Class");
					e ?? (e = n.types.cloneNode(d));
					for (const t of r) {
						t.isClassProperty() && c.assertFieldTransformed(t);
						const r = !(null != n.types.isStaticBlock && n.types.isStaticBlock(t.node)) && t.node.static, h = !r, x = t.isPrivate(), T = !x, S = t.isProperty(), P = !S, _ = null == t.isStaticBlock ? void 0 : t.isStaticBlock();
						if (r && (m |= 1), r || P && x || _) {
							new i.default({
								methodPath: t,
								constantSuper: u,
								file: o,
								refToPreserve: d,
								getSuperRef: v,
								getObjectRef: () => (m |= 2, r || _ ? E : n.types.memberExpression(E, n.types.identifier("prototype")))
							}).replace();
							replaceThisContext(t, E, d) && (m |= 2);
						}
						switch (b = !1, !0) {
							case _: {
								const e = t.node.body;
								1 === e.length && n.types.isExpressionStatement(e[0]) ? f.push(inheritPropComments(e[0], t)) : f.push(n.types.inheritsComments(n.template.statement.ast`(() => { ${e} })()`, t.node));
								break;
							}
							case r && x && S && l:
								f.push(buildPrivateFieldInitLoose(n.types.cloneNode(e), t, s));
								break;
							case r && x && S && !l:
								newHelpers(o) ? f.push(buildPrivateStaticFieldInitSpec(t, s, p)) : f.push(buildPrivateStaticFieldInitSpecOld(t, s));
								break;
							case r && T && S && a: if (!isNameOrLength(t.node)) {
								f.push(buildPublicFieldInitLoose(n.types.cloneNode(e), t));
								break;
							}
							case r && T && S && !a:
								f.push(buildPublicFieldInitSpec(n.types.cloneNode(e), t, o));
								break;
							case h && x && S && l:
								y.push(buildPrivateFieldInitLoose(n.types.thisExpression(), t, s));
								break;
							case h && x && S && !l:
								y.push(buildPrivateInstanceFieldInitSpec(n.types.thisExpression(), t, s, o));
								break;
							case h && x && P && l:
								y.unshift(buildPrivateMethodInitLoose(n.types.thisExpression(), t, s)), g.push(buildPrivateMethodDeclaration(o, t, s, l));
								break;
							case h && x && P && !l:
								y.unshift(buildPrivateInstanceMethodInitSpec(n.types.thisExpression(), t, s, o)), g.push(buildPrivateMethodDeclaration(o, t, s, l));
								break;
							case r && x && P && !l:
								newHelpers(o) || f.unshift(buildPrivateStaticFieldInitSpecOld(t, s)), g.push(buildPrivateMethodDeclaration(o, t, s, l));
								break;
							case r && x && P && l:
								f.unshift(buildPrivateStaticMethodInitLoose(n.types.cloneNode(e), t, o, s)), g.push(buildPrivateMethodDeclaration(o, t, s, l));
								break;
							case h && T && S && a:
								y.push(buildPublicFieldInitLoose(n.types.thisExpression(), t));
								break;
							case h && T && S && !a:
								b = !0, y.push(buildPublicFieldInitSpec(n.types.thisExpression(), t, o));
								break;
							default: throw new Error("Unreachable.");
						}
					}
					2 & m && null != d && (x = n.types.expressionStatement(n.types.assignmentExpression("=", n.types.cloneNode(E), n.types.cloneNode(d))));
					return {
						staticNodes: f.filter(Boolean),
						instanceNodes: y.filter(Boolean),
						lastInstanceNodeReturnsThis: b,
						pureStaticNodes: g.filter(Boolean),
						classBindingNode: x,
						wrapClass(t) {
							for (const e of r) e.node.leadingComments = null, e.remove();
							return h && (t.scope.push({ id: n.types.cloneNode(h) }), t.set("superClass", n.types.assignmentExpression("=", h, t.node.superClass))), 0 !== m && (t.isClassExpression() ? (t.scope.push({ id: e }), t.replaceWith(n.types.assignmentExpression("=", n.types.cloneNode(e), t.node))) : (d ?? (t.node.id = e), null != x && t.scope.push({ id: E }))), t;
						}
					};
				}, t.buildPrivateNamesMap = function(e, t, r, s) {
					const i = /* @__PURE__ */ new Map();
					let o;
					for (const a of r) if (a.isPrivate()) {
						const { name: r } = a.node.key.id;
						let l = i.get(r);
						if (!l) {
							const n = !a.isProperty(), p = a.node.static;
							let c, u = !1;
							!t && newHelpers(s) && n && !p ? (u = !!o, o ?? (o = a.scope.generateUidIdentifier(`${e}_brand`)), c = o) : c = a.scope.generateUidIdentifier(r), l = {
								id: c,
								static: p,
								method: n,
								initAdded: u
							}, i.set(r, l);
						}
						if (a.isClassPrivateMethod()) if ("get" === a.node.kind) {
							const { body: e } = a.node.body;
							let t;
							1 === e.length && n.types.isReturnStatement(t = e[0]) && n.types.isCallExpression(t = t.argument) && 1 === t.arguments.length && n.types.isThisExpression(t.arguments[0]) && n.types.isIdentifier(t = t.callee) ? (l.getId = n.types.cloneNode(t), l.getterDeclared = !0) : l.getId = a.scope.generateUidIdentifier(`get_${r}`);
						} else if ("set" === a.node.kind) {
							const { params: e } = a.node, { body: t } = a.node.body;
							let s;
							1 === t.length && n.types.isExpressionStatement(s = t[0]) && n.types.isCallExpression(s = s.expression) && 2 === s.arguments.length && n.types.isThisExpression(s.arguments[0]) && n.types.isIdentifier(s.arguments[1], { name: e[0].name }) && n.types.isIdentifier(s = s.callee) ? (l.setId = n.types.cloneNode(s), l.setterDeclared = !0) : l.setId = a.scope.generateUidIdentifier(`set_${r}`);
						} else "method" === a.node.kind && (l.methodId = a.scope.generateUidIdentifier(r));
						i.set(r, l);
					}
					return i;
				}, t.buildPrivateNamesNodes = function(e, t, r, s) {
					const i = [], o = /* @__PURE__ */ new Set();
					for (const [a, p] of e) {
						const { static: e, method: c, getId: u, setId: d } = p, h = u || d, m = n.types.cloneNode(p.id);
						let f;
						if (t) f = n.types.callExpression(s.addHelper("classPrivateFieldLooseKey"), [n.types.stringLiteral(a)]);
						else if (r) f = n.types.callExpression(n.types.identifier("Symbol"), [n.types.stringLiteral(a)]);
						else if (!e) {
							if (o.has(m.name)) continue;
							o.add(m.name), f = n.types.newExpression(n.types.identifier(!c || h && !newHelpers(s) ? "WeakMap" : "WeakSet"), []);
						}
						f && (r || (0, l.default)(f), i.push(n.template.statement.ast`var ${m} = ${f}`));
					}
					return i;
				}, t.privateNameVisitorFactory = privateNameVisitorFactory, t.transformPrivateNamesUsage = function(e, t, r, { privateFieldsAsProperties: n, noUninitializedPrivateFieldAccess: s, noDocumentAll: i, innerBinding: a }, l) {
					if (!r.size) return;
					const p = t.get("body"), c = n ? m : h;
					(0, o.default)(p, u, Object.assign({
						privateNamesMap: r,
						classRef: e,
						file: l
					}, c, {
						noDocumentAll: i,
						noUninitializedPrivateFieldAccess: s,
						innerBinding: a
					})), p.traverse(d, {
						privateNamesMap: r,
						classRef: e,
						file: l,
						privateFieldsAsProperties: n,
						innerBinding: a
					});
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), s = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js"), i = r("./node_modules/.pnpm/@babel+helper-replace-supers@7.27.1_@babel+core@7.28.4/node_modules/@babel/helper-replace-supers/lib/index.js"), o = r("./node_modules/.pnpm/@babel+helper-member-expression-to-functions@7.27.1/node_modules/@babel/helper-member-expression-to-functions/lib/index.js"), a = r("./node_modules/.pnpm/@babel+helper-optimise-call-expression@7.27.1/node_modules/@babel/helper-optimise-call-expression/lib/index.js"), l = r("./node_modules/.pnpm/@babel+helper-annotate-as-pure@7.27.3/node_modules/@babel/helper-annotate-as-pure/lib/index.js"), p = r("./node_modules/.pnpm/@babel+helper-skip-transparent-expression-wrappers@7.27.1/node_modules/@babel/helper-skip-transparent-expression-wrappers/lib/index.js"), c = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/typescript.js"), newHelpers = (e) => e.availableHelper("classPrivateFieldGet2");
				function privateNameVisitorFactory(e) {
					const t = s.visitors.environmentVisitor(Object.assign({}, e)), r = Object.assign({}, e, { Class(e) {
						const { privateNamesMap: n } = this, s = e.get("body.body"), i = new Map(n), o = [];
						for (const e of s) {
							if (!e.isPrivate()) continue;
							const { name: t } = e.node.key.id;
							i.delete(t), o.push(t);
						}
						o.length && (e.get("body").traverse(t, Object.assign({}, this, { redeclared: o })), e.traverse(r, Object.assign({}, this, { privateNamesMap: i })), e.skipKey("body"));
					} });
					return r;
				}
				const u = privateNameVisitorFactory({ PrivateName(e, { noDocumentAll: t }) {
					const { privateNamesMap: r, redeclared: n } = this, { node: s, parentPath: i } = e;
					if (!i.isMemberExpression({ property: s }) && !i.isOptionalMemberExpression({ property: s })) return;
					const { name: o } = s.id;
					r.has(o) && (null != n && n.includes(o) || this.handle(i, t));
				} });
				function unshadow(e, t, r) {
					for (; null != (n = t) && n.hasBinding(e) && !t.bindingIdentifierEquals(e, r);) {
						var n;
						t.rename(e), t = t.parent;
					}
				}
				function buildCheckInRHS(e, t, r) {
					return r || null == t.availableHelper || !t.availableHelper("checkInRHS") ? e : n.types.callExpression(t.addHelper("checkInRHS"), [e]);
				}
				const d = privateNameVisitorFactory({ BinaryExpression(e, { file: t }) {
					const { operator: r, left: s, right: i } = e.node;
					if ("in" !== r) return;
					if (!n.types.isPrivateName(s)) return;
					const { privateFieldsAsProperties: o, privateNamesMap: a, redeclared: l } = this, { name: p } = s.id;
					if (!a.has(p)) return;
					if (null != l && l.includes(p)) return;
					if (unshadow(this.classRef.name, e.scope, this.innerBinding), o) {
						const { id: r } = a.get(p);
						e.replaceWith(n.template.expression.ast`
        Object.prototype.hasOwnProperty.call(${buildCheckInRHS(i, t)}, ${n.types.cloneNode(r)})
      `);
						return;
					}
					const { id: c, static: u } = a.get(p);
					u ? e.replaceWith(n.template.expression.ast`${buildCheckInRHS(i, t)} === ${n.types.cloneNode(this.classRef)}`) : e.replaceWith(n.template.expression.ast`${n.types.cloneNode(c)}.has(${buildCheckInRHS(i, t)})`);
				} });
				function readOnlyError(e, t) {
					return n.types.callExpression(e.addHelper("readOnlyError"), [n.types.stringLiteral(`#${t}`)]);
				}
				function writeOnlyError(e, t) {
					return e.availableHelper("writeOnlyError") ? n.types.callExpression(e.addHelper("writeOnlyError"), [n.types.stringLiteral(`#${t}`)]) : (console.warn("@babel/helpers is outdated, update it to silence this warning."), n.types.buildUndefinedNode());
				}
				function buildStaticPrivateFieldAccess(e, t) {
					return t ? e : n.types.memberExpression(e, n.types.identifier("_"));
				}
				function autoInherits(e) {
					return function(t) {
						return n.types.inherits(e.apply(this, arguments), t.node);
					};
				}
				const h = {
					memoise(e, t) {
						const { scope: r } = e, { object: n } = e.node, s = r.maybeGenerateMemoised(n);
						s && this.memoiser.set(n, s, t);
					},
					receiver(e) {
						const { object: t } = e.node;
						return this.memoiser.has(t) ? n.types.cloneNode(this.memoiser.get(t)) : n.types.cloneNode(t);
					},
					get: autoInherits(function(e) {
						const { classRef: t, privateNamesMap: r, file: s, innerBinding: i, noUninitializedPrivateFieldAccess: o } = this, a = e.node.property, { name: l } = a.id, { id: p, static: c, method: u, methodId: d, getId: h, setId: m } = r.get(l), f = h || m, cloneId = (e) => n.types.inherits(n.types.cloneNode(e), a);
						if (c) {
							if (unshadow(t.name, e.scope, i), !newHelpers(s)) {
								const r = u && !f ? "classStaticPrivateMethodGet" : "classStaticPrivateFieldSpecGet";
								return n.types.callExpression(s.addHelper(r), [
									this.receiver(e),
									n.types.cloneNode(t),
									cloneId(p)
								]);
							}
							const r = this.receiver(e), a = n.types.isIdentifier(r) && r.name === t.name;
							if (!u) return buildStaticPrivateFieldAccess(a ? cloneId(p) : n.types.callExpression(s.addHelper("assertClassBrand"), [
								n.types.cloneNode(t),
								r,
								cloneId(p)
							]), o);
							if (h) return a ? n.types.callExpression(cloneId(h), [r]) : n.types.callExpression(s.addHelper("classPrivateGetter"), [
								n.types.cloneNode(t),
								r,
								cloneId(h)
							]);
							if (m) {
								const e = n.types.buildUndefinedNode();
								return a ? e : n.types.sequenceExpression([n.types.callExpression(s.addHelper("assertClassBrand"), [n.types.cloneNode(t), r]), e]);
							}
							return a ? cloneId(p) : n.types.callExpression(s.addHelper("assertClassBrand"), [
								n.types.cloneNode(t),
								r,
								cloneId(p)
							]);
						}
						return u ? f ? h ? newHelpers(s) ? n.types.callExpression(s.addHelper("classPrivateGetter"), [
							n.types.cloneNode(p),
							this.receiver(e),
							cloneId(h)
						]) : n.types.callExpression(s.addHelper("classPrivateFieldGet"), [this.receiver(e), cloneId(p)]) : n.types.sequenceExpression([this.receiver(e), writeOnlyError(s, l)]) : newHelpers(s) ? n.types.callExpression(s.addHelper("assertClassBrand"), [
							n.types.cloneNode(p),
							this.receiver(e),
							cloneId(d)
						]) : n.types.callExpression(s.addHelper("classPrivateMethodGet"), [
							this.receiver(e),
							n.types.cloneNode(p),
							cloneId(d)
						]) : newHelpers(s) ? n.types.callExpression(s.addHelper("classPrivateFieldGet2"), [cloneId(p), this.receiver(e)]) : n.types.callExpression(s.addHelper("classPrivateFieldGet"), [this.receiver(e), cloneId(p)]);
					}),
					boundGet(e) {
						return this.memoise(e, 1), n.types.callExpression(n.types.memberExpression(this.get(e), n.types.identifier("bind")), [this.receiver(e)]);
					},
					set: autoInherits(function(e, t) {
						const { classRef: r, privateNamesMap: s, file: i, noUninitializedPrivateFieldAccess: o } = this, a = e.node.property, { name: l } = a.id, { id: p, static: c, method: u, setId: d, getId: h } = s.get(l), m = h || d, cloneId = (e) => n.types.inherits(n.types.cloneNode(e), a);
						if (c) {
							if (!newHelpers(i)) {
								const s = u && !m ? "classStaticPrivateMethodSet" : "classStaticPrivateFieldSpecSet";
								return n.types.callExpression(i.addHelper(s), [
									this.receiver(e),
									n.types.cloneNode(r),
									cloneId(p),
									t
								]);
							}
							const s = this.receiver(e), a = n.types.isIdentifier(s) && s.name === r.name;
							if (u && !d) {
								const e = readOnlyError(i, l);
								return a ? n.types.sequenceExpression([t, e]) : n.types.sequenceExpression([
									t,
									n.types.callExpression(i.addHelper("assertClassBrand"), [n.types.cloneNode(r), s]),
									readOnlyError(i, l)
								]);
							}
							return d ? a ? n.types.callExpression(n.types.cloneNode(d), [s, t]) : n.types.callExpression(i.addHelper("classPrivateSetter"), [
								n.types.cloneNode(r),
								cloneId(d),
								s,
								t
							]) : n.types.assignmentExpression("=", buildStaticPrivateFieldAccess(cloneId(p), o), a ? t : n.types.callExpression(i.addHelper("assertClassBrand"), [
								n.types.cloneNode(r),
								s,
								t
							]));
						}
						return u ? d ? newHelpers(i) ? n.types.callExpression(i.addHelper("classPrivateSetter"), [
							n.types.cloneNode(p),
							cloneId(d),
							this.receiver(e),
							t
						]) : n.types.callExpression(i.addHelper("classPrivateFieldSet"), [
							this.receiver(e),
							cloneId(p),
							t
						]) : n.types.sequenceExpression([
							this.receiver(e),
							t,
							readOnlyError(i, l)
						]) : newHelpers(i) ? n.types.callExpression(i.addHelper("classPrivateFieldSet2"), [
							cloneId(p),
							this.receiver(e),
							t
						]) : n.types.callExpression(i.addHelper("classPrivateFieldSet"), [
							this.receiver(e),
							cloneId(p),
							t
						]);
					}),
					destructureSet(e) {
						const { classRef: t, privateNamesMap: r, file: s, noUninitializedPrivateFieldAccess: i } = this, o = e.node.property, { name: a } = o.id, { id: l, static: p, method: c, setId: u } = r.get(a), cloneId = (e) => n.types.inherits(n.types.cloneNode(e), o);
						if (!newHelpers(s)) {
							if (p) {
								try {
									var d = s.addHelper("classStaticPrivateFieldDestructureSet");
								} catch (e) {
									throw new Error("Babel can not transpile `[C.#p] = [0]` with @babel/helpers < 7.13.10, \nplease update @babel/helpers to the latest version.");
								}
								return n.types.memberExpression(n.types.callExpression(d, [
									this.receiver(e),
									n.types.cloneNode(t),
									cloneId(l)
								]), n.types.identifier("value"));
							}
							return n.types.memberExpression(n.types.callExpression(s.addHelper("classPrivateFieldDestructureSet"), [this.receiver(e), cloneId(l)]), n.types.identifier("value"));
						}
						if (c && !u) return n.types.memberExpression(n.types.sequenceExpression([e.node.object, readOnlyError(s, a)]), n.types.identifier("_"));
						if (p && !c) {
							const t = this.get(e);
							if (!i || !n.types.isCallExpression(t)) return t;
							const r = t.arguments.pop();
							return t.arguments.push(n.template.expression.ast`(_) => ${r} = _`), n.types.memberExpression(n.types.callExpression(s.addHelper("toSetter"), [t]), n.types.identifier("_"));
						}
						const h = this.set(e, n.types.identifier("_"));
						if (!n.types.isCallExpression(h) || !n.types.isIdentifier(h.arguments[h.arguments.length - 1], { name: "_" })) throw e.buildCodeFrameError("Internal Babel error while compiling this code. This is a Babel bug. Please report it at https://github.com/babel/babel/issues.");
						let m;
						return m = n.types.isMemberExpression(h.callee, { computed: !1 }) && n.types.isIdentifier(h.callee.property) && "call" === h.callee.property.name ? [
							h.callee.object,
							n.types.arrayExpression(h.arguments.slice(1, -1)),
							h.arguments[0]
						] : [h.callee, n.types.arrayExpression(h.arguments.slice(0, -1))], n.types.memberExpression(n.types.callExpression(s.addHelper("toSetter"), m), n.types.identifier("_"));
					},
					call(e, t) {
						return this.memoise(e, 1), (0, a.default)(this.get(e), this.receiver(e), t, !1);
					},
					optionalCall(e, t) {
						return this.memoise(e, 1), (0, a.default)(this.get(e), this.receiver(e), t, !0);
					},
					delete() {
						throw new Error("Internal Babel error: deleting private elements is a parsing error.");
					}
				}, m = {
					get(e) {
						const { privateNamesMap: t, file: r } = this, { object: s } = e.node, { name: i } = e.node.property.id;
						return n.template.expression`BASE(REF, PROP)[PROP]`({
							BASE: r.addHelper("classPrivateFieldLooseBase"),
							REF: n.types.cloneNode(s),
							PROP: n.types.cloneNode(t.get(i).id)
						});
					},
					set() {
						throw new Error("private name handler with loose = true don't need set()");
					},
					boundGet(e) {
						return n.types.callExpression(n.types.memberExpression(this.get(e), n.types.identifier("bind")), [n.types.cloneNode(e.node.object)]);
					},
					simpleSet(e) {
						return this.get(e);
					},
					destructureSet(e) {
						return this.get(e);
					},
					call(e, t) {
						return n.types.callExpression(this.get(e), t);
					},
					optionalCall(e, t) {
						return n.types.optionalCallExpression(this.get(e), t, !0);
					},
					delete() {
						throw new Error("Internal Babel error: deleting private elements is a parsing error.");
					}
				};
				function buildPrivateFieldInitLoose(e, t, r) {
					const { id: s } = r.get(t.node.key.id.name), i = t.node.value || t.scope.buildUndefinedNode();
					return inheritPropComments(n.template.statement.ast`
      Object.defineProperty(${e}, ${n.types.cloneNode(s)}, {
        // configurable is false by default
        // enumerable is false by default
        writable: true,
        value: ${i}
      });
    `, t);
				}
				function buildPrivateInstanceFieldInitSpec(e, t, r, s) {
					const { id: i } = r.get(t.node.key.id.name), o = t.node.value || t.scope.buildUndefinedNode();
					if (!s.availableHelper("classPrivateFieldInitSpec")) return inheritPropComments(n.template.statement.ast`${n.types.cloneNode(i)}.set(${e}, {
          // configurable is always false for private elements
          // enumerable is always false for private elements
          writable: true,
          value: ${o},
        })`, t);
					const a = s.addHelper("classPrivateFieldInitSpec");
					return inheritLoc(inheritPropComments(n.types.expressionStatement(n.types.callExpression(a, [
						n.types.thisExpression(),
						inheritLoc(n.types.cloneNode(i), t.node.key),
						newHelpers(s) ? o : n.template.expression.ast`{ writable: true, value: ${o} }`
					])), t), t.node);
				}
				function buildPrivateStaticFieldInitSpec(e, t, r) {
					const s = t.get(e.node.key.id.name), i = r ? e.node.value : n.template.expression.ast`{
        _: ${e.node.value || n.types.buildUndefinedNode()}
      }`;
					return inheritPropComments(n.types.variableDeclaration("var", [n.types.variableDeclarator(n.types.cloneNode(s.id), i)]), e);
				}
				var buildPrivateStaticFieldInitSpecOld = function(e, t) {
					const r = t.get(e.node.key.id.name), { id: s, getId: i, setId: o, initAdded: a } = r, l = i || o;
					if (!e.isProperty() && (a || !l)) return;
					if (l) return t.set(e.node.key.id.name, Object.assign({}, r, { initAdded: !0 })), inheritPropComments(n.template.statement.ast`
          var ${n.types.cloneNode(s)} = {
            // configurable is false by default
            // enumerable is false by default
            // writable is false by default
            get: ${i ? i.name : e.scope.buildUndefinedNode()},
            set: ${o ? o.name : e.scope.buildUndefinedNode()}
          }
        `, e);
					const p = e.node.value || e.scope.buildUndefinedNode();
					return inheritPropComments(n.template.statement.ast`
        var ${n.types.cloneNode(s)} = {
          // configurable is false by default
          // enumerable is false by default
          writable: true,
          value: ${p}
        };
      `, e);
				};
				function buildPrivateMethodInitLoose(e, t, r) {
					const s = r.get(t.node.key.id.name), { methodId: i, id: o, getId: a, setId: l, initAdded: p } = s;
					if (p) return;
					if (i) return inheritPropComments(n.template.statement.ast`
        Object.defineProperty(${e}, ${o}, {
          // configurable is false by default
          // enumerable is false by default
          // writable is false by default
          value: ${i.name}
        });
      `, t);
					return a || l ? (r.set(t.node.key.id.name, Object.assign({}, s, { initAdded: !0 })), inheritPropComments(n.template.statement.ast`
        Object.defineProperty(${e}, ${o}, {
          // configurable is false by default
          // enumerable is false by default
          // writable is false by default
          get: ${a ? a.name : t.scope.buildUndefinedNode()},
          set: ${l ? l.name : t.scope.buildUndefinedNode()}
        });
      `, t)) : void 0;
				}
				function buildPrivateInstanceMethodInitSpec(e, t, r, s) {
					const i = r.get(t.node.key.id.name);
					if (!i.initAdded) {
						if (!newHelpers(s)) {
							if (i.getId || i.setId) return function(e, t, r, s) {
								const i = r.get(t.node.key.id.name), { id: o, getId: a, setId: l } = i;
								if (r.set(t.node.key.id.name, Object.assign({}, i, { initAdded: !0 })), !s.availableHelper("classPrivateFieldInitSpec")) return inheritPropComments(n.template.statement.ast`
          ${o}.set(${e}, {
            get: ${a ? a.name : t.scope.buildUndefinedNode()},
            set: ${l ? l.name : t.scope.buildUndefinedNode()}
          });
        `, t);
								const p = s.addHelper("classPrivateFieldInitSpec");
								return inheritLoc(inheritPropComments(n.template.statement.ast`${p}(
      ${n.types.thisExpression()},
      ${n.types.cloneNode(o)},
      {
        get: ${a ? a.name : t.scope.buildUndefinedNode()},
        set: ${l ? l.name : t.scope.buildUndefinedNode()}
      },
    )`, t), t.node);
							}(e, t, r, s);
						}
						return function(e, t, r, s) {
							const { id: o } = r.get(t.node.key.id.name);
							if (!s.availableHelper("classPrivateMethodInitSpec")) return inheritPropComments(n.template.statement.ast`${o}.add(${e})`, t);
							const a = s.addHelper("classPrivateMethodInitSpec");
							return inheritPropComments(n.template.statement.ast`${a}(
      ${n.types.thisExpression()},
      ${n.types.cloneNode(o)}
    )`, t);
						}(e, t, r, s);
					}
				}
				function buildPublicFieldInitLoose(e, t) {
					const { key: r, computed: s } = t.node, i = t.node.value || t.scope.buildUndefinedNode();
					return inheritPropComments(n.types.expressionStatement(n.types.assignmentExpression("=", n.types.memberExpression(e, r, s || n.types.isLiteral(r)), i)), t);
				}
				function buildPublicFieldInitSpec(e, t, r) {
					const { key: s, computed: i } = t.node, o = t.node.value || t.scope.buildUndefinedNode();
					return inheritPropComments(n.types.expressionStatement(n.types.callExpression(r.addHelper("defineProperty"), [
						e,
						i || n.types.isLiteral(s) ? s : n.types.stringLiteral(s.name),
						o
					])), t);
				}
				function buildPrivateStaticMethodInitLoose(e, t, r, s) {
					const i = s.get(t.node.key.id.name), { id: o, methodId: a, getId: l, setId: p, initAdded: c } = i;
					if (c) return;
					return l || p ? (s.set(t.node.key.id.name, Object.assign({}, i, { initAdded: !0 })), inheritPropComments(n.template.statement.ast`
        Object.defineProperty(${e}, ${o}, {
          // configurable is false by default
          // enumerable is false by default
          // writable is false by default
          get: ${l ? l.name : t.scope.buildUndefinedNode()},
          set: ${p ? p.name : t.scope.buildUndefinedNode()}
        })
      `, t)) : inheritPropComments(n.template.statement.ast`
      Object.defineProperty(${e}, ${o}, {
        // configurable is false by default
        // enumerable is false by default
        // writable is false by default
        value: ${a.name}
      });
    `, t);
				}
				function buildPrivateMethodDeclaration(e, t, r, s = !1) {
					const i = r.get(t.node.key.id.name), { id: o, methodId: a, getId: l, setId: p, getterDeclared: c, setterDeclared: u, static: d } = i, { params: h, body: m, generator: y, async: b } = t.node, g = l && 0 === h.length, x = p && h.length > 0;
					if (g && c || x && u) return r.set(t.node.key.id.name, Object.assign({}, i, { initAdded: !0 })), null;
					if (newHelpers(e) && (g || x) && !s) {
						const e = t.get("body").scope, r = e.generateUidIdentifier("this"), s = {
							thisRef: r,
							argumentsPath: []
						};
						if (t.traverse(f, s), s.argumentsPath.length) {
							const t = e.generateUidIdentifier("arguments");
							e.push({
								id: t,
								init: n.template.expression.ast`[].slice.call(arguments, 1)`
							});
							for (const e of s.argumentsPath) e.replaceWith(n.types.cloneNode(t));
						}
						h.unshift(n.types.cloneNode(r));
					}
					let v = a;
					return g ? (r.set(t.node.key.id.name, Object.assign({}, i, {
						getterDeclared: !0,
						initAdded: !0
					})), v = l) : x ? (r.set(t.node.key.id.name, Object.assign({}, i, {
						setterDeclared: !0,
						initAdded: !0
					})), v = p) : d && !s && (v = o), inheritPropComments(n.types.functionDeclaration(n.types.cloneNode(v), h, m, y, b), t);
				}
				const f = s.visitors.environmentVisitor({
					Identifier(e, t) {
						t.argumentsPath && "arguments" === e.node.name && t.argumentsPath.push(e);
					},
					UnaryExpression(e) {
						const { node: t } = e;
						if ("delete" === t.operator) {
							const r = (0, p.skipTransparentExprWrapperNodes)(t.argument);
							n.types.isThisExpression(r) && e.replaceWith(n.types.booleanLiteral(!0));
						}
					},
					ThisExpression(e, t) {
						t.needsClassRef = !0, e.replaceWith(n.types.cloneNode(t.thisRef));
					},
					MetaProperty(e) {
						const { node: t, scope: r } = e;
						"new" === t.meta.name && "target" === t.property.name && e.replaceWith(r.buildUndefinedNode());
					}
				}), y = { ReferencedIdentifier(e, t) {
					e.scope.bindingIdentifierEquals(e.node.name, t.innerBinding) && (t.needsClassRef = !0, e.node.name = t.thisRef.name);
				} };
				function replaceThisContext(e, t, r) {
					var n;
					const s = {
						thisRef: t,
						needsClassRef: !1,
						innerBinding: r
					};
					return e.isMethod() || e.traverse(f, s), null != r && null != (n = s.thisRef) && n.name && s.thisRef.name !== r.name && e.traverse(y, s), s.needsClassRef;
				}
				function isNameOrLength({ key: e, computed: t }) {
					return "Identifier" === e.type ? !t && ("name" === e.name || "length" === e.name) : "StringLiteral" === e.type && ("name" === e.value || "length" === e.value);
				}
				function inheritPropComments(e, t) {
					return n.types.inheritLeadingComments(e, t.node), n.types.inheritInnerComments(e, t.node), e;
				}
				function inheritLoc(e, t) {
					return e.start = t.start, e.end = t.end, e.loc = t.loc, e;
				}
			},
			"./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), Object.defineProperty(t, "FEATURES", {
					enumerable: !0,
					get: function() {
						return p.FEATURES;
					}
				}), Object.defineProperty(t, "buildCheckInRHS", {
					enumerable: !0,
					get: function() {
						return i.buildCheckInRHS;
					}
				}), Object.defineProperty(t, "buildNamedEvaluationVisitor", {
					enumerable: !0,
					get: function() {
						return o.buildNamedEvaluationVisitor;
					}
				}), t.createClassFeaturePlugin = function({ name: e, feature: t, loose: d, manipulateOptions: h, api: m, inherits: f, decoratorVersion: y }) {
					var b;
					if (t & p.FEATURES.decorators && ("2023-11" === y || "2023-05" === y || "2023-01" === y || "2022-03" === y || "2021-12" === y)) return (0, o.default)(m, { loose: d }, y, f);
					m ?? (m = { assumption: () => {} });
					const g = m.assumption("setPublicClassFields"), x = m.assumption("privateFieldsAsSymbols"), v = m.assumption("privateFieldsAsProperties"), E = null != (b = m.assumption("noUninitializedPrivateFieldAccess")) && b, T = m.assumption("constantSuper"), S = m.assumption("noDocumentAll");
					if (v && x) throw new Error("Cannot enable both the \"privateFieldsAsProperties\" and \"privateFieldsAsSymbols\" assumptions as the same time.");
					const P = v || x;
					if (!0 === d) {
						const t = [];
						void 0 !== g && t.push("\"setPublicClassFields\""), void 0 !== v && t.push("\"privateFieldsAsProperties\""), void 0 !== x && t.push("\"privateFieldsAsSymbols\""), 0 !== t.length && console.warn(`[${e}]: You are using the "loose: true" option and you are explicitly setting a value for the ${t.join(" and ")} assumption${t.length > 1 ? "s" : ""}. The "loose" option can cause incompatibilities with the other class features plugins, so it's recommended that you replace it with the following top-level option:\n\t"assumptions": {\n\t\t"setPublicClassFields": true,\n\t\t"privateFieldsAsSymbols": true\n\t}`);
					}
					return {
						name: e,
						manipulateOptions: h,
						inherits: f,
						pre(e) {
							(0, p.enableFeature)(e, t, d), "number" != typeof e.get(u) && e.get(u) && !s.lt(e.get(u), "7.28.3") || e.set(u, "7.28.3");
						},
						visitor: {
							Class(e, { file: s }) {
								if ("7.28.3" !== s.get(u)) return;
								if (!(0, p.shouldTransform)(e, s)) return;
								const d = e.isClassDeclaration();
								d && (0, c.assertFieldTransformed)(e);
								const h = (0, p.isLoose)(s, t);
								let m;
								const f = (0, o.hasDecorators)(e.node), y = [], b = [], _ = [], A = /* @__PURE__ */ new Set(), C = e.get("body");
								for (const e of C.get("body")) {
									if ((e.isClassProperty() || e.isClassMethod()) && e.node.computed && _.push(e), e.isPrivate()) {
										const { name: t } = e.node.key.id, r = `get ${t}`, n = `set ${t}`;
										if (e.isClassPrivateMethod()) {
											if ("get" === e.node.kind) {
												if (A.has(r) || A.has(t) && !A.has(n)) throw e.buildCodeFrameError("Duplicate private field");
												A.add(r).add(t);
											} else if ("set" === e.node.kind) {
												if (A.has(n) || A.has(t) && !A.has(r)) throw e.buildCodeFrameError("Duplicate private field");
												A.add(n).add(t);
											}
										} else {
											if (A.has(t) && !A.has(r) && !A.has(n) || A.has(t) && (A.has(r) || A.has(n))) throw e.buildCodeFrameError("Duplicate private field");
											A.add(t);
										}
									}
									e.isClassMethod({ kind: "constructor" }) ? m = e : (b.push(e), (e.isProperty() || e.isPrivate() || null != e.isStaticBlock && e.isStaticBlock()) && y.push(e));
								}
								if (!y.length && !f) return;
								const w = e.node.id;
								let I;
								w && d || (e.ensureFunctionName ?? (e.ensureFunctionName = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js").NodePath.prototype.ensureFunctionName), e.ensureFunctionName(!1), I = e.scope.generateUidIdentifier((null == w ? void 0 : w.name) || "Class"));
								const D = null != I ? I : n.types.cloneNode(w), k = (0, i.buildPrivateNamesMap)(D.name, null != P ? P : h, y, s), N = (0, i.buildPrivateNamesNodes)(k, null != v ? v : h, null != x && x, s);
								let O, j, F, L, M, B, R;
								(0, i.transformPrivateNamesUsage)(D, e, k, {
									privateFieldsAsProperties: null != P ? P : h,
									noUninitializedPrivateFieldAccess: E,
									noDocumentAll: S,
									innerBinding: w
								}, s), f ? (j = M = O = [], {instanceNodes: F, wrapClass: R} = (0, a.buildDecoratedClass)(D, e, b, s)) : (O = (0, l.extractComputedKeys)(e, _, s), {staticNodes: j, pureStaticNodes: M, instanceNodes: F, lastInstanceNodeReturnsThis: L, classBindingNode: B, wrapClass: R} = (0, i.buildFieldsInitNodes)(I, e.node.superClass, y, k, s, null != g ? g : h, null != P ? P : h, E, null != T ? T : h, w)), F.length > 0 && (0, l.injectInitialization)(e, m, F, (e, t) => {
									if (!f) for (const r of y) null != n.types.isStaticBlock && n.types.isStaticBlock(r.node) || r.node.static || r.traverse(e, t);
								}, L);
								const U = R(e);
								U.insertBefore([...N, ...O]), j.length > 0 && U.insertAfter(j), M.length > 0 && U.find((e) => e.isStatement() || e.isDeclaration()).insertAfter(M), null != B && d && U.insertAfter(B);
							},
							ExportDefaultDeclaration(e, { file: t }) {
								{
									if ("7.28.3" !== t.get(u)) return;
									const n = e.get("declaration");
									if (n.isClassDeclaration() && (0, o.hasDecorators)(n.node)) if (n.node.id) e.splitExportDeclaration ?? (e.splitExportDeclaration = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js").NodePath.prototype.splitExportDeclaration), e.splitExportDeclaration();
									else n.node.type = "ClassExpression";
								}
							}
						}
					};
				}, Object.defineProperty(t, "enableFeature", {
					enumerable: !0,
					get: function() {
						return p.enableFeature;
					}
				}), Object.defineProperty(t, "injectInitialization", {
					enumerable: !0,
					get: function() {
						return l.injectInitialization;
					}
				});
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), s = r("./node_modules/.pnpm/semver@6.3.1/node_modules/semver/semver.js"), i = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/fields.js"), o = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/decorators.js"), a = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/decorators-2018-09.js"), l = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/misc.js"), p = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/features.js"), c = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/typescript.js");
				const u = "@babel/plugin-class-features/version";
			},
			"./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/misc.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.extractComputedKeys = function(e, t, r) {
					const { scope: s } = e, i = [], a = {
						classBinding: e.node.id && s.getBinding(e.node.id.name),
						file: r
					};
					for (const e of t) {
						const t = e.get("key");
						t.isReferencedIdentifier() ? handleClassTDZ(t, a) : t.traverse(o, a);
						const r = e.node;
						if (!t.isConstantExpression()) {
							const e = memoiseComputedKey(t.node, s, s.generateUidBasedOnNode(t.node));
							e && (i.push(n.types.expressionStatement(e)), r.key = n.types.cloneNode(e.left));
						}
					}
					return i;
				}, t.injectInitialization = function(e, t, r, o, a) {
					if (!r.length) return;
					const l = !!e.node.superClass;
					if (!t) {
						const r = n.types.classMethod("constructor", n.types.identifier("constructor"), [], n.types.blockStatement([]));
						l && (r.params = [n.types.restElement(n.types.identifier("args"))], r.body.body.push(n.template.statement.ast`super(...args)`)), [t] = e.get("body").unshiftContainer("body", r);
					}
					o && o(i, { scope: t.scope });
					if (l) {
						const e = [];
						t.traverse(s, e);
						let i = !0;
						for (const t of e) if (i ? i = !1 : r = r.map((e) => n.types.cloneNode(e)), t.parentPath.isExpressionStatement()) t.insertAfter(r);
						else {
							const e = [t.node, ...r.map((e) => n.types.toExpression(e))];
							a || e.push(n.types.thisExpression()), t.replaceWith(n.types.sequenceExpression(e));
						}
					} else t.get("body").unshiftContainer("body", r);
				}, t.memoiseComputedKey = memoiseComputedKey;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js");
				const s = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js").visitors.environmentVisitor({ Super(e) {
					const { node: t, parentPath: r } = e;
					r.isCallExpression({ callee: t }) && this.push(r);
				} }), i = {
					"TSTypeAnnotation|TypeAnnotation"(e) {
						e.skip();
					},
					ReferencedIdentifier(e, { scope: t }) {
						t.hasOwnBinding(e.node.name) && (t.rename(e.node.name), e.skip());
					}
				};
				function handleClassTDZ(e, t) {
					if (t.classBinding && t.classBinding === e.scope.getBinding(e.node.name)) {
						const r = t.file.addHelper("classNameTDZError"), s = n.types.callExpression(r, [n.types.stringLiteral(e.node.name)]);
						e.replaceWith(n.types.sequenceExpression([s, e.node])), e.skip();
					}
				}
				const o = {
					ReferencedIdentifier: handleClassTDZ,
					"TSTypeAnnotation|TypeAnnotation"(e) {
						e.skip();
					}
				};
				function memoiseComputedKey(e, t, r) {
					if (n.types.isIdentifier(e) && t.hasUid(e.name)) return;
					if (n.types.isAssignmentExpression(e, { operator: "=" }) && n.types.isIdentifier(e.left) && t.hasUid(e.left.name)) return n.types.cloneNode(e);
					{
						const s = n.types.identifier(r);
						return t.push({
							id: s,
							kind: "let"
						}), n.types.assignmentExpression("=", n.types.cloneNode(s), e);
					}
				}
			},
			"./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/typescript.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.assertFieldTransformed = function(e) {
					if (e.node.declare) throw e.buildCodeFrameError("TypeScript 'declare' fields must first be transformed by @babel/plugin-transform-typescript.\nIf you have already enabled that plugin (or '@babel/preset-typescript'), make sure that it runs before any plugin related to additional class features:\n - @babel/plugin-transform-class-properties\n - @babel/plugin-transform-private-methods\n - @babel/plugin-proposal-decorators");
				};
			},
			"./node_modules/.pnpm/@babel+helper-member-expression-to-functions@7.27.1/node_modules/@babel/helper-member-expression-to-functions/lib/index.js": function(e, t, r) {
				"use strict";
				function _interopNamespace(e) {
					if (e && e.__esModule) return e;
					var t = Object.create(null);
					return e && Object.keys(e).forEach(function(r) {
						if ("default" !== r) {
							var n = Object.getOwnPropertyDescriptor(e, r);
							Object.defineProperty(t, r, n.get ? n : {
								enumerable: !0,
								get: function() {
									return e[r];
								}
							});
						}
					}), t.default = e, Object.freeze(t);
				}
				Object.defineProperty(t, "__esModule", { value: !0 });
				var n = _interopNamespace(r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"));
				function willPathCastToBoolean(e) {
					const { node: r, parentPath: n } = e;
					if (n.isLogicalExpression()) {
						const { operator: e, right: t } = n.node;
						if ("&&" === e || "||" === e || "??" === e && r === t) return willPathCastToBoolean(n);
					}
					if (n.isSequenceExpression()) {
						const { expressions: e } = n.node;
						return e[e.length - 1] !== r || willPathCastToBoolean(n);
					}
					return n.isConditional({ test: r }) || n.isUnaryExpression({ operator: "!" }) || n.isLoop({ test: r });
				}
				const { LOGICAL_OPERATORS: s, arrowFunctionExpression: i, assignmentExpression: o, binaryExpression: a, booleanLiteral: l, callExpression: p, cloneNode: c, conditionalExpression: u, identifier: d, isMemberExpression: h, isOptionalCallExpression: m, isOptionalMemberExpression: f, isUpdateExpression: y, logicalExpression: b, memberExpression: g, nullLiteral: x, optionalCallExpression: v, optionalMemberExpression: E, sequenceExpression: T, updateExpression: S } = n;
				class AssignmentMemoiser {
					constructor() {
						this._map = void 0, this._map = /* @__PURE__ */ new WeakMap();
					}
					has(e) {
						return this._map.has(e);
					}
					get(e) {
						if (!this.has(e)) return;
						const t = this._map.get(e), { value: r } = t;
						return t.count--, 0 === t.count ? o("=", r, e) : r;
					}
					set(e, t, r) {
						return this._map.set(e, {
							count: r,
							value: t
						});
					}
				}
				function toNonOptional(e, t) {
					const { node: r } = e;
					if (f(r)) return g(t, r.property, r.computed);
					if (e.isOptionalCallExpression()) {
						const r = e.get("callee");
						if (e.node.optional && r.isOptionalMemberExpression()) {
							const n = r.node.object, s = e.scope.maybeGenerateMemoised(n);
							return r.get("object").replaceWith(o("=", s, n)), p(g(t, d("call")), [s, ...e.node.arguments]);
						}
						return p(t, e.node.arguments);
					}
					return e.node;
				}
				const P = {
					memoise() {},
					handle(e, t) {
						const { node: r, parent: n, parentPath: s, scope: g } = e;
						if (e.isOptionalMemberExpression()) {
							if (function(e) {
								for (; e && !e.isProgram();) {
									const { parentPath: t, container: r, listKey: n } = e, s = t.node;
									if (n) {
										if (r !== s[n]) return !0;
									} else if (r !== s) return !0;
									e = t;
								}
								return !1;
							}(e)) return;
							const y = e.find(({ node: t, parent: r }) => f(r) ? r.optional || r.object !== t : !m(r) || t !== e.node && r.optional || r.callee !== t);
							if (g.path.isPattern()) return void y.replaceWith(p(i([], y.node), []));
							const T = willPathCastToBoolean(y), S = y.parentPath;
							if (S.isUpdateExpression({ argument: r })) throw e.buildCodeFrameError("can't handle update expression");
							const P = S.isAssignmentExpression({ left: y.node }), _ = S.isUnaryExpression({ operator: "delete" });
							if (_ && y.isOptionalMemberExpression() && y.get("property").isPrivateName()) throw e.buildCodeFrameError("can't delete a private class element");
							let A = e;
							for (;;) if (A.isOptionalMemberExpression()) {
								if (A.node.optional) break;
								A = A.get("object");
							} else {
								if (!A.isOptionalCallExpression()) throw new Error(`Internal error: unexpected ${A.node.type}`);
								if (A.node.optional) break;
								A = A.get("callee");
							}
							const C = A.isOptionalMemberExpression() ? A.node.object : A.node.callee, w = g.maybeGenerateMemoised(C), I = null != w ? w : C, D = s.isOptionalCallExpression({ callee: r }), isOptionalCall = (e) => D, k = s.isCallExpression({ callee: r });
							A.replaceWith(toNonOptional(A, I)), isOptionalCall() ? n.optional ? s.replaceWith(this.optionalCall(e, n.arguments)) : s.replaceWith(this.call(e, n.arguments)) : k ? e.replaceWith(this.boundGet(e)) : this.delete && s.isUnaryExpression({ operator: "delete" }) ? s.replaceWith(this.delete(e)) : s.isAssignmentExpression() ? handleAssignment(this, e, s) : e.replaceWith(this.get(e));
							let N, O = e.node;
							for (let t = e; t !== y;) {
								const e = t.parentPath;
								if (e === y && isOptionalCall() && n.optional) {
									O = e.node;
									break;
								}
								O = toNonOptional(e, O), t = e;
							}
							const j = y.parentPath;
							if (h(O) && j.isOptionalCallExpression({
								callee: y.node,
								optional: !0
							})) {
								const { object: t } = O;
								N = e.scope.maybeGenerateMemoised(t), N && (O.object = o("=", N, t));
							}
							let F = y;
							(_ || P) && (F = j, O = j.node);
							const L = w ? o("=", c(I), c(C)) : c(I);
							if (T) {
								let e;
								e = t ? a("!=", L, x()) : b("&&", a("!==", L, x()), a("!==", c(I), g.buildUndefinedNode())), F.replaceWith(b("&&", e, O));
							} else {
								let e;
								e = t ? a("==", L, x()) : b("||", a("===", L, x()), a("===", c(I), g.buildUndefinedNode())), F.replaceWith(u(e, _ ? l(!0) : g.buildUndefinedNode(), O));
							}
							if (N) {
								const e = j.node;
								j.replaceWith(v(E(e.callee, d("call"), !1, !0), [c(N), ...e.arguments], !1));
							}
							return;
						}
						if (y(n, { argument: r })) {
							if (this.simpleSet) return void e.replaceWith(this.simpleSet(e));
							const { operator: t, prefix: i } = n;
							this.memoise(e, 2);
							const a = g.generateUidIdentifierBasedOnNode(r);
							g.push({ id: a });
							const l = [o("=", c(a), this.get(e))];
							if (i) {
								l.push(S(t, c(a), i));
								const r = T(l);
								s.replaceWith(this.set(e, r));
								return;
							}
							{
								const n = g.generateUidIdentifierBasedOnNode(r);
								g.push({ id: n }), l.push(o("=", c(n), S(t, c(a), i)), c(a));
								const p = T(l);
								s.replaceWith(T([this.set(e, p), c(n)]));
								return;
							}
						}
						if (s.isAssignmentExpression({ left: r })) handleAssignment(this, e, s);
						else {
							if (!s.isCallExpression({ callee: r })) return s.isOptionalCallExpression({ callee: r }) ? g.path.isPattern() ? void s.replaceWith(p(i([], s.node), [])) : void s.replaceWith(this.optionalCall(e, s.node.arguments)) : void (this.delete && s.isUnaryExpression({ operator: "delete" }) ? s.replaceWith(this.delete(e)) : s.isForXStatement({ left: r }) || s.isObjectProperty({ value: r }) && s.parentPath.isObjectPattern() || s.isAssignmentPattern({ left: r }) && s.parentPath.isObjectProperty({ value: n }) && s.parentPath.parentPath.isObjectPattern() || s.isArrayPattern() || s.isAssignmentPattern({ left: r }) && s.parentPath.isArrayPattern() || s.isRestElement() ? e.replaceWith(this.destructureSet(e)) : s.isTaggedTemplateExpression() ? e.replaceWith(this.boundGet(e)) : e.replaceWith(this.get(e)));
							s.replaceWith(this.call(e, s.node.arguments));
						}
					}
				};
				function handleAssignment(e, t, r) {
					if (e.simpleSet) return void t.replaceWith(e.simpleSet(t));
					const { operator: n, right: i } = r.node;
					if ("=" === n) r.replaceWith(e.set(t, i));
					else {
						const o = n.slice(0, -1);
						s.includes(o) ? (e.memoise(t, 1), r.replaceWith(b(o, e.get(t), e.set(t, i)))) : (e.memoise(t, 2), r.replaceWith(e.set(t, a(o, e.get(t), i))));
					}
				}
				t.default = function(e, t, r) {
					e.traverse(t, Object.assign({}, P, r, { memoiser: new AssignmentMemoiser() }));
				};
			},
			"./node_modules/.pnpm/@babel+helper-module-imports@7.27.1/node_modules/@babel/helper-module-imports/lib/import-builder.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("assert");
				const { callExpression: i, cloneNode: o, expressionStatement: a, identifier: l, importDeclaration: p, importDefaultSpecifier: c, importNamespaceSpecifier: u, importSpecifier: d, memberExpression: h, stringLiteral: m, variableDeclaration: f, variableDeclarator: y } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
				t.default = class {
					constructor(e, t, r) {
						this._statements = [], this._resultName = null, this._importedSource = void 0, this._scope = t, this._hub = r, this._importedSource = e;
					}
					done() {
						return {
							statements: this._statements,
							resultName: this._resultName
						};
					}
					import() {
						return this._statements.push(p([], m(this._importedSource))), this;
					}
					require() {
						return this._statements.push(a(i(l("require"), [m(this._importedSource)]))), this;
					}
					namespace(e = "namespace") {
						const t = this._scope.generateUidIdentifier(e), r = this._statements[this._statements.length - 1];
						return n("ImportDeclaration" === r.type), n(0 === r.specifiers.length), r.specifiers = [u(t)], this._resultName = o(t), this;
					}
					default(e) {
						const t = this._scope.generateUidIdentifier(e), r = this._statements[this._statements.length - 1];
						return n("ImportDeclaration" === r.type), n(0 === r.specifiers.length), r.specifiers = [c(t)], this._resultName = o(t), this;
					}
					named(e, t) {
						if ("default" === t) return this.default(e);
						const r = this._scope.generateUidIdentifier(e), s = this._statements[this._statements.length - 1];
						return n("ImportDeclaration" === s.type), n(0 === s.specifiers.length), s.specifiers = [d(r, l(t))], this._resultName = o(r), this;
					}
					var(e) {
						const t = this._scope.generateUidIdentifier(e);
						let r = this._statements[this._statements.length - 1];
						return "ExpressionStatement" !== r.type && (n(this._resultName), r = a(this._resultName), this._statements.push(r)), this._statements[this._statements.length - 1] = f("var", [y(t, r.expression)]), this._resultName = o(t), this;
					}
					defaultInterop() {
						return this._interop(this._hub.addHelper("interopRequireDefault"));
					}
					wildcardInterop() {
						return this._interop(this._hub.addHelper("interopRequireWildcard"));
					}
					_interop(e) {
						const t = this._statements[this._statements.length - 1];
						return "ExpressionStatement" === t.type ? t.expression = i(e, [t.expression]) : "VariableDeclaration" === t.type ? (n(1 === t.declarations.length), t.declarations[0].init = i(e, [t.declarations[0].init])) : n.fail("Unexpected type."), this;
					}
					prop(e) {
						const t = this._statements[this._statements.length - 1];
						return "ExpressionStatement" === t.type ? t.expression = h(t.expression, l(e)) : "VariableDeclaration" === t.type ? (n(1 === t.declarations.length), t.declarations[0].init = h(t.declarations[0].init, l(e))) : n.fail("Unexpected type:" + t.type), this;
					}
					read(e) {
						this._resultName = h(this._resultName, l(e));
					}
				};
			},
			"./node_modules/.pnpm/@babel+helper-module-imports@7.27.1/node_modules/@babel/helper-module-imports/lib/import-injector.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("assert"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), i = r("./node_modules/.pnpm/@babel+helper-module-imports@7.27.1/node_modules/@babel/helper-module-imports/lib/import-builder.js"), o = r("./node_modules/.pnpm/@babel+helper-module-imports@7.27.1/node_modules/@babel/helper-module-imports/lib/is-module.js");
				const { identifier: a, importSpecifier: l, numericLiteral: p, sequenceExpression: c, isImportDeclaration: u } = s;
				function isValueImport(e) {
					return "type" !== e.importKind && "typeof" !== e.importKind;
				}
				function hasNamespaceImport(e) {
					return 1 === e.specifiers.length && "ImportNamespaceSpecifier" === e.specifiers[0].type || 2 === e.specifiers.length && "ImportNamespaceSpecifier" === e.specifiers[1].type;
				}
				function hasDefaultImport(e) {
					return e.specifiers.length > 0 && "ImportDefaultSpecifier" === e.specifiers[0].type;
				}
				function maybeAppendImportSpecifiers(e, t) {
					return e.specifiers.length ? !t.specifiers.length || !hasNamespaceImport(e) && !hasNamespaceImport(t) && (hasDefaultImport(t) && (hasDefaultImport(e) ? t.specifiers[0] = l(t.specifiers[0].local, a("default")) : e.specifiers.unshift(t.specifiers.shift())), e.specifiers.push(...t.specifiers), !0) : (e.specifiers = t.specifiers, !0);
				}
				t.default = class {
					constructor(e, t, r) {
						this._defaultOpts = {
							importedSource: null,
							importedType: "commonjs",
							importedInterop: "babel",
							importingInterop: "babel",
							ensureLiveReference: !1,
							ensureNoContext: !1,
							importPosition: "before"
						};
						const n = e.find((e) => e.isProgram());
						this._programPath = n, this._programScope = n.scope, this._hub = n.hub, this._defaultOpts = this._applyDefaults(t, r, !0);
					}
					addDefault(e, t) {
						return this.addNamed("default", e, t);
					}
					addNamed(e, t, r) {
						return n("string" == typeof e), this._generateImport(this._applyDefaults(t, r), e);
					}
					addNamespace(e, t) {
						return this._generateImport(this._applyDefaults(e, t), null);
					}
					addSideEffect(e, t) {
						return this._generateImport(this._applyDefaults(e, t), void 0);
					}
					_applyDefaults(e, t, r = !1) {
						let s;
						return "string" == typeof e ? s = Object.assign({}, this._defaultOpts, { importedSource: e }, t) : (n(!t, "Unexpected secondary arguments."), s = Object.assign({}, this._defaultOpts, e)), !r && t && (void 0 !== t.nameHint && (s.nameHint = t.nameHint), void 0 !== t.blockHoist && (s.blockHoist = t.blockHoist)), s;
					}
					_generateImport(e, t) {
						const r = "default" === t, n = !!t && !r, s = null === t, { importedSource: a, importedType: l, importedInterop: u, importingInterop: d, ensureLiveReference: h, ensureNoContext: m, nameHint: f, importPosition: y, blockHoist: b } = e;
						let g = f || t;
						const x = (0, o.default)(this._programPath), v = x && "node" === d, E = x && "babel" === d;
						if ("after" === y && !x) throw new Error("\"importPosition\": \"after\" is only supported in modules");
						const T = new i.default(a, this._programScope, this._hub);
						if ("es6" === l) {
							if (!v && !E) throw new Error("Cannot import an ES6 module from CommonJS");
							T.import(), s ? T.namespace(f || a) : (r || n) && T.named(g, t);
						} else {
							if ("commonjs" !== l) throw new Error(`Unexpected interopType "${l}"`);
							if ("babel" === u) if (v) {
								g = "default" !== g ? g : a;
								const e = `${a}$es6Default`;
								T.import(), s ? T.default(e).var(g || a).wildcardInterop() : r ? h ? T.default(e).var(g || a).defaultInterop().read("default") : T.default(e).var(g).defaultInterop().prop(t) : n && T.default(e).read(t);
							} else E ? (T.import(), s ? T.namespace(g || a) : (r || n) && T.named(g, t)) : (T.require(), s ? T.var(g || a).wildcardInterop() : (r || n) && h ? r ? (g = "default" !== g ? g : a, T.var(g).read(t), T.defaultInterop()) : T.var(a).read(t) : r ? T.var(g).defaultInterop().prop(t) : n && T.var(g).prop(t));
							else if ("compiled" === u) v ? (T.import(), s ? T.default(g || a) : (r || n) && T.default(a).read(g)) : E ? (T.import(), s ? T.namespace(g || a) : (r || n) && T.named(g, t)) : (T.require(), s ? T.var(g || a) : (r || n) && (h ? T.var(a).read(g) : T.prop(t).var(g)));
							else {
								if ("uncompiled" !== u) throw new Error(`Unknown importedInterop "${u}".`);
								if (r && h) throw new Error("No live reference for commonjs default");
								v ? (T.import(), s ? T.default(g || a) : r ? T.default(g) : n && T.default(a).read(g)) : E ? (T.import(), s ? T.default(g || a) : r ? T.default(g) : n && T.named(g, t)) : (T.require(), s ? T.var(g || a) : r ? T.var(g) : n && (h ? T.var(a).read(g) : T.var(g).prop(t)));
							}
						}
						const { statements: S, resultName: P } = T.done();
						return this._insertStatements(S, y, b), (r || n) && m && "Identifier" !== P.type ? c([p(0), P]) : P;
					}
					_insertStatements(e, t = "before", r = 3) {
						if ("after" === t) {
							if (this._insertStatementsAfter(e)) return;
						} else if (this._insertStatementsBefore(e, r)) return;
						this._programPath.unshiftContainer("body", e);
					}
					_insertStatementsBefore(e, t) {
						if (1 === e.length && u(e[0]) && isValueImport(e[0])) {
							const t = this._programPath.get("body").find((e) => e.isImportDeclaration() && isValueImport(e.node));
							if ((null == t ? void 0 : t.node.source.value) === e[0].source.value && maybeAppendImportSpecifiers(t.node, e[0])) return !0;
						}
						e.forEach((e) => {
							e._blockHoist = t;
						});
						const r = this._programPath.get("body").find((e) => {
							const t = e.node._blockHoist;
							return Number.isFinite(t) && t < 4;
						});
						return !!r && (r.insertBefore(e), !0);
					}
					_insertStatementsAfter(e) {
						const t = new Set(e), r = /* @__PURE__ */ new Map();
						for (const t of e) if (u(t) && isValueImport(t)) {
							const e = t.source.value;
							r.has(e) || r.set(e, []), r.get(e).push(t);
						}
						let n = null;
						for (const e of this._programPath.get("body")) if (e.isImportDeclaration() && isValueImport(e.node)) {
							n = e;
							const s = e.node.source.value, i = r.get(s);
							if (!i) continue;
							for (const r of i) t.has(r) && maybeAppendImportSpecifiers(e.node, r) && t.delete(r);
						}
						return 0 === t.size || (n && n.insertAfter(Array.from(t)), !!n);
					}
				};
			},
			"./node_modules/.pnpm/@babel+helper-module-imports@7.27.1/node_modules/@babel/helper-module-imports/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), Object.defineProperty(t, "ImportInjector", {
					enumerable: !0,
					get: function() {
						return n.default;
					}
				}), t.addDefault = function(e, t, r) {
					return new n.default(e).addDefault(t, r);
				}, t.addNamed = function(e, t, r, s) {
					return new n.default(e).addNamed(t, r, s);
				}, t.addNamespace = function(e, t, r) {
					return new n.default(e).addNamespace(t, r);
				}, t.addSideEffect = function(e, t, r) {
					return new n.default(e).addSideEffect(t, r);
				}, Object.defineProperty(t, "isModule", {
					enumerable: !0,
					get: function() {
						return s.default;
					}
				});
				var n = r("./node_modules/.pnpm/@babel+helper-module-imports@7.27.1/node_modules/@babel/helper-module-imports/lib/import-injector.js"), s = r("./node_modules/.pnpm/@babel+helper-module-imports@7.27.1/node_modules/@babel/helper-module-imports/lib/is-module.js");
			},
			"./node_modules/.pnpm/@babel+helper-module-imports@7.27.1/node_modules/@babel/helper-module-imports/lib/is-module.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return "module" === e.node.sourceType;
				};
			},
			"./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/dynamic-import.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.buildDynamicImport = function(e, t, r, s) {
					const i = n.types.isCallExpression(e) ? e.arguments[0] : e.source;
					if (n.types.isStringLiteral(i) || n.types.isTemplateLiteral(i) && 0 === i.quasis.length) return t ? n.template.expression.ast`
        Promise.resolve().then(() => ${s(i)})
      ` : s(i);
					const o = n.types.isTemplateLiteral(i) ? n.types.identifier("specifier") : n.types.templateLiteral([n.types.templateElement({ raw: "" }), n.types.templateElement({ raw: "" })], [n.types.identifier("specifier")]);
					return t ? n.template.expression.ast`
      (specifier =>
        new Promise(r => r(${o}))
          .then(s => ${s(n.types.identifier("s"))})
      )(${i})
    ` : r ? n.template.expression.ast`
      (specifier =>
        new Promise(r => r(${s(o)}))
      )(${i})
    ` : n.template.expression.ast`
      (specifier => ${s(o)})(${i})
    `;
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js");
				t.getDynamicImportSource = function(e) {
					const [t] = e.arguments;
					return n.types.isStringLiteral(t) || n.types.isTemplateLiteral(t) ? t : n.template.expression.ast`\`\${${t}}\``;
				};
			},
			"./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/get-module-name.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = getModuleName;
				{
					const e = getModuleName;
					t.default = getModuleName = function(t, r) {
						var n, s, i, o;
						return e(t, {
							moduleId: null != (n = r.moduleId) ? n : t.moduleId,
							moduleIds: null != (s = r.moduleIds) ? s : t.moduleIds,
							getModuleId: null != (i = r.getModuleId) ? i : t.getModuleId,
							moduleRoot: null != (o = r.moduleRoot) ? o : t.moduleRoot
						});
					};
				}
				function getModuleName(e, t) {
					const { filename: r, filenameRelative: n = r, sourceRoot: s = t.moduleRoot } = e, { moduleId: i, moduleIds: o = !!i, getModuleId: a, moduleRoot: l = s } = t;
					if (!o) return null;
					if (null != i && !a) return i;
					let p = null != l ? l + "/" : "";
					if (n) {
						const e = null != s ? new RegExp("^" + s + "/?") : "";
						p += n.replace(e, "").replace(/\.\w*$/, "");
					}
					return p = p.replace(/\\/g, "/"), a && a(p) || p;
				}
			},
			"./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), Object.defineProperty(t, "buildDynamicImport", {
					enumerable: !0,
					get: function() {
						return c.buildDynamicImport;
					}
				}), t.buildNamespaceInitStatements = function(e, t, r = !1, n = p.wrapReference) {
					var i;
					const o = [], a = s.types.identifier(t.name);
					for (const e of t.importsNamespace) e !== t.name && o.push(s.template.statement`var NAME = SOURCE;`({
						NAME: e,
						SOURCE: s.types.cloneNode(a)
					}));
					const l = null != (i = n(a, t.wrap)) ? i : a;
					r && o.push(...buildReexportsFromMeta(e, t, !0, n));
					for (const r of t.reexportNamespace) o.push((s.types.isIdentifier(l) ? s.template.statement`EXPORTS.NAME = NAMESPACE;` : s.template.statement`
            Object.defineProperty(EXPORTS, "NAME", {
              enumerable: true,
              get: function() {
                return NAMESPACE;
              }
            });
          `)({
						EXPORTS: e.exportName,
						NAME: r,
						NAMESPACE: s.types.cloneNode(l)
					}));
					if (t.reexportAll) {
						const n = function(e, t, r) {
							return (r ? s.template.statement`
        Object.keys(NAMESPACE).forEach(function(key) {
          if (key === "default" || key === "__esModule") return;
          VERIFY_NAME_LIST;
          if (key in EXPORTS && EXPORTS[key] === NAMESPACE[key]) return;

          EXPORTS[key] = NAMESPACE[key];
        });
      ` : s.template.statement`
        Object.keys(NAMESPACE).forEach(function(key) {
          if (key === "default" || key === "__esModule") return;
          VERIFY_NAME_LIST;
          if (key in EXPORTS && EXPORTS[key] === NAMESPACE[key]) return;

          Object.defineProperty(EXPORTS, key, {
            enumerable: true,
            get: function() {
              return NAMESPACE[key];
            },
          });
        });
    `)({
								NAMESPACE: t,
								EXPORTS: e.exportName,
								VERIFY_NAME_LIST: e.exportNameListName ? s.template`
            if (Object.prototype.hasOwnProperty.call(EXPORTS_LIST, key)) return;
          `({ EXPORTS_LIST: e.exportNameListName }) : null
							});
						}(e, s.types.cloneNode(l), r);
						n.loc = t.reexportAll.loc, o.push(n);
					}
					return o;
				}, t.ensureStatementsHoisted = function(e) {
					e.forEach((e) => {
						e._blockHoist = 3;
					});
				}, Object.defineProperty(t, "getModuleName", {
					enumerable: !0,
					get: function() {
						return u.default;
					}
				}), Object.defineProperty(t, "hasExports", {
					enumerable: !0,
					get: function() {
						return l.hasExports;
					}
				}), Object.defineProperty(t, "isModule", {
					enumerable: !0,
					get: function() {
						return i.isModule;
					}
				}), Object.defineProperty(t, "isSideEffectImport", {
					enumerable: !0,
					get: function() {
						return l.isSideEffectImport;
					}
				}), t.rewriteModuleStatementsAndPrepareHeader = function(e, { exportName: t, strict: r, allowTopLevelThis: c, strictMode: u, noInterop: d, importInterop: h = d ? "none" : "babel", lazy: m, getWrapperPayload: f = p.toGetWrapperPayload(null != m && m), wrapReference: y = p.wrapReference, esNamespaceOnly: b, filename: g, constantReexports: x = arguments[1].loose, enumerableModuleMeta: v = arguments[1].loose, noIncompleteNsImportDetection: E }) {
					(0, l.validateImportInteropOption)(h), n((0, i.isModule)(e), "Cannot process module statements in a script"), e.node.sourceType = "script";
					const T = (0, l.default)(e, t, {
						importInterop: h,
						initializeReexports: x,
						getWrapperPayload: f,
						esNamespaceOnly: b,
						filename: g
					});
					c || (0, o.default)(e);
					if ((0, a.default)(e, T, y), !1 !== u) e.node.directives.some((e) => "use strict" === e.value.value) || e.unshiftContainer("directives", s.types.directive(s.types.directiveLiteral("use strict")));
					const S = [];
					(0, l.hasExports)(T) && !r && S.push(function(e, t = !1) {
						return (t ? s.template.statement`
        EXPORTS.__esModule = true;
      ` : s.template.statement`
        Object.defineProperty(EXPORTS, "__esModule", {
          value: true,
        });
      `)({ EXPORTS: e.exportName });
					}(T, v));
					const P = function(e, t) {
						const r = Object.create(null);
						for (const e of t.local.values()) for (const t of e.names) r[t] = !0;
						let n = !1;
						for (const e of t.source.values()) {
							for (const t of e.reexports.keys()) r[t] = !0;
							for (const t of e.reexportNamespace) r[t] = !0;
							n = n || !!e.reexportAll;
						}
						if (!n || 0 === Object.keys(r).length) return null;
						const i = e.scope.generateUidIdentifier("exportNames");
						return delete r.default, {
							name: i.name,
							statement: s.types.variableDeclaration("var", [s.types.variableDeclarator(i, s.types.valueToNode(r))])
						};
					}(e, T);
					P && (T.exportNameListName = P.name, S.push(P.statement));
					return S.push(...function(e, t, r, n = !1, i = !1) {
						const o = [];
						for (const [e, r] of t.local) if ("import" === r.kind);
						else if ("hoisted" === r.kind) o.push([r.names[0], buildInitStatement(t, r.names, s.types.identifier(e))]);
						else if (!i) for (const e of r.names) o.push([e, null]);
						for (const e of t.source.values()) {
							if (!n) {
								const n = buildReexportsFromMeta(t, e, !1, r), s = [...e.reexports.keys()];
								for (let e = 0; e < n.length; e++) o.push([s[e], n[e]]);
							}
							if (!i) for (const t of e.reexportNamespace) o.push([t, null]);
						}
						o.sort(([e], [t]) => e < t ? -1 : t < e ? 1 : 0);
						const a = [];
						if (i) for (const [, e] of o) a.push(e);
						else {
							const r = 100;
							for (let n = 0; n < o.length; n += r) {
								let s = [];
								for (let i = 0; i < r && n + i < o.length; i++) {
									const [r, l] = o[n + i];
									null !== l ? (s.length > 0 && (a.push(buildInitStatement(t, s, e.scope.buildUndefinedNode())), s = []), a.push(l)) : s.push(r);
								}
								s.length > 0 && a.push(buildInitStatement(t, s, e.scope.buildUndefinedNode()));
							}
						}
						return a;
					}(e, T, y, x, E)), {
						meta: T,
						headers: S
					};
				}, Object.defineProperty(t, "rewriteThis", {
					enumerable: !0,
					get: function() {
						return o.default;
					}
				}), t.wrapInterop = function(e, t, r) {
					if ("none" === r) return null;
					if ("node-namespace" === r) return s.types.callExpression(e.hub.addHelper("interopRequireWildcard"), [t, s.types.booleanLiteral(!0)]);
					if ("node-default" === r) return null;
					let n;
					if ("default" === r) n = "interopRequireDefault";
					else {
						if ("namespace" !== r) throw new Error(`Unknown interop: ${r}`);
						n = "interopRequireWildcard";
					}
					return s.types.callExpression(e.hub.addHelper(n), [t]);
				};
				var n = r("assert"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), i = r("./node_modules/.pnpm/@babel+helper-module-imports@7.27.1/node_modules/@babel/helper-module-imports/lib/index.js"), o = r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/rewrite-this.js"), a = r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/rewrite-live-references.js"), l = r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/normalize-and-load-metadata.js"), p = r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/lazy-modules.js"), c = r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/dynamic-import.js"), u = r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/get-module-name.js");
				t.getDynamicImportSource = r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/dynamic-import.js").getDynamicImportSource;
				const d = {
					constant: ({ exports: e, exportName: t, namespaceImport: r }) => s.template.statement.ast`
      ${e}.${t} = ${r};
    `,
					constantComputed: ({ exports: e, exportName: t, namespaceImport: r }) => s.template.statement.ast`
      ${e}["${t}"] = ${r};
    `,
					spec: ({ exports: e, exportName: t, namespaceImport: r }) => s.template.statement.ast`
      Object.defineProperty(${e}, "${t}", {
        enumerable: true,
        get: function() {
          return ${r};
        },
      });
    `
				};
				function buildReexportsFromMeta(e, t, r, n) {
					var i;
					let o = s.types.identifier(t.name);
					o = null != (i = n(o, t.wrap)) ? i : o;
					const { stringSpecifiers: a } = e;
					return Array.from(t.reexports, ([n, i]) => {
						let l = s.types.cloneNode(o);
						"default" === i && "node-default" === t.interop || (l = a.has(i) ? s.types.memberExpression(l, s.types.stringLiteral(i), !0) : s.types.memberExpression(l, s.types.identifier(i)));
						const p = {
							exports: e.exportName,
							exportName: n,
							namespaceImport: l
						};
						return r || s.types.isIdentifier(l) ? a.has(n) ? d.constantComputed(p) : d.constant(p) : d.spec(p);
					});
				}
				const h = {
					computed: ({ exports: e, name: t, value: r }) => s.template.expression.ast`${e}["${t}"] = ${r}`,
					default: ({ exports: e, name: t, value: r }) => s.template.expression.ast`${e}.${t} = ${r}`,
					define: ({ exports: e, name: t, value: r }) => s.template.expression.ast`
      Object.defineProperty(${e}, "${t}", {
        enumerable: true,
        value: void 0,
        writable: true
      })["${t}"] = ${r}`
				};
				function buildInitStatement(e, t, r) {
					const { stringSpecifiers: n, exportName: i } = e;
					return s.types.expressionStatement(t.reduce((e, t) => {
						const r = {
							exports: i,
							name: t,
							value: e
						};
						return "__proto__" === t ? h.define(r) : n.has(t) ? h.computed(r) : h.default(r);
					}, r));
				}
			},
			"./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/lazy-modules.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.toGetWrapperPayload = function(e) {
					return (t, r) => {
						if (!1 === e) return null;
						if ((0, s.isSideEffectImport)(r) || r.reexportAll) return null;
						if (!0 === e) return t.includes(".") ? null : "lazy";
						if (Array.isArray(e)) return e.includes(t) ? "lazy" : null;
						if ("function" == typeof e) return e(t) ? "lazy" : null;
						throw new Error(".lazy must be a boolean, string array, or function");
					};
				}, t.wrapReference = function(e, t) {
					return "lazy" === t ? n.types.callExpression(e, []) : null;
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), s = r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/normalize-and-load-metadata.js");
			},
			"./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/normalize-and-load-metadata.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, { importInterop: s, initializeReexports: i = !1, getWrapperPayload: o, esNamespaceOnly: a = !1, filename: l }) {
					t || (t = e.scope.generateUidIdentifier("exports").name);
					const p = /* @__PURE__ */ new Set();
					(function(e) {
						e.get("body").forEach((e) => {
							e.isExportDefaultDeclaration() && (e.splitExportDeclaration ?? (e.splitExportDeclaration = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js").NodePath.prototype.splitExportDeclaration), e.splitExportDeclaration());
						});
					})(e);
					const { local: c, sources: u, hasExports: d } = function(e, { getWrapperPayload: t, initializeReexports: r }, s) {
						const i = function(e, t, r) {
							const n = /* @__PURE__ */ new Map(), s = e.scope, i = e.get("body");
							i.forEach((e) => {
								let r;
								if (e.isImportDeclaration()) r = "import";
								else {
									if (e.isExportDefaultDeclaration() && (e = e.get("declaration")), e.isExportNamedDeclaration()) {
										if (e.node.declaration) e = e.get("declaration");
										else if (t && e.node.source && e.get("source").isStringLiteral()) return void e.get("specifiers").forEach((e) => {
											assertExportSpecifier(e), n.set(e.get("local").node.name, "block");
										});
									}
									if (e.isFunctionDeclaration()) r = "hoisted";
									else if (e.isClassDeclaration()) r = "block";
									else if (e.isVariableDeclaration({ kind: "var" })) r = "var";
									else {
										if (!e.isVariableDeclaration()) return;
										r = "block";
									}
								}
								Object.keys(e.getOuterBindingIdentifiers()).forEach((e) => {
									n.set(e, r);
								});
							});
							const o = /* @__PURE__ */ new Map(), getLocalMetadata = (e) => {
								const t = e.node.name;
								let r = o.get(t);
								if (!r) {
									var i, a;
									const l = null != (i = n.get(t)) ? i : null == (a = s.getBinding(t)) ? void 0 : a.kind;
									if (void 0 === l) throw e.buildCodeFrameError(`Exporting local "${t}", which is not declared.`);
									r = {
										names: [],
										kind: l
									}, o.set(t, r);
								}
								return r;
							};
							return i.forEach((e) => {
								if (!e.isExportNamedDeclaration() || !t && e.node.source) {
									if (e.isExportDefaultDeclaration()) {
										const t = e.get("declaration");
										if (!t.isFunctionDeclaration() && !t.isClassDeclaration()) throw t.buildCodeFrameError("Unexpected default expression export.");
										getLocalMetadata(t.get("id")).names.push("default");
									}
								} else if (e.node.declaration) {
									const t = e.get("declaration"), r = t.getOuterBindingIdentifierPaths();
									Object.keys(r).forEach((e) => {
										if ("__esModule" === e) throw t.buildCodeFrameError("Illegal export \"__esModule\".");
										getLocalMetadata(r[e]).names.push(e);
									});
								} else e.get("specifiers").forEach((e) => {
									const t = e.get("local"), n = e.get("exported"), s = getLocalMetadata(t), i = getExportSpecifierName(n, r);
									if ("__esModule" === i) throw n.buildCodeFrameError("Illegal export \"__esModule\".");
									s.names.push(i);
								});
							}), o;
						}(e, r, s), o = /* @__PURE__ */ new Map(), a = /* @__PURE__ */ new Map(), getData = (t, r) => {
							const s = t.value;
							let i = a.get(s);
							return i ? o.get(s).push(r) : (i = {
								name: e.scope.generateUidIdentifier((0, n.basename)(s, (0, n.extname)(s))).name,
								interop: "none",
								loc: null,
								imports: /* @__PURE__ */ new Map(),
								importsNamespace: /* @__PURE__ */ new Set(),
								reexports: /* @__PURE__ */ new Map(),
								reexportNamespace: /* @__PURE__ */ new Set(),
								reexportAll: null,
								wrap: null,
								get lazy() {
									return "lazy" === this.wrap;
								},
								referenced: !1
							}, a.set(s, i), o.set(s, [r])), i;
						};
						let l = !1;
						e.get("body").forEach((e) => {
							if (e.isImportDeclaration()) {
								const t = getData(e.node.source, e.node);
								t.loc || (t.loc = e.node.loc), e.get("specifiers").forEach((e) => {
									if (e.isImportDefaultSpecifier()) {
										const r = e.get("local").node.name;
										t.imports.set(r, "default");
										const n = i.get(r);
										n && (i.delete(r), n.names.forEach((e) => {
											t.reexports.set(e, "default");
										}), t.referenced = !0);
									} else if (e.isImportNamespaceSpecifier()) {
										const r = e.get("local").node.name;
										t.importsNamespace.add(r);
										const n = i.get(r);
										n && (i.delete(r), n.names.forEach((e) => {
											t.reexportNamespace.add(e);
										}), t.referenced = !0);
									} else if (e.isImportSpecifier()) {
										const r = getExportSpecifierName(e.get("imported"), s), n = e.get("local").node.name;
										t.imports.set(n, r);
										const o = i.get(n);
										o && (i.delete(n), o.names.forEach((e) => {
											t.reexports.set(e, r);
										}), t.referenced = !0);
									}
								});
							} else if (e.isExportAllDeclaration()) {
								l = !0;
								const t = getData(e.node.source, e.node);
								t.loc || (t.loc = e.node.loc), t.reexportAll = { loc: e.node.loc }, t.referenced = !0;
							} else if (e.isExportNamedDeclaration() && e.node.source) {
								l = !0;
								const t = getData(e.node.source, e.node);
								t.loc || (t.loc = e.node.loc), e.get("specifiers").forEach((e) => {
									assertExportSpecifier(e);
									const r = getExportSpecifierName(e.get("local"), s), n = getExportSpecifierName(e.get("exported"), s);
									if (t.reexports.set(n, r), t.referenced = !0, "__esModule" === n) throw e.get("exported").buildCodeFrameError("Illegal export \"__esModule\".");
								});
							} else (e.isExportNamedDeclaration() || e.isExportDefaultDeclaration()) && (l = !0);
						});
						for (const e of a.values()) {
							let t = !1, r = !1;
							e.importsNamespace.size > 0 && (t = !0, r = !0), e.reexportAll && (r = !0);
							for (const n of e.imports.values()) "default" === n ? t = !0 : r = !0;
							for (const n of e.reexports.values()) "default" === n ? t = !0 : r = !0;
							t && r ? e.interop = "namespace" : t && (e.interop = "default");
						}
						if (t) for (const [e, r] of a) r.wrap = t(e, r, o.get(e));
						return {
							hasExports: l,
							local: i,
							sources: a
						};
					}(e, {
						initializeReexports: i,
						getWrapperPayload: o
					}, p);
					(function(e) {
						e.get("body").forEach((e) => {
							if (e.isImportDeclaration()) e.remove();
							else if (e.isExportNamedDeclaration()) e.node.declaration ? (e.node.declaration._blockHoist = e.node._blockHoist, e.replaceWith(e.node.declaration)) : e.remove();
							else if (e.isExportDefaultDeclaration()) {
								const t = e.get("declaration");
								if (!t.isFunctionDeclaration() && !t.isClassDeclaration()) throw t.buildCodeFrameError("Unexpected default expression export.");
								t._blockHoist = e.node._blockHoist, e.replaceWith(t);
							} else e.isExportAllDeclaration() && e.remove();
						});
					})(e);
					for (const [e, t] of u) {
						const { importsNamespace: r, imports: n } = t;
						if (r.size > 0 && 0 === n.size) {
							const [e] = r;
							t.name = e;
						}
						const i = resolveImportInterop(s, e, l);
						"none" === i ? t.interop = "none" : "node" === i && "namespace" === t.interop ? t.interop = "node-namespace" : "node" === i && "default" === t.interop ? t.interop = "node-default" : a && "namespace" === t.interop && (t.interop = "default");
					}
					return {
						exportName: t,
						exportNameListName: null,
						hasExports: d,
						local: c,
						source: u,
						stringSpecifiers: p
					};
				}, t.hasExports = function(e) {
					return e.hasExports;
				}, t.isSideEffectImport = function(e) {
					return 0 === e.imports.size && 0 === e.importsNamespace.size && 0 === e.reexports.size && 0 === e.reexportNamespace.size && !e.reexportAll;
				}, t.validateImportInteropOption = validateImportInteropOption;
				var n = r("path"), s = r("./node_modules/.pnpm/@babel+helper-validator-identifier@7.27.1/node_modules/@babel/helper-validator-identifier/lib/index.js");
				function validateImportInteropOption(e) {
					if ("function" != typeof e && "none" !== e && "babel" !== e && "node" !== e) throw new Error(`.importInterop must be one of "none", "babel", "node", or a function returning one of those values (received ${e}).`);
					return e;
				}
				function resolveImportInterop(e, t, r) {
					return "function" == typeof e ? validateImportInteropOption(e(t, r)) : e;
				}
				function getExportSpecifierName(e, t) {
					if (e.isIdentifier()) return e.node.name;
					if (e.isStringLiteral()) {
						const r = e.node.value;
						return (0, s.isIdentifierName)(r) || t.add(r), r;
					}
					throw new Error(`Expected export specifier to be either Identifier or StringLiteral, got ${e.node.type}`);
				}
				function assertExportSpecifier(e) {
					if (!e.isExportSpecifier()) throw e.isExportNamespaceSpecifier() ? e.buildCodeFrameError("Export namespace should be first transformed by `@babel/plugin-transform-export-namespace-from`.") : e.buildCodeFrameError("Unexpected export specifier type");
				}
			},
			"./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/rewrite-live-references.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					const o = /* @__PURE__ */ new Map(), a = /* @__PURE__ */ new Map(), requeueInParent = (t) => {
						e.requeue(t);
					};
					for (const [e, r] of t.source) {
						for (const [t, n] of r.imports) o.set(t, [
							e,
							n,
							null
						]);
						for (const t of r.importsNamespace) o.set(t, [
							e,
							null,
							t
						]);
					}
					for (const [e, r] of t.local) {
						let t = a.get(e);
						t || (t = [], a.set(e, t)), t.push(...r.names);
					}
					const l = {
						metadata: t,
						requeueInParent,
						scope: e.scope,
						exported: a
					};
					e.traverse(s, l);
					const p = {
						seen: /* @__PURE__ */ new WeakSet(),
						metadata: t,
						requeueInParent,
						scope: e.scope,
						imported: o,
						exported: a,
						buildImportReference([e, s, i], o) {
							const a = t.source.get(e);
							if (a.referenced = !0, i) {
								var l;
								if (a.wrap) o = null != (l = r(o, a.wrap)) ? l : o;
								return o;
							}
							let p = n.types.identifier(a.name);
							var c;
							a.wrap && (p = null != (c = r(p, a.wrap)) ? c : p);
							if ("default" === s && "node-default" === a.interop) return p;
							const u = t.stringSpecifiers.has(s);
							return n.types.memberExpression(p, u ? n.types.stringLiteral(s) : n.types.identifier(s), u);
						}
					};
					e.traverse(i, p);
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js");
				const s = {
					Scope(e) {
						e.skip();
					},
					ClassDeclaration(e) {
						const { requeueInParent: t, exported: r, metadata: s } = this, { id: i } = e.node;
						if (!i) throw new Error("Expected class to have a name");
						const o = i.name, a = r.get(o) || [];
						if (a.length > 0) {
							const r = n.types.expressionStatement(buildBindingExportAssignmentExpression(s, a, n.types.identifier(o), e.scope));
							r._blockHoist = e.node._blockHoist, t(e.insertAfter(r)[0]);
						}
					},
					VariableDeclaration(e) {
						const { requeueInParent: t, exported: r, metadata: s } = this, i = "var" === e.node.kind;
						for (const o of e.get("declarations")) {
							const { id: a } = o.node;
							let { init: l } = o.node;
							if (!n.types.isIdentifier(a) || !r.has(a.name) || n.types.isArrowFunctionExpression(l) || n.types.isFunctionExpression(l) && !l.id || n.types.isClassExpression(l) && !l.id) {
								for (const i of Object.keys(o.getOuterBindingIdentifiers())) if (r.has(i)) {
									const o = n.types.expressionStatement(buildBindingExportAssignmentExpression(s, r.get(i), n.types.identifier(i), e.scope));
									o._blockHoist = e.node._blockHoist, t(e.insertAfter(o)[0]);
								}
							} else {
								if (!l) {
									if (i) continue;
									l = e.scope.buildUndefinedNode();
								}
								o.node.init = buildBindingExportAssignmentExpression(s, r.get(a.name), l, e.scope), t(o.get("init"));
							}
						}
					}
				}, buildBindingExportAssignmentExpression = (e, t, r, s) => {
					const i = e.exportName;
					for (let e = s; null != e; e = e.parent) e.hasOwnBinding(i) && e.rename(i);
					return (t || []).reduce((t, r) => {
						const { stringSpecifiers: s } = e, o = s.has(r);
						return n.types.assignmentExpression("=", n.types.memberExpression(n.types.identifier(i), o ? n.types.stringLiteral(r) : n.types.identifier(r), o), t);
					}, r);
				}, buildImportThrow = (e) => n.template.expression.ast`
    (function() {
      throw new Error('"' + '${e}' + '" is read-only.');
    })()
  `, i = {
					ReferencedIdentifier(e) {
						const { seen: t, buildImportReference: r, scope: s, imported: i, requeueInParent: o } = this;
						if (t.has(e.node)) return;
						t.add(e.node);
						const a = e.node.name, l = i.get(a);
						if (l) {
							if (function(e) {
								do
									switch (e.parent.type) {
										case "TSTypeAnnotation":
										case "TSTypeAliasDeclaration":
										case "TSTypeReference":
										case "TypeAnnotation":
										case "TypeAlias": return !0;
										case "ExportSpecifier": return "type" === e.parentPath.parent.exportKind;
										default: if (e.parentPath.isStatement() || e.parentPath.isExpression()) return !1;
									}
								while (e = e.parentPath);
							}(e)) throw e.buildCodeFrameError(`Cannot transform the imported binding "${a}" since it's also used in a type annotation. Please strip type annotations using @babel/preset-typescript or @babel/preset-flow.`);
							const t = e.scope.getBinding(a);
							if (s.getBinding(a) !== t) return;
							const i = r(l, e.node);
							if (i.loc = e.node.loc, (e.parentPath.isCallExpression({ callee: e.node }) || e.parentPath.isOptionalCallExpression({ callee: e.node }) || e.parentPath.isTaggedTemplateExpression({ tag: e.node })) && n.types.isMemberExpression(i)) e.replaceWith(n.types.sequenceExpression([n.types.numericLiteral(0), i]));
							else if (e.isJSXIdentifier() && n.types.isMemberExpression(i)) {
								const { object: t, property: r } = i;
								e.replaceWith(n.types.jsxMemberExpression(n.types.jsxIdentifier(t.name), n.types.jsxIdentifier(r.name)));
							} else e.replaceWith(i);
							o(e), e.skip();
						}
					},
					UpdateExpression(e) {
						const { scope: t, seen: r, imported: s, exported: i, requeueInParent: o, buildImportReference: a } = this;
						if (r.has(e.node)) return;
						r.add(e.node);
						const l = e.get("argument");
						if (l.isMemberExpression()) return;
						const p = e.node;
						if (l.isIdentifier()) {
							const r = l.node.name;
							if (t.getBinding(r) !== e.scope.getBinding(r)) return;
							const o = i.get(r), c = s.get(r);
							if ((null == o ? void 0 : o.length) > 0 || c) if (c) e.replaceWith(n.types.assignmentExpression(p.operator[0] + "=", a(c, l.node), buildImportThrow(r)));
							else if (p.prefix) e.replaceWith(buildBindingExportAssignmentExpression(this.metadata, o, n.types.cloneNode(p), e.scope));
							else {
								const s = t.generateDeclaredUidIdentifier(r);
								e.replaceWith(n.types.sequenceExpression([
									n.types.assignmentExpression("=", n.types.cloneNode(s), n.types.cloneNode(p)),
									buildBindingExportAssignmentExpression(this.metadata, o, n.types.identifier(r), e.scope),
									n.types.cloneNode(s)
								]));
							}
						}
						o(e), e.skip();
					},
					AssignmentExpression: { exit(e) {
						const { scope: t, seen: r, imported: s, exported: i, requeueInParent: o, buildImportReference: a } = this;
						if (r.has(e.node)) return;
						r.add(e.node);
						const l = e.get("left");
						if (!l.isMemberExpression()) if (l.isIdentifier()) {
							const r = l.node.name;
							if (t.getBinding(r) !== e.scope.getBinding(r)) return;
							const p = i.get(r), c = s.get(r);
							if ((null == p ? void 0 : p.length) > 0 || c) {
								const t = e.node;
								c && (t.left = a(c, l.node), t.right = n.types.sequenceExpression([t.right, buildImportThrow(r)]));
								const { operator: s } = t;
								let i;
								i = "=" === s ? t : "&&=" === s || "||=" === s || "??=" === s ? n.types.assignmentExpression("=", t.left, n.types.logicalExpression(s.slice(0, -1), n.types.cloneNode(t.left), t.right)) : n.types.assignmentExpression("=", t.left, n.types.binaryExpression(s.slice(0, -1), n.types.cloneNode(t.left), t.right)), e.replaceWith(buildBindingExportAssignmentExpression(this.metadata, p, i, e.scope)), o(e), e.skip();
							}
						} else {
							const r = l.getOuterBindingIdentifiers(), a = Object.keys(r).filter((r) => t.getBinding(r) === e.scope.getBinding(r)), p = a.find((e) => s.has(e));
							p && (e.node.right = n.types.sequenceExpression([e.node.right, buildImportThrow(p)]));
							const c = [];
							if (a.forEach((t) => {
								const r = i.get(t) || [];
								r.length > 0 && c.push(buildBindingExportAssignmentExpression(this.metadata, r, n.types.identifier(t), e.scope));
							}), c.length > 0) {
								let t = n.types.sequenceExpression(c);
								e.parentPath.isExpressionStatement() && (t = n.types.expressionStatement(t), t._blockHoist = e.parentPath.node._blockHoist);
								o(e.insertAfter(t)[0]);
							}
						}
					} },
					ForXStatement(e) {
						const { scope: t, node: r } = e, { left: s } = r, { exported: i, imported: o, scope: a } = this;
						if (!n.types.isVariableDeclaration(s)) {
							let r, l = !1;
							const p = e.get("body").scope;
							for (const e of Object.keys(n.types.getOuterBindingIdentifiers(s))) a.getBinding(e) === t.getBinding(e) && (i.has(e) && (l = !0, p.hasOwnBinding(e) && p.rename(e)), o.has(e) && !r && (r = e));
							if (!l && !r) return;
							e.ensureBlock();
							const c = e.get("body"), u = t.generateUidIdentifierBasedOnNode(s);
							e.get("left").replaceWith(n.types.variableDeclaration("let", [n.types.variableDeclarator(n.types.cloneNode(u))])), t.registerDeclaration(e.get("left")), l && c.unshiftContainer("body", n.types.expressionStatement(n.types.assignmentExpression("=", s, u))), r && c.unshiftContainer("body", n.types.expressionStatement(buildImportThrow(r)));
						}
					}
				};
			},
			"./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/rewrite-this.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					i || (i = s.visitors.environmentVisitor({ ThisExpression(e) {
						e.replaceWith(n.types.unaryExpression("void", n.types.numericLiteral(0), !0));
					} }), i.noScope = !0);
					(0, s.default)(e.node, i);
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), s = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js");
				let i;
			},
			"./node_modules/.pnpm/@babel+helper-optimise-call-expression@7.27.1/node_modules/@babel/helper-optimise-call-expression/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r, n) {
					return 1 === r.length && a(r[0]) && o(r[0].argument, { name: "arguments" }) ? n ? p(c(e, i("apply"), !1, !0), [t, r[0].argument], !1) : s(l(e, i("apply")), [t, r[0].argument]) : n ? p(c(e, i("call"), !1, !0), [t, ...r], !1) : s(l(e, i("call")), [t, ...r]);
				};
				const { callExpression: s, identifier: i, isIdentifier: o, isSpreadElement: a, memberExpression: l, optionalCallExpression: p, optionalMemberExpression: c } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
			},
			"./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.declare = declare, t.declarePreset = void 0;
				const r = { assertVersion: (e) => (t) => {
					(function(e, t) {
						if ("number" == typeof e) {
							if (!Number.isInteger(e)) throw new Error("Expected string or integer value.");
							e = `^${e}.0.0-0`;
						}
						if ("string" != typeof e) throw new Error("Expected string or integer value.");
						const r = Error.stackTraceLimit;
						"number" == typeof r && r < 25 && (Error.stackTraceLimit = 25);
						let n;
						n = "7." === t.slice(0, 2) ? /* @__PURE__ */ new Error(`Requires Babel "^7.0.0-beta.41", but was loaded with "${t}". You'll need to update your @babel/core version.`) : /* @__PURE__ */ new Error(`Requires Babel "${e}", but was loaded with "${t}". If you are sure you have a compatible version of @babel/core, it is likely that something in your build process is loading the wrong version. Inspect the stack trace of this error to look for the first entry that doesn't mention "@babel/core" or "babel-core" to see what is calling Babel.`);
						"number" == typeof r && (Error.stackTraceLimit = r);
						throw Object.assign(n, {
							code: "BABEL_VERSION_UNSUPPORTED",
							version: t,
							range: e
						});
					})(t, e.version);
				} };
				function declare(e) {
					return (t, n, s) => {
						let i;
						for (const e of Object.keys(r)) t[e] || (i ?? (i = copyApiObject(t)), i[e] = r[e](i));
						return e(null != i ? i : t, n || {}, s);
					};
				}
				Object.assign(r, {
					targets: () => () => ({}),
					assumption: () => () => {},
					addExternalDependency: () => () => {}
				});
				t.declarePreset = declare;
				function copyApiObject(e) {
					let t = null;
					return "string" == typeof e.version && /^7\./.test(e.version) && (t = Object.getPrototypeOf(e), !t || hasOwnProperty.call(t, "version") && hasOwnProperty.call(t, "transform") && hasOwnProperty.call(t, "template") && hasOwnProperty.call(t, "types") || (t = null)), Object.assign({}, t, e);
				}
			},
			"./node_modules/.pnpm/@babel+helper-replace-supers@7.27.1_@babel+core@7.28.4/node_modules/@babel/helper-replace-supers/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+helper-member-expression-to-functions@7.27.1/node_modules/@babel/helper-member-expression-to-functions/lib/index.js"), s = r("./node_modules/.pnpm/@babel+helper-optimise-call-expression@7.27.1/node_modules/@babel/helper-optimise-call-expression/lib/index.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), o = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js");
				const { assignmentExpression: a, callExpression: l, cloneNode: p, identifier: c, memberExpression: u, sequenceExpression: d, stringLiteral: h, thisExpression: m } = i.types;
				t.environmentVisitor = o.visitors.environmentVisitor({}), t.skipAllButComputedKey = function(e) {
					e.skip(), e.node.computed && e.context.maybeQueue(e.get("key"));
				};
				const f = o.visitors.environmentVisitor({ Super(e, t) {
					const { node: r, parentPath: n } = e;
					n.isMemberExpression({ object: r }) && t.handle(n);
				} }), y = o.visitors.environmentVisitor({ Scopable(e, { refName: t }) {
					const r = e.scope.getOwnBinding(t);
					r && r.identifier.name === t && e.scope.rename(t);
				} }), b = {
					memoise(e, t) {
						const { scope: r, node: n } = e, { computed: s, property: i } = n;
						if (!s) return;
						const o = r.maybeGenerateMemoised(i);
						o && this.memoiser.set(i, o, t);
					},
					prop(e) {
						const { computed: t, property: r } = e.node;
						return this.memoiser.has(r) ? p(this.memoiser.get(r)) : t ? p(r) : h(r.name);
					},
					_getPrototypeOfExpression() {
						const e = p(this.getObjectRef()), t = this.isStatic || this.isPrivateMethod ? e : u(e, c("prototype"));
						return l(this.file.addHelper("getPrototypeOf"), [t]);
					},
					get(e) {
						const t = p(this.getObjectRef());
						return l(this.file.addHelper("superPropGet"), [
							this.isDerivedConstructor ? d([m(), t]) : t,
							this.prop(e),
							m(),
							...this.isStatic || this.isPrivateMethod ? [] : [i.types.numericLiteral(1)]
						]);
					},
					_call(e, t, r) {
						const n = p(this.getObjectRef());
						let s;
						s = 1 === t.length && i.types.isSpreadElement(t[0]) && (i.types.isIdentifier(t[0].argument) || i.types.isArrayExpression(t[0].argument)) ? t[0].argument : i.types.arrayExpression(t);
						const o = i.types.callExpression(this.file.addHelper("superPropGet"), [
							this.isDerivedConstructor ? d([m(), n]) : n,
							this.prop(e),
							m(),
							i.types.numericLiteral(2 | (this.isStatic || this.isPrivateMethod ? 0 : 1))
						]);
						return r ? i.types.optionalCallExpression(o, [s], !0) : l(o, [s]);
					},
					set(e, t) {
						const r = p(this.getObjectRef());
						return l(this.file.addHelper("superPropSet"), [
							this.isDerivedConstructor ? d([m(), r]) : r,
							this.prop(e),
							t,
							m(),
							i.types.numericLiteral(e.isInStrictMode() ? 1 : 0),
							...this.isStatic || this.isPrivateMethod ? [] : [i.types.numericLiteral(1)]
						]);
					},
					destructureSet(e) {
						throw e.buildCodeFrameError("Destructuring to a super field is not supported yet.");
					},
					call(e, t) {
						return this._call(e, t, !1);
					},
					optionalCall(e, t) {
						return this._call(e, t, !0);
					},
					delete(e) {
						return e.node.computed ? d([l(this.file.addHelper("toPropertyKey"), [p(e.node.property)]), i.template.expression.ast`
          function () { throw new ReferenceError("'delete super[expr]' is invalid"); }()
        `]) : i.template.expression.ast`
        function () { throw new ReferenceError("'delete super.prop' is invalid"); }()
      `;
					}
				}, g = {
					memoise(e, t) {
						const { scope: r, node: n } = e, { computed: s, property: i } = n;
						if (!s) return;
						const o = r.maybeGenerateMemoised(i);
						o && this.memoiser.set(i, o, t);
					},
					prop(e) {
						const { computed: t, property: r } = e.node;
						return this.memoiser.has(r) ? p(this.memoiser.get(r)) : t ? p(r) : h(r.name);
					},
					_getPrototypeOfExpression() {
						const e = p(this.getObjectRef()), t = this.isStatic || this.isPrivateMethod ? e : u(e, c("prototype"));
						return l(this.file.addHelper("getPrototypeOf"), [t]);
					},
					get(e) {
						return this._get(e);
					},
					_get(e) {
						const t = this._getPrototypeOfExpression();
						return l(this.file.addHelper("get"), [
							this.isDerivedConstructor ? d([m(), t]) : t,
							this.prop(e),
							m()
						]);
					},
					set(e, t) {
						const r = this._getPrototypeOfExpression();
						return l(this.file.addHelper("set"), [
							this.isDerivedConstructor ? d([m(), r]) : r,
							this.prop(e),
							t,
							m(),
							i.types.booleanLiteral(e.isInStrictMode())
						]);
					},
					destructureSet(e) {
						throw e.buildCodeFrameError("Destructuring to a super field is not supported yet.");
					},
					call(e, t) {
						return (0, s.default)(this._get(e), m(), t, !1);
					},
					optionalCall(e, t) {
						return (0, s.default)(this._get(e), p(m()), t, !0);
					},
					delete(e) {
						return e.node.computed ? d([l(this.file.addHelper("toPropertyKey"), [p(e.node.property)]), i.template.expression.ast`
          function () { throw new ReferenceError("'delete super[expr]' is invalid"); }()
        `]) : i.template.expression.ast`
        function () { throw new ReferenceError("'delete super.prop' is invalid"); }()
      `;
					}
				}, x = Object.assign({}, b, {
					prop(e) {
						const { property: t } = e.node;
						return this.memoiser.has(t) ? p(this.memoiser.get(t)) : p(t);
					},
					get(e) {
						const { isStatic: t, getSuperRef: r } = this, { computed: n } = e.node, s = this.prop(e);
						let i;
						var o, a;
						t ? i = null != (o = r()) ? o : u(c("Function"), c("prototype")) : i = u(null != (a = r()) ? a : c("Object"), c("prototype"));
						return u(i, s, n);
					},
					set(e, t) {
						const { computed: r } = e.node, n = this.prop(e);
						return a("=", u(m(), n, r), t);
					},
					destructureSet(e) {
						const { computed: t } = e.node, r = this.prop(e);
						return u(m(), r, t);
					},
					call(e, t) {
						return (0, s.default)(this.get(e), m(), t, !1);
					},
					optionalCall(e, t) {
						return (0, s.default)(this.get(e), m(), t, !0);
					}
				});
				t.default = class {
					constructor(e) {
						var t;
						const r = e.methodPath;
						this.methodPath = r, this.isDerivedConstructor = r.isClassMethod({ kind: "constructor" }) && !!e.superRef, this.isStatic = r.isObjectMethod() || r.node.static || (null == r.isStaticBlock ? void 0 : r.isStaticBlock()), this.isPrivateMethod = r.isPrivate() && r.isMethod(), this.file = e.file, this.constantSuper = null != (t = e.constantSuper) ? t : e.isLoose, this.opts = e;
					}
					getObjectRef() {
						return p(this.opts.objectRef || this.opts.getObjectRef());
					}
					getSuperRef() {
						return this.opts.superRef ? p(this.opts.superRef) : this.opts.getSuperRef ? p(this.opts.getSuperRef()) : void 0;
					}
					replace() {
						const { methodPath: e } = this;
						this.opts.refToPreserve && e.traverse(y, { refName: this.opts.refToPreserve.name });
						const t = this.constantSuper ? x : this.file.availableHelper("superPropSet") ? b : g;
						f.shouldSkip = (t) => {
							if (t.parentPath === e && ("decorators" === t.parentKey || "key" === t.parentKey)) return !0;
						}, (0, n.default)(e, f, Object.assign({
							file: this.file,
							scope: this.methodPath.scope,
							isDerivedConstructor: this.isDerivedConstructor,
							isStatic: this.isStatic,
							isPrivateMethod: this.isPrivateMethod,
							getObjectRef: this.getObjectRef.bind(this),
							getSuperRef: this.getSuperRef.bind(this),
							boundGet: t.get
						}, t));
					}
				};
			},
			"./node_modules/.pnpm/@babel+helper-simple-access@7.27.1/node_modules/@babel/helper-simple-access/lib/index.js": function(e, t, r) {
				"use strict";
				t.default = function(e, t) {
					var r;
					e.traverse(h, {
						scope: e.scope,
						bindingNames: t,
						seen: /* @__PURE__ */ new WeakSet(),
						includeUpdateExpression: null == (r = arguments[2]) || r
					});
				};
				const { LOGICAL_OPERATORS: s, assignmentExpression: i, binaryExpression: o, cloneNode: a, identifier: l, logicalExpression: p, numericLiteral: c, sequenceExpression: u, unaryExpression: d } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), h = { AssignmentExpression: { exit(e) {
					const { scope: t, seen: r, bindingNames: n } = this;
					if ("=" === e.node.operator) return;
					if (r.has(e.node)) return;
					r.add(e.node);
					const l = e.get("left");
					if (!l.isIdentifier()) return;
					const c = l.node.name;
					if (!n.has(c)) return;
					if (t.getBinding(c) !== e.scope.getBinding(c)) return;
					const u = e.node.operator.slice(0, -1);
					s.includes(u) ? e.replaceWith(p(u, e.node.left, i("=", a(e.node.left), e.node.right))) : (e.node.right = o(u, a(e.node.left), e.node.right), e.node.operator = "=");
				} } };
				h.UpdateExpression = { exit(e) {
					if (!this.includeUpdateExpression) return;
					const { scope: t, bindingNames: r } = this, n = e.get("argument");
					if (!n.isIdentifier()) return;
					const s = n.node.name;
					if (r.has(s) && t.getBinding(s) === e.scope.getBinding(s)) if (e.parentPath.isExpressionStatement() && !e.isCompletionRecord()) {
						const t = "++" === e.node.operator ? "+=" : "-=";
						e.replaceWith(i(t, n.node, c(1)));
					} else if (e.node.prefix) e.replaceWith(i("=", l(s), o(e.node.operator[0], d("+", n.node), c(1))));
					else {
						const t = e.scope.generateUidIdentifierBasedOnNode(n.node, "old"), r = t.name;
						e.scope.push({ id: t });
						const s = o(e.node.operator[0], l(r), c(1));
						e.replaceWith(u([
							i("=", l(r), d("+", n.node)),
							i("=", a(n.node), s),
							l(r)
						]));
					}
				} };
			},
			"./node_modules/.pnpm/@babel+helper-skip-transparent-expression-wrappers@7.27.1/node_modules/@babel/helper-skip-transparent-expression-wrappers/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.isTransparentExprWrapper = isTransparentExprWrapper, t.skipTransparentExprWrapperNodes = function(e) {
					for (; isTransparentExprWrapper(e);) e = e.expression;
					return e;
				}, t.skipTransparentExprWrappers = function(e) {
					for (; isTransparentExprWrapper(e.node);) e = e.get("expression");
					return e;
				};
				const { isParenthesizedExpression: s, isTSAsExpression: i, isTSNonNullExpression: o, isTSSatisfiesExpression: a, isTSTypeAssertion: l, isTypeCastExpression: p } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
				function isTransparentExprWrapper(e) {
					return i(e) || a(e) || l(e) || o(e) || p(e) || s(e);
				}
			},
			"./node_modules/.pnpm/@babel+helper-string-parser@7.27.1/node_modules/@babel/helper-string-parser/lib/index.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.readCodePoint = readCodePoint, t.readInt = readInt, t.readStringContents = function(e, t, r, n, s, i) {
					const o = r, a = n, l = s;
					let p = "", c = null, u = r;
					const { length: d } = t;
					for (;;) {
						if (r >= d) {
							i.unterminated(o, a, l), p += t.slice(u, r);
							break;
						}
						const h = t.charCodeAt(r);
						if (isStringEnd(e, h, t, r)) {
							p += t.slice(u, r);
							break;
						}
						if (92 === h) {
							p += t.slice(u, r);
							const o = readEscapedChar(t, r, n, s, "template" === e, i);
							null !== o.ch || c ? p += o.ch : c = {
								pos: r,
								lineStart: n,
								curLine: s
							}, {pos: r, lineStart: n, curLine: s} = o, u = r;
						} else 8232 === h || 8233 === h ? (++s, n = ++r) : 10 === h || 13 === h ? "template" === e ? (p += t.slice(u, r) + "\n", ++r, 13 === h && 10 === t.charCodeAt(r) && ++r, ++s, u = n = r) : i.unterminated(o, a, l) : ++r;
					}
					return {
						pos: r,
						str: p,
						firstInvalidLoc: c,
						lineStart: n,
						curLine: s,
						containsInvalid: !!c
					};
				};
				var _isDigit = function(e) {
					return e >= 48 && e <= 57;
				};
				const r = {
					decBinOct: new Set([
						46,
						66,
						69,
						79,
						95,
						98,
						101,
						111
					]),
					hex: new Set([
						46,
						88,
						95,
						120
					])
				}, n = {
					bin: (e) => 48 === e || 49 === e,
					oct: (e) => e >= 48 && e <= 55,
					dec: (e) => e >= 48 && e <= 57,
					hex: (e) => e >= 48 && e <= 57 || e >= 65 && e <= 70 || e >= 97 && e <= 102
				};
				function isStringEnd(e, t, r, n) {
					return "template" === e ? 96 === t || 36 === t && 123 === r.charCodeAt(n + 1) : t === ("double" === e ? 34 : 39);
				}
				function readEscapedChar(e, t, r, n, s, i) {
					const o = !s;
					t++;
					const res = (e) => ({
						pos: t,
						ch: e,
						lineStart: r,
						curLine: n
					}), a = e.charCodeAt(t++);
					switch (a) {
						case 110: return res("\n");
						case 114: return res("\r");
						case 120: {
							let s;
							return {code: s, pos: t} = readHexChar(e, t, r, n, 2, !1, o, i), res(null === s ? null : String.fromCharCode(s));
						}
						case 117: {
							let s;
							return {code: s, pos: t} = readCodePoint(e, t, r, n, o, i), res(null === s ? null : String.fromCodePoint(s));
						}
						case 116: return res("	");
						case 98: return res("\b");
						case 118: return res("\v");
						case 102: return res("\f");
						case 13: 10 === e.charCodeAt(t) && ++t;
						case 10: r = t, ++n;
						case 8232:
						case 8233: return res("");
						case 56:
						case 57:
							if (s) return res(null);
							i.strictNumericEscape(t - 1, r, n);
						default:
							if (a >= 48 && a <= 55) {
								const o = t - 1;
								let a = /^[0-7]+/.exec(e.slice(o, t + 2))[0], l = parseInt(a, 8);
								l > 255 && (a = a.slice(0, -1), l = parseInt(a, 8)), t += a.length - 1;
								const p = e.charCodeAt(t);
								if ("0" !== a || 56 === p || 57 === p) {
									if (s) return res(null);
									i.strictNumericEscape(o, r, n);
								}
								return res(String.fromCharCode(l));
							}
							return res(String.fromCharCode(a));
					}
				}
				function readHexChar(e, t, r, n, s, i, o, a) {
					const l = t;
					let p;
					return {n: p, pos: t} = readInt(e, t, r, n, 16, s, i, !1, a, !o), null === p && (o ? a.invalidEscapeSequence(l, r, n) : t = l - 1), {
						code: p,
						pos: t
					};
				}
				function readInt(e, t, s, i, o, a, l, p, c, u) {
					const d = t, h = 16 === o ? r.hex : r.decBinOct, m = 16 === o ? n.hex : 10 === o ? n.dec : 8 === o ? n.oct : n.bin;
					let f = !1, y = 0;
					for (let r = 0, n = null == a ? Infinity : a; r < n; ++r) {
						const r = e.charCodeAt(t);
						let n;
						if (95 === r && "bail" !== p) {
							const r = e.charCodeAt(t - 1), n = e.charCodeAt(t + 1);
							if (p) {
								if (Number.isNaN(n) || !m(n) || h.has(r) || h.has(n)) {
									if (u) return {
										n: null,
										pos: t
									};
									c.unexpectedNumericSeparator(t, s, i);
								}
							} else {
								if (u) return {
									n: null,
									pos: t
								};
								c.numericSeparatorInEscapeSequence(t, s, i);
							}
							++t;
							continue;
						}
						if (n = r >= 97 ? r - 97 + 10 : r >= 65 ? r - 65 + 10 : _isDigit(r) ? r - 48 : Infinity, n >= o) {
							if (n <= 9 && u) return {
								n: null,
								pos: t
							};
							if (n <= 9 && c.invalidDigit(t, s, i, o)) n = 0;
							else {
								if (!l) break;
								n = 0, f = !0;
							}
						}
						++t, y = y * o + n;
					}
					return t === d || null != a && t - d !== a || f ? {
						n: null,
						pos: t
					} : {
						n: y,
						pos: t
					};
				}
				function readCodePoint(e, t, r, n, s, i) {
					let o;
					if (123 === e.charCodeAt(t)) {
						if (++t, {code: o, pos: t} = readHexChar(e, t, r, n, e.indexOf("}", t) - t, !0, s, i), ++t, null !== o && o > 1114111) {
							if (!s) return {
								code: null,
								pos: t
							};
							i.invalidCodePoint(t, r, n);
						}
					} else ({code: o, pos: t} = readHexChar(e, t, r, n, 4, !1, s, i));
					return {
						code: o,
						pos: t
					};
				}
			},
			"./node_modules/.pnpm/@babel+helper-validator-identifier@7.27.1/node_modules/@babel/helper-validator-identifier/lib/identifier.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.isIdentifierChar = isIdentifierChar, t.isIdentifierName = function(e) {
					let t = !0;
					for (let r = 0; r < e.length; r++) {
						let n = e.charCodeAt(r);
						if (55296 == (64512 & n) && r + 1 < e.length) {
							const t = e.charCodeAt(++r);
							56320 == (64512 & t) && (n = 65536 + ((1023 & n) << 10) + (1023 & t));
						}
						if (t) {
							if (t = !1, !isIdentifierStart(n)) return !1;
						} else if (!isIdentifierChar(n)) return !1;
					}
					return !t;
				}, t.isIdentifierStart = isIdentifierStart;
				let r = "ªµºÀ-ÖØ-öø-ˁˆ-ˑˠ-ˤˬˮͰ-ʹͶͷͺ-ͽͿΆΈ-ΊΌΎ-ΡΣ-ϵϷ-ҁҊ-ԯԱ-Ֆՙՠ-ֈא-תׯ-ײؠ-يٮٯٱ-ۓەۥۦۮۯۺ-ۼۿܐܒ-ܯݍ-ޥޱߊ-ߪߴߵߺࠀ-ࠕࠚࠤࠨࡀ-ࡘࡠ-ࡪࡰ-ࢇࢉ-ࢎࢠ-ࣉऄ-हऽॐक़-ॡॱ-ঀঅ-ঌএঐও-নপ-রলশ-হঽৎড়ঢ়য়-ৡৰৱৼਅ-ਊਏਐਓ-ਨਪ-ਰਲਲ਼ਵਸ਼ਸਹਖ਼-ੜਫ਼ੲ-ੴઅ-ઍએ-ઑઓ-નપ-રલળવ-હઽૐૠૡૹଅ-ଌଏଐଓ-ନପ-ରଲଳଵ-ହଽଡ଼ଢ଼ୟ-ୡୱஃஅ-ஊஎ-ஐஒ-கஙசஜஞடணதந-பம-ஹௐఅ-ఌఎ-ఐఒ-నప-హఽౘ-ౚౝౠౡಀಅ-ಌಎ-ಐಒ-ನಪ-ಳವ-ಹಽೝೞೠೡೱೲഄ-ഌഎ-ഐഒ-ഺഽൎൔ-ൖൟ-ൡൺ-ൿඅ-ඖක-නඳ-රලව-ෆก-ะาำเ-ๆກຂຄຆ-ຊຌ-ຣລວ-ະາຳຽເ-ໄໆໜ-ໟༀཀ-ཇཉ-ཬྈ-ྌက-ဪဿၐ-ၕၚ-ၝၡၥၦၮ-ၰၵ-ႁႎႠ-ჅჇჍა-ჺჼ-ቈቊ-ቍቐ-ቖቘቚ-ቝበ-ኈኊ-ኍነ-ኰኲ-ኵኸ-ኾዀዂ-ዅወ-ዖዘ-ጐጒ-ጕጘ-ፚᎀ-ᎏᎠ-Ᏽᏸ-ᏽᐁ-ᙬᙯ-ᙿᚁ-ᚚᚠ-ᛪᛮ-ᛸᜀ-ᜑᜟ-ᜱᝀ-ᝑᝠ-ᝬᝮ-ᝰក-ឳៗៜᠠ-ᡸᢀ-ᢨᢪᢰ-ᣵᤀ-ᤞᥐ-ᥭᥰ-ᥴᦀ-ᦫᦰ-ᧉᨀ-ᨖᨠ-ᩔᪧᬅ-ᬳᭅ-ᭌᮃ-ᮠᮮᮯᮺ-ᯥᰀ-ᰣᱍ-ᱏᱚ-ᱽᲀ-ᲊᲐ-ᲺᲽ-Ჿᳩ-ᳬᳮ-ᳳᳵᳶᳺᴀ-ᶿḀ-ἕἘ-Ἕἠ-ὅὈ-Ὅὐ-ὗὙὛὝὟ-ώᾀ-ᾴᾶ-ᾼιῂ-ῄῆ-ῌῐ-ΐῖ-Ίῠ-Ῥῲ-ῴῶ-ῼⁱⁿₐ-ₜℂℇℊ-ℓℕ℘-ℝℤΩℨK-ℹℼ-ℿⅅ-ⅉⅎⅠ-ↈⰀ-ⳤⳫ-ⳮⳲⳳⴀ-ⴥⴧⴭⴰ-ⵧⵯⶀ-ⶖⶠ-ⶦⶨ-ⶮⶰ-ⶶⶸ-ⶾⷀ-ⷆⷈ-ⷎⷐ-ⷖⷘ-ⷞ々-〇〡-〩〱-〵〸-〼ぁ-ゖ゛-ゟァ-ヺー-ヿㄅ-ㄯㄱ-ㆎㆠ-ㆿㇰ-ㇿ㐀-䶿一-ꒌꓐ-ꓽꔀ-ꘌꘐ-ꘟꘪꘫꙀ-ꙮꙿ-ꚝꚠ-ꛯꜗ-ꜟꜢ-ꞈꞋ-ꟍꟐꟑꟓꟕ-Ƛꟲ-ꠁꠃ-ꠅꠇ-ꠊꠌ-ꠢꡀ-ꡳꢂ-ꢳꣲ-ꣷꣻꣽꣾꤊ-ꤥꤰ-ꥆꥠ-ꥼꦄ-ꦲꧏꧠ-ꧤꧦ-ꧯꧺ-ꧾꨀ-ꨨꩀ-ꩂꩄ-ꩋꩠ-ꩶꩺꩾ-ꪯꪱꪵꪶꪹ-ꪽꫀꫂꫛ-ꫝꫠ-ꫪꫲ-ꫴꬁ-ꬆꬉ-ꬎꬑ-ꬖꬠ-ꬦꬨ-ꬮꬰ-ꭚꭜ-ꭩꭰ-ꯢ가-힣ힰ-ퟆퟋ-ퟻ豈-舘並-龎ﬀ-ﬆﬓ-ﬗיִײַ-ﬨשׁ-זּטּ-לּמּנּסּףּפּצּ-ﮱﯓ-ﴽﵐ-ﶏﶒ-ﷇﷰ-ﷻﹰ-ﹴﹶ-ﻼＡ-Ｚａ-ｚｦ-ﾾￂ-ￇￊ-ￏￒ-ￗￚ-ￜ", n = "·̀-ͯ·҃-֑҇-ׇֽֿׁׂׅׄؐ-ًؚ-٩ٰۖ-ۜ۟-۪ۤۧۨ-ۭ۰-۹ܑܰ-݊ަ-ް߀-߉߫-߽߳ࠖ-࠙ࠛ-ࠣࠥ-ࠧࠩ-࡙࠭-࡛ࢗ-࢟࣊-ࣣ࣡-ःऺ-़ा-ॏ॑-ॗॢॣ०-९ঁ-ঃ়া-ৄেৈো-্ৗৢৣ০-৯৾ਁ-ਃ਼ਾ-ੂੇੈੋ-੍ੑ੦-ੱੵઁ-ઃ઼ા-ૅે-ૉો-્ૢૣ૦-૯ૺ-૿ଁ-ଃ଼ା-ୄେୈୋ-୍୕-ୗୢୣ୦-୯ஂா-ூெ-ைொ-்ௗ௦-௯ఀ-ఄ఼ా-ౄె-ైొ-్ౕౖౢౣ౦-౯ಁ-ಃ಼ಾ-ೄೆ-ೈೊ-್ೕೖೢೣ೦-೯ೳഀ-ഃ഻഼ാ-ൄെ-ൈൊ-്ൗൢൣ൦-൯ඁ-ඃ්ා-ුූෘ-ෟ෦-෯ෲෳัิ-ฺ็-๎๐-๙ັິ-ຼ່-໎໐-໙༘༙༠-༩༹༵༷༾༿ཱ-྄྆྇ྍ-ྗྙ-ྼ࿆ါ-ှ၀-၉ၖ-ၙၞ-ၠၢ-ၤၧ-ၭၱ-ၴႂ-ႍႏ-ႝ፝-፟፩-፱ᜒ-᜕ᜲ-᜴ᝒᝓᝲᝳ឴-៓៝០-៩᠋-᠍᠏-᠙ᢩᤠ-ᤫᤰ-᤻᥆-᥏᧐-᧚ᨗ-ᨛᩕ-ᩞ᩠-᩿᩼-᪉᪐-᪙᪰-᪽ᪿ-ᫎᬀ-ᬄ᬴-᭄᭐-᭙᭫-᭳ᮀ-ᮂᮡ-ᮭ᮰-᮹᯦-᯳ᰤ-᰷᱀-᱉᱐-᱙᳐-᳔᳒-᳨᳭᳴᳷-᳹᷀-᷿‌‍‿⁀⁔⃐-⃥⃜⃡-⃰⳯-⵿⳱ⷠ-〪ⷿ-゙゚〯・꘠-꘩꙯ꙴ-꙽ꚞꚟ꛰꛱ꠂ꠆ꠋꠣ-ꠧ꠬ꢀꢁꢴ-ꣅ꣐-꣙꣠-꣱ꣿ-꤉ꤦ-꤭ꥇ-꥓ꦀ-ꦃ꦳-꧀꧐-꧙ꧥ꧰-꧹ꨩ-ꨶꩃꩌꩍ꩐-꩙ꩻ-ꩽꪰꪲ-ꪴꪷꪸꪾ꪿꫁ꫫ-ꫯꫵ꫶ꯣ-ꯪ꯬꯭꯰-꯹ﬞ︀-️︠-︯︳︴﹍-﹏０-９＿･";
				const s = new RegExp("[" + r + "]"), i = new RegExp("[" + r + n + "]");
				r = n = null;
				const o = [
					0,
					11,
					2,
					25,
					2,
					18,
					2,
					1,
					2,
					14,
					3,
					13,
					35,
					122,
					70,
					52,
					268,
					28,
					4,
					48,
					48,
					31,
					14,
					29,
					6,
					37,
					11,
					29,
					3,
					35,
					5,
					7,
					2,
					4,
					43,
					157,
					19,
					35,
					5,
					35,
					5,
					39,
					9,
					51,
					13,
					10,
					2,
					14,
					2,
					6,
					2,
					1,
					2,
					10,
					2,
					14,
					2,
					6,
					2,
					1,
					4,
					51,
					13,
					310,
					10,
					21,
					11,
					7,
					25,
					5,
					2,
					41,
					2,
					8,
					70,
					5,
					3,
					0,
					2,
					43,
					2,
					1,
					4,
					0,
					3,
					22,
					11,
					22,
					10,
					30,
					66,
					18,
					2,
					1,
					11,
					21,
					11,
					25,
					71,
					55,
					7,
					1,
					65,
					0,
					16,
					3,
					2,
					2,
					2,
					28,
					43,
					28,
					4,
					28,
					36,
					7,
					2,
					27,
					28,
					53,
					11,
					21,
					11,
					18,
					14,
					17,
					111,
					72,
					56,
					50,
					14,
					50,
					14,
					35,
					39,
					27,
					10,
					22,
					251,
					41,
					7,
					1,
					17,
					2,
					60,
					28,
					11,
					0,
					9,
					21,
					43,
					17,
					47,
					20,
					28,
					22,
					13,
					52,
					58,
					1,
					3,
					0,
					14,
					44,
					33,
					24,
					27,
					35,
					30,
					0,
					3,
					0,
					9,
					34,
					4,
					0,
					13,
					47,
					15,
					3,
					22,
					0,
					2,
					0,
					36,
					17,
					2,
					24,
					20,
					1,
					64,
					6,
					2,
					0,
					2,
					3,
					2,
					14,
					2,
					9,
					8,
					46,
					39,
					7,
					3,
					1,
					3,
					21,
					2,
					6,
					2,
					1,
					2,
					4,
					4,
					0,
					19,
					0,
					13,
					4,
					31,
					9,
					2,
					0,
					3,
					0,
					2,
					37,
					2,
					0,
					26,
					0,
					2,
					0,
					45,
					52,
					19,
					3,
					21,
					2,
					31,
					47,
					21,
					1,
					2,
					0,
					185,
					46,
					42,
					3,
					37,
					47,
					21,
					0,
					60,
					42,
					14,
					0,
					72,
					26,
					38,
					6,
					186,
					43,
					117,
					63,
					32,
					7,
					3,
					0,
					3,
					7,
					2,
					1,
					2,
					23,
					16,
					0,
					2,
					0,
					95,
					7,
					3,
					38,
					17,
					0,
					2,
					0,
					29,
					0,
					11,
					39,
					8,
					0,
					22,
					0,
					12,
					45,
					20,
					0,
					19,
					72,
					200,
					32,
					32,
					8,
					2,
					36,
					18,
					0,
					50,
					29,
					113,
					6,
					2,
					1,
					2,
					37,
					22,
					0,
					26,
					5,
					2,
					1,
					2,
					31,
					15,
					0,
					328,
					18,
					16,
					0,
					2,
					12,
					2,
					33,
					125,
					0,
					80,
					921,
					103,
					110,
					18,
					195,
					2637,
					96,
					16,
					1071,
					18,
					5,
					26,
					3994,
					6,
					582,
					6842,
					29,
					1763,
					568,
					8,
					30,
					18,
					78,
					18,
					29,
					19,
					47,
					17,
					3,
					32,
					20,
					6,
					18,
					433,
					44,
					212,
					63,
					129,
					74,
					6,
					0,
					67,
					12,
					65,
					1,
					2,
					0,
					29,
					6135,
					9,
					1237,
					42,
					9,
					8936,
					3,
					2,
					6,
					2,
					1,
					2,
					290,
					16,
					0,
					30,
					2,
					3,
					0,
					15,
					3,
					9,
					395,
					2309,
					106,
					6,
					12,
					4,
					8,
					8,
					9,
					5991,
					84,
					2,
					70,
					2,
					1,
					3,
					0,
					3,
					1,
					3,
					3,
					2,
					11,
					2,
					0,
					2,
					6,
					2,
					64,
					2,
					3,
					3,
					7,
					2,
					6,
					2,
					27,
					2,
					3,
					2,
					4,
					2,
					0,
					4,
					6,
					2,
					339,
					3,
					24,
					2,
					24,
					2,
					30,
					2,
					24,
					2,
					30,
					2,
					24,
					2,
					30,
					2,
					24,
					2,
					30,
					2,
					24,
					2,
					7,
					1845,
					30,
					7,
					5,
					262,
					61,
					147,
					44,
					11,
					6,
					17,
					0,
					322,
					29,
					19,
					43,
					485,
					27,
					229,
					29,
					3,
					0,
					496,
					6,
					2,
					3,
					2,
					1,
					2,
					14,
					2,
					196,
					60,
					67,
					8,
					0,
					1205,
					3,
					2,
					26,
					2,
					1,
					2,
					0,
					3,
					0,
					2,
					9,
					2,
					3,
					2,
					0,
					2,
					0,
					7,
					0,
					5,
					0,
					2,
					0,
					2,
					0,
					2,
					2,
					2,
					1,
					2,
					0,
					3,
					0,
					2,
					0,
					2,
					0,
					2,
					0,
					2,
					0,
					2,
					1,
					2,
					0,
					3,
					3,
					2,
					6,
					2,
					3,
					2,
					3,
					2,
					0,
					2,
					9,
					2,
					16,
					6,
					2,
					2,
					4,
					2,
					16,
					4421,
					42719,
					33,
					4153,
					7,
					221,
					3,
					5761,
					15,
					7472,
					16,
					621,
					2467,
					541,
					1507,
					4938,
					6,
					4191
				], a = [
					509,
					0,
					227,
					0,
					150,
					4,
					294,
					9,
					1368,
					2,
					2,
					1,
					6,
					3,
					41,
					2,
					5,
					0,
					166,
					1,
					574,
					3,
					9,
					9,
					7,
					9,
					32,
					4,
					318,
					1,
					80,
					3,
					71,
					10,
					50,
					3,
					123,
					2,
					54,
					14,
					32,
					10,
					3,
					1,
					11,
					3,
					46,
					10,
					8,
					0,
					46,
					9,
					7,
					2,
					37,
					13,
					2,
					9,
					6,
					1,
					45,
					0,
					13,
					2,
					49,
					13,
					9,
					3,
					2,
					11,
					83,
					11,
					7,
					0,
					3,
					0,
					158,
					11,
					6,
					9,
					7,
					3,
					56,
					1,
					2,
					6,
					3,
					1,
					3,
					2,
					10,
					0,
					11,
					1,
					3,
					6,
					4,
					4,
					68,
					8,
					2,
					0,
					3,
					0,
					2,
					3,
					2,
					4,
					2,
					0,
					15,
					1,
					83,
					17,
					10,
					9,
					5,
					0,
					82,
					19,
					13,
					9,
					214,
					6,
					3,
					8,
					28,
					1,
					83,
					16,
					16,
					9,
					82,
					12,
					9,
					9,
					7,
					19,
					58,
					14,
					5,
					9,
					243,
					14,
					166,
					9,
					71,
					5,
					2,
					1,
					3,
					3,
					2,
					0,
					2,
					1,
					13,
					9,
					120,
					6,
					3,
					6,
					4,
					0,
					29,
					9,
					41,
					6,
					2,
					3,
					9,
					0,
					10,
					10,
					47,
					15,
					343,
					9,
					54,
					7,
					2,
					7,
					17,
					9,
					57,
					21,
					2,
					13,
					123,
					5,
					4,
					0,
					2,
					1,
					2,
					6,
					2,
					0,
					9,
					9,
					49,
					4,
					2,
					1,
					2,
					4,
					9,
					9,
					330,
					3,
					10,
					1,
					2,
					0,
					49,
					6,
					4,
					4,
					14,
					10,
					5350,
					0,
					7,
					14,
					11465,
					27,
					2343,
					9,
					87,
					9,
					39,
					4,
					60,
					6,
					26,
					9,
					535,
					9,
					470,
					0,
					2,
					54,
					8,
					3,
					82,
					0,
					12,
					1,
					19628,
					1,
					4178,
					9,
					519,
					45,
					3,
					22,
					543,
					4,
					4,
					5,
					9,
					7,
					3,
					6,
					31,
					3,
					149,
					2,
					1418,
					49,
					513,
					54,
					5,
					49,
					9,
					0,
					15,
					0,
					23,
					4,
					2,
					14,
					1361,
					6,
					2,
					16,
					3,
					6,
					2,
					1,
					2,
					4,
					101,
					0,
					161,
					6,
					10,
					9,
					357,
					0,
					62,
					13,
					499,
					13,
					245,
					1,
					2,
					9,
					726,
					6,
					110,
					6,
					6,
					9,
					4759,
					9,
					787719,
					239
				];
				function isInAstralSet(e, t) {
					let r = 65536;
					for (let n = 0, s = t.length; n < s; n += 2) {
						if (r += t[n], r > e) return !1;
						if (r += t[n + 1], r >= e) return !0;
					}
					return !1;
				}
				function isIdentifierStart(e) {
					return e < 65 ? 36 === e : e <= 90 || (e < 97 ? 95 === e : e <= 122 || (e <= 65535 ? e >= 170 && s.test(String.fromCharCode(e)) : isInAstralSet(e, o)));
				}
				function isIdentifierChar(e) {
					return e < 48 ? 36 === e : e < 58 || !(e < 65) && (e <= 90 || (e < 97 ? 95 === e : e <= 122 || (e <= 65535 ? e >= 170 && i.test(String.fromCharCode(e)) : isInAstralSet(e, o) || isInAstralSet(e, a))));
				}
			},
			"./node_modules/.pnpm/@babel+helper-validator-identifier@7.27.1/node_modules/@babel/helper-validator-identifier/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), Object.defineProperty(t, "isIdentifierChar", {
					enumerable: !0,
					get: function() {
						return n.isIdentifierChar;
					}
				}), Object.defineProperty(t, "isIdentifierName", {
					enumerable: !0,
					get: function() {
						return n.isIdentifierName;
					}
				}), Object.defineProperty(t, "isIdentifierStart", {
					enumerable: !0,
					get: function() {
						return n.isIdentifierStart;
					}
				}), Object.defineProperty(t, "isKeyword", {
					enumerable: !0,
					get: function() {
						return s.isKeyword;
					}
				}), Object.defineProperty(t, "isReservedWord", {
					enumerable: !0,
					get: function() {
						return s.isReservedWord;
					}
				}), Object.defineProperty(t, "isStrictBindOnlyReservedWord", {
					enumerable: !0,
					get: function() {
						return s.isStrictBindOnlyReservedWord;
					}
				}), Object.defineProperty(t, "isStrictBindReservedWord", {
					enumerable: !0,
					get: function() {
						return s.isStrictBindReservedWord;
					}
				}), Object.defineProperty(t, "isStrictReservedWord", {
					enumerable: !0,
					get: function() {
						return s.isStrictReservedWord;
					}
				});
				var n = r("./node_modules/.pnpm/@babel+helper-validator-identifier@7.27.1/node_modules/@babel/helper-validator-identifier/lib/identifier.js"), s = r("./node_modules/.pnpm/@babel+helper-validator-identifier@7.27.1/node_modules/@babel/helper-validator-identifier/lib/keyword.js");
			},
			"./node_modules/.pnpm/@babel+helper-validator-identifier@7.27.1/node_modules/@babel/helper-validator-identifier/lib/keyword.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.isKeyword = function(e) {
					return s.has(e);
				}, t.isReservedWord = isReservedWord, t.isStrictBindOnlyReservedWord = isStrictBindOnlyReservedWord, t.isStrictBindReservedWord = function(e, t) {
					return isStrictReservedWord(e, t) || isStrictBindOnlyReservedWord(e);
				}, t.isStrictReservedWord = isStrictReservedWord;
				const r = [
					"implements",
					"interface",
					"let",
					"package",
					"private",
					"protected",
					"public",
					"static",
					"yield"
				], n = ["eval", "arguments"], s = new Set([
					"break",
					"case",
					"catch",
					"continue",
					"debugger",
					"default",
					"do",
					"else",
					"finally",
					"for",
					"function",
					"if",
					"return",
					"switch",
					"throw",
					"try",
					"var",
					"const",
					"while",
					"with",
					"new",
					"this",
					"super",
					"class",
					"extends",
					"export",
					"import",
					"null",
					"true",
					"false",
					"in",
					"instanceof",
					"typeof",
					"void",
					"delete"
				]), i = new Set(r), o = new Set(n);
				function isReservedWord(e, t) {
					return t && "await" === e || "enum" === e;
				}
				function isStrictReservedWord(e, t) {
					return isReservedWord(e, t) || i.has(e);
				}
				function isStrictBindOnlyReservedWord(e) {
					return o.has(e);
				}
			},
			"./node_modules/.pnpm/@babel+helper-validator-option@7.27.1/node_modules/@babel/helper-validator-option/lib/find-suggestion.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.findSuggestion = function(e, t) {
					const n = t.map((t) => function(e, t) {
						let n, s, i = [], o = [];
						const a = e.length, l = t.length;
						if (!a) return l;
						if (!l) return a;
						for (s = 0; s <= l; s++) i[s] = s;
						for (n = 1; n <= a; n++) {
							for (o = [n], s = 1; s <= l; s++) o[s] = e[n - 1] === t[s - 1] ? i[s - 1] : r(i[s - 1], i[s], o[s - 1]) + 1;
							i = o;
						}
						return o[l];
					}(t, e));
					return t[n.indexOf(r(...n))];
				};
				const { min: r } = Math;
			},
			"./node_modules/.pnpm/@babel+helper-validator-option@7.27.1/node_modules/@babel/helper-validator-option/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), Object.defineProperty(t, "OptionValidator", {
					enumerable: !0,
					get: function() {
						return n.OptionValidator;
					}
				}), Object.defineProperty(t, "findSuggestion", {
					enumerable: !0,
					get: function() {
						return s.findSuggestion;
					}
				});
				var n = r("./node_modules/.pnpm/@babel+helper-validator-option@7.27.1/node_modules/@babel/helper-validator-option/lib/validator.js"), s = r("./node_modules/.pnpm/@babel+helper-validator-option@7.27.1/node_modules/@babel/helper-validator-option/lib/find-suggestion.js");
			},
			"./node_modules/.pnpm/@babel+helper-validator-option@7.27.1/node_modules/@babel/helper-validator-option/lib/validator.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.OptionValidator = void 0;
				var n = r("./node_modules/.pnpm/@babel+helper-validator-option@7.27.1/node_modules/@babel/helper-validator-option/lib/find-suggestion.js");
				t.OptionValidator = class {
					constructor(e) {
						this.descriptor = e;
					}
					validateTopLevelOptions(e, t) {
						const r = Object.keys(t);
						for (const t of Object.keys(e)) if (!r.includes(t)) throw new Error(this.formatMessage(`'${t}' is not a valid top-level option.\n- Did you mean '${(0, n.findSuggestion)(t, r)}'?`));
					}
					validateBooleanOption(e, t, r) {
						return void 0 === t ? r : (this.invariant("boolean" == typeof t, `'${e}' option must be a boolean.`), t);
					}
					validateStringOption(e, t, r) {
						return void 0 === t ? r : (this.invariant("string" == typeof t, `'${e}' option must be a string.`), t);
					}
					invariant(e, t) {
						if (!e) throw new Error(this.formatMessage(t));
					}
					formatMessage(e) {
						return `${this.descriptor}: ${e}`;
					}
				};
			},
			"./node_modules/.pnpm/@babel+helpers@7.28.4/node_modules/@babel/helpers/lib/helpers-generated.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/index.js");
				function helper(e, t, r) {
					return Object.freeze({
						minVersion: e,
						ast: () => n.default.program.ast(t, { preserveComments: !0 }),
						metadata: r
					});
				}
				const s = t.default = {
					__proto__: null,
					OverloadYield: helper("7.18.14", "function _OverloadYield(e,d){this.v=e,this.k=d}", {
						globals: [],
						locals: { _OverloadYield: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_OverloadYield",
						dependencies: {},
						internal: !1
					}),
					applyDecoratedDescriptor: helper("7.0.0-beta.0", "function _applyDecoratedDescriptor(i,e,r,n,l){var a={};return Object.keys(n).forEach(function(i){a[i]=n[i]}),a.enumerable=!!a.enumerable,a.configurable=!!a.configurable,(\"value\"in a||a.initializer)&&(a.writable=!0),a=r.slice().reverse().reduce(function(r,n){return n(i,e,r)||r},a),l&&void 0!==a.initializer&&(a.value=a.initializer?a.initializer.call(l):void 0,a.initializer=void 0),void 0===a.initializer?(Object.defineProperty(i,e,a),null):a}", {
						globals: ["Object"],
						locals: { _applyDecoratedDescriptor: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_applyDecoratedDescriptor",
						dependencies: {},
						internal: !1
					}),
					applyDecs2311: helper("7.24.0", "function applyDecs2311(e,t,n,r,o,i){var a,c,u,s,f,l,p,d=Symbol.metadata||Symbol.for(\"Symbol.metadata\"),m=Object.defineProperty,h=Object.create,y=[h(null),h(null)],v=t.length;function g(t,n,r){return function(o,i){n&&(i=o,o=e);for(var a=0;a<t.length;a++)i=t[a].apply(o,r?[i]:[]);return r?i:o}}function b(e,t,n,r){if(\"function\"!=typeof e&&(r||void 0!==e))throw new TypeError(t+\" must \"+(n||\"be\")+\" a function\"+(r?\"\":\" or undefined\"));return e}function applyDec(e,t,n,r,o,i,u,s,f,l,p){function d(e){if(!p(e))throw new TypeError(\"Attempted to access private element on non-instance\")}var h=[].concat(t[0]),v=t[3],w=!u,D=1===o,S=3===o,j=4===o,E=2===o;function I(t,n,r){return function(o,i){return n&&(i=o,o=e),r&&r(o),P[t].call(o,i)}}if(!w){var P={},k=[],F=S?\"get\":j||D?\"set\":\"value\";if(f?(l||D?P={get:setFunctionName(function(){return v(this)},r,\"get\"),set:function(e){t[4](this,e)}}:P[F]=v,l||setFunctionName(P[F],r,E?\"\":F)):l||(P=Object.getOwnPropertyDescriptor(e,r)),!l&&!f){if((c=y[+s][r])&&7!==(c^o))throw Error(\"Decorating two elements with the same name (\"+P[F].name+\") is not supported yet\");y[+s][r]=o<3?1:o}}for(var N=e,O=h.length-1;O>=0;O-=n?2:1){var T=b(h[O],\"A decorator\",\"be\",!0),z=n?h[O-1]:void 0,A={},H={kind:[\"field\",\"accessor\",\"method\",\"getter\",\"setter\",\"class\"][o],name:r,metadata:a,addInitializer:function(e,t){if(e.v)throw new TypeError(\"attempted to call addInitializer after decoration was finished\");b(t,\"An initializer\",\"be\",!0),i.push(t)}.bind(null,A)};if(w)c=T.call(z,N,H),A.v=1,b(c,\"class decorators\",\"return\")&&(N=c);else if(H.static=s,H.private=f,c=H.access={has:f?p.bind():function(e){return r in e}},j||(c.get=f?E?function(e){return d(e),P.value}:I(\"get\",0,d):function(e){return e[r]}),E||S||(c.set=f?I(\"set\",0,d):function(e,t){e[r]=t}),N=T.call(z,D?{get:P.get,set:P.set}:P[F],H),A.v=1,D){if(\"object\"==typeof N&&N)(c=b(N.get,\"accessor.get\"))&&(P.get=c),(c=b(N.set,\"accessor.set\"))&&(P.set=c),(c=b(N.init,\"accessor.init\"))&&k.unshift(c);else if(void 0!==N)throw new TypeError(\"accessor decorators must return an object with get, set, or init properties or undefined\")}else b(N,(l?\"field\":\"method\")+\" decorators\",\"return\")&&(l?k.unshift(N):P[F]=N)}return o<2&&u.push(g(k,s,1),g(i,s,0)),l||w||(f?D?u.splice(-1,0,I(\"get\",s),I(\"set\",s)):u.push(E?P[F]:b.call.bind(P[F])):m(e,r,P)),N}function w(e){return m(e,d,{configurable:!0,enumerable:!0,value:a})}return void 0!==i&&(a=i[d]),a=h(null==a?null:a),f=[],l=function(e){e&&f.push(g(e))},p=function(t,r){for(var i=0;i<n.length;i++){var a=n[i],c=a[1],l=7&c;if((8&c)==t&&!l==r){var p=a[2],d=!!a[3],m=16&c;applyDec(t?e:e.prototype,a,m,d?\"#\"+p:toPropertyKey(p),l,l<2?[]:t?s=s||[]:u=u||[],f,!!t,d,r,t&&d?function(t){return checkInRHS(t)===e}:o)}}},p(8,0),p(0,0),p(8,1),p(0,1),l(u),l(s),c=f,v||w(e),{e:c,get c(){var n=[];return v&&[w(e=applyDec(e,[t],r,e.name,5,n)),g(n,1)]}}}", {
						globals: [
							"Symbol",
							"Object",
							"TypeError",
							"Error"
						],
						locals: { applyDecs2311: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "applyDecs2311",
						dependencies: {
							checkInRHS: ["body.0.body.body.5.argument.expressions.4.right.body.body.0.body.body.1.consequent.body.1.expression.arguments.10.consequent.body.body.0.argument.left.callee"],
							setFunctionName: ["body.0.body.body.3.body.body.3.consequent.body.1.test.expressions.0.consequent.expressions.0.consequent.right.properties.0.value.callee", "body.0.body.body.3.body.body.3.consequent.body.1.test.expressions.0.consequent.expressions.1.right.callee"],
							toPropertyKey: ["body.0.body.body.5.argument.expressions.4.right.body.body.0.body.body.1.consequent.body.1.expression.arguments.3.alternate.callee"]
						},
						internal: !1
					}),
					arrayLikeToArray: helper("7.9.0", "function _arrayLikeToArray(r,a){(null==a||a>r.length)&&(a=r.length);for(var e=0,n=Array(a);e<a;e++)n[e]=r[e];return n}", {
						globals: ["Array"],
						locals: { _arrayLikeToArray: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_arrayLikeToArray",
						dependencies: {},
						internal: !1
					}),
					arrayWithHoles: helper("7.0.0-beta.0", "function _arrayWithHoles(r){if(Array.isArray(r))return r}", {
						globals: ["Array"],
						locals: { _arrayWithHoles: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_arrayWithHoles",
						dependencies: {},
						internal: !1
					}),
					arrayWithoutHoles: helper("7.0.0-beta.0", "function _arrayWithoutHoles(r){if(Array.isArray(r))return arrayLikeToArray(r)}", {
						globals: ["Array"],
						locals: { _arrayWithoutHoles: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_arrayWithoutHoles",
						dependencies: { arrayLikeToArray: ["body.0.body.body.0.consequent.argument.callee"] },
						internal: !1
					}),
					assertClassBrand: helper("7.24.0", "function _assertClassBrand(e,t,n){if(\"function\"==typeof e?e===t:e.has(t))return arguments.length<3?t:n;throw new TypeError(\"Private element is not present on this object\")}", {
						globals: ["TypeError"],
						locals: { _assertClassBrand: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_assertClassBrand",
						dependencies: {},
						internal: !1
					}),
					assertThisInitialized: helper("7.0.0-beta.0", "function _assertThisInitialized(e){if(void 0===e)throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\");return e}", {
						globals: ["ReferenceError"],
						locals: { _assertThisInitialized: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_assertThisInitialized",
						dependencies: {},
						internal: !1
					}),
					asyncGeneratorDelegate: helper("7.0.0-beta.0", "function _asyncGeneratorDelegate(t){var e={},n=!1;function pump(e,r){return n=!0,r=new Promise(function(n){n(t[e](r))}),{done:!1,value:new OverloadYield(r,1)}}return e[\"undefined\"!=typeof Symbol&&Symbol.iterator||\"@@iterator\"]=function(){return this},e.next=function(t){return n?(n=!1,t):pump(\"next\",t)},\"function\"==typeof t.throw&&(e.throw=function(t){if(n)throw n=!1,t;return pump(\"throw\",t)}),\"function\"==typeof t.return&&(e.return=function(t){return n?(n=!1,t):pump(\"return\",t)}),e}", {
						globals: ["Promise", "Symbol"],
						locals: { _asyncGeneratorDelegate: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_asyncGeneratorDelegate",
						dependencies: { OverloadYield: ["body.0.body.body.1.body.body.0.argument.expressions.2.properties.1.value.callee"] },
						internal: !1
					}),
					asyncIterator: helper("7.15.9", "function _asyncIterator(r){var n,t,o,e=2;for(\"undefined\"!=typeof Symbol&&(t=Symbol.asyncIterator,o=Symbol.iterator);e--;){if(t&&null!=(n=r[t]))return n.call(r);if(o&&null!=(n=r[o]))return new AsyncFromSyncIterator(n.call(r));t=\"@@asyncIterator\",o=\"@@iterator\"}throw new TypeError(\"Object is not async iterable\")}function AsyncFromSyncIterator(r){function AsyncFromSyncIteratorContinuation(r){if(Object(r)!==r)return Promise.reject(new TypeError(r+\" is not an object.\"));var n=r.done;return Promise.resolve(r.value).then(function(r){return{value:r,done:n}})}return AsyncFromSyncIterator=function(r){this.s=r,this.n=r.next},AsyncFromSyncIterator.prototype={s:null,n:null,next:function(){return AsyncFromSyncIteratorContinuation(this.n.apply(this.s,arguments))},return:function(r){var n=this.s.return;return void 0===n?Promise.resolve({value:r,done:!0}):AsyncFromSyncIteratorContinuation(n.apply(this.s,arguments))},throw:function(r){var n=this.s.return;return void 0===n?Promise.reject(r):AsyncFromSyncIteratorContinuation(n.apply(this.s,arguments))}},new AsyncFromSyncIterator(r)}", {
						globals: [
							"Symbol",
							"TypeError",
							"Object",
							"Promise"
						],
						locals: {
							_asyncIterator: ["body.0.id"],
							AsyncFromSyncIterator: [
								"body.1.id",
								"body.0.body.body.1.body.body.1.consequent.argument.callee",
								"body.1.body.body.1.argument.expressions.1.left.object",
								"body.1.body.body.1.argument.expressions.2.callee",
								"body.1.body.body.1.argument.expressions.0.left"
							]
						},
						exportBindingAssignments: [],
						exportName: "_asyncIterator",
						dependencies: {},
						internal: !1
					}),
					asyncToGenerator: helper("7.0.0-beta.0", "function asyncGeneratorStep(n,t,e,r,o,a,c){try{var i=n[a](c),u=i.value}catch(n){return void e(n)}i.done?t(u):Promise.resolve(u).then(r,o)}function _asyncToGenerator(n){return function(){var t=this,e=arguments;return new Promise(function(r,o){var a=n.apply(t,e);function _next(n){asyncGeneratorStep(a,r,o,_next,_throw,\"next\",n)}function _throw(n){asyncGeneratorStep(a,r,o,_next,_throw,\"throw\",n)}_next(void 0)})}}", {
						globals: ["Promise"],
						locals: {
							asyncGeneratorStep: [
								"body.0.id",
								"body.1.body.body.0.argument.body.body.1.argument.arguments.0.body.body.1.body.body.0.expression.callee",
								"body.1.body.body.0.argument.body.body.1.argument.arguments.0.body.body.2.body.body.0.expression.callee"
							],
							_asyncToGenerator: ["body.1.id"]
						},
						exportBindingAssignments: [],
						exportName: "_asyncToGenerator",
						dependencies: {},
						internal: !1
					}),
					awaitAsyncGenerator: helper("7.0.0-beta.0", "function _awaitAsyncGenerator(e){return new OverloadYield(e,0)}", {
						globals: [],
						locals: { _awaitAsyncGenerator: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_awaitAsyncGenerator",
						dependencies: { OverloadYield: ["body.0.body.body.0.argument.callee"] },
						internal: !1
					}),
					callSuper: helper("7.23.8", "function _callSuper(t,o,e){return o=getPrototypeOf(o),possibleConstructorReturn(t,isNativeReflectConstruct()?Reflect.construct(o,e||[],getPrototypeOf(t).constructor):o.apply(t,e))}", {
						globals: ["Reflect"],
						locals: { _callSuper: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_callSuper",
						dependencies: {
							getPrototypeOf: ["body.0.body.body.0.argument.expressions.0.right.callee", "body.0.body.body.0.argument.expressions.1.arguments.1.consequent.arguments.2.object.callee"],
							isNativeReflectConstruct: ["body.0.body.body.0.argument.expressions.1.arguments.1.test.callee"],
							possibleConstructorReturn: ["body.0.body.body.0.argument.expressions.1.callee"]
						},
						internal: !1
					}),
					checkInRHS: helper("7.20.5", "function _checkInRHS(e){if(Object(e)!==e)throw TypeError(\"right-hand side of 'in' should be an object, got \"+(null!==e?typeof e:\"null\"));return e}", {
						globals: ["Object", "TypeError"],
						locals: { _checkInRHS: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_checkInRHS",
						dependencies: {},
						internal: !1
					}),
					checkPrivateRedeclaration: helper("7.14.1", "function _checkPrivateRedeclaration(e,t){if(t.has(e))throw new TypeError(\"Cannot initialize the same private elements twice on an object\")}", {
						globals: ["TypeError"],
						locals: { _checkPrivateRedeclaration: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_checkPrivateRedeclaration",
						dependencies: {},
						internal: !1
					}),
					classCallCheck: helper("7.0.0-beta.0", "function _classCallCheck(a,n){if(!(a instanceof n))throw new TypeError(\"Cannot call a class as a function\")}", {
						globals: ["TypeError"],
						locals: { _classCallCheck: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classCallCheck",
						dependencies: {},
						internal: !1
					}),
					classNameTDZError: helper("7.0.0-beta.0", "function _classNameTDZError(e){throw new ReferenceError('Class \"'+e+'\" cannot be referenced in computed property keys.')}", {
						globals: ["ReferenceError"],
						locals: { _classNameTDZError: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classNameTDZError",
						dependencies: {},
						internal: !1
					}),
					classPrivateFieldGet2: helper("7.24.0", "function _classPrivateFieldGet2(s,a){return s.get(assertClassBrand(s,a))}", {
						globals: [],
						locals: { _classPrivateFieldGet2: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateFieldGet2",
						dependencies: { assertClassBrand: ["body.0.body.body.0.argument.arguments.0.callee"] },
						internal: !1
					}),
					classPrivateFieldInitSpec: helper("7.14.1", "function _classPrivateFieldInitSpec(e,t,a){checkPrivateRedeclaration(e,t),t.set(e,a)}", {
						globals: [],
						locals: { _classPrivateFieldInitSpec: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateFieldInitSpec",
						dependencies: { checkPrivateRedeclaration: ["body.0.body.body.0.expression.expressions.0.callee"] },
						internal: !1
					}),
					classPrivateFieldLooseBase: helper("7.0.0-beta.0", "function _classPrivateFieldBase(e,t){if(!{}.hasOwnProperty.call(e,t))throw new TypeError(\"attempted to use private field on non-instance\");return e}", {
						globals: ["TypeError"],
						locals: { _classPrivateFieldBase: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateFieldBase",
						dependencies: {},
						internal: !1
					}),
					classPrivateFieldLooseKey: helper("7.0.0-beta.0", "var id=0;function _classPrivateFieldKey(e){return\"__private_\"+id+++\"_\"+e}", {
						globals: [],
						locals: {
							id: [
								"body.0.declarations.0.id",
								"body.1.body.body.0.argument.left.left.right.argument",
								"body.1.body.body.0.argument.left.left.right.argument"
							],
							_classPrivateFieldKey: ["body.1.id"]
						},
						exportBindingAssignments: [],
						exportName: "_classPrivateFieldKey",
						dependencies: {},
						internal: !1
					}),
					classPrivateFieldSet2: helper("7.24.0", "function _classPrivateFieldSet2(s,a,r){return s.set(assertClassBrand(s,a),r),r}", {
						globals: [],
						locals: { _classPrivateFieldSet2: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateFieldSet2",
						dependencies: { assertClassBrand: ["body.0.body.body.0.argument.expressions.0.arguments.0.callee"] },
						internal: !1
					}),
					classPrivateGetter: helper("7.24.0", "function _classPrivateGetter(s,r,a){return a(assertClassBrand(s,r))}", {
						globals: [],
						locals: { _classPrivateGetter: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateGetter",
						dependencies: { assertClassBrand: ["body.0.body.body.0.argument.arguments.0.callee"] },
						internal: !1
					}),
					classPrivateMethodInitSpec: helper("7.14.1", "function _classPrivateMethodInitSpec(e,a){checkPrivateRedeclaration(e,a),a.add(e)}", {
						globals: [],
						locals: { _classPrivateMethodInitSpec: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateMethodInitSpec",
						dependencies: { checkPrivateRedeclaration: ["body.0.body.body.0.expression.expressions.0.callee"] },
						internal: !1
					}),
					classPrivateSetter: helper("7.24.0", "function _classPrivateSetter(s,r,a,t){return r(assertClassBrand(s,a),t),t}", {
						globals: [],
						locals: { _classPrivateSetter: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateSetter",
						dependencies: { assertClassBrand: ["body.0.body.body.0.argument.expressions.0.arguments.0.callee"] },
						internal: !1
					}),
					classStaticPrivateMethodGet: helper("7.3.2", "function _classStaticPrivateMethodGet(s,a,t){return assertClassBrand(a,s),t}", {
						globals: [],
						locals: { _classStaticPrivateMethodGet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classStaticPrivateMethodGet",
						dependencies: { assertClassBrand: ["body.0.body.body.0.argument.expressions.0.callee"] },
						internal: !1
					}),
					construct: helper("7.0.0-beta.0", "function _construct(t,e,r){if(isNativeReflectConstruct())return Reflect.construct.apply(null,arguments);var o=[null];o.push.apply(o,e);var p=new(t.bind.apply(t,o));return r&&setPrototypeOf(p,r.prototype),p}", {
						globals: ["Reflect"],
						locals: { _construct: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_construct",
						dependencies: {
							isNativeReflectConstruct: ["body.0.body.body.0.test.callee"],
							setPrototypeOf: ["body.0.body.body.4.argument.expressions.0.right.callee"]
						},
						internal: !1
					}),
					createClass: helper("7.0.0-beta.0", "function _defineProperties(e,r){for(var t=0;t<r.length;t++){var o=r[t];o.enumerable=o.enumerable||!1,o.configurable=!0,\"value\"in o&&(o.writable=!0),Object.defineProperty(e,toPropertyKey(o.key),o)}}function _createClass(e,r,t){return r&&_defineProperties(e.prototype,r),t&&_defineProperties(e,t),Object.defineProperty(e,\"prototype\",{writable:!1}),e}", {
						globals: ["Object"],
						locals: {
							_defineProperties: [
								"body.0.id",
								"body.1.body.body.0.argument.expressions.0.right.callee",
								"body.1.body.body.0.argument.expressions.1.right.callee"
							],
							_createClass: ["body.1.id"]
						},
						exportBindingAssignments: [],
						exportName: "_createClass",
						dependencies: { toPropertyKey: ["body.0.body.body.0.body.body.1.expression.expressions.3.arguments.1.callee"] },
						internal: !1
					}),
					createForOfIteratorHelper: helper("7.9.0", "function _createForOfIteratorHelper(r,e){var t=\"undefined\"!=typeof Symbol&&r[Symbol.iterator]||r[\"@@iterator\"];if(!t){if(Array.isArray(r)||(t=unsupportedIterableToArray(r))||e&&r&&\"number\"==typeof r.length){t&&(r=t);var n=0,F=function(){};return{s:F,n:function(){return n>=r.length?{done:!0}:{done:!1,value:r[n++]}},e:function(r){throw r},f:F}}throw new TypeError(\"Invalid attempt to iterate non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}var o,a=!0,u=!1;return{s:function(){t=t.call(r)},n:function(){var r=t.next();return a=r.done,r},e:function(r){u=!0,o=r},f:function(){try{a||null==t.return||t.return()}finally{if(u)throw o}}}}", {
						globals: [
							"Symbol",
							"Array",
							"TypeError"
						],
						locals: { _createForOfIteratorHelper: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_createForOfIteratorHelper",
						dependencies: { unsupportedIterableToArray: ["body.0.body.body.1.consequent.body.0.test.left.right.right.callee"] },
						internal: !1
					}),
					createForOfIteratorHelperLoose: helper("7.9.0", "function _createForOfIteratorHelperLoose(r,e){var t=\"undefined\"!=typeof Symbol&&r[Symbol.iterator]||r[\"@@iterator\"];if(t)return(t=t.call(r)).next.bind(t);if(Array.isArray(r)||(t=unsupportedIterableToArray(r))||e&&r&&\"number\"==typeof r.length){t&&(r=t);var o=0;return function(){return o>=r.length?{done:!0}:{done:!1,value:r[o++]}}}throw new TypeError(\"Invalid attempt to iterate non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}", {
						globals: [
							"Symbol",
							"Array",
							"TypeError"
						],
						locals: { _createForOfIteratorHelperLoose: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_createForOfIteratorHelperLoose",
						dependencies: { unsupportedIterableToArray: ["body.0.body.body.2.test.left.right.right.callee"] },
						internal: !1
					}),
					createSuper: helper("7.9.0", "function _createSuper(t){var r=isNativeReflectConstruct();return function(){var e,o=getPrototypeOf(t);if(r){var s=getPrototypeOf(this).constructor;e=Reflect.construct(o,arguments,s)}else e=o.apply(this,arguments);return possibleConstructorReturn(this,e)}}", {
						globals: ["Reflect"],
						locals: { _createSuper: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_createSuper",
						dependencies: {
							getPrototypeOf: ["body.0.body.body.1.argument.body.body.0.declarations.1.init.callee", "body.0.body.body.1.argument.body.body.1.consequent.body.0.declarations.0.init.object.callee"],
							isNativeReflectConstruct: ["body.0.body.body.0.declarations.0.init.callee"],
							possibleConstructorReturn: ["body.0.body.body.1.argument.body.body.2.argument.callee"]
						},
						internal: !1
					}),
					decorate: helper("7.1.5", "function _decorate(e,r,t,i){var o=_getDecoratorsApi();if(i)for(var n=0;n<i.length;n++)o=i[n](o);var s=r(function(e){o.initializeInstanceElements(e,a.elements)},t),a=o.decorateClass(_coalesceClassElements(s.d.map(_createElementDescriptor)),e);return o.initializeClassElements(s.F,a.elements),o.runClassFinishers(s.F,a.finishers)}function _getDecoratorsApi(){_getDecoratorsApi=function(){return e};var e={elementsDefinitionOrder:[[\"method\"],[\"field\"]],initializeInstanceElements:function(e,r){[\"method\",\"field\"].forEach(function(t){r.forEach(function(r){r.kind===t&&\"own\"===r.placement&&this.defineClassElement(e,r)},this)},this)},initializeClassElements:function(e,r){var t=e.prototype;[\"method\",\"field\"].forEach(function(i){r.forEach(function(r){var o=r.placement;if(r.kind===i&&(\"static\"===o||\"prototype\"===o)){var n=\"static\"===o?e:t;this.defineClassElement(n,r)}},this)},this)},defineClassElement:function(e,r){var t=r.descriptor;if(\"field\"===r.kind){var i=r.initializer;t={enumerable:t.enumerable,writable:t.writable,configurable:t.configurable,value:void 0===i?void 0:i.call(e)}}Object.defineProperty(e,r.key,t)},decorateClass:function(e,r){var t=[],i=[],o={static:[],prototype:[],own:[]};if(e.forEach(function(e){this.addElementPlacement(e,o)},this),e.forEach(function(e){if(!_hasDecorators(e))return t.push(e);var r=this.decorateElement(e,o);t.push(r.element),t.push.apply(t,r.extras),i.push.apply(i,r.finishers)},this),!r)return{elements:t,finishers:i};var n=this.decorateConstructor(t,r);return i.push.apply(i,n.finishers),n.finishers=i,n},addElementPlacement:function(e,r,t){var i=r[e.placement];if(!t&&-1!==i.indexOf(e.key))throw new TypeError(\"Duplicated element (\"+e.key+\")\");i.push(e.key)},decorateElement:function(e,r){for(var t=[],i=[],o=e.decorators,n=o.length-1;n>=0;n--){var s=r[e.placement];s.splice(s.indexOf(e.key),1);var a=this.fromElementDescriptor(e),l=this.toElementFinisherExtras((0,o[n])(a)||a);e=l.element,this.addElementPlacement(e,r),l.finisher&&i.push(l.finisher);var c=l.extras;if(c){for(var p=0;p<c.length;p++)this.addElementPlacement(c[p],r);t.push.apply(t,c)}}return{element:e,finishers:i,extras:t}},decorateConstructor:function(e,r){for(var t=[],i=r.length-1;i>=0;i--){var o=this.fromClassDescriptor(e),n=this.toClassDescriptor((0,r[i])(o)||o);if(void 0!==n.finisher&&t.push(n.finisher),void 0!==n.elements){e=n.elements;for(var s=0;s<e.length-1;s++)for(var a=s+1;a<e.length;a++)if(e[s].key===e[a].key&&e[s].placement===e[a].placement)throw new TypeError(\"Duplicated element (\"+e[s].key+\")\")}}return{elements:e,finishers:t}},fromElementDescriptor:function(e){var r={kind:e.kind,key:e.key,placement:e.placement,descriptor:e.descriptor};return Object.defineProperty(r,Symbol.toStringTag,{value:\"Descriptor\",configurable:!0}),\"field\"===e.kind&&(r.initializer=e.initializer),r},toElementDescriptors:function(e){if(void 0!==e)return toArray(e).map(function(e){var r=this.toElementDescriptor(e);return this.disallowProperty(e,\"finisher\",\"An element descriptor\"),this.disallowProperty(e,\"extras\",\"An element descriptor\"),r},this)},toElementDescriptor:function(e){var r=e.kind+\"\";if(\"method\"!==r&&\"field\"!==r)throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or \"field\", but a decorator created an element descriptor with .kind \"'+r+'\"');var t=toPropertyKey(e.key),i=e.placement+\"\";if(\"static\"!==i&&\"prototype\"!==i&&\"own\"!==i)throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\", \"prototype\" or \"own\", but a decorator created an element descriptor with .placement \"'+i+'\"');var o=e.descriptor;this.disallowProperty(e,\"elements\",\"An element descriptor\");var n={kind:r,key:t,placement:i,descriptor:Object.assign({},o)};return\"field\"!==r?this.disallowProperty(e,\"initializer\",\"A method descriptor\"):(this.disallowProperty(o,\"get\",\"The property descriptor of a field descriptor\"),this.disallowProperty(o,\"set\",\"The property descriptor of a field descriptor\"),this.disallowProperty(o,\"value\",\"The property descriptor of a field descriptor\"),n.initializer=e.initializer),n},toElementFinisherExtras:function(e){return{element:this.toElementDescriptor(e),finisher:_optionalCallableProperty(e,\"finisher\"),extras:this.toElementDescriptors(e.extras)}},fromClassDescriptor:function(e){var r={kind:\"class\",elements:e.map(this.fromElementDescriptor,this)};return Object.defineProperty(r,Symbol.toStringTag,{value:\"Descriptor\",configurable:!0}),r},toClassDescriptor:function(e){var r=e.kind+\"\";if(\"class\"!==r)throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator created a class descriptor with .kind \"'+r+'\"');this.disallowProperty(e,\"key\",\"A class descriptor\"),this.disallowProperty(e,\"placement\",\"A class descriptor\"),this.disallowProperty(e,\"descriptor\",\"A class descriptor\"),this.disallowProperty(e,\"initializer\",\"A class descriptor\"),this.disallowProperty(e,\"extras\",\"A class descriptor\");var t=_optionalCallableProperty(e,\"finisher\");return{elements:this.toElementDescriptors(e.elements),finisher:t}},runClassFinishers:function(e,r){for(var t=0;t<r.length;t++){var i=(0,r[t])(e);if(void 0!==i){if(\"function\"!=typeof i)throw new TypeError(\"Finishers must return a constructor.\");e=i}}return e},disallowProperty:function(e,r,t){if(void 0!==e[r])throw new TypeError(t+\" can't have a .\"+r+\" property.\")}};return e}function _createElementDescriptor(e){var r,t=toPropertyKey(e.key);\"method\"===e.kind?r={value:e.value,writable:!0,configurable:!0,enumerable:!1}:\"get\"===e.kind?r={get:e.value,configurable:!0,enumerable:!1}:\"set\"===e.kind?r={set:e.value,configurable:!0,enumerable:!1}:\"field\"===e.kind&&(r={configurable:!0,writable:!0,enumerable:!0});var i={kind:\"field\"===e.kind?\"field\":\"method\",key:t,placement:e.static?\"static\":\"field\"===e.kind?\"own\":\"prototype\",descriptor:r};return e.decorators&&(i.decorators=e.decorators),\"field\"===e.kind&&(i.initializer=e.value),i}function _coalesceGetterSetter(e,r){void 0!==e.descriptor.get?r.descriptor.get=e.descriptor.get:r.descriptor.set=e.descriptor.set}function _coalesceClassElements(e){for(var r=[],isSameElement=function(e){return\"method\"===e.kind&&e.key===o.key&&e.placement===o.placement},t=0;t<e.length;t++){var i,o=e[t];if(\"method\"===o.kind&&(i=r.find(isSameElement)))if(_isDataDescriptor(o.descriptor)||_isDataDescriptor(i.descriptor)){if(_hasDecorators(o)||_hasDecorators(i))throw new ReferenceError(\"Duplicated methods (\"+o.key+\") can't be decorated.\");i.descriptor=o.descriptor}else{if(_hasDecorators(o)){if(_hasDecorators(i))throw new ReferenceError(\"Decorators can't be placed on different accessors with for the same property (\"+o.key+\").\");i.decorators=o.decorators}_coalesceGetterSetter(o,i)}else r.push(o)}return r}function _hasDecorators(e){return e.decorators&&e.decorators.length}function _isDataDescriptor(e){return void 0!==e&&!(void 0===e.value&&void 0===e.writable)}function _optionalCallableProperty(e,r){var t=e[r];if(void 0!==t&&\"function\"!=typeof t)throw new TypeError(\"Expected '\"+r+\"' to be a function\");return t}", {
						globals: [
							"Object",
							"TypeError",
							"Symbol",
							"ReferenceError"
						],
						locals: {
							_decorate: ["body.0.id"],
							_getDecoratorsApi: [
								"body.1.id",
								"body.0.body.body.0.declarations.0.init.callee",
								"body.1.body.body.0.expression.left"
							],
							_createElementDescriptor: ["body.2.id", "body.0.body.body.2.declarations.1.init.arguments.0.arguments.0.arguments.0"],
							_coalesceGetterSetter: ["body.3.id", "body.4.body.body.0.body.body.1.consequent.alternate.body.1.expression.callee"],
							_coalesceClassElements: ["body.4.id", "body.0.body.body.2.declarations.1.init.arguments.0.callee"],
							_hasDecorators: [
								"body.5.id",
								"body.1.body.body.1.declarations.0.init.properties.4.value.body.body.1.test.expressions.1.arguments.0.body.body.0.test.argument.callee",
								"body.4.body.body.0.body.body.1.consequent.consequent.body.0.test.left.callee",
								"body.4.body.body.0.body.body.1.consequent.consequent.body.0.test.right.callee",
								"body.4.body.body.0.body.body.1.consequent.alternate.body.0.test.callee",
								"body.4.body.body.0.body.body.1.consequent.alternate.body.0.consequent.body.0.test.callee"
							],
							_isDataDescriptor: [
								"body.6.id",
								"body.4.body.body.0.body.body.1.consequent.test.left.callee",
								"body.4.body.body.0.body.body.1.consequent.test.right.callee"
							],
							_optionalCallableProperty: [
								"body.7.id",
								"body.1.body.body.1.declarations.0.init.properties.11.value.body.body.0.argument.properties.1.value.callee",
								"body.1.body.body.1.declarations.0.init.properties.13.value.body.body.3.declarations.0.init.callee"
							]
						},
						exportBindingAssignments: [],
						exportName: "_decorate",
						dependencies: {
							toArray: ["body.1.body.body.1.declarations.0.init.properties.9.value.body.body.0.consequent.argument.callee.object.callee"],
							toPropertyKey: ["body.1.body.body.1.declarations.0.init.properties.10.value.body.body.2.declarations.0.init.callee", "body.2.body.body.0.declarations.1.init.callee"]
						},
						internal: !1
					}),
					defaults: helper("7.0.0-beta.0", "function _defaults(e,r){for(var t=Object.getOwnPropertyNames(r),o=0;o<t.length;o++){var n=t[o],a=Object.getOwnPropertyDescriptor(r,n);a&&a.configurable&&void 0===e[n]&&Object.defineProperty(e,n,a)}return e}", {
						globals: ["Object"],
						locals: { _defaults: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_defaults",
						dependencies: {},
						internal: !1
					}),
					defineAccessor: helper("7.20.7", "function _defineAccessor(e,r,n,t){var c={configurable:!0,enumerable:!0};return c[e]=t,Object.defineProperty(r,n,c)}", {
						globals: ["Object"],
						locals: { _defineAccessor: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_defineAccessor",
						dependencies: {},
						internal: !1
					}),
					defineProperty: helper("7.0.0-beta.0", "function _defineProperty(e,r,t){return(r=toPropertyKey(r))in e?Object.defineProperty(e,r,{value:t,enumerable:!0,configurable:!0,writable:!0}):e[r]=t,e}", {
						globals: ["Object"],
						locals: { _defineProperty: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_defineProperty",
						dependencies: { toPropertyKey: ["body.0.body.body.0.argument.expressions.0.test.left.right.callee"] },
						internal: !1
					}),
					extends: helper("7.0.0-beta.0", "function _extends(){return _extends=Object.assign?Object.assign.bind():function(n){for(var e=1;e<arguments.length;e++){var t=arguments[e];for(var r in t)({}).hasOwnProperty.call(t,r)&&(n[r]=t[r])}return n},_extends.apply(null,arguments)}", {
						globals: ["Object"],
						locals: { _extends: [
							"body.0.id",
							"body.0.body.body.0.argument.expressions.1.callee.object",
							"body.0.body.body.0.argument.expressions.0.left"
						] },
						exportBindingAssignments: ["body.0.body.body.0.argument.expressions.0"],
						exportName: "_extends",
						dependencies: {},
						internal: !1
					}),
					get: helper("7.0.0-beta.0", "function _get(){return _get=\"undefined\"!=typeof Reflect&&Reflect.get?Reflect.get.bind():function(e,t,r){var p=superPropBase(e,t);if(p){var n=Object.getOwnPropertyDescriptor(p,t);return n.get?n.get.call(arguments.length<3?e:r):n.value}},_get.apply(null,arguments)}", {
						globals: ["Reflect", "Object"],
						locals: { _get: [
							"body.0.id",
							"body.0.body.body.0.argument.expressions.1.callee.object",
							"body.0.body.body.0.argument.expressions.0.left"
						] },
						exportBindingAssignments: ["body.0.body.body.0.argument.expressions.0"],
						exportName: "_get",
						dependencies: { superPropBase: ["body.0.body.body.0.argument.expressions.0.right.alternate.body.body.0.declarations.0.init.callee"] },
						internal: !1
					}),
					getPrototypeOf: helper("7.0.0-beta.0", "function _getPrototypeOf(t){return _getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},_getPrototypeOf(t)}", {
						globals: ["Object"],
						locals: { _getPrototypeOf: [
							"body.0.id",
							"body.0.body.body.0.argument.expressions.1.callee",
							"body.0.body.body.0.argument.expressions.0.left"
						] },
						exportBindingAssignments: ["body.0.body.body.0.argument.expressions.0"],
						exportName: "_getPrototypeOf",
						dependencies: {},
						internal: !1
					}),
					identity: helper("7.17.0", "function _identity(t){return t}", {
						globals: [],
						locals: { _identity: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_identity",
						dependencies: {},
						internal: !1
					}),
					importDeferProxy: helper("7.23.0", "function _importDeferProxy(e){var t=null,constValue=function(e){return function(){return e}},proxy=function(r){return function(n,o,f){return null===t&&(t=e()),r(t,o,f)}};return new Proxy({},{defineProperty:constValue(!1),deleteProperty:constValue(!1),get:proxy(Reflect.get),getOwnPropertyDescriptor:proxy(Reflect.getOwnPropertyDescriptor),getPrototypeOf:constValue(null),isExtensible:constValue(!1),has:proxy(Reflect.has),ownKeys:proxy(Reflect.ownKeys),preventExtensions:constValue(!0),set:constValue(!1),setPrototypeOf:constValue(!1)})}", {
						globals: ["Proxy", "Reflect"],
						locals: { _importDeferProxy: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_importDeferProxy",
						dependencies: {},
						internal: !1
					}),
					inherits: helper("7.0.0-beta.0", "function _inherits(t,e){if(\"function\"!=typeof e&&null!==e)throw new TypeError(\"Super expression must either be null or a function\");t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),Object.defineProperty(t,\"prototype\",{writable:!1}),e&&setPrototypeOf(t,e)}", {
						globals: ["TypeError", "Object"],
						locals: { _inherits: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_inherits",
						dependencies: { setPrototypeOf: ["body.0.body.body.1.expression.expressions.2.right.callee"] },
						internal: !1
					}),
					inheritsLoose: helper("7.0.0-beta.0", "function _inheritsLoose(t,o){t.prototype=Object.create(o.prototype),t.prototype.constructor=t,setPrototypeOf(t,o)}", {
						globals: ["Object"],
						locals: { _inheritsLoose: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_inheritsLoose",
						dependencies: { setPrototypeOf: ["body.0.body.body.0.expression.expressions.2.callee"] },
						internal: !1
					}),
					initializerDefineProperty: helper("7.0.0-beta.0", "function _initializerDefineProperty(e,i,r,l){r&&Object.defineProperty(e,i,{enumerable:r.enumerable,configurable:r.configurable,writable:r.writable,value:r.initializer?r.initializer.call(l):void 0})}", {
						globals: ["Object"],
						locals: { _initializerDefineProperty: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_initializerDefineProperty",
						dependencies: {},
						internal: !1
					}),
					initializerWarningHelper: helper("7.0.0-beta.0", "function _initializerWarningHelper(r,e){throw Error(\"Decorating class property failed. Please ensure that transform-class-properties is enabled and runs after the decorators transform.\")}", {
						globals: ["Error"],
						locals: { _initializerWarningHelper: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_initializerWarningHelper",
						dependencies: {},
						internal: !1
					}),
					instanceof: helper("7.0.0-beta.0", "function _instanceof(n,e){return null!=e&&\"undefined\"!=typeof Symbol&&e[Symbol.hasInstance]?!!e[Symbol.hasInstance](n):n instanceof e}", {
						globals: ["Symbol"],
						locals: { _instanceof: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_instanceof",
						dependencies: {},
						internal: !1
					}),
					interopRequireDefault: helper("7.0.0-beta.0", "function _interopRequireDefault(e){return e&&e.__esModule?e:{default:e}}", {
						globals: [],
						locals: { _interopRequireDefault: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_interopRequireDefault",
						dependencies: {},
						internal: !1
					}),
					interopRequireWildcard: helper("7.14.0", "function _interopRequireWildcard(e,t){if(\"function\"==typeof WeakMap)var r=new WeakMap,n=new WeakMap;return(_interopRequireWildcard=function(e,t){if(!t&&e&&e.__esModule)return e;var o,i,f={__proto__:null,default:e};if(null===e||\"object\"!=typeof e&&\"function\"!=typeof e)return f;if(o=t?n:r){if(o.has(e))return o.get(e);o.set(e,f)}for(const t in e)\"default\"!==t&&{}.hasOwnProperty.call(e,t)&&((i=(o=Object.defineProperty)&&Object.getOwnPropertyDescriptor(e,t))&&(i.get||i.set)?o(f,t,i):f[t]=e[t]);return f})(e,t)}", {
						globals: ["WeakMap", "Object"],
						locals: { _interopRequireWildcard: ["body.0.id", "body.0.body.body.1.argument.callee.left"] },
						exportBindingAssignments: ["body.0.body.body.1.argument.callee"],
						exportName: "_interopRequireWildcard",
						dependencies: {},
						internal: !1
					}),
					isNativeFunction: helper("7.0.0-beta.0", "function _isNativeFunction(t){try{return-1!==Function.toString.call(t).indexOf(\"[native code]\")}catch(n){return\"function\"==typeof t}}", {
						globals: ["Function"],
						locals: { _isNativeFunction: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_isNativeFunction",
						dependencies: {},
						internal: !1
					}),
					isNativeReflectConstruct: helper("7.9.0", "function _isNativeReflectConstruct(){try{var t=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch(t){}return(_isNativeReflectConstruct=function(){return!!t})()}", {
						globals: ["Boolean", "Reflect"],
						locals: { _isNativeReflectConstruct: ["body.0.id", "body.0.body.body.1.argument.callee.left"] },
						exportBindingAssignments: ["body.0.body.body.1.argument.callee"],
						exportName: "_isNativeReflectConstruct",
						dependencies: {},
						internal: !1
					}),
					iterableToArray: helper("7.0.0-beta.0", "function _iterableToArray(r){if(\"undefined\"!=typeof Symbol&&null!=r[Symbol.iterator]||null!=r[\"@@iterator\"])return Array.from(r)}", {
						globals: ["Symbol", "Array"],
						locals: { _iterableToArray: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_iterableToArray",
						dependencies: {},
						internal: !1
					}),
					iterableToArrayLimit: helper("7.0.0-beta.0", "function _iterableToArrayLimit(r,l){var t=null==r?null:\"undefined\"!=typeof Symbol&&r[Symbol.iterator]||r[\"@@iterator\"];if(null!=t){var e,n,i,u,a=[],f=!0,o=!1;try{if(i=(t=t.call(r)).next,0===l){if(Object(t)!==t)return;f=!1}else for(;!(f=(e=i.call(t)).done)&&(a.push(e.value),a.length!==l);f=!0);}catch(r){o=!0,n=r}finally{try{if(!f&&null!=t.return&&(u=t.return(),Object(u)!==u))return}finally{if(o)throw n}}return a}}", {
						globals: ["Symbol", "Object"],
						locals: { _iterableToArrayLimit: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_iterableToArrayLimit",
						dependencies: {},
						internal: !1
					}),
					jsx: helper("7.0.0-beta.0", "var REACT_ELEMENT_TYPE;function _createRawReactElement(e,r,E,l){REACT_ELEMENT_TYPE||(REACT_ELEMENT_TYPE=\"function\"==typeof Symbol&&Symbol.for&&Symbol.for(\"react.element\")||60103);var o=e&&e.defaultProps,n=arguments.length-3;if(r||0===n||(r={children:void 0}),1===n)r.children=l;else if(n>1){for(var t=Array(n),f=0;f<n;f++)t[f]=arguments[f+3];r.children=t}if(r&&o)for(var i in o)void 0===r[i]&&(r[i]=o[i]);else r||(r=o||{});return{$$typeof:REACT_ELEMENT_TYPE,type:e,key:void 0===E?null:\"\"+E,ref:null,props:r,_owner:null}}", {
						globals: ["Symbol", "Array"],
						locals: {
							REACT_ELEMENT_TYPE: [
								"body.0.declarations.0.id",
								"body.1.body.body.0.expression.left",
								"body.1.body.body.4.argument.properties.0.value",
								"body.1.body.body.0.expression.right.left"
							],
							_createRawReactElement: ["body.1.id"]
						},
						exportBindingAssignments: [],
						exportName: "_createRawReactElement",
						dependencies: {},
						internal: !1
					}),
					maybeArrayLike: helper("7.9.0", "function _maybeArrayLike(r,a,e){if(a&&!Array.isArray(a)&&\"number\"==typeof a.length){var y=a.length;return arrayLikeToArray(a,void 0!==e&&e<y?e:y)}return r(a,e)}", {
						globals: ["Array"],
						locals: { _maybeArrayLike: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_maybeArrayLike",
						dependencies: { arrayLikeToArray: ["body.0.body.body.0.consequent.body.1.argument.callee"] },
						internal: !1
					}),
					newArrowCheck: helper("7.0.0-beta.0", "function _newArrowCheck(n,r){if(n!==r)throw new TypeError(\"Cannot instantiate an arrow function\")}", {
						globals: ["TypeError"],
						locals: { _newArrowCheck: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_newArrowCheck",
						dependencies: {},
						internal: !1
					}),
					nonIterableRest: helper("7.0.0-beta.0", "function _nonIterableRest(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}", {
						globals: ["TypeError"],
						locals: { _nonIterableRest: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_nonIterableRest",
						dependencies: {},
						internal: !1
					}),
					nonIterableSpread: helper("7.0.0-beta.0", "function _nonIterableSpread(){throw new TypeError(\"Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}", {
						globals: ["TypeError"],
						locals: { _nonIterableSpread: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_nonIterableSpread",
						dependencies: {},
						internal: !1
					}),
					nullishReceiverError: helper("7.22.6", "function _nullishReceiverError(r){throw new TypeError(\"Cannot set property of null or undefined.\")}", {
						globals: ["TypeError"],
						locals: { _nullishReceiverError: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_nullishReceiverError",
						dependencies: {},
						internal: !1
					}),
					objectDestructuringEmpty: helper("7.0.0-beta.0", "function _objectDestructuringEmpty(t){if(null==t)throw new TypeError(\"Cannot destructure \"+t)}", {
						globals: ["TypeError"],
						locals: { _objectDestructuringEmpty: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_objectDestructuringEmpty",
						dependencies: {},
						internal: !1
					}),
					objectSpread2: helper("7.5.0", "function ownKeys(e,r){var t=Object.keys(e);if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(e);r&&(o=o.filter(function(r){return Object.getOwnPropertyDescriptor(e,r).enumerable})),t.push.apply(t,o)}return t}function _objectSpread2(e){for(var r=1;r<arguments.length;r++){var t=null!=arguments[r]?arguments[r]:{};r%2?ownKeys(Object(t),!0).forEach(function(r){defineProperty(e,r,t[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(t)):ownKeys(Object(t)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(t,r))})}return e}", {
						globals: ["Object"],
						locals: {
							ownKeys: [
								"body.0.id",
								"body.1.body.body.0.body.body.1.expression.consequent.callee.object.callee",
								"body.1.body.body.0.body.body.1.expression.alternate.alternate.callee.object.callee"
							],
							_objectSpread2: ["body.1.id"]
						},
						exportBindingAssignments: [],
						exportName: "_objectSpread2",
						dependencies: { defineProperty: ["body.1.body.body.0.body.body.1.expression.consequent.arguments.0.body.body.0.expression.callee"] },
						internal: !1
					}),
					objectWithoutProperties: helper("7.0.0-beta.0", "function _objectWithoutProperties(e,t){if(null==e)return{};var o,r,i=objectWithoutPropertiesLoose(e,t);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);for(r=0;r<n.length;r++)o=n[r],-1===t.indexOf(o)&&{}.propertyIsEnumerable.call(e,o)&&(i[o]=e[o])}return i}", {
						globals: ["Object"],
						locals: { _objectWithoutProperties: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_objectWithoutProperties",
						dependencies: { objectWithoutPropertiesLoose: ["body.0.body.body.1.declarations.2.init.callee"] },
						internal: !1
					}),
					objectWithoutPropertiesLoose: helper("7.0.0-beta.0", "function _objectWithoutPropertiesLoose(r,e){if(null==r)return{};var t={};for(var n in r)if({}.hasOwnProperty.call(r,n)){if(-1!==e.indexOf(n))continue;t[n]=r[n]}return t}", {
						globals: [],
						locals: { _objectWithoutPropertiesLoose: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_objectWithoutPropertiesLoose",
						dependencies: {},
						internal: !1
					}),
					possibleConstructorReturn: helper("7.0.0-beta.0", "function _possibleConstructorReturn(t,e){if(e&&(\"object\"==typeof e||\"function\"==typeof e))return e;if(void 0!==e)throw new TypeError(\"Derived constructors may only return object or undefined\");return assertThisInitialized(t)}", {
						globals: ["TypeError"],
						locals: { _possibleConstructorReturn: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_possibleConstructorReturn",
						dependencies: { assertThisInitialized: ["body.0.body.body.2.argument.callee"] },
						internal: !1
					}),
					readOnlyError: helper("7.0.0-beta.0", "function _readOnlyError(r){throw new TypeError('\"'+r+'\" is read-only')}", {
						globals: ["TypeError"],
						locals: { _readOnlyError: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_readOnlyError",
						dependencies: {},
						internal: !1
					}),
					regenerator: helper("7.27.0", "function _regenerator(){\n/*! regenerator-runtime -- Copyright (c) 2014-present, Facebook, Inc. -- license (MIT): https://github.com/babel/babel/blob/main/packages/babel-helpers/LICENSE */\nvar e,t,r=\"function\"==typeof Symbol?Symbol:{},n=r.iterator||\"@@iterator\",o=r.toStringTag||\"@@toStringTag\";function i(r,n,o,i){var c=n&&n.prototype instanceof Generator?n:Generator,u=Object.create(c.prototype);return define(u,\"_invoke\",function(r,n,o){var i,c,u,f=0,p=o||[],y=!1,G={p:0,n:0,v:e,a:d,f:d.bind(e,4),d:function(t,r){return i=t,c=0,u=e,G.n=r,a}};function d(r,n){for(c=r,u=n,t=0;!y&&f&&!o&&t<p.length;t++){var o,i=p[t],d=G.p,l=i[2];r>3?(o=l===n)&&(u=i[(c=i[4])?5:(c=3,3)],i[4]=i[5]=e):i[0]<=d&&((o=r<2&&d<i[1])?(c=0,G.v=n,G.n=i[1]):d<l&&(o=r<3||i[0]>n||n>l)&&(i[4]=r,i[5]=n,G.n=l,c=0))}if(o||r>1)return a;throw y=!0,n}return function(o,p,l){if(f>1)throw TypeError(\"Generator is already running\");for(y&&1===p&&d(p,l),c=p,u=l;(t=c<2?e:u)||!y;){i||(c?c<3?(c>1&&(G.n=-1),d(c,u)):G.n=u:G.v=u);try{if(f=2,i){if(c||(o=\"next\"),t=i[o]){if(!(t=t.call(i,u)))throw TypeError(\"iterator result is not an object\");if(!t.done)return t;u=t.value,c<2&&(c=0)}else 1===c&&(t=i.return)&&t.call(i),c<2&&(u=TypeError(\"The iterator does not provide a '\"+o+\"' method\"),c=1);i=e}else if((t=(y=G.n<0)?u:r.call(n,G))!==a)break}catch(t){i=e,c=1,u=t}finally{f=1}}return{value:t,done:y}}}(r,o,i),!0),u}var a={};function Generator(){}function GeneratorFunction(){}function GeneratorFunctionPrototype(){}t=Object.getPrototypeOf;var c=[][n]?t(t([][n]())):(define(t={},n,function(){return this}),t),u=GeneratorFunctionPrototype.prototype=Generator.prototype=Object.create(c);function f(e){return Object.setPrototypeOf?Object.setPrototypeOf(e,GeneratorFunctionPrototype):(e.__proto__=GeneratorFunctionPrototype,define(e,o,\"GeneratorFunction\")),e.prototype=Object.create(u),e}return GeneratorFunction.prototype=GeneratorFunctionPrototype,define(u,\"constructor\",GeneratorFunctionPrototype),define(GeneratorFunctionPrototype,\"constructor\",GeneratorFunction),GeneratorFunction.displayName=\"GeneratorFunction\",define(GeneratorFunctionPrototype,o,\"GeneratorFunction\"),define(u),define(u,o,\"Generator\"),define(u,n,function(){return this}),define(u,\"toString\",function(){return\"[object Generator]\"}),(_regenerator=function(){return{w:i,m:f}})()}", {
						globals: [
							"Symbol",
							"Object",
							"TypeError"
						],
						locals: { _regenerator: ["body.0.id", "body.0.body.body.9.argument.expressions.9.callee.left"] },
						exportBindingAssignments: ["body.0.body.body.9.argument.expressions.9.callee"],
						exportName: "_regenerator",
						dependencies: { regeneratorDefine: [
							"body.0.body.body.1.body.body.1.argument.expressions.0.callee",
							"body.0.body.body.7.declarations.0.init.alternate.expressions.0.callee",
							"body.0.body.body.8.body.body.0.argument.expressions.0.alternate.expressions.1.callee",
							"body.0.body.body.9.argument.expressions.1.callee",
							"body.0.body.body.9.argument.expressions.2.callee",
							"body.0.body.body.9.argument.expressions.4.callee",
							"body.0.body.body.9.argument.expressions.5.callee",
							"body.0.body.body.9.argument.expressions.6.callee",
							"body.0.body.body.9.argument.expressions.7.callee",
							"body.0.body.body.9.argument.expressions.8.callee"
						] },
						internal: !1
					}),
					regeneratorAsync: helper("7.27.0", "function _regeneratorAsync(n,e,r,t,o){var a=asyncGen(n,e,r,t,o);return a.next().then(function(n){return n.done?n.value:a.next()})}", {
						globals: [],
						locals: { _regeneratorAsync: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_regeneratorAsync",
						dependencies: { regeneratorAsyncGen: ["body.0.body.body.0.declarations.0.init.callee"] },
						internal: !1
					}),
					regeneratorAsyncGen: helper("7.27.0", "function _regeneratorAsyncGen(r,e,t,o,n){return new regeneratorAsyncIterator(regenerator().w(r,e,t,o),n||Promise)}", {
						globals: ["Promise"],
						locals: { _regeneratorAsyncGen: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_regeneratorAsyncGen",
						dependencies: {
							regenerator: ["body.0.body.body.0.argument.arguments.0.callee.object.callee"],
							regeneratorAsyncIterator: ["body.0.body.body.0.argument.callee"]
						},
						internal: !1
					}),
					regeneratorAsyncIterator: helper("7.27.0", "function AsyncIterator(t,e){function n(r,o,i,f){try{var c=t[r](o),u=c.value;return u instanceof OverloadYield?e.resolve(u.v).then(function(t){n(\"next\",t,i,f)},function(t){n(\"throw\",t,i,f)}):e.resolve(u).then(function(t){c.value=t,i(c)},function(t){return n(\"throw\",t,i,f)})}catch(t){f(t)}}var r;this.next||(define(AsyncIterator.prototype),define(AsyncIterator.prototype,\"function\"==typeof Symbol&&Symbol.asyncIterator||\"@asyncIterator\",function(){return this})),define(this,\"_invoke\",function(t,o,i){function f(){return new e(function(e,r){n(t,i,e,r)})}return r=r?r.then(f,f):f()},!0)}", {
						globals: ["Symbol"],
						locals: { AsyncIterator: [
							"body.0.id",
							"body.0.body.body.2.expression.expressions.0.right.expressions.0.arguments.0.object",
							"body.0.body.body.2.expression.expressions.0.right.expressions.1.arguments.0.object"
						] },
						exportBindingAssignments: [],
						exportName: "AsyncIterator",
						dependencies: {
							OverloadYield: ["body.0.body.body.0.body.body.0.block.body.1.argument.test.right"],
							regeneratorDefine: [
								"body.0.body.body.2.expression.expressions.0.right.expressions.0.callee",
								"body.0.body.body.2.expression.expressions.0.right.expressions.1.callee",
								"body.0.body.body.2.expression.expressions.1.callee"
							]
						},
						internal: !0
					}),
					regeneratorDefine: helper("7.27.0", "function regeneratorDefine(e,r,n,t){var i=Object.defineProperty;try{i({},\"\",{})}catch(e){i=0}regeneratorDefine=function(e,r,n,t){function o(r,n){regeneratorDefine(e,r,function(e){return this._invoke(r,n,e)})}r?i?i(e,r,{value:n,enumerable:!t,configurable:!t,writable:!t}):e[r]=n:(o(\"next\",0),o(\"throw\",1),o(\"return\",2))},regeneratorDefine(e,r,n,t)}", {
						globals: ["Object"],
						locals: { regeneratorDefine: [
							"body.0.id",
							"body.0.body.body.2.expression.expressions.0.right.body.body.0.body.body.0.expression.callee",
							"body.0.body.body.2.expression.expressions.1.callee",
							"body.0.body.body.2.expression.expressions.0.left"
						] },
						exportBindingAssignments: ["body.0.body.body.2.expression.expressions.0"],
						exportName: "regeneratorDefine",
						dependencies: {},
						internal: !0
					}),
					regeneratorKeys: helper("7.27.0", "function _regeneratorKeys(e){var n=Object(e),r=[];for(var t in n)r.unshift(t);return function e(){for(;r.length;)if((t=r.pop())in n)return e.value=t,e.done=!1,e;return e.done=!0,e}}", {
						globals: ["Object"],
						locals: { _regeneratorKeys: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_regeneratorKeys",
						dependencies: {},
						internal: !1
					}),
					regeneratorValues: helper("7.18.0", "function _regeneratorValues(e){if(null!=e){var t=e[\"function\"==typeof Symbol&&Symbol.iterator||\"@@iterator\"],r=0;if(t)return t.call(e);if(\"function\"==typeof e.next)return e;if(!isNaN(e.length))return{next:function(){return e&&r>=e.length&&(e=void 0),{value:e&&e[r++],done:!e}}}}throw new TypeError(typeof e+\" is not iterable\")}", {
						globals: [
							"Symbol",
							"isNaN",
							"TypeError"
						],
						locals: { _regeneratorValues: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_regeneratorValues",
						dependencies: {},
						internal: !1
					}),
					set: helper("7.0.0-beta.0", "function set(e,r,t,o){return set=\"undefined\"!=typeof Reflect&&Reflect.set?Reflect.set:function(e,r,t,o){var f,i=superPropBase(e,r);if(i){if((f=Object.getOwnPropertyDescriptor(i,r)).set)return f.set.call(o,t),!0;if(!f.writable)return!1}if(f=Object.getOwnPropertyDescriptor(o,r)){if(!f.writable)return!1;f.value=t,Object.defineProperty(o,r,f)}else defineProperty(o,r,t);return!0},set(e,r,t,o)}function _set(e,r,t,o,f){if(!set(e,r,t,o||e)&&f)throw new TypeError(\"failed to set property\");return t}", {
						globals: [
							"Reflect",
							"Object",
							"TypeError"
						],
						locals: {
							set: [
								"body.0.id",
								"body.0.body.body.0.argument.expressions.1.callee",
								"body.1.body.body.0.test.left.argument.callee",
								"body.0.body.body.0.argument.expressions.0.left"
							],
							_set: ["body.1.id"]
						},
						exportBindingAssignments: [],
						exportName: "_set",
						dependencies: {
							superPropBase: ["body.0.body.body.0.argument.expressions.0.right.alternate.body.body.0.declarations.1.init.callee"],
							defineProperty: ["body.0.body.body.0.argument.expressions.0.right.alternate.body.body.2.alternate.expression.callee"]
						},
						internal: !1
					}),
					setFunctionName: helper("7.23.6", "function setFunctionName(e,t,n){\"symbol\"==typeof t&&(t=(t=t.description)?\"[\"+t+\"]\":\"\");try{Object.defineProperty(e,\"name\",{configurable:!0,value:n?n+\" \"+t:t})}catch(e){}return e}", {
						globals: ["Object"],
						locals: { setFunctionName: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "setFunctionName",
						dependencies: {},
						internal: !1
					}),
					setPrototypeOf: helper("7.0.0-beta.0", "function _setPrototypeOf(t,e){return _setPrototypeOf=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(t,e){return t.__proto__=e,t},_setPrototypeOf(t,e)}", {
						globals: ["Object"],
						locals: { _setPrototypeOf: [
							"body.0.id",
							"body.0.body.body.0.argument.expressions.1.callee",
							"body.0.body.body.0.argument.expressions.0.left"
						] },
						exportBindingAssignments: ["body.0.body.body.0.argument.expressions.0"],
						exportName: "_setPrototypeOf",
						dependencies: {},
						internal: !1
					}),
					skipFirstGeneratorNext: helper("7.0.0-beta.0", "function _skipFirstGeneratorNext(t){return function(){var r=t.apply(this,arguments);return r.next(),r}}", {
						globals: [],
						locals: { _skipFirstGeneratorNext: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_skipFirstGeneratorNext",
						dependencies: {},
						internal: !1
					}),
					slicedToArray: helper("7.0.0-beta.0", "function _slicedToArray(r,e){return arrayWithHoles(r)||iterableToArrayLimit(r,e)||unsupportedIterableToArray(r,e)||nonIterableRest()}", {
						globals: [],
						locals: { _slicedToArray: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_slicedToArray",
						dependencies: {
							arrayWithHoles: ["body.0.body.body.0.argument.left.left.left.callee"],
							iterableToArrayLimit: ["body.0.body.body.0.argument.left.left.right.callee"],
							unsupportedIterableToArray: ["body.0.body.body.0.argument.left.right.callee"],
							nonIterableRest: ["body.0.body.body.0.argument.right.callee"]
						},
						internal: !1
					}),
					superPropBase: helper("7.0.0-beta.0", "function _superPropBase(t,o){for(;!{}.hasOwnProperty.call(t,o)&&null!==(t=getPrototypeOf(t)););return t}", {
						globals: [],
						locals: { _superPropBase: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_superPropBase",
						dependencies: { getPrototypeOf: ["body.0.body.body.0.test.right.right.right.callee"] },
						internal: !1
					}),
					superPropGet: helper("7.25.0", "function _superPropGet(t,o,e,r){var p=get(getPrototypeOf(1&r?t.prototype:t),o,e);return 2&r&&\"function\"==typeof p?function(t){return p.apply(e,t)}:p}", {
						globals: [],
						locals: { _superPropGet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_superPropGet",
						dependencies: {
							get: ["body.0.body.body.0.declarations.0.init.callee"],
							getPrototypeOf: ["body.0.body.body.0.declarations.0.init.arguments.0.callee"]
						},
						internal: !1
					}),
					superPropSet: helper("7.25.0", "function _superPropSet(t,e,o,r,p,f){return set(getPrototypeOf(f?t.prototype:t),e,o,r,p)}", {
						globals: [],
						locals: { _superPropSet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_superPropSet",
						dependencies: {
							set: ["body.0.body.body.0.argument.callee"],
							getPrototypeOf: ["body.0.body.body.0.argument.arguments.0.callee"]
						},
						internal: !1
					}),
					taggedTemplateLiteral: helper("7.0.0-beta.0", "function _taggedTemplateLiteral(e,t){return t||(t=e.slice(0)),Object.freeze(Object.defineProperties(e,{raw:{value:Object.freeze(t)}}))}", {
						globals: ["Object"],
						locals: { _taggedTemplateLiteral: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_taggedTemplateLiteral",
						dependencies: {},
						internal: !1
					}),
					taggedTemplateLiteralLoose: helper("7.0.0-beta.0", "function _taggedTemplateLiteralLoose(e,t){return t||(t=e.slice(0)),e.raw=t,e}", {
						globals: [],
						locals: { _taggedTemplateLiteralLoose: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_taggedTemplateLiteralLoose",
						dependencies: {},
						internal: !1
					}),
					tdz: helper("7.5.5", "function _tdzError(e){throw new ReferenceError(e+\" is not defined - temporal dead zone\")}", {
						globals: ["ReferenceError"],
						locals: { _tdzError: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_tdzError",
						dependencies: {},
						internal: !1
					}),
					temporalRef: helper("7.0.0-beta.0", "function _temporalRef(r,e){return r===undef?err(e):r}", {
						globals: [],
						locals: { _temporalRef: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_temporalRef",
						dependencies: {
							temporalUndefined: ["body.0.body.body.0.argument.test.right"],
							tdz: ["body.0.body.body.0.argument.consequent.callee"]
						},
						internal: !1
					}),
					temporalUndefined: helper("7.0.0-beta.0", "function _temporalUndefined(){}", {
						globals: [],
						locals: { _temporalUndefined: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_temporalUndefined",
						dependencies: {},
						internal: !1
					}),
					toArray: helper("7.0.0-beta.0", "function _toArray(r){return arrayWithHoles(r)||iterableToArray(r)||unsupportedIterableToArray(r)||nonIterableRest()}", {
						globals: [],
						locals: { _toArray: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_toArray",
						dependencies: {
							arrayWithHoles: ["body.0.body.body.0.argument.left.left.left.callee"],
							iterableToArray: ["body.0.body.body.0.argument.left.left.right.callee"],
							unsupportedIterableToArray: ["body.0.body.body.0.argument.left.right.callee"],
							nonIterableRest: ["body.0.body.body.0.argument.right.callee"]
						},
						internal: !1
					}),
					toConsumableArray: helper("7.0.0-beta.0", "function _toConsumableArray(r){return arrayWithoutHoles(r)||iterableToArray(r)||unsupportedIterableToArray(r)||nonIterableSpread()}", {
						globals: [],
						locals: { _toConsumableArray: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_toConsumableArray",
						dependencies: {
							arrayWithoutHoles: ["body.0.body.body.0.argument.left.left.left.callee"],
							iterableToArray: ["body.0.body.body.0.argument.left.left.right.callee"],
							unsupportedIterableToArray: ["body.0.body.body.0.argument.left.right.callee"],
							nonIterableSpread: ["body.0.body.body.0.argument.right.callee"]
						},
						internal: !1
					}),
					toPrimitive: helper("7.1.5", "function toPrimitive(t,r){if(\"object\"!=typeof t||!t)return t;var e=t[Symbol.toPrimitive];if(void 0!==e){var i=e.call(t,r||\"default\");if(\"object\"!=typeof i)return i;throw new TypeError(\"@@toPrimitive must return a primitive value.\")}return(\"string\"===r?String:Number)(t)}", {
						globals: [
							"Symbol",
							"TypeError",
							"String",
							"Number"
						],
						locals: { toPrimitive: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "toPrimitive",
						dependencies: {},
						internal: !1
					}),
					toPropertyKey: helper("7.1.5", "function toPropertyKey(t){var i=toPrimitive(t,\"string\");return\"symbol\"==typeof i?i:i+\"\"}", {
						globals: [],
						locals: { toPropertyKey: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "toPropertyKey",
						dependencies: { toPrimitive: ["body.0.body.body.0.declarations.0.init.callee"] },
						internal: !1
					}),
					toSetter: helper("7.24.0", "function _toSetter(t,e,n){e||(e=[]);var r=e.length++;return Object.defineProperty({},\"_\",{set:function(o){e[r]=o,t.apply(n,e)}})}", {
						globals: ["Object"],
						locals: { _toSetter: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_toSetter",
						dependencies: {},
						internal: !1
					}),
					tsRewriteRelativeImportExtensions: helper("7.27.0", "function tsRewriteRelativeImportExtensions(t,e){return\"string\"==typeof t&&/^\\.\\.?\\//.test(t)?t.replace(/\\.(tsx)$|((?:\\.d)?)((?:\\.[^./]+)?)\\.([cm]?)ts$/i,function(t,s,r,n,o){return s?e?\".jsx\":\".js\":!r||n&&o?r+n+\".\"+o.toLowerCase()+\"js\":t}):t}", {
						globals: [],
						locals: { tsRewriteRelativeImportExtensions: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "tsRewriteRelativeImportExtensions",
						dependencies: {},
						internal: !1
					}),
					typeof: helper("7.0.0-beta.0", "function _typeof(o){\"@babel/helpers - typeof\";return _typeof=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(o){return typeof o}:function(o){return o&&\"function\"==typeof Symbol&&o.constructor===Symbol&&o!==Symbol.prototype?\"symbol\":typeof o},_typeof(o)}", {
						globals: ["Symbol"],
						locals: { _typeof: [
							"body.0.id",
							"body.0.body.body.0.argument.expressions.1.callee",
							"body.0.body.body.0.argument.expressions.0.left"
						] },
						exportBindingAssignments: ["body.0.body.body.0.argument.expressions.0"],
						exportName: "_typeof",
						dependencies: {},
						internal: !1
					}),
					unsupportedIterableToArray: helper("7.9.0", "function _unsupportedIterableToArray(r,a){if(r){if(\"string\"==typeof r)return arrayLikeToArray(r,a);var t={}.toString.call(r).slice(8,-1);return\"Object\"===t&&r.constructor&&(t=r.constructor.name),\"Map\"===t||\"Set\"===t?Array.from(r):\"Arguments\"===t||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t)?arrayLikeToArray(r,a):void 0}}", {
						globals: ["Array"],
						locals: { _unsupportedIterableToArray: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_unsupportedIterableToArray",
						dependencies: { arrayLikeToArray: ["body.0.body.body.0.consequent.body.0.consequent.argument.callee", "body.0.body.body.0.consequent.body.2.argument.expressions.1.alternate.consequent.callee"] },
						internal: !1
					}),
					usingCtx: helper("7.23.9", "function _usingCtx(){var r=\"function\"==typeof SuppressedError?SuppressedError:function(r,e){var n=Error();return n.name=\"SuppressedError\",n.error=r,n.suppressed=e,n},e={},n=[];function using(r,e){if(null!=e){if(Object(e)!==e)throw new TypeError(\"using declarations can only be used with objects, functions, null, or undefined.\");if(r)var o=e[Symbol.asyncDispose||Symbol.for(\"Symbol.asyncDispose\")];if(void 0===o&&(o=e[Symbol.dispose||Symbol.for(\"Symbol.dispose\")],r))var t=o;if(\"function\"!=typeof o)throw new TypeError(\"Object is not disposable.\");t&&(o=function(){try{t.call(e)}catch(r){return Promise.reject(r)}}),n.push({v:e,d:o,a:r})}else r&&n.push({d:e,a:r});return e}return{e:e,u:using.bind(null,!1),a:using.bind(null,!0),d:function(){var o,t=this.e,s=0;function next(){for(;o=n.pop();)try{if(!o.a&&1===s)return s=0,n.push(o),Promise.resolve().then(next);if(o.d){var r=o.d.call(o.v);if(o.a)return s|=2,Promise.resolve(r).then(next,err)}else s|=1}catch(r){return err(r)}if(1===s)return t!==e?Promise.reject(t):Promise.resolve();if(t!==e)throw t}function err(n){return t=t!==e?new r(n,t):n,next()}return next()}}}", {
						globals: [
							"SuppressedError",
							"Error",
							"Object",
							"TypeError",
							"Symbol",
							"Promise"
						],
						locals: { _usingCtx: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_usingCtx",
						dependencies: {},
						internal: !1
					}),
					wrapAsyncGenerator: helper("7.0.0-beta.0", "function _wrapAsyncGenerator(e){return function(){return new AsyncGenerator(e.apply(this,arguments))}}function AsyncGenerator(e){var r,t;function resume(r,t){try{var n=e[r](t),o=n.value,u=o instanceof OverloadYield;Promise.resolve(u?o.v:o).then(function(t){if(u){var i=\"return\"===r?\"return\":\"next\";if(!o.k||t.done)return resume(i,t);t=e[i](t).value}settle(n.done?\"return\":\"normal\",t)},function(e){resume(\"throw\",e)})}catch(e){settle(\"throw\",e)}}function settle(e,n){switch(e){case\"return\":r.resolve({value:n,done:!0});break;case\"throw\":r.reject(n);break;default:r.resolve({value:n,done:!1})}(r=r.next)?resume(r.key,r.arg):t=null}this._invoke=function(e,n){return new Promise(function(o,u){var i={key:e,arg:n,resolve:o,reject:u,next:null};t?t=t.next=i:(r=t=i,resume(e,n))})},\"function\"!=typeof e.return&&(this.return=void 0)}AsyncGenerator.prototype[\"function\"==typeof Symbol&&Symbol.asyncIterator||\"@@asyncIterator\"]=function(){return this},AsyncGenerator.prototype.next=function(e){return this._invoke(\"next\",e)},AsyncGenerator.prototype.throw=function(e){return this._invoke(\"throw\",e)},AsyncGenerator.prototype.return=function(e){return this._invoke(\"return\",e)};", {
						globals: ["Promise", "Symbol"],
						locals: {
							_wrapAsyncGenerator: ["body.0.id"],
							AsyncGenerator: [
								"body.1.id",
								"body.0.body.body.0.argument.body.body.0.argument.callee",
								"body.2.expression.expressions.0.left.object.object",
								"body.2.expression.expressions.1.left.object.object",
								"body.2.expression.expressions.2.left.object.object",
								"body.2.expression.expressions.3.left.object.object"
							]
						},
						exportBindingAssignments: [],
						exportName: "_wrapAsyncGenerator",
						dependencies: { OverloadYield: ["body.1.body.body.1.body.body.0.block.body.0.declarations.2.init.right"] },
						internal: !1
					}),
					wrapNativeSuper: helper("7.0.0-beta.0", "function _wrapNativeSuper(t){var r=\"function\"==typeof Map?new Map:void 0;return _wrapNativeSuper=function(t){if(null===t||!isNativeFunction(t))return t;if(\"function\"!=typeof t)throw new TypeError(\"Super expression must either be null or a function\");if(void 0!==r){if(r.has(t))return r.get(t);r.set(t,Wrapper)}function Wrapper(){return construct(t,arguments,getPrototypeOf(this).constructor)}return Wrapper.prototype=Object.create(t.prototype,{constructor:{value:Wrapper,enumerable:!1,writable:!0,configurable:!0}}),setPrototypeOf(Wrapper,t)},_wrapNativeSuper(t)}", {
						globals: [
							"Map",
							"TypeError",
							"Object"
						],
						locals: { _wrapNativeSuper: [
							"body.0.id",
							"body.0.body.body.1.argument.expressions.1.callee",
							"body.0.body.body.1.argument.expressions.0.left"
						] },
						exportBindingAssignments: ["body.0.body.body.1.argument.expressions.0"],
						exportName: "_wrapNativeSuper",
						dependencies: {
							getPrototypeOf: ["body.0.body.body.1.argument.expressions.0.right.body.body.3.body.body.0.argument.arguments.2.object.callee"],
							setPrototypeOf: ["body.0.body.body.1.argument.expressions.0.right.body.body.4.argument.expressions.1.callee"],
							isNativeFunction: ["body.0.body.body.1.argument.expressions.0.right.body.body.0.test.right.argument.callee"],
							construct: ["body.0.body.body.1.argument.expressions.0.right.body.body.3.body.body.0.argument.callee"]
						},
						internal: !1
					}),
					wrapRegExp: helper("7.19.0", "function _wrapRegExp(){_wrapRegExp=function(e,r){return new BabelRegExp(e,void 0,r)};var e=RegExp.prototype,r=new WeakMap;function BabelRegExp(e,t,p){var o=RegExp(e,t);return r.set(o,p||r.get(e)),setPrototypeOf(o,BabelRegExp.prototype)}function buildGroups(e,t){var p=r.get(t);return Object.keys(p).reduce(function(r,t){var o=p[t];if(\"number\"==typeof o)r[t]=e[o];else{for(var i=0;void 0===e[o[i]]&&i+1<o.length;)i++;r[t]=e[o[i]]}return r},Object.create(null))}return inherits(BabelRegExp,RegExp),BabelRegExp.prototype.exec=function(r){var t=e.exec.call(this,r);if(t){t.groups=buildGroups(t,this);var p=t.indices;p&&(p.groups=buildGroups(p,this))}return t},BabelRegExp.prototype[Symbol.replace]=function(t,p){if(\"string\"==typeof p){var o=r.get(this);return e[Symbol.replace].call(this,t,p.replace(/\\$<([^>]+)(>|$)/g,function(e,r,t){if(\"\"===t)return e;var p=o[r];return Array.isArray(p)?\"$\"+p.join(\"$\"):\"number\"==typeof p?\"$\"+p:\"\"}))}if(\"function\"==typeof p){var i=this;return e[Symbol.replace].call(this,t,function(){var e=arguments;return\"object\"!=typeof e[e.length-1]&&(e=[].slice.call(e)).push(buildGroups(e,i)),p.apply(this,e)})}return e[Symbol.replace].call(this,t,p)},_wrapRegExp.apply(this,arguments)}", {
						globals: [
							"RegExp",
							"WeakMap",
							"Object",
							"Symbol",
							"Array"
						],
						locals: { _wrapRegExp: [
							"body.0.id",
							"body.0.body.body.4.argument.expressions.3.callee.object",
							"body.0.body.body.0.expression.left"
						] },
						exportBindingAssignments: ["body.0.body.body.0.expression"],
						exportName: "_wrapRegExp",
						dependencies: {
							setPrototypeOf: ["body.0.body.body.2.body.body.1.argument.expressions.1.callee"],
							inherits: ["body.0.body.body.4.argument.expressions.0.callee"]
						},
						internal: !1
					}),
					writeOnlyError: helper("7.12.13", "function _writeOnlyError(r){throw new TypeError('\"'+r+'\" is write-only')}", {
						globals: ["TypeError"],
						locals: { _writeOnlyError: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_writeOnlyError",
						dependencies: {},
						internal: !1
					})
				};
				Object.assign(s, {
					AwaitValue: helper("7.0.0-beta.0", "function _AwaitValue(t){this.wrapped=t}", {
						globals: [],
						locals: { _AwaitValue: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_AwaitValue",
						dependencies: {},
						internal: !1
					}),
					applyDecs: helper("7.17.8", "function old_createMetadataMethodsForProperty(e,t,a,r){return{getMetadata:function(o){old_assertNotFinished(r,\"getMetadata\"),old_assertMetadataKey(o);var i=e[o];if(void 0!==i)if(1===t){var n=i.public;if(void 0!==n)return n[a]}else if(2===t){var l=i.private;if(void 0!==l)return l.get(a)}else if(Object.hasOwnProperty.call(i,\"constructor\"))return i.constructor},setMetadata:function(o,i){old_assertNotFinished(r,\"setMetadata\"),old_assertMetadataKey(o);var n=e[o];if(void 0===n&&(n=e[o]={}),1===t){var l=n.public;void 0===l&&(l=n.public={}),l[a]=i}else if(2===t){var s=n.priv;void 0===s&&(s=n.private=new Map),s.set(a,i)}else n.constructor=i}}}function old_convertMetadataMapToFinal(e,t){var a=e[Symbol.metadata||Symbol.for(\"Symbol.metadata\")],r=Object.getOwnPropertySymbols(t);if(0!==r.length){for(var o=0;o<r.length;o++){var i=r[o],n=t[i],l=a?a[i]:null,s=n.public,c=l?l.public:null;s&&c&&Object.setPrototypeOf(s,c);var d=n.private;if(d){var u=Array.from(d.values()),f=l?l.private:null;f&&(u=u.concat(f)),n.private=u}l&&Object.setPrototypeOf(n,l)}a&&Object.setPrototypeOf(t,a),e[Symbol.metadata||Symbol.for(\"Symbol.metadata\")]=t}}function old_createAddInitializerMethod(e,t){return function(a){old_assertNotFinished(t,\"addInitializer\"),old_assertCallable(a,\"An initializer\"),e.push(a)}}function old_memberDec(e,t,a,r,o,i,n,l,s){var c;switch(i){case 1:c=\"accessor\";break;case 2:c=\"method\";break;case 3:c=\"getter\";break;case 4:c=\"setter\";break;default:c=\"field\"}var d,u,f={kind:c,name:l?\"#\"+t:toPropertyKey(t),isStatic:n,isPrivate:l},p={v:!1};if(0!==i&&(f.addInitializer=old_createAddInitializerMethod(o,p)),l){d=2,u=Symbol(t);var v={};0===i?(v.get=a.get,v.set=a.set):2===i?v.get=function(){return a.value}:(1!==i&&3!==i||(v.get=function(){return a.get.call(this)}),1!==i&&4!==i||(v.set=function(e){a.set.call(this,e)})),f.access=v}else d=1,u=t;try{return e(s,Object.assign(f,old_createMetadataMethodsForProperty(r,d,u,p)))}finally{p.v=!0}}function old_assertNotFinished(e,t){if(e.v)throw Error(\"attempted to call \"+t+\" after decoration was finished\")}function old_assertMetadataKey(e){if(\"symbol\"!=typeof e)throw new TypeError(\"Metadata keys must be symbols, received: \"+e)}function old_assertCallable(e,t){if(\"function\"!=typeof e)throw new TypeError(t+\" must be a function\")}function old_assertValidReturnValue(e,t){var a=typeof t;if(1===e){if(\"object\"!==a||null===t)throw new TypeError(\"accessor decorators must return an object with get, set, or init properties or void 0\");void 0!==t.get&&old_assertCallable(t.get,\"accessor.get\"),void 0!==t.set&&old_assertCallable(t.set,\"accessor.set\"),void 0!==t.init&&old_assertCallable(t.init,\"accessor.init\"),void 0!==t.initializer&&old_assertCallable(t.initializer,\"accessor.initializer\")}else if(\"function\"!==a)throw new TypeError((0===e?\"field\":10===e?\"class\":\"method\")+\" decorators must return a function or void 0\")}function old_getInit(e){var t;return null==(t=e.init)&&(t=e.initializer)&&void 0!==console&&console.warn(\".initializer has been renamed to .init as of March 2022\"),t}function old_applyMemberDec(e,t,a,r,o,i,n,l,s){var c,d,u,f,p,v,y,h=a[0];if(n?(0===o||1===o?(c={get:a[3],set:a[4]},u=\"get\"):3===o?(c={get:a[3]},u=\"get\"):4===o?(c={set:a[3]},u=\"set\"):c={value:a[3]},0!==o&&(1===o&&setFunctionName(a[4],\"#\"+r,\"set\"),setFunctionName(a[3],\"#\"+r,u))):0!==o&&(c=Object.getOwnPropertyDescriptor(t,r)),1===o?f={get:c.get,set:c.set}:2===o?f=c.value:3===o?f=c.get:4===o&&(f=c.set),\"function\"==typeof h)void 0!==(p=old_memberDec(h,r,c,l,s,o,i,n,f))&&(old_assertValidReturnValue(o,p),0===o?d=p:1===o?(d=old_getInit(p),v=p.get||f.get,y=p.set||f.set,f={get:v,set:y}):f=p);else for(var m=h.length-1;m>=0;m--){var b;void 0!==(p=old_memberDec(h[m],r,c,l,s,o,i,n,f))&&(old_assertValidReturnValue(o,p),0===o?b=p:1===o?(b=old_getInit(p),v=p.get||f.get,y=p.set||f.set,f={get:v,set:y}):f=p,void 0!==b&&(void 0===d?d=b:\"function\"==typeof d?d=[d,b]:d.push(b)))}if(0===o||1===o){if(void 0===d)d=function(e,t){return t};else if(\"function\"!=typeof d){var g=d;d=function(e,t){for(var a=t,r=0;r<g.length;r++)a=g[r].call(e,a);return a}}else{var _=d;d=function(e,t){return _.call(e,t)}}e.push(d)}0!==o&&(1===o?(c.get=f.get,c.set=f.set):2===o?c.value=f:3===o?c.get=f:4===o&&(c.set=f),n?1===o?(e.push(function(e,t){return f.get.call(e,t)}),e.push(function(e,t){return f.set.call(e,t)})):2===o?e.push(f):e.push(function(e,t){return f.call(e,t)}):Object.defineProperty(t,r,c))}function old_applyMemberDecs(e,t,a,r,o){for(var i,n,l=new Map,s=new Map,c=0;c<o.length;c++){var d=o[c];if(Array.isArray(d)){var u,f,p,v=d[1],y=d[2],h=d.length>3,m=v>=5;if(m?(u=t,f=r,0!=(v-=5)&&(p=n=n||[])):(u=t.prototype,f=a,0!==v&&(p=i=i||[])),0!==v&&!h){var b=m?s:l,g=b.get(y)||0;if(!0===g||3===g&&4!==v||4===g&&3!==v)throw Error(\"Attempted to decorate a public method/accessor that has the same name as a previously decorated public method/accessor. This is not currently supported by the decorators plugin. Property name was: \"+y);!g&&v>2?b.set(y,v):b.set(y,!0)}old_applyMemberDec(e,u,d,y,v,m,h,f,p)}}old_pushInitializers(e,i),old_pushInitializers(e,n)}function old_pushInitializers(e,t){t&&e.push(function(e){for(var a=0;a<t.length;a++)t[a].call(e);return e})}function old_applyClassDecs(e,t,a,r){if(r.length>0){for(var o=[],i=t,n=t.name,l=r.length-1;l>=0;l--){var s={v:!1};try{var c=Object.assign({kind:\"class\",name:n,addInitializer:old_createAddInitializerMethod(o,s)},old_createMetadataMethodsForProperty(a,0,n,s)),d=r[l](i,c)}finally{s.v=!0}void 0!==d&&(old_assertValidReturnValue(10,d),i=d)}e.push(i,function(){for(var e=0;e<o.length;e++)o[e].call(i)})}}function applyDecs(e,t,a){var r=[],o={},i={};return old_applyMemberDecs(r,e,i,o,t),old_convertMetadataMapToFinal(e.prototype,i),old_applyClassDecs(r,e,o,a),old_convertMetadataMapToFinal(e,o),r}", {
						globals: [
							"Object",
							"Map",
							"Symbol",
							"Array",
							"Error",
							"TypeError",
							"console"
						],
						locals: {
							old_createMetadataMethodsForProperty: [
								"body.0.id",
								"body.3.body.body.4.block.body.0.argument.arguments.1.arguments.1.callee",
								"body.12.body.body.0.consequent.body.0.body.body.1.block.body.0.declarations.0.init.arguments.1.callee"
							],
							old_convertMetadataMapToFinal: [
								"body.1.id",
								"body.13.body.body.1.argument.expressions.1.callee",
								"body.13.body.body.1.argument.expressions.3.callee"
							],
							old_createAddInitializerMethod: [
								"body.2.id",
								"body.3.body.body.3.test.expressions.0.right.right.callee",
								"body.12.body.body.0.consequent.body.0.body.body.1.block.body.0.declarations.0.init.arguments.0.properties.2.value.callee"
							],
							old_memberDec: [
								"body.3.id",
								"body.9.body.body.1.consequent.expression.left.right.right.callee",
								"body.9.body.body.1.alternate.body.body.1.expression.left.right.right.callee"
							],
							old_assertNotFinished: [
								"body.4.id",
								"body.0.body.body.0.argument.properties.0.value.body.body.0.expression.expressions.0.callee",
								"body.0.body.body.0.argument.properties.1.value.body.body.0.expression.expressions.0.callee",
								"body.2.body.body.0.argument.body.body.0.expression.expressions.0.callee"
							],
							old_assertMetadataKey: [
								"body.5.id",
								"body.0.body.body.0.argument.properties.0.value.body.body.0.expression.expressions.1.callee",
								"body.0.body.body.0.argument.properties.1.value.body.body.0.expression.expressions.1.callee"
							],
							old_assertCallable: [
								"body.6.id",
								"body.2.body.body.0.argument.body.body.0.expression.expressions.1.callee",
								"body.7.body.body.1.consequent.body.1.expression.expressions.0.right.callee",
								"body.7.body.body.1.consequent.body.1.expression.expressions.1.right.callee",
								"body.7.body.body.1.consequent.body.1.expression.expressions.2.right.callee",
								"body.7.body.body.1.consequent.body.1.expression.expressions.3.right.callee"
							],
							old_assertValidReturnValue: [
								"body.7.id",
								"body.9.body.body.1.consequent.expression.right.expressions.0.callee",
								"body.9.body.body.1.alternate.body.body.1.expression.right.expressions.0.callee",
								"body.12.body.body.0.consequent.body.0.body.body.2.expression.right.expressions.0.callee"
							],
							old_getInit: [
								"body.8.id",
								"body.9.body.body.1.consequent.expression.right.expressions.1.alternate.consequent.expressions.0.right.callee",
								"body.9.body.body.1.alternate.body.body.1.expression.right.expressions.1.alternate.consequent.expressions.0.right.callee"
							],
							old_applyMemberDec: ["body.9.id", "body.10.body.body.0.body.body.1.consequent.body.2.expression.callee"],
							old_applyMemberDecs: ["body.10.id", "body.13.body.body.1.argument.expressions.0.callee"],
							old_pushInitializers: [
								"body.11.id",
								"body.10.body.body.1.expression.expressions.0.callee",
								"body.10.body.body.1.expression.expressions.1.callee"
							],
							old_applyClassDecs: ["body.12.id", "body.13.body.body.1.argument.expressions.2.callee"],
							applyDecs: ["body.13.id"]
						},
						exportBindingAssignments: [],
						exportName: "applyDecs",
						dependencies: {
							setFunctionName: ["body.9.body.body.1.test.expressions.0.consequent.expressions.1.right.expressions.0.right.callee", "body.9.body.body.1.test.expressions.0.consequent.expressions.1.right.expressions.1.callee"],
							toPropertyKey: ["body.3.body.body.2.declarations.2.init.properties.1.value.alternate.callee"]
						},
						internal: !1
					}),
					applyDecs2203: helper("7.19.0", "function applyDecs2203Factory(){function createAddInitializerMethod(e,t){return function(r){!function(e){if(e.v)throw Error(\"attempted to call addInitializer after decoration was finished\")}(t),assertCallable(r,\"An initializer\"),e.push(r)}}function memberDec(e,t,r,a,n,i,s,o){var c;switch(n){case 1:c=\"accessor\";break;case 2:c=\"method\";break;case 3:c=\"getter\";break;case 4:c=\"setter\";break;default:c=\"field\"}var l,u,f={kind:c,name:s?\"#\"+t:t,static:i,private:s},p={v:!1};0!==n&&(f.addInitializer=createAddInitializerMethod(a,p)),0===n?s?(l=r.get,u=r.set):(l=function(){return this[t]},u=function(e){this[t]=e}):2===n?l=function(){return r.value}:(1!==n&&3!==n||(l=function(){return r.get.call(this)}),1!==n&&4!==n||(u=function(e){r.set.call(this,e)})),f.access=l&&u?{get:l,set:u}:l?{get:l}:{set:u};try{return e(o,f)}finally{p.v=!0}}function assertCallable(e,t){if(\"function\"!=typeof e)throw new TypeError(t+\" must be a function\")}function assertValidReturnValue(e,t){var r=typeof t;if(1===e){if(\"object\"!==r||null===t)throw new TypeError(\"accessor decorators must return an object with get, set, or init properties or void 0\");void 0!==t.get&&assertCallable(t.get,\"accessor.get\"),void 0!==t.set&&assertCallable(t.set,\"accessor.set\"),void 0!==t.init&&assertCallable(t.init,\"accessor.init\")}else if(\"function\"!==r)throw new TypeError((0===e?\"field\":10===e?\"class\":\"method\")+\" decorators must return a function or void 0\")}function applyMemberDec(e,t,r,a,n,i,s,o){var c,l,u,f,p,d,h=r[0];if(s?c=0===n||1===n?{get:r[3],set:r[4]}:3===n?{get:r[3]}:4===n?{set:r[3]}:{value:r[3]}:0!==n&&(c=Object.getOwnPropertyDescriptor(t,a)),1===n?u={get:c.get,set:c.set}:2===n?u=c.value:3===n?u=c.get:4===n&&(u=c.set),\"function\"==typeof h)void 0!==(f=memberDec(h,a,c,o,n,i,s,u))&&(assertValidReturnValue(n,f),0===n?l=f:1===n?(l=f.init,p=f.get||u.get,d=f.set||u.set,u={get:p,set:d}):u=f);else for(var v=h.length-1;v>=0;v--){var g;void 0!==(f=memberDec(h[v],a,c,o,n,i,s,u))&&(assertValidReturnValue(n,f),0===n?g=f:1===n?(g=f.init,p=f.get||u.get,d=f.set||u.set,u={get:p,set:d}):u=f,void 0!==g&&(void 0===l?l=g:\"function\"==typeof l?l=[l,g]:l.push(g)))}if(0===n||1===n){if(void 0===l)l=function(e,t){return t};else if(\"function\"!=typeof l){var y=l;l=function(e,t){for(var r=t,a=0;a<y.length;a++)r=y[a].call(e,r);return r}}else{var m=l;l=function(e,t){return m.call(e,t)}}e.push(l)}0!==n&&(1===n?(c.get=u.get,c.set=u.set):2===n?c.value=u:3===n?c.get=u:4===n&&(c.set=u),s?1===n?(e.push(function(e,t){return u.get.call(e,t)}),e.push(function(e,t){return u.set.call(e,t)})):2===n?e.push(u):e.push(function(e,t){return u.call(e,t)}):Object.defineProperty(t,a,c))}function pushInitializers(e,t){t&&e.push(function(e){for(var r=0;r<t.length;r++)t[r].call(e);return e})}return function(e,t,r){var a=[];return function(e,t,r){for(var a,n,i=new Map,s=new Map,o=0;o<r.length;o++){var c=r[o];if(Array.isArray(c)){var l,u,f=c[1],p=c[2],d=c.length>3,h=f>=5;if(h?(l=t,0!=(f-=5)&&(u=n=n||[])):(l=t.prototype,0!==f&&(u=a=a||[])),0!==f&&!d){var v=h?s:i,g=v.get(p)||0;if(!0===g||3===g&&4!==f||4===g&&3!==f)throw Error(\"Attempted to decorate a public method/accessor that has the same name as a previously decorated public method/accessor. This is not currently supported by the decorators plugin. Property name was: \"+p);!g&&f>2?v.set(p,f):v.set(p,!0)}applyMemberDec(e,l,c,p,f,h,d,u)}}pushInitializers(e,a),pushInitializers(e,n)}(a,e,t),function(e,t,r){if(r.length>0){for(var a=[],n=t,i=t.name,s=r.length-1;s>=0;s--){var o={v:!1};try{var c=r[s](n,{kind:\"class\",name:i,addInitializer:createAddInitializerMethod(a,o)})}finally{o.v=!0}void 0!==c&&(assertValidReturnValue(10,c),n=c)}e.push(n,function(){for(var e=0;e<a.length;e++)a[e].call(n)})}}(a,e,r),a}}var applyDecs2203Impl;function applyDecs2203(e,t,r){return(applyDecs2203Impl=applyDecs2203Impl||applyDecs2203Factory())(e,t,r)}", {
						globals: [
							"Error",
							"TypeError",
							"Object",
							"Map",
							"Array"
						],
						locals: {
							applyDecs2203Factory: ["body.0.id", "body.2.body.body.0.argument.callee.right.right.callee"],
							applyDecs2203Impl: [
								"body.1.declarations.0.id",
								"body.2.body.body.0.argument.callee.right.left",
								"body.2.body.body.0.argument.callee.left"
							],
							applyDecs2203: ["body.2.id"]
						},
						exportBindingAssignments: [],
						exportName: "applyDecs2203",
						dependencies: {},
						internal: !1
					}),
					applyDecs2203R: helper("7.20.0", "function applyDecs2203RFactory(){function createAddInitializerMethod(e,t){return function(r){!function(e){if(e.v)throw Error(\"attempted to call addInitializer after decoration was finished\")}(t),assertCallable(r,\"An initializer\"),e.push(r)}}function memberDec(e,t,r,n,a,i,o,s){var c;switch(a){case 1:c=\"accessor\";break;case 2:c=\"method\";break;case 3:c=\"getter\";break;case 4:c=\"setter\";break;default:c=\"field\"}var l,u,f={kind:c,name:o?\"#\"+t:toPropertyKey(t),static:i,private:o},p={v:!1};0!==a&&(f.addInitializer=createAddInitializerMethod(n,p)),0===a?o?(l=r.get,u=r.set):(l=function(){return this[t]},u=function(e){this[t]=e}):2===a?l=function(){return r.value}:(1!==a&&3!==a||(l=function(){return r.get.call(this)}),1!==a&&4!==a||(u=function(e){r.set.call(this,e)})),f.access=l&&u?{get:l,set:u}:l?{get:l}:{set:u};try{return e(s,f)}finally{p.v=!0}}function assertCallable(e,t){if(\"function\"!=typeof e)throw new TypeError(t+\" must be a function\")}function assertValidReturnValue(e,t){var r=typeof t;if(1===e){if(\"object\"!==r||null===t)throw new TypeError(\"accessor decorators must return an object with get, set, or init properties or void 0\");void 0!==t.get&&assertCallable(t.get,\"accessor.get\"),void 0!==t.set&&assertCallable(t.set,\"accessor.set\"),void 0!==t.init&&assertCallable(t.init,\"accessor.init\")}else if(\"function\"!==r)throw new TypeError((0===e?\"field\":10===e?\"class\":\"method\")+\" decorators must return a function or void 0\")}function applyMemberDec(e,t,r,n,a,i,o,s){var c,l,u,f,p,d,h,v=r[0];if(o?(0===a||1===a?(c={get:r[3],set:r[4]},u=\"get\"):3===a?(c={get:r[3]},u=\"get\"):4===a?(c={set:r[3]},u=\"set\"):c={value:r[3]},0!==a&&(1===a&&setFunctionName(r[4],\"#\"+n,\"set\"),setFunctionName(r[3],\"#\"+n,u))):0!==a&&(c=Object.getOwnPropertyDescriptor(t,n)),1===a?f={get:c.get,set:c.set}:2===a?f=c.value:3===a?f=c.get:4===a&&(f=c.set),\"function\"==typeof v)void 0!==(p=memberDec(v,n,c,s,a,i,o,f))&&(assertValidReturnValue(a,p),0===a?l=p:1===a?(l=p.init,d=p.get||f.get,h=p.set||f.set,f={get:d,set:h}):f=p);else for(var g=v.length-1;g>=0;g--){var y;void 0!==(p=memberDec(v[g],n,c,s,a,i,o,f))&&(assertValidReturnValue(a,p),0===a?y=p:1===a?(y=p.init,d=p.get||f.get,h=p.set||f.set,f={get:d,set:h}):f=p,void 0!==y&&(void 0===l?l=y:\"function\"==typeof l?l=[l,y]:l.push(y)))}if(0===a||1===a){if(void 0===l)l=function(e,t){return t};else if(\"function\"!=typeof l){var m=l;l=function(e,t){for(var r=t,n=0;n<m.length;n++)r=m[n].call(e,r);return r}}else{var b=l;l=function(e,t){return b.call(e,t)}}e.push(l)}0!==a&&(1===a?(c.get=f.get,c.set=f.set):2===a?c.value=f:3===a?c.get=f:4===a&&(c.set=f),o?1===a?(e.push(function(e,t){return f.get.call(e,t)}),e.push(function(e,t){return f.set.call(e,t)})):2===a?e.push(f):e.push(function(e,t){return f.call(e,t)}):Object.defineProperty(t,n,c))}function applyMemberDecs(e,t){for(var r,n,a=[],i=new Map,o=new Map,s=0;s<t.length;s++){var c=t[s];if(Array.isArray(c)){var l,u,f=c[1],p=c[2],d=c.length>3,h=f>=5;if(h?(l=e,0!=(f-=5)&&(u=n=n||[])):(l=e.prototype,0!==f&&(u=r=r||[])),0!==f&&!d){var v=h?o:i,g=v.get(p)||0;if(!0===g||3===g&&4!==f||4===g&&3!==f)throw Error(\"Attempted to decorate a public method/accessor that has the same name as a previously decorated public method/accessor. This is not currently supported by the decorators plugin. Property name was: \"+p);!g&&f>2?v.set(p,f):v.set(p,!0)}applyMemberDec(a,l,c,p,f,h,d,u)}}return pushInitializers(a,r),pushInitializers(a,n),a}function pushInitializers(e,t){t&&e.push(function(e){for(var r=0;r<t.length;r++)t[r].call(e);return e})}return function(e,t,r){return{e:applyMemberDecs(e,t),get c(){return function(e,t){if(t.length>0){for(var r=[],n=e,a=e.name,i=t.length-1;i>=0;i--){var o={v:!1};try{var s=t[i](n,{kind:\"class\",name:a,addInitializer:createAddInitializerMethod(r,o)})}finally{o.v=!0}void 0!==s&&(assertValidReturnValue(10,s),n=s)}return[n,function(){for(var e=0;e<r.length;e++)r[e].call(n)}]}}(e,r)}}}}function applyDecs2203R(e,t,r){return(applyDecs2203R=applyDecs2203RFactory())(e,t,r)}", {
						globals: [
							"Error",
							"TypeError",
							"Object",
							"Map",
							"Array"
						],
						locals: {
							applyDecs2203RFactory: ["body.0.id", "body.1.body.body.0.argument.callee.right.callee"],
							applyDecs2203R: ["body.1.id", "body.1.body.body.0.argument.callee.left"]
						},
						exportBindingAssignments: ["body.1.body.body.0.argument.callee"],
						exportName: "applyDecs2203R",
						dependencies: {
							setFunctionName: ["body.0.body.body.4.body.body.1.test.expressions.0.consequent.expressions.1.right.expressions.0.right.callee", "body.0.body.body.4.body.body.1.test.expressions.0.consequent.expressions.1.right.expressions.1.callee"],
							toPropertyKey: ["body.0.body.body.1.body.body.2.declarations.2.init.properties.1.value.alternate.callee"]
						},
						internal: !1
					}),
					applyDecs2301: helper("7.21.0", "function applyDecs2301Factory(){function createAddInitializerMethod(e,t){return function(r){!function(e){if(e.v)throw Error(\"attempted to call addInitializer after decoration was finished\")}(t),assertCallable(r,\"An initializer\"),e.push(r)}}function assertInstanceIfPrivate(e,t){if(!e(t))throw new TypeError(\"Attempted to access private element on non-instance\")}function memberDec(e,t,r,n,a,i,s,o,c){var u;switch(a){case 1:u=\"accessor\";break;case 2:u=\"method\";break;case 3:u=\"getter\";break;case 4:u=\"setter\";break;default:u=\"field\"}var l,f,p={kind:u,name:s?\"#\"+t:toPropertyKey(t),static:i,private:s},d={v:!1};if(0!==a&&(p.addInitializer=createAddInitializerMethod(n,d)),s||0!==a&&2!==a)if(2===a)l=function(e){return assertInstanceIfPrivate(c,e),r.value};else{var h=0===a||1===a;(h||3===a)&&(l=s?function(e){return assertInstanceIfPrivate(c,e),r.get.call(e)}:function(e){return r.get.call(e)}),(h||4===a)&&(f=s?function(e,t){assertInstanceIfPrivate(c,e),r.set.call(e,t)}:function(e,t){r.set.call(e,t)})}else l=function(e){return e[t]},0===a&&(f=function(e,r){e[t]=r});var v=s?c.bind():function(e){return t in e};p.access=l&&f?{get:l,set:f,has:v}:l?{get:l,has:v}:{set:f,has:v};try{return e(o,p)}finally{d.v=!0}}function assertCallable(e,t){if(\"function\"!=typeof e)throw new TypeError(t+\" must be a function\")}function assertValidReturnValue(e,t){var r=typeof t;if(1===e){if(\"object\"!==r||null===t)throw new TypeError(\"accessor decorators must return an object with get, set, or init properties or void 0\");void 0!==t.get&&assertCallable(t.get,\"accessor.get\"),void 0!==t.set&&assertCallable(t.set,\"accessor.set\"),void 0!==t.init&&assertCallable(t.init,\"accessor.init\")}else if(\"function\"!==r)throw new TypeError((0===e?\"field\":10===e?\"class\":\"method\")+\" decorators must return a function or void 0\")}function curryThis2(e){return function(t){e(this,t)}}function applyMemberDec(e,t,r,n,a,i,s,o,c){var u,l,f,p,d,h,v,y,g=r[0];if(s?(0===a||1===a?(u={get:(d=r[3],function(){return d(this)}),set:curryThis2(r[4])},f=\"get\"):3===a?(u={get:r[3]},f=\"get\"):4===a?(u={set:r[3]},f=\"set\"):u={value:r[3]},0!==a&&(1===a&&setFunctionName(u.set,\"#\"+n,\"set\"),setFunctionName(u[f||\"value\"],\"#\"+n,f))):0!==a&&(u=Object.getOwnPropertyDescriptor(t,n)),1===a?p={get:u.get,set:u.set}:2===a?p=u.value:3===a?p=u.get:4===a&&(p=u.set),\"function\"==typeof g)void 0!==(h=memberDec(g,n,u,o,a,i,s,p,c))&&(assertValidReturnValue(a,h),0===a?l=h:1===a?(l=h.init,v=h.get||p.get,y=h.set||p.set,p={get:v,set:y}):p=h);else for(var m=g.length-1;m>=0;m--){var b;void 0!==(h=memberDec(g[m],n,u,o,a,i,s,p,c))&&(assertValidReturnValue(a,h),0===a?b=h:1===a?(b=h.init,v=h.get||p.get,y=h.set||p.set,p={get:v,set:y}):p=h,void 0!==b&&(void 0===l?l=b:\"function\"==typeof l?l=[l,b]:l.push(b)))}if(0===a||1===a){if(void 0===l)l=function(e,t){return t};else if(\"function\"!=typeof l){var I=l;l=function(e,t){for(var r=t,n=0;n<I.length;n++)r=I[n].call(e,r);return r}}else{var w=l;l=function(e,t){return w.call(e,t)}}e.push(l)}0!==a&&(1===a?(u.get=p.get,u.set=p.set):2===a?u.value=p:3===a?u.get=p:4===a&&(u.set=p),s?1===a?(e.push(function(e,t){return p.get.call(e,t)}),e.push(function(e,t){return p.set.call(e,t)})):2===a?e.push(p):e.push(function(e,t){return p.call(e,t)}):Object.defineProperty(t,n,u))}function applyMemberDecs(e,t,r){for(var n,a,i,s=[],o=new Map,c=new Map,u=0;u<t.length;u++){var l=t[u];if(Array.isArray(l)){var f,p,d=l[1],h=l[2],v=l.length>3,y=d>=5,g=r;if(y?(f=e,0!=(d-=5)&&(p=a=a||[]),v&&!i&&(i=function(t){return checkInRHS(t)===e}),g=i):(f=e.prototype,0!==d&&(p=n=n||[])),0!==d&&!v){var m=y?c:o,b=m.get(h)||0;if(!0===b||3===b&&4!==d||4===b&&3!==d)throw Error(\"Attempted to decorate a public method/accessor that has the same name as a previously decorated public method/accessor. This is not currently supported by the decorators plugin. Property name was: \"+h);!b&&d>2?m.set(h,d):m.set(h,!0)}applyMemberDec(s,f,l,h,d,y,v,p,g)}}return pushInitializers(s,n),pushInitializers(s,a),s}function pushInitializers(e,t){t&&e.push(function(e){for(var r=0;r<t.length;r++)t[r].call(e);return e})}return function(e,t,r,n){return{e:applyMemberDecs(e,t,n),get c(){return function(e,t){if(t.length>0){for(var r=[],n=e,a=e.name,i=t.length-1;i>=0;i--){var s={v:!1};try{var o=t[i](n,{kind:\"class\",name:a,addInitializer:createAddInitializerMethod(r,s)})}finally{s.v=!0}void 0!==o&&(assertValidReturnValue(10,o),n=o)}return[n,function(){for(var e=0;e<r.length;e++)r[e].call(n)}]}}(e,r)}}}}function applyDecs2301(e,t,r,n){return(applyDecs2301=applyDecs2301Factory())(e,t,r,n)}", {
						globals: [
							"Error",
							"TypeError",
							"Object",
							"Map",
							"Array"
						],
						locals: {
							applyDecs2301Factory: ["body.0.id", "body.1.body.body.0.argument.callee.right.callee"],
							applyDecs2301: ["body.1.id", "body.1.body.body.0.argument.callee.left"]
						},
						exportBindingAssignments: ["body.1.body.body.0.argument.callee"],
						exportName: "applyDecs2301",
						dependencies: {
							checkInRHS: ["body.0.body.body.7.body.body.0.body.body.1.consequent.body.1.test.expressions.0.consequent.expressions.2.right.right.body.body.0.argument.left.callee"],
							setFunctionName: ["body.0.body.body.6.body.body.1.test.expressions.0.consequent.expressions.1.right.expressions.0.right.callee", "body.0.body.body.6.body.body.1.test.expressions.0.consequent.expressions.1.right.expressions.1.callee"],
							toPropertyKey: ["body.0.body.body.2.body.body.2.declarations.2.init.properties.1.value.alternate.callee"]
						},
						internal: !1
					}),
					applyDecs2305: helper("7.21.0", "function applyDecs2305(e,t,r,n,o,a){function i(e,t,r){return function(n,o){return r&&r(n),e[t].call(n,o)}}function c(e,t){for(var r=0;r<e.length;r++)e[r].call(t);return t}function s(e,t,r,n){if(\"function\"!=typeof e&&(n||void 0!==e))throw new TypeError(t+\" must \"+(r||\"be\")+\" a function\"+(n?\"\":\" or undefined\"));return e}function applyDec(e,t,r,n,o,a,c,u,l,f,p,d,h){function m(e){if(!h(e))throw new TypeError(\"Attempted to access private element on non-instance\")}var y,v=t[0],g=t[3],b=!u;if(!b){r||Array.isArray(v)||(v=[v]);var w={},S=[],A=3===o?\"get\":4===o||d?\"set\":\"value\";f?(p||d?w={get:setFunctionName(function(){return g(this)},n,\"get\"),set:function(e){t[4](this,e)}}:w[A]=g,p||setFunctionName(w[A],n,2===o?\"\":A)):p||(w=Object.getOwnPropertyDescriptor(e,n))}for(var P=e,j=v.length-1;j>=0;j-=r?2:1){var D=v[j],E=r?v[j-1]:void 0,I={},O={kind:[\"field\",\"accessor\",\"method\",\"getter\",\"setter\",\"class\"][o],name:n,metadata:a,addInitializer:function(e,t){if(e.v)throw Error(\"attempted to call addInitializer after decoration was finished\");s(t,\"An initializer\",\"be\",!0),c.push(t)}.bind(null,I)};try{if(b)(y=s(D.call(E,P,O),\"class decorators\",\"return\"))&&(P=y);else{var k,F;O.static=l,O.private=f,f?2===o?k=function(e){return m(e),w.value}:(o<4&&(k=i(w,\"get\",m)),3!==o&&(F=i(w,\"set\",m))):(k=function(e){return e[n]},(o<2||4===o)&&(F=function(e,t){e[n]=t}));var N=O.access={has:f?h.bind():function(e){return n in e}};if(k&&(N.get=k),F&&(N.set=F),P=D.call(E,d?{get:w.get,set:w.set}:w[A],O),d){if(\"object\"==typeof P&&P)(y=s(P.get,\"accessor.get\"))&&(w.get=y),(y=s(P.set,\"accessor.set\"))&&(w.set=y),(y=s(P.init,\"accessor.init\"))&&S.push(y);else if(void 0!==P)throw new TypeError(\"accessor decorators must return an object with get, set, or init properties or void 0\")}else s(P,(p?\"field\":\"method\")+\" decorators\",\"return\")&&(p?S.push(P):w[A]=P)}}finally{I.v=!0}}return(p||d)&&u.push(function(e,t){for(var r=S.length-1;r>=0;r--)t=S[r].call(e,t);return t}),p||b||(f?d?u.push(i(w,\"get\"),i(w,\"set\")):u.push(2===o?w[A]:i.call.bind(w[A])):Object.defineProperty(e,n,w)),P}function u(e,t){return Object.defineProperty(e,Symbol.metadata||Symbol.for(\"Symbol.metadata\"),{configurable:!0,enumerable:!0,value:t})}if(arguments.length>=6)var l=a[Symbol.metadata||Symbol.for(\"Symbol.metadata\")];var f=Object.create(null==l?null:l),p=function(e,t,r,n){var o,a,i=[],s=function(t){return checkInRHS(t)===e},u=new Map;function l(e){e&&i.push(c.bind(null,e))}for(var f=0;f<t.length;f++){var p=t[f];if(Array.isArray(p)){var d=p[1],h=p[2],m=p.length>3,y=16&d,v=!!(8&d),g=0==(d&=7),b=h+\"/\"+v;if(!g&&!m){var w=u.get(b);if(!0===w||3===w&&4!==d||4===w&&3!==d)throw Error(\"Attempted to decorate a public method/accessor that has the same name as a previously decorated public method/accessor. This is not currently supported by the decorators plugin. Property name was: \"+h);u.set(b,!(d>2)||d)}applyDec(v?e:e.prototype,p,y,m?\"#\"+h:toPropertyKey(h),d,n,v?a=a||[]:o=o||[],i,v,m,g,1===d,v&&m?s:r)}}return l(o),l(a),i}(e,t,o,f);return r.length||u(e,f),{e:p,get c(){var t=[];return r.length&&[u(applyDec(e,[r],n,e.name,5,f,t),f),c.bind(null,t,e)]}}}", {
						globals: [
							"TypeError",
							"Array",
							"Object",
							"Error",
							"Symbol",
							"Map"
						],
						locals: { applyDecs2305: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "applyDecs2305",
						dependencies: {
							checkInRHS: ["body.0.body.body.6.declarations.1.init.callee.body.body.0.declarations.3.init.body.body.0.argument.left.callee"],
							setFunctionName: ["body.0.body.body.3.body.body.2.consequent.body.2.expression.consequent.expressions.0.consequent.right.properties.0.value.callee", "body.0.body.body.3.body.body.2.consequent.body.2.expression.consequent.expressions.1.right.callee"],
							toPropertyKey: ["body.0.body.body.6.declarations.1.init.callee.body.body.2.body.body.1.consequent.body.2.expression.arguments.3.alternate.callee"]
						},
						internal: !1
					}),
					classApplyDescriptorDestructureSet: helper("7.13.10", "function _classApplyDescriptorDestructureSet(e,t){if(t.set)return\"__destrObj\"in t||(t.__destrObj={set value(r){t.set.call(e,r)}}),t.__destrObj;if(!t.writable)throw new TypeError(\"attempted to set read only private field\");return t}", {
						globals: ["TypeError"],
						locals: { _classApplyDescriptorDestructureSet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classApplyDescriptorDestructureSet",
						dependencies: {},
						internal: !1
					}),
					classApplyDescriptorGet: helper("7.13.10", "function _classApplyDescriptorGet(e,t){return t.get?t.get.call(e):t.value}", {
						globals: [],
						locals: { _classApplyDescriptorGet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classApplyDescriptorGet",
						dependencies: {},
						internal: !1
					}),
					classApplyDescriptorSet: helper("7.13.10", "function _classApplyDescriptorSet(e,t,l){if(t.set)t.set.call(e,l);else{if(!t.writable)throw new TypeError(\"attempted to set read only private field\");t.value=l}}", {
						globals: ["TypeError"],
						locals: { _classApplyDescriptorSet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classApplyDescriptorSet",
						dependencies: {},
						internal: !1
					}),
					classCheckPrivateStaticAccess: helper("7.13.10", "function _classCheckPrivateStaticAccess(s,a,r){return assertClassBrand(a,s,r)}", {
						globals: [],
						locals: { _classCheckPrivateStaticAccess: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classCheckPrivateStaticAccess",
						dependencies: { assertClassBrand: ["body.0.body.body.0.argument.callee"] },
						internal: !1
					}),
					classCheckPrivateStaticFieldDescriptor: helper("7.13.10", "function _classCheckPrivateStaticFieldDescriptor(t,e){if(void 0===t)throw new TypeError(\"attempted to \"+e+\" private static field before its declaration\")}", {
						globals: ["TypeError"],
						locals: { _classCheckPrivateStaticFieldDescriptor: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classCheckPrivateStaticFieldDescriptor",
						dependencies: {},
						internal: !1
					}),
					classExtractFieldDescriptor: helper("7.13.10", "function _classExtractFieldDescriptor(e,t){return classPrivateFieldGet2(t,e)}", {
						globals: [],
						locals: { _classExtractFieldDescriptor: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classExtractFieldDescriptor",
						dependencies: { classPrivateFieldGet2: ["body.0.body.body.0.argument.callee"] },
						internal: !1
					}),
					classPrivateFieldDestructureSet: helper("7.4.4", "function _classPrivateFieldDestructureSet(e,t){var r=classPrivateFieldGet2(t,e);return classApplyDescriptorDestructureSet(e,r)}", {
						globals: [],
						locals: { _classPrivateFieldDestructureSet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateFieldDestructureSet",
						dependencies: {
							classApplyDescriptorDestructureSet: ["body.0.body.body.1.argument.callee"],
							classPrivateFieldGet2: ["body.0.body.body.0.declarations.0.init.callee"]
						},
						internal: !1
					}),
					classPrivateFieldGet: helper("7.0.0-beta.0", "function _classPrivateFieldGet(e,t){var r=classPrivateFieldGet2(t,e);return classApplyDescriptorGet(e,r)}", {
						globals: [],
						locals: { _classPrivateFieldGet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateFieldGet",
						dependencies: {
							classApplyDescriptorGet: ["body.0.body.body.1.argument.callee"],
							classPrivateFieldGet2: ["body.0.body.body.0.declarations.0.init.callee"]
						},
						internal: !1
					}),
					classPrivateFieldSet: helper("7.0.0-beta.0", "function _classPrivateFieldSet(e,t,r){var s=classPrivateFieldGet2(t,e);return classApplyDescriptorSet(e,s,r),r}", {
						globals: [],
						locals: { _classPrivateFieldSet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateFieldSet",
						dependencies: {
							classApplyDescriptorSet: ["body.0.body.body.1.argument.expressions.0.callee"],
							classPrivateFieldGet2: ["body.0.body.body.0.declarations.0.init.callee"]
						},
						internal: !1
					}),
					classPrivateMethodGet: helper("7.1.6", "function _classPrivateMethodGet(s,a,r){return assertClassBrand(a,s),r}", {
						globals: [],
						locals: { _classPrivateMethodGet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateMethodGet",
						dependencies: { assertClassBrand: ["body.0.body.body.0.argument.expressions.0.callee"] },
						internal: !1
					}),
					classPrivateMethodSet: helper("7.1.6", "function _classPrivateMethodSet(){throw new TypeError(\"attempted to reassign private method\")}", {
						globals: ["TypeError"],
						locals: { _classPrivateMethodSet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classPrivateMethodSet",
						dependencies: {},
						internal: !1
					}),
					classStaticPrivateFieldDestructureSet: helper("7.13.10", "function _classStaticPrivateFieldDestructureSet(t,r,s){return assertClassBrand(r,t),classCheckPrivateStaticFieldDescriptor(s,\"set\"),classApplyDescriptorDestructureSet(t,s)}", {
						globals: [],
						locals: { _classStaticPrivateFieldDestructureSet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classStaticPrivateFieldDestructureSet",
						dependencies: {
							classApplyDescriptorDestructureSet: ["body.0.body.body.0.argument.expressions.2.callee"],
							assertClassBrand: ["body.0.body.body.0.argument.expressions.0.callee"],
							classCheckPrivateStaticFieldDescriptor: ["body.0.body.body.0.argument.expressions.1.callee"]
						},
						internal: !1
					}),
					classStaticPrivateFieldSpecGet: helper("7.0.2", "function _classStaticPrivateFieldSpecGet(t,s,r){return assertClassBrand(s,t),classCheckPrivateStaticFieldDescriptor(r,\"get\"),classApplyDescriptorGet(t,r)}", {
						globals: [],
						locals: { _classStaticPrivateFieldSpecGet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classStaticPrivateFieldSpecGet",
						dependencies: {
							classApplyDescriptorGet: ["body.0.body.body.0.argument.expressions.2.callee"],
							assertClassBrand: ["body.0.body.body.0.argument.expressions.0.callee"],
							classCheckPrivateStaticFieldDescriptor: ["body.0.body.body.0.argument.expressions.1.callee"]
						},
						internal: !1
					}),
					classStaticPrivateFieldSpecSet: helper("7.0.2", "function _classStaticPrivateFieldSpecSet(s,t,r,e){return assertClassBrand(t,s),classCheckPrivateStaticFieldDescriptor(r,\"set\"),classApplyDescriptorSet(s,r,e),e}", {
						globals: [],
						locals: { _classStaticPrivateFieldSpecSet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classStaticPrivateFieldSpecSet",
						dependencies: {
							classApplyDescriptorSet: ["body.0.body.body.0.argument.expressions.2.callee"],
							assertClassBrand: ["body.0.body.body.0.argument.expressions.0.callee"],
							classCheckPrivateStaticFieldDescriptor: ["body.0.body.body.0.argument.expressions.1.callee"]
						},
						internal: !1
					}),
					classStaticPrivateMethodSet: helper("7.3.2", "function _classStaticPrivateMethodSet(){throw new TypeError(\"attempted to set read only static private field\")}", {
						globals: ["TypeError"],
						locals: { _classStaticPrivateMethodSet: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_classStaticPrivateMethodSet",
						dependencies: {},
						internal: !1
					}),
					defineEnumerableProperties: helper("7.0.0-beta.0", "function _defineEnumerableProperties(e,r){for(var t in r){var n=r[t];n.configurable=n.enumerable=!0,\"value\"in n&&(n.writable=!0),Object.defineProperty(e,t,n)}if(Object.getOwnPropertySymbols)for(var a=Object.getOwnPropertySymbols(r),b=0;b<a.length;b++){var i=a[b];(n=r[i]).configurable=n.enumerable=!0,\"value\"in n&&(n.writable=!0),Object.defineProperty(e,i,n)}return e}", {
						globals: ["Object"],
						locals: { _defineEnumerableProperties: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_defineEnumerableProperties",
						dependencies: {},
						internal: !1
					}),
					dispose: helper("7.22.0", "function dispose_SuppressedError(r,e){return\"undefined\"!=typeof SuppressedError?dispose_SuppressedError=SuppressedError:(dispose_SuppressedError=function(r,e){this.suppressed=e,this.error=r,this.stack=Error().stack},dispose_SuppressedError.prototype=Object.create(Error.prototype,{constructor:{value:dispose_SuppressedError,writable:!0,configurable:!0}})),new dispose_SuppressedError(r,e)}function _dispose(r,e,s){function next(){for(;r.length>0;)try{var o=r.pop(),p=o.d.call(o.v);if(o.a)return Promise.resolve(p).then(next,err)}catch(r){return err(r)}if(s)throw e}function err(r){return e=s?new dispose_SuppressedError(e,r):r,s=!0,next()}return next()}", {
						globals: [
							"SuppressedError",
							"Error",
							"Object",
							"Promise"
						],
						locals: {
							dispose_SuppressedError: [
								"body.0.id",
								"body.0.body.body.0.argument.expressions.0.alternate.expressions.1.left.object",
								"body.0.body.body.0.argument.expressions.0.alternate.expressions.1.right.arguments.1.properties.0.value.properties.0.value",
								"body.0.body.body.0.argument.expressions.1.callee",
								"body.1.body.body.1.body.body.0.argument.expressions.0.right.consequent.callee",
								"body.0.body.body.0.argument.expressions.0.consequent.left",
								"body.0.body.body.0.argument.expressions.0.alternate.expressions.0.left"
							],
							_dispose: ["body.1.id"]
						},
						exportBindingAssignments: [],
						exportName: "_dispose",
						dependencies: {},
						internal: !1
					}),
					objectSpread: helper("7.0.0-beta.0", "function _objectSpread(e){for(var r=1;r<arguments.length;r++){var t=null!=arguments[r]?Object(arguments[r]):{},o=Object.keys(t);\"function\"==typeof Object.getOwnPropertySymbols&&o.push.apply(o,Object.getOwnPropertySymbols(t).filter(function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable})),o.forEach(function(r){defineProperty(e,r,t[r])})}return e}", {
						globals: ["Object"],
						locals: { _objectSpread: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_objectSpread",
						dependencies: { defineProperty: ["body.0.body.body.0.body.body.1.expression.expressions.1.arguments.0.body.body.0.expression.callee"] },
						internal: !1
					}),
					regeneratorRuntime: helper("7.18.0", "function _regeneratorRuntime(){\"use strict\";var r=regenerator(),e=r.m(_regeneratorRuntime),t=(Object.getPrototypeOf?Object.getPrototypeOf(e):e.__proto__).constructor;function n(r){var e=\"function\"==typeof r&&r.constructor;return!!e&&(e===t||\"GeneratorFunction\"===(e.displayName||e.name))}var o={throw:1,return:2,break:3,continue:3};function a(r){var e,t;return function(n){e||(e={stop:function(){return t(n.a,2)},catch:function(){return n.v},abrupt:function(r,e){return t(n.a,o[r],e)},delegateYield:function(r,o,a){return e.resultName=o,t(n.d,values(r),a)},finish:function(r){return t(n.f,r)}},t=function(r,t,o){n.p=e.prev,n.n=e.next;try{return r(t,o)}finally{e.next=n.n}}),e.resultName&&(e[e.resultName]=n.v,e.resultName=void 0),e.sent=n.v,e.next=n.n;try{return r.call(this,e)}finally{n.p=e.prev,n.n=e.next}}}return(_regeneratorRuntime=function(){return{wrap:function(e,t,n,o){return r.w(a(e),t,n,o&&o.reverse())},isGeneratorFunction:n,mark:r.m,awrap:function(r,e){return new OverloadYield(r,e)},AsyncIterator:AsyncIterator,async:function(r,e,t,o,u){return(n(e)?asyncGen:async)(a(r),e,t,o,u)},keys:keys,values:values}})()}", {
						globals: ["Object"],
						locals: { _regeneratorRuntime: [
							"body.0.id",
							"body.0.body.body.0.declarations.1.init.arguments.0",
							"body.0.body.body.4.argument.callee.left"
						] },
						exportBindingAssignments: ["body.0.body.body.4.argument.callee"],
						exportName: "_regeneratorRuntime",
						dependencies: {
							OverloadYield: ["body.0.body.body.4.argument.callee.right.body.body.0.argument.properties.3.value.body.body.0.argument.callee"],
							regenerator: ["body.0.body.body.0.declarations.0.init.callee"],
							regeneratorAsync: ["body.0.body.body.4.argument.callee.right.body.body.0.argument.properties.5.value.body.body.0.argument.callee.alternate"],
							regeneratorAsyncGen: ["body.0.body.body.4.argument.callee.right.body.body.0.argument.properties.5.value.body.body.0.argument.callee.consequent"],
							regeneratorAsyncIterator: ["body.0.body.body.4.argument.callee.right.body.body.0.argument.properties.4.value"],
							regeneratorKeys: ["body.0.body.body.4.argument.callee.right.body.body.0.argument.properties.6.value"],
							regeneratorValues: ["body.0.body.body.3.body.body.1.argument.body.body.0.expression.expressions.0.right.expressions.0.right.properties.3.value.body.body.0.argument.expressions.1.arguments.1.callee", "body.0.body.body.4.argument.callee.right.body.body.0.argument.properties.7.value"]
						},
						internal: !1
					}),
					using: helper("7.22.0", "function _using(o,n,e){if(null==n)return n;if(Object(n)!==n)throw new TypeError(\"using declarations can only be used with objects, functions, null, or undefined.\");if(e)var r=n[Symbol.asyncDispose||Symbol.for(\"Symbol.asyncDispose\")];if(null==r&&(r=n[Symbol.dispose||Symbol.for(\"Symbol.dispose\")]),\"function\"!=typeof r)throw new TypeError(\"Property [Symbol.dispose] is not a function.\");return o.push({v:n,d:r,a:e}),n}", {
						globals: [
							"Object",
							"TypeError",
							"Symbol"
						],
						locals: { _using: ["body.0.id"] },
						exportBindingAssignments: [],
						exportName: "_using",
						dependencies: {},
						internal: !1
					})
				});
			},
			"./node_modules/.pnpm/@babel+helpers@7.28.4/node_modules/@babel/helpers/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0, t.get = get, t.getDependencies = function(e) {
					return loadHelper(e).getDependencies();
				}, t.isInternal = function(e) {
					var t;
					return null == (t = s.default[e]) ? void 0 : t.metadata.internal;
				}, t.list = void 0, t.minVersion = function(e) {
					return loadHelper(e).minVersion;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = r("./node_modules/.pnpm/@babel+helpers@7.28.4/node_modules/@babel/helpers/lib/helpers-generated.js");
				const { cloneNode: i, identifier: o } = n;
				function deep(e, t, r) {
					try {
						const n = t.split(".");
						let s = n.shift();
						for (; n.length > 0;) e = e[s], s = n.shift();
						if (!(arguments.length > 2)) return e[s];
						e[s] = r;
					} catch (e) {
						throw e.message += ` (when accessing ${t})`, e;
					}
				}
				const a = Object.create(null);
				function loadHelper(e) {
					if (!a[e]) {
						const t = s.default[e];
						if (!t) throw Object.assign(/* @__PURE__ */ new ReferenceError(`Unknown helper ${e}`), {
							code: "BABEL_HELPER_UNKNOWN",
							helper: e
						});
						a[e] = {
							minVersion: t.minVersion,
							build(e, r, n, s) {
								const a = t.ast();
								return function(e, t, r, n, s, a) {
									const { locals: l, dependencies: p, exportBindingAssignments: c, exportName: u } = t, d = new Set(n || []);
									r && d.add(r);
									for (const [t, n] of (Object.entries || ((e) => Object.keys(e).map((t) => [t, e[t]])))(l)) {
										let s = t;
										if (r && t === u) s = r;
										else for (; d.has(s);) s = "_" + s;
										if (s !== t) for (const t of n) deep(e, t, o(s));
									}
									for (const [t, r] of (Object.entries || ((e) => Object.keys(e).map((t) => [t, e[t]])))(p)) {
										const n = "function" == typeof s && s(t) || o(t);
										for (const t of r) deep(e, t, i(n));
									}
									a?.(e, u, (t) => {
										c.forEach((r) => deep(e, r, t(deep(e, r))));
									});
								}(a, t.metadata, r, n, e, s), {
									nodes: a.body,
									globals: t.metadata.globals
								};
							},
							getDependencies: () => Object.keys(t.metadata.dependencies)
						};
					}
					return a[e];
				}
				function get(e, t, r, n, s) {
					if ("object" == typeof r) {
						const e = r;
						r = "Identifier" === (null == e ? void 0 : e.type) ? e.name : void 0;
					}
					return loadHelper(e).build(t, r, n, s);
				}
				t.ensure = (e) => {
					loadHelper(e);
				};
				t.list = Object.keys(s.default).map((e) => e.replace(/^_/, ""));
				t.default = get;
			},
			"./node_modules/.pnpm/@babel+parser@7.28.4/node_modules/@babel/parser/lib/index.js": function(e, t) {
				"use strict";
				function _objectWithoutPropertiesLoose(e, t) {
					if (null == e) return {};
					var r = {};
					for (var n in e) if ({}.hasOwnProperty.call(e, n)) {
						if (-1 !== t.indexOf(n)) continue;
						r[n] = e[n];
					}
					return r;
				}
				Object.defineProperty(t, "__esModule", { value: !0 });
				class Position {
					constructor(e, t, r) {
						this.line = void 0, this.column = void 0, this.index = void 0, this.line = e, this.column = t, this.index = r;
					}
				}
				class SourceLocation {
					constructor(e, t) {
						this.start = void 0, this.end = void 0, this.filename = void 0, this.identifierName = void 0, this.start = e, this.end = t;
					}
				}
				function createPositionWithColumnOffset(e, t) {
					const { line: r, column: n, index: s } = e;
					return new Position(r, n + t, s + t);
				}
				const r = "BABEL_PARSER_SOURCETYPE_MODULE_REQUIRED";
				var n = {
					ImportMetaOutsideModule: {
						message: "import.meta may appear only with 'sourceType: \"module\"'",
						code: r
					},
					ImportOutsideModule: {
						message: "'import' and 'export' may appear only with 'sourceType: \"module\"'",
						code: r
					}
				};
				const s = {
					ArrayPattern: "array destructuring pattern",
					AssignmentExpression: "assignment expression",
					AssignmentPattern: "assignment expression",
					ArrowFunctionExpression: "arrow function expression",
					ConditionalExpression: "conditional expression",
					CatchClause: "catch clause",
					ForOfStatement: "for-of statement",
					ForInStatement: "for-in statement",
					ForStatement: "for-loop",
					FormalParameters: "function parameter list",
					Identifier: "identifier",
					ImportSpecifier: "import specifier",
					ImportDefaultSpecifier: "import default specifier",
					ImportNamespaceSpecifier: "import namespace specifier",
					ObjectPattern: "object destructuring pattern",
					ParenthesizedExpression: "parenthesized expression",
					RestElement: "rest element",
					UpdateExpression: {
						true: "prefix operation",
						false: "postfix operation"
					},
					VariableDeclarator: "variable declaration",
					YieldExpression: "yield expression"
				}, toNodeDescription = (e) => "UpdateExpression" === e.type ? s.UpdateExpression[`${e.prefix}`] : s[e.type];
				var i = {
					AccessorIsGenerator: ({ kind: e }) => `A ${e}ter cannot be a generator.`,
					ArgumentsInClass: "'arguments' is only allowed in functions and class methods.",
					AsyncFunctionInSingleStatementContext: "Async functions can only be declared at the top level or inside a block.",
					AwaitBindingIdentifier: "Can not use 'await' as identifier inside an async function.",
					AwaitBindingIdentifierInStaticBlock: "Can not use 'await' as identifier inside a static block.",
					AwaitExpressionFormalParameter: "'await' is not allowed in async function parameters.",
					AwaitUsingNotInAsyncContext: "'await using' is only allowed within async functions and at the top levels of modules.",
					AwaitNotInAsyncContext: "'await' is only allowed within async functions and at the top levels of modules.",
					BadGetterArity: "A 'get' accessor must not have any formal parameters.",
					BadSetterArity: "A 'set' accessor must have exactly one formal parameter.",
					BadSetterRestParameter: "A 'set' accessor function argument must not be a rest parameter.",
					ConstructorClassField: "Classes may not have a field named 'constructor'.",
					ConstructorClassPrivateField: "Classes may not have a private field named '#constructor'.",
					ConstructorIsAccessor: "Class constructor may not be an accessor.",
					ConstructorIsAsync: "Constructor can't be an async function.",
					ConstructorIsGenerator: "Constructor can't be a generator.",
					DeclarationMissingInitializer: ({ kind: e }) => `Missing initializer in ${e} declaration.`,
					DecoratorArgumentsOutsideParentheses: "Decorator arguments must be moved inside parentheses: use '@(decorator(args))' instead of '@(decorator)(args)'.",
					DecoratorBeforeExport: "Decorators must be placed *before* the 'export' keyword. Remove the 'decoratorsBeforeExport: true' option to use the 'export @decorator class {}' syntax.",
					DecoratorsBeforeAfterExport: "Decorators can be placed *either* before or after the 'export' keyword, but not in both locations at the same time.",
					DecoratorConstructor: "Decorators can't be used with a constructor. Did you mean '@dec class { ... }'?",
					DecoratorExportClass: "Decorators must be placed *after* the 'export' keyword. Remove the 'decoratorsBeforeExport: false' option to use the '@decorator export class {}' syntax.",
					DecoratorSemicolon: "Decorators must not be followed by a semicolon.",
					DecoratorStaticBlock: "Decorators can't be used with a static block.",
					DeferImportRequiresNamespace: "Only `import defer * as x from \"./module\"` is valid.",
					DeletePrivateField: "Deleting a private field is not allowed.",
					DestructureNamedImport: "ES2015 named imports do not destructure. Use another statement for destructuring after the import.",
					DuplicateConstructor: "Duplicate constructor in the same class.",
					DuplicateDefaultExport: "Only one default export allowed per module.",
					DuplicateExport: ({ exportName: e }) => `\`${e}\` has already been exported. Exported identifiers must be unique.`,
					DuplicateProto: "Redefinition of __proto__ property.",
					DuplicateRegExpFlags: "Duplicate regular expression flag.",
					ElementAfterRest: "Rest element must be last element.",
					EscapedCharNotAnIdentifier: "Invalid Unicode escape.",
					ExportBindingIsString: ({ localName: e, exportName: t }) => `A string literal cannot be used as an exported binding without \`from\`.\n- Did you mean \`export { '${e}' as '${t}' } from 'some-module'\`?`,
					ExportDefaultFromAsIdentifier: "'from' is not allowed as an identifier after 'export default'.",
					ForInOfLoopInitializer: ({ type: e }) => `'${"ForInStatement" === e ? "for-in" : "for-of"}' loop variable declaration may not have an initializer.`,
					ForInUsing: "For-in loop may not start with 'using' declaration.",
					ForOfAsync: "The left-hand side of a for-of loop may not be 'async'.",
					ForOfLet: "The left-hand side of a for-of loop may not start with 'let'.",
					GeneratorInSingleStatementContext: "Generators can only be declared at the top level or inside a block.",
					IllegalBreakContinue: ({ type: e }) => `Unsyntactic ${"BreakStatement" === e ? "break" : "continue"}.`,
					IllegalLanguageModeDirective: "Illegal 'use strict' directive in function with non-simple parameter list.",
					IllegalReturn: "'return' outside of function.",
					ImportAttributesUseAssert: "The `assert` keyword in import attributes is deprecated and it has been replaced by the `with` keyword. You can enable the `deprecatedImportAssert` parser plugin to suppress this error.",
					ImportBindingIsString: ({ importName: e }) => `A string literal cannot be used as an imported binding.\n- Did you mean \`import { "${e}" as foo }\`?`,
					ImportCallArity: "`import()` requires exactly one or two arguments.",
					ImportCallNotNewExpression: "Cannot use new with import(...).",
					ImportCallSpreadArgument: "`...` is not allowed in `import()`.",
					ImportJSONBindingNotDefault: "A JSON module can only be imported with `default`.",
					ImportReflectionHasAssertion: "`import module x` cannot have assertions.",
					ImportReflectionNotBinding: "Only `import module x from \"./module\"` is valid.",
					IncompatibleRegExpUVFlags: "The 'u' and 'v' regular expression flags cannot be enabled at the same time.",
					InvalidBigIntLiteral: "Invalid BigIntLiteral.",
					InvalidCodePoint: "Code point out of bounds.",
					InvalidCoverDiscardElement: "'void' must be followed by an expression when not used in a binding position.",
					InvalidCoverInitializedName: "Invalid shorthand property initializer.",
					InvalidDecimal: "Invalid decimal.",
					InvalidDigit: ({ radix: e }) => `Expected number in radix ${e}.`,
					InvalidEscapeSequence: "Bad character escape sequence.",
					InvalidEscapeSequenceTemplate: "Invalid escape sequence in template.",
					InvalidEscapedReservedWord: ({ reservedWord: e }) => `Escape sequence in keyword ${e}.`,
					InvalidIdentifier: ({ identifierName: e }) => `Invalid identifier ${e}.`,
					InvalidLhs: ({ ancestor: e }) => `Invalid left-hand side in ${toNodeDescription(e)}.`,
					InvalidLhsBinding: ({ ancestor: e }) => `Binding invalid left-hand side in ${toNodeDescription(e)}.`,
					InvalidLhsOptionalChaining: ({ ancestor: e }) => `Invalid optional chaining in the left-hand side of ${toNodeDescription(e)}.`,
					InvalidNumber: "Invalid number.",
					InvalidOrMissingExponent: "Floating-point numbers require a valid exponent after the 'e'.",
					InvalidOrUnexpectedToken: ({ unexpected: e }) => `Unexpected character '${e}'.`,
					InvalidParenthesizedAssignment: "Invalid parenthesized assignment pattern.",
					InvalidPrivateFieldResolution: ({ identifierName: e }) => `Private name #${e} is not defined.`,
					InvalidPropertyBindingPattern: "Binding member expression.",
					InvalidRecordProperty: "Only properties and spread elements are allowed in record definitions.",
					InvalidRestAssignmentPattern: "Invalid rest operator's argument.",
					LabelRedeclaration: ({ labelName: e }) => `Label '${e}' is already declared.`,
					LetInLexicalBinding: "'let' is disallowed as a lexically bound name.",
					LineTerminatorBeforeArrow: "No line break is allowed before '=>'.",
					MalformedRegExpFlags: "Invalid regular expression flag.",
					MissingClassName: "A class name is required.",
					MissingEqInAssignment: "Only '=' operator can be used for specifying default value.",
					MissingSemicolon: "Missing semicolon.",
					MissingPlugin: ({ missingPlugin: e }) => `This experimental syntax requires enabling the parser plugin: ${e.map((e) => JSON.stringify(e)).join(", ")}.`,
					MissingOneOfPlugins: ({ missingPlugin: e }) => `This experimental syntax requires enabling one of the following parser plugin(s): ${e.map((e) => JSON.stringify(e)).join(", ")}.`,
					MissingUnicodeEscape: "Expecting Unicode escape sequence \\uXXXX.",
					MixingCoalesceWithLogical: "Nullish coalescing operator(??) requires parens when mixing with logical operators.",
					ModuleAttributeDifferentFromType: "The only accepted module attribute is `type`.",
					ModuleAttributeInvalidValue: "Only string literals are allowed as module attribute values.",
					ModuleAttributesWithDuplicateKeys: ({ key: e }) => `Duplicate key "${e}" is not allowed in module attributes.`,
					ModuleExportNameHasLoneSurrogate: ({ surrogateCharCode: e }) => `An export name cannot include a lone surrogate, found '\\u${e.toString(16)}'.`,
					ModuleExportUndefined: ({ localName: e }) => `Export '${e}' is not defined.`,
					MultipleDefaultsInSwitch: "Multiple default clauses.",
					NewlineAfterThrow: "Illegal newline after throw.",
					NoCatchOrFinally: "Missing catch or finally clause.",
					NumberIdentifier: "Identifier directly after number.",
					NumericSeparatorInEscapeSequence: "Numeric separators are not allowed inside unicode escape sequences or hex escape sequences.",
					ObsoleteAwaitStar: "'await*' has been removed from the async functions proposal. Use Promise.all() instead.",
					OptionalChainingNoNew: "Constructors in/after an Optional Chain are not allowed.",
					OptionalChainingNoTemplate: "Tagged Template Literals are not allowed in optionalChain.",
					OverrideOnConstructor: "'override' modifier cannot appear on a constructor declaration.",
					ParamDupe: "Argument name clash.",
					PatternHasAccessor: "Object pattern can't contain getter or setter.",
					PatternHasMethod: "Object pattern can't contain methods.",
					PrivateInExpectedIn: ({ identifierName: e }) => `Private names are only allowed in property accesses (\`obj.#${e}\`) or in \`in\` expressions (\`#${e} in obj\`).`,
					PrivateNameRedeclaration: ({ identifierName: e }) => `Duplicate private name #${e}.`,
					RecordExpressionBarIncorrectEndSyntaxType: "Record expressions ending with '|}' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.",
					RecordExpressionBarIncorrectStartSyntaxType: "Record expressions starting with '{|' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.",
					RecordExpressionHashIncorrectStartSyntaxType: "Record expressions starting with '#{' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'hash'.",
					RecordNoProto: "'__proto__' is not allowed in Record expressions.",
					RestTrailingComma: "Unexpected trailing comma after rest element.",
					SloppyFunction: "In non-strict mode code, functions can only be declared at top level or inside a block.",
					SloppyFunctionAnnexB: "In non-strict mode code, functions can only be declared at top level, inside a block, or as the body of an if statement.",
					SourcePhaseImportRequiresDefault: "Only `import source x from \"./module\"` is valid.",
					StaticPrototype: "Classes may not have static property named prototype.",
					SuperNotAllowed: "`super()` is only valid inside a class constructor of a subclass. Maybe a typo in the method name ('constructor') or not extending another class?",
					SuperPrivateField: "Private fields can't be accessed on super.",
					TrailingDecorator: "Decorators must be attached to a class element.",
					TupleExpressionBarIncorrectEndSyntaxType: "Tuple expressions ending with '|]' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.",
					TupleExpressionBarIncorrectStartSyntaxType: "Tuple expressions starting with '[|' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'bar'.",
					TupleExpressionHashIncorrectStartSyntaxType: "Tuple expressions starting with '#[' are only allowed when the 'syntaxType' option of the 'recordAndTuple' plugin is set to 'hash'.",
					UnexpectedArgumentPlaceholder: "Unexpected argument placeholder.",
					UnexpectedAwaitAfterPipelineBody: "Unexpected \"await\" after pipeline body; await must have parentheses in minimal proposal.",
					UnexpectedDigitAfterHash: "Unexpected digit after hash token.",
					UnexpectedImportExport: "'import' and 'export' may only appear at the top level.",
					UnexpectedKeyword: ({ keyword: e }) => `Unexpected keyword '${e}'.`,
					UnexpectedLeadingDecorator: "Leading decorators must be attached to a class declaration.",
					UnexpectedLexicalDeclaration: "Lexical declaration cannot appear in a single-statement context.",
					UnexpectedNewTarget: "`new.target` can only be used in functions or class properties.",
					UnexpectedNumericSeparator: "A numeric separator is only allowed between two digits.",
					UnexpectedPrivateField: "Unexpected private name.",
					UnexpectedReservedWord: ({ reservedWord: e }) => `Unexpected reserved word '${e}'.`,
					UnexpectedSuper: "'super' is only allowed in object methods and classes.",
					UnexpectedToken: ({ expected: e, unexpected: t }) => `Unexpected token${t ? ` '${t}'.` : ""}${e ? `, expected "${e}"` : ""}`,
					UnexpectedTokenUnaryExponentiation: "Illegal expression. Wrap left hand side or entire exponentiation in parentheses.",
					UnexpectedUsingDeclaration: "Using declaration cannot appear in the top level when source type is `script` or in the bare case statement.",
					UnexpectedVoidPattern: "Unexpected void binding.",
					UnsupportedBind: "Binding should be performed on object property.",
					UnsupportedDecoratorExport: "A decorated export must export a class declaration.",
					UnsupportedDefaultExport: "Only expressions, functions or classes are allowed as the `default` export.",
					UnsupportedImport: "`import` can only be used in `import()` or `import.meta`.",
					UnsupportedMetaProperty: ({ target: e, onlyValidPropertyName: t }) => `The only valid meta property for ${e} is ${e}.${t}.`,
					UnsupportedParameterDecorator: "Decorators cannot be used to decorate parameters.",
					UnsupportedPropertyDecorator: "Decorators cannot be used to decorate object literal properties.",
					UnsupportedSuper: "'super' can only be used with function calls (i.e. super()) or in property accesses (i.e. super.prop or super[prop]).",
					UnterminatedComment: "Unterminated comment.",
					UnterminatedRegExp: "Unterminated regular expression.",
					UnterminatedString: "Unterminated string constant.",
					UnterminatedTemplate: "Unterminated template.",
					UsingDeclarationExport: "Using declaration cannot be exported.",
					UsingDeclarationHasBindingPattern: "Using declaration cannot have destructuring patterns.",
					VarRedeclaration: ({ identifierName: e }) => `Identifier '${e}' has already been declared.`,
					VoidPatternCatchClauseParam: "A void binding can not be the catch clause parameter. Use `try { ... } catch { ... }` if you want to discard the caught error.",
					VoidPatternInitializer: "A void binding may not have an initializer.",
					YieldBindingIdentifier: "Can not use 'yield' as identifier inside a generator.",
					YieldInParameter: "Yield expression is not allowed in formal parameters.",
					YieldNotInGeneratorFunction: "'yield' is only allowed within generator functions.",
					ZeroDigitNumericSeparator: "Numeric separator can not be used after leading 0."
				}, o = {
					ParseExpressionEmptyInput: "Unexpected parseExpression() input: The input is empty or contains only comments.",
					ParseExpressionExpectsEOF: ({ unexpected: e }) => `Unexpected parseExpression() input: The input should contain exactly one expression, but the first expression is followed by the unexpected character \`${String.fromCodePoint(e)}\`.`
				};
				const a = new Set([
					"ArrowFunctionExpression",
					"AssignmentExpression",
					"ConditionalExpression",
					"YieldExpression"
				]);
				var l = Object.assign({
					PipeBodyIsTighter: "Unexpected yield after pipeline body; any yield expression acting as Hack-style pipe body must be parenthesized due to its loose operator precedence.",
					PipeTopicRequiresHackPipes: "Topic reference is used, but the pipelineOperator plugin was not passed a \"proposal\": \"hack\" or \"smart\" option.",
					PipeTopicUnbound: "Topic reference is unbound; it must be inside a pipe body.",
					PipeTopicUnconfiguredToken: ({ token: e }) => `Invalid topic token ${e}. In order to use ${e} as a topic reference, the pipelineOperator plugin must be configured with { "proposal": "hack", "topicToken": "${e}" }.`,
					PipeTopicUnused: "Hack-style pipe body does not contain a topic reference; Hack-style pipes must use topic at least once.",
					PipeUnparenthesizedBody: ({ type: e }) => `Hack-style pipe body cannot be an unparenthesized ${toNodeDescription({ type: e })}; please wrap it in parentheses.`
				}, {
					PipelineBodyNoArrow: "Unexpected arrow \"=>\" after pipeline body; arrow function in pipeline body must be parenthesized.",
					PipelineBodySequenceExpression: "Pipeline body may not be a comma-separated sequence expression.",
					PipelineHeadSequenceExpression: "Pipeline head should not be a comma-separated sequence expression.",
					PipelineTopicUnused: "Pipeline is in topic style but does not use topic reference.",
					PrimaryTopicNotAllowed: "Topic reference was used in a lexical context without topic binding.",
					PrimaryTopicRequiresSmartPipeline: "Topic reference is used, but the pipelineOperator plugin was not passed a \"proposal\": \"hack\" or \"smart\" option."
				});
				const p = ["message"];
				function defineHidden(e, t, r) {
					Object.defineProperty(e, t, {
						enumerable: !1,
						configurable: !0,
						value: r
					});
				}
				function toParseErrorConstructor({ toMessage: e, code: t, reasonCode: r, syntaxPlugin: n }) {
					const s = "MissingPlugin" === r || "MissingOneOfPlugins" === r;
					{
						const e = {
							AccessorCannotDeclareThisParameter: "AccesorCannotDeclareThisParameter",
							AccessorCannotHaveTypeParameters: "AccesorCannotHaveTypeParameters",
							ConstInitializerMustBeStringOrNumericLiteralOrLiteralEnumReference: "ConstInitiailizerMustBeStringOrNumericLiteralOrLiteralEnumReference",
							SetAccessorCannotHaveOptionalParameter: "SetAccesorCannotHaveOptionalParameter",
							SetAccessorCannotHaveRestParameter: "SetAccesorCannotHaveRestParameter",
							SetAccessorCannotHaveReturnType: "SetAccesorCannotHaveReturnType"
						};
						e[r] && (r = e[r]);
					}
					return function constructor(i, o) {
						const a = /* @__PURE__ */ new SyntaxError();
						return a.code = t, a.reasonCode = r, a.loc = i, a.pos = i.index, a.syntaxPlugin = n, s && (a.missingPlugin = o.missingPlugin), defineHidden(a, "clone", function(e = {}) {
							var t;
							const { line: r, column: n, index: s } = null != (t = e.loc) ? t : i;
							return constructor(new Position(r, n, s), Object.assign({}, o, e.details));
						}), defineHidden(a, "details", o), Object.defineProperty(a, "message", {
							configurable: !0,
							get() {
								const t = `${e(o)} (${i.line}:${i.column})`;
								return this.message = t, t;
							},
							set(e) {
								Object.defineProperty(this, "message", {
									value: e,
									writable: !0
								});
							}
						}), a;
					};
				}
				function ParseErrorEnum(e, t) {
					if (Array.isArray(e)) return (t) => ParseErrorEnum(t, e[0]);
					const r = {};
					for (const n of Object.keys(e)) {
						const s = e[n], i = "string" == typeof s ? { message: () => s } : "function" == typeof s ? { message: s } : s, { message: o } = i, a = _objectWithoutPropertiesLoose(i, p);
						r[n] = toParseErrorConstructor(Object.assign({
							code: "BABEL_PARSER_SYNTAX_ERROR",
							reasonCode: n,
							toMessage: "string" == typeof o ? () => o : o
						}, t ? { syntaxPlugin: t } : {}, a));
					}
					return r;
				}
				const c = Object.assign({}, ParseErrorEnum(n), ParseErrorEnum(i), ParseErrorEnum({
					StrictDelete: "Deleting local variable in strict mode.",
					StrictEvalArguments: ({ referenceName: e }) => `Assigning to '${e}' in strict mode.`,
					StrictEvalArgumentsBinding: ({ bindingName: e }) => `Binding '${e}' in strict mode.`,
					StrictFunction: "In strict mode code, functions can only be declared at top level or inside a block.",
					StrictNumericEscape: "The only valid numeric escape in strict mode is '\\0'.",
					StrictOctalLiteral: "Legacy octal literals are not allowed in strict mode.",
					StrictWith: "'with' in strict mode."
				}), ParseErrorEnum(o), ParseErrorEnum`pipelineOperator`(l));
				const { defineProperty: u } = Object, toUnenumerable = (e, t) => {
					e && u(e, t, {
						enumerable: !1,
						value: e[t]
					});
				};
				function toESTreeLocation(e) {
					return toUnenumerable(e.loc.start, "index"), toUnenumerable(e.loc.end, "index"), e;
				}
				class TokContext {
					constructor(e, t) {
						this.token = void 0, this.preserveSpace = void 0, this.token = e, this.preserveSpace = !!t;
					}
				}
				const d = {
					brace: new TokContext("{"),
					j_oTag: new TokContext("<tag"),
					j_cTag: new TokContext("</tag"),
					j_expr: new TokContext("<tag>...</tag>", !0)
				};
				d.template = new TokContext("`", !0);
				const h = !0, m = !0, f = !0, y = !0, b = !0;
				class ExportedTokenType {
					constructor(e, t = {}) {
						this.label = void 0, this.keyword = void 0, this.beforeExpr = void 0, this.startsExpr = void 0, this.rightAssociative = void 0, this.isLoop = void 0, this.isAssign = void 0, this.prefix = void 0, this.postfix = void 0, this.binop = void 0, this.label = e, this.keyword = t.keyword, this.beforeExpr = !!t.beforeExpr, this.startsExpr = !!t.startsExpr, this.rightAssociative = !!t.rightAssociative, this.isLoop = !!t.isLoop, this.isAssign = !!t.isAssign, this.prefix = !!t.prefix, this.postfix = !!t.postfix, this.binop = null != t.binop ? t.binop : null, this.updateContext = null;
					}
				}
				const g = /* @__PURE__ */ new Map();
				function createKeyword(e, t = {}) {
					t.keyword = e;
					const r = createToken(e, t);
					return g.set(e, r), r;
				}
				function createBinop(e, t) {
					return createToken(e, {
						beforeExpr: h,
						binop: t
					});
				}
				let x = -1;
				const v = [], E = [], T = [], S = [], P = [], _ = [];
				function createToken(e, t = {}) {
					var r, n, s, i;
					return ++x, E.push(e), T.push(null != (r = t.binop) ? r : -1), S.push(null != (n = t.beforeExpr) && n), P.push(null != (s = t.startsExpr) && s), _.push(null != (i = t.prefix) && i), v.push(new ExportedTokenType(e, t)), x;
				}
				function createKeywordLike(e, t = {}) {
					var r, n, s, i;
					return ++x, g.set(e, x), E.push(e), T.push(null != (r = t.binop) ? r : -1), S.push(null != (n = t.beforeExpr) && n), P.push(null != (s = t.startsExpr) && s), _.push(null != (i = t.prefix) && i), v.push(new ExportedTokenType("name", t)), x;
				}
				const A = {
					bracketL: createToken("[", {
						beforeExpr: h,
						startsExpr: m
					}),
					bracketHashL: createToken("#[", {
						beforeExpr: h,
						startsExpr: m
					}),
					bracketBarL: createToken("[|", {
						beforeExpr: h,
						startsExpr: m
					}),
					bracketR: createToken("]"),
					bracketBarR: createToken("|]"),
					braceL: createToken("{", {
						beforeExpr: h,
						startsExpr: m
					}),
					braceBarL: createToken("{|", {
						beforeExpr: h,
						startsExpr: m
					}),
					braceHashL: createToken("#{", {
						beforeExpr: h,
						startsExpr: m
					}),
					braceR: createToken("}"),
					braceBarR: createToken("|}"),
					parenL: createToken("(", {
						beforeExpr: h,
						startsExpr: m
					}),
					parenR: createToken(")"),
					comma: createToken(",", { beforeExpr: h }),
					semi: createToken(";", { beforeExpr: h }),
					colon: createToken(":", { beforeExpr: h }),
					doubleColon: createToken("::", { beforeExpr: h }),
					dot: createToken("."),
					question: createToken("?", { beforeExpr: h }),
					questionDot: createToken("?."),
					arrow: createToken("=>", { beforeExpr: h }),
					template: createToken("template"),
					ellipsis: createToken("...", { beforeExpr: h }),
					backQuote: createToken("`", { startsExpr: m }),
					dollarBraceL: createToken("${", {
						beforeExpr: h,
						startsExpr: m
					}),
					templateTail: createToken("...`", { startsExpr: m }),
					templateNonTail: createToken("...${", {
						beforeExpr: h,
						startsExpr: m
					}),
					at: createToken("@"),
					hash: createToken("#", { startsExpr: m }),
					interpreterDirective: createToken("#!..."),
					eq: createToken("=", {
						beforeExpr: h,
						isAssign: y
					}),
					assign: createToken("_=", {
						beforeExpr: h,
						isAssign: y
					}),
					slashAssign: createToken("_=", {
						beforeExpr: h,
						isAssign: y
					}),
					xorAssign: createToken("_=", {
						beforeExpr: h,
						isAssign: y
					}),
					moduloAssign: createToken("_=", {
						beforeExpr: h,
						isAssign: y
					}),
					incDec: createToken("++/--", {
						prefix: b,
						postfix: !0,
						startsExpr: m
					}),
					bang: createToken("!", {
						beforeExpr: h,
						prefix: b,
						startsExpr: m
					}),
					tilde: createToken("~", {
						beforeExpr: h,
						prefix: b,
						startsExpr: m
					}),
					doubleCaret: createToken("^^", { startsExpr: m }),
					doubleAt: createToken("@@", { startsExpr: m }),
					pipeline: createBinop("|>", 0),
					nullishCoalescing: createBinop("??", 1),
					logicalOR: createBinop("||", 1),
					logicalAND: createBinop("&&", 2),
					bitwiseOR: createBinop("|", 3),
					bitwiseXOR: createBinop("^", 4),
					bitwiseAND: createBinop("&", 5),
					equality: createBinop("==/!=/===/!==", 6),
					lt: createBinop("</>/<=/>=", 7),
					gt: createBinop("</>/<=/>=", 7),
					relational: createBinop("</>/<=/>=", 7),
					bitShift: createBinop("<</>>/>>>", 8),
					bitShiftL: createBinop("<</>>/>>>", 8),
					bitShiftR: createBinop("<</>>/>>>", 8),
					plusMin: createToken("+/-", {
						beforeExpr: h,
						binop: 9,
						prefix: b,
						startsExpr: m
					}),
					modulo: createToken("%", {
						binop: 10,
						startsExpr: m
					}),
					star: createToken("*", { binop: 10 }),
					slash: createBinop("/", 10),
					exponent: createToken("**", {
						beforeExpr: h,
						binop: 11,
						rightAssociative: !0
					}),
					_in: createKeyword("in", {
						beforeExpr: h,
						binop: 7
					}),
					_instanceof: createKeyword("instanceof", {
						beforeExpr: h,
						binop: 7
					}),
					_break: createKeyword("break"),
					_case: createKeyword("case", { beforeExpr: h }),
					_catch: createKeyword("catch"),
					_continue: createKeyword("continue"),
					_debugger: createKeyword("debugger"),
					_default: createKeyword("default", { beforeExpr: h }),
					_else: createKeyword("else", { beforeExpr: h }),
					_finally: createKeyword("finally"),
					_function: createKeyword("function", { startsExpr: m }),
					_if: createKeyword("if"),
					_return: createKeyword("return", { beforeExpr: h }),
					_switch: createKeyword("switch"),
					_throw: createKeyword("throw", {
						beforeExpr: h,
						prefix: b,
						startsExpr: m
					}),
					_try: createKeyword("try"),
					_var: createKeyword("var"),
					_const: createKeyword("const"),
					_with: createKeyword("with"),
					_new: createKeyword("new", {
						beforeExpr: h,
						startsExpr: m
					}),
					_this: createKeyword("this", { startsExpr: m }),
					_super: createKeyword("super", { startsExpr: m }),
					_class: createKeyword("class", { startsExpr: m }),
					_extends: createKeyword("extends", { beforeExpr: h }),
					_export: createKeyword("export"),
					_import: createKeyword("import", { startsExpr: m }),
					_null: createKeyword("null", { startsExpr: m }),
					_true: createKeyword("true", { startsExpr: m }),
					_false: createKeyword("false", { startsExpr: m }),
					_typeof: createKeyword("typeof", {
						beforeExpr: h,
						prefix: b,
						startsExpr: m
					}),
					_void: createKeyword("void", {
						beforeExpr: h,
						prefix: b,
						startsExpr: m
					}),
					_delete: createKeyword("delete", {
						beforeExpr: h,
						prefix: b,
						startsExpr: m
					}),
					_do: createKeyword("do", {
						isLoop: f,
						beforeExpr: h
					}),
					_for: createKeyword("for", { isLoop: f }),
					_while: createKeyword("while", { isLoop: f }),
					_as: createKeywordLike("as", { startsExpr: m }),
					_assert: createKeywordLike("assert", { startsExpr: m }),
					_async: createKeywordLike("async", { startsExpr: m }),
					_await: createKeywordLike("await", { startsExpr: m }),
					_defer: createKeywordLike("defer", { startsExpr: m }),
					_from: createKeywordLike("from", { startsExpr: m }),
					_get: createKeywordLike("get", { startsExpr: m }),
					_let: createKeywordLike("let", { startsExpr: m }),
					_meta: createKeywordLike("meta", { startsExpr: m }),
					_of: createKeywordLike("of", { startsExpr: m }),
					_sent: createKeywordLike("sent", { startsExpr: m }),
					_set: createKeywordLike("set", { startsExpr: m }),
					_source: createKeywordLike("source", { startsExpr: m }),
					_static: createKeywordLike("static", { startsExpr: m }),
					_using: createKeywordLike("using", { startsExpr: m }),
					_yield: createKeywordLike("yield", { startsExpr: m }),
					_asserts: createKeywordLike("asserts", { startsExpr: m }),
					_checks: createKeywordLike("checks", { startsExpr: m }),
					_exports: createKeywordLike("exports", { startsExpr: m }),
					_global: createKeywordLike("global", { startsExpr: m }),
					_implements: createKeywordLike("implements", { startsExpr: m }),
					_intrinsic: createKeywordLike("intrinsic", { startsExpr: m }),
					_infer: createKeywordLike("infer", { startsExpr: m }),
					_is: createKeywordLike("is", { startsExpr: m }),
					_mixins: createKeywordLike("mixins", { startsExpr: m }),
					_proto: createKeywordLike("proto", { startsExpr: m }),
					_require: createKeywordLike("require", { startsExpr: m }),
					_satisfies: createKeywordLike("satisfies", { startsExpr: m }),
					_keyof: createKeywordLike("keyof", { startsExpr: m }),
					_readonly: createKeywordLike("readonly", { startsExpr: m }),
					_unique: createKeywordLike("unique", { startsExpr: m }),
					_abstract: createKeywordLike("abstract", { startsExpr: m }),
					_declare: createKeywordLike("declare", { startsExpr: m }),
					_enum: createKeywordLike("enum", { startsExpr: m }),
					_module: createKeywordLike("module", { startsExpr: m }),
					_namespace: createKeywordLike("namespace", { startsExpr: m }),
					_interface: createKeywordLike("interface", { startsExpr: m }),
					_type: createKeywordLike("type", { startsExpr: m }),
					_opaque: createKeywordLike("opaque", { startsExpr: m }),
					name: createToken("name", { startsExpr: m }),
					placeholder: createToken("%%", { startsExpr: m }),
					string: createToken("string", { startsExpr: m }),
					num: createToken("num", { startsExpr: m }),
					bigint: createToken("bigint", { startsExpr: m }),
					decimal: createToken("decimal", { startsExpr: m }),
					regexp: createToken("regexp", { startsExpr: m }),
					privateName: createToken("#name", { startsExpr: m }),
					eof: createToken("eof"),
					jsxName: createToken("jsxName"),
					jsxText: createToken("jsxText", { beforeExpr: h }),
					jsxTagStart: createToken("jsxTagStart", { startsExpr: m }),
					jsxTagEnd: createToken("jsxTagEnd")
				};
				function tokenIsIdentifier(e) {
					return e >= 93 && e <= 133;
				}
				function tokenIsKeywordOrIdentifier(e) {
					return e >= 58 && e <= 133;
				}
				function tokenIsLiteralPropertyName(e) {
					return e >= 58 && e <= 137;
				}
				function tokenCanStartExpression(e) {
					return P[e];
				}
				function tokenIsFlowInterfaceOrTypeOrOpaque(e) {
					return e >= 129 && e <= 131;
				}
				function tokenIsKeyword(e) {
					return e >= 58 && e <= 92;
				}
				function tokenIsPostfix(e) {
					return 34 === e;
				}
				function tokenLabelName(e) {
					return E[e];
				}
				function tokenOperatorPrecedence(e) {
					return T[e];
				}
				function tokenIsTemplate(e) {
					return e >= 24 && e <= 25;
				}
				function getExportedToken(e) {
					return v[e];
				}
				v[8].updateContext = (e) => {
					e.pop();
				}, v[5].updateContext = v[7].updateContext = v[23].updateContext = (e) => {
					e.push(d.brace);
				}, v[22].updateContext = (e) => {
					e[e.length - 1] === d.template ? e.pop() : e.push(d.template);
				}, v[143].updateContext = (e) => {
					e.push(d.j_expr, d.j_oTag);
				};
				let C = "ªµºÀ-ÖØ-öø-ˁˆ-ˑˠ-ˤˬˮͰ-ʹͶͷͺ-ͽͿΆΈ-ΊΌΎ-ΡΣ-ϵϷ-ҁҊ-ԯԱ-Ֆՙՠ-ֈא-תׯ-ײؠ-يٮٯٱ-ۓەۥۦۮۯۺ-ۼۿܐܒ-ܯݍ-ޥޱߊ-ߪߴߵߺࠀ-ࠕࠚࠤࠨࡀ-ࡘࡠ-ࡪࡰ-ࢇࢉ-ࢎࢠ-ࣉऄ-हऽॐक़-ॡॱ-ঀঅ-ঌএঐও-নপ-রলশ-হঽৎড়ঢ়য়-ৡৰৱৼਅ-ਊਏਐਓ-ਨਪ-ਰਲਲ਼ਵਸ਼ਸਹਖ਼-ੜਫ਼ੲ-ੴઅ-ઍએ-ઑઓ-નપ-રલળવ-હઽૐૠૡૹଅ-ଌଏଐଓ-ନପ-ରଲଳଵ-ହଽଡ଼ଢ଼ୟ-ୡୱஃஅ-ஊஎ-ஐஒ-கஙசஜஞடணதந-பம-ஹௐఅ-ఌఎ-ఐఒ-నప-హఽౘ-ౚౝౠౡಀಅ-ಌಎ-ಐಒ-ನಪ-ಳವ-ಹಽೝೞೠೡೱೲഄ-ഌഎ-ഐഒ-ഺഽൎൔ-ൖൟ-ൡൺ-ൿඅ-ඖක-නඳ-රලව-ෆก-ะาำเ-ๆກຂຄຆ-ຊຌ-ຣລວ-ະາຳຽເ-ໄໆໜ-ໟༀཀ-ཇཉ-ཬྈ-ྌက-ဪဿၐ-ၕၚ-ၝၡၥၦၮ-ၰၵ-ႁႎႠ-ჅჇჍა-ჺჼ-ቈቊ-ቍቐ-ቖቘቚ-ቝበ-ኈኊ-ኍነ-ኰኲ-ኵኸ-ኾዀዂ-ዅወ-ዖዘ-ጐጒ-ጕጘ-ፚᎀ-ᎏᎠ-Ᏽᏸ-ᏽᐁ-ᙬᙯ-ᙿᚁ-ᚚᚠ-ᛪᛮ-ᛸᜀ-ᜑᜟ-ᜱᝀ-ᝑᝠ-ᝬᝮ-ᝰក-ឳៗៜᠠ-ᡸᢀ-ᢨᢪᢰ-ᣵᤀ-ᤞᥐ-ᥭᥰ-ᥴᦀ-ᦫᦰ-ᧉᨀ-ᨖᨠ-ᩔᪧᬅ-ᬳᭅ-ᭌᮃ-ᮠᮮᮯᮺ-ᯥᰀ-ᰣᱍ-ᱏᱚ-ᱽᲀ-ᲊᲐ-ᲺᲽ-Ჿᳩ-ᳬᳮ-ᳳᳵᳶᳺᴀ-ᶿḀ-ἕἘ-Ἕἠ-ὅὈ-Ὅὐ-ὗὙὛὝὟ-ώᾀ-ᾴᾶ-ᾼιῂ-ῄῆ-ῌῐ-ΐῖ-Ίῠ-Ῥῲ-ῴῶ-ῼⁱⁿₐ-ₜℂℇℊ-ℓℕ℘-ℝℤΩℨK-ℹℼ-ℿⅅ-ⅉⅎⅠ-ↈⰀ-ⳤⳫ-ⳮⳲⳳⴀ-ⴥⴧⴭⴰ-ⵧⵯⶀ-ⶖⶠ-ⶦⶨ-ⶮⶰ-ⶶⶸ-ⶾⷀ-ⷆⷈ-ⷎⷐ-ⷖⷘ-ⷞ々-〇〡-〩〱-〵〸-〼ぁ-ゖ゛-ゟァ-ヺー-ヿㄅ-ㄯㄱ-ㆎㆠ-ㆿㇰ-ㇿ㐀-䶿一-ꒌꓐ-ꓽꔀ-ꘌꘐ-ꘟꘪꘫꙀ-ꙮꙿ-ꚝꚠ-ꛯꜗ-ꜟꜢ-ꞈꞋ-ꟍꟐꟑꟓꟕ-Ƛꟲ-ꠁꠃ-ꠅꠇ-ꠊꠌ-ꠢꡀ-ꡳꢂ-ꢳꣲ-ꣷꣻꣽꣾꤊ-ꤥꤰ-ꥆꥠ-ꥼꦄ-ꦲꧏꧠ-ꧤꧦ-ꧯꧺ-ꧾꨀ-ꨨꩀ-ꩂꩄ-ꩋꩠ-ꩶꩺꩾ-ꪯꪱꪵꪶꪹ-ꪽꫀꫂꫛ-ꫝꫠ-ꫪꫲ-ꫴꬁ-ꬆꬉ-ꬎꬑ-ꬖꬠ-ꬦꬨ-ꬮꬰ-ꭚꭜ-ꭩꭰ-ꯢ가-힣ힰ-ퟆퟋ-ퟻ豈-舘並-龎ﬀ-ﬆﬓ-ﬗיִײַ-ﬨשׁ-זּטּ-לּמּנּסּףּפּצּ-ﮱﯓ-ﴽﵐ-ﶏﶒ-ﷇﷰ-ﷻﹰ-ﹴﹶ-ﻼＡ-Ｚａ-ｚｦ-ﾾￂ-ￇￊ-ￏￒ-ￗￚ-ￜ", w = "·̀-ͯ·҃-֑҇-ׇֽֿׁׂׅׄؐ-ًؚ-٩ٰۖ-ۜ۟-۪ۤۧۨ-ۭ۰-۹ܑܰ-݊ަ-ް߀-߉߫-߽߳ࠖ-࠙ࠛ-ࠣࠥ-ࠧࠩ-࡙࠭-࡛ࢗ-࢟࣊-ࣣ࣡-ःऺ-़ा-ॏ॑-ॗॢॣ०-९ঁ-ঃ়া-ৄেৈো-্ৗৢৣ০-৯৾ਁ-ਃ਼ਾ-ੂੇੈੋ-੍ੑ੦-ੱੵઁ-ઃ઼ા-ૅે-ૉો-્ૢૣ૦-૯ૺ-૿ଁ-ଃ଼ା-ୄେୈୋ-୍୕-ୗୢୣ୦-୯ஂா-ூெ-ைொ-்ௗ௦-௯ఀ-ఄ఼ా-ౄె-ైొ-్ౕౖౢౣ౦-౯ಁ-ಃ಼ಾ-ೄೆ-ೈೊ-್ೕೖೢೣ೦-೯ೳഀ-ഃ഻഼ാ-ൄെ-ൈൊ-്ൗൢൣ൦-൯ඁ-ඃ්ා-ුූෘ-ෟ෦-෯ෲෳัิ-ฺ็-๎๐-๙ັິ-ຼ່-໎໐-໙༘༙༠-༩༹༵༷༾༿ཱ-྄྆྇ྍ-ྗྙ-ྼ࿆ါ-ှ၀-၉ၖ-ၙၞ-ၠၢ-ၤၧ-ၭၱ-ၴႂ-ႍႏ-ႝ፝-፟፩-፱ᜒ-᜕ᜲ-᜴ᝒᝓᝲᝳ឴-៓៝០-៩᠋-᠍᠏-᠙ᢩᤠ-ᤫᤰ-᤻᥆-᥏᧐-᧚ᨗ-ᨛᩕ-ᩞ᩠-᩿᩼-᪉᪐-᪙᪰-᪽ᪿ-ᫎᬀ-ᬄ᬴-᭄᭐-᭙᭫-᭳ᮀ-ᮂᮡ-ᮭ᮰-᮹᯦-᯳ᰤ-᰷᱀-᱉᱐-᱙᳐-᳔᳒-᳨᳭᳴᳷-᳹᷀-᷿‌‍‿⁀⁔⃐-⃥⃜⃡-⃰⳯-⵿⳱ⷠ-〪ⷿ-゙゚〯・꘠-꘩꙯ꙴ-꙽ꚞꚟ꛰꛱ꠂ꠆ꠋꠣ-ꠧ꠬ꢀꢁꢴ-ꣅ꣐-꣙꣠-꣱ꣿ-꤉ꤦ-꤭ꥇ-꥓ꦀ-ꦃ꦳-꧀꧐-꧙ꧥ꧰-꧹ꨩ-ꨶꩃꩌꩍ꩐-꩙ꩻ-ꩽꪰꪲ-ꪴꪷꪸꪾ꪿꫁ꫫ-ꫯꫵ꫶ꯣ-ꯪ꯬꯭꯰-꯹ﬞ︀-️︠-︯︳︴﹍-﹏０-９＿･";
				const I = new RegExp("[" + C + "]"), D = new RegExp("[" + C + w + "]");
				C = w = null;
				const k = [
					0,
					11,
					2,
					25,
					2,
					18,
					2,
					1,
					2,
					14,
					3,
					13,
					35,
					122,
					70,
					52,
					268,
					28,
					4,
					48,
					48,
					31,
					14,
					29,
					6,
					37,
					11,
					29,
					3,
					35,
					5,
					7,
					2,
					4,
					43,
					157,
					19,
					35,
					5,
					35,
					5,
					39,
					9,
					51,
					13,
					10,
					2,
					14,
					2,
					6,
					2,
					1,
					2,
					10,
					2,
					14,
					2,
					6,
					2,
					1,
					4,
					51,
					13,
					310,
					10,
					21,
					11,
					7,
					25,
					5,
					2,
					41,
					2,
					8,
					70,
					5,
					3,
					0,
					2,
					43,
					2,
					1,
					4,
					0,
					3,
					22,
					11,
					22,
					10,
					30,
					66,
					18,
					2,
					1,
					11,
					21,
					11,
					25,
					71,
					55,
					7,
					1,
					65,
					0,
					16,
					3,
					2,
					2,
					2,
					28,
					43,
					28,
					4,
					28,
					36,
					7,
					2,
					27,
					28,
					53,
					11,
					21,
					11,
					18,
					14,
					17,
					111,
					72,
					56,
					50,
					14,
					50,
					14,
					35,
					39,
					27,
					10,
					22,
					251,
					41,
					7,
					1,
					17,
					2,
					60,
					28,
					11,
					0,
					9,
					21,
					43,
					17,
					47,
					20,
					28,
					22,
					13,
					52,
					58,
					1,
					3,
					0,
					14,
					44,
					33,
					24,
					27,
					35,
					30,
					0,
					3,
					0,
					9,
					34,
					4,
					0,
					13,
					47,
					15,
					3,
					22,
					0,
					2,
					0,
					36,
					17,
					2,
					24,
					20,
					1,
					64,
					6,
					2,
					0,
					2,
					3,
					2,
					14,
					2,
					9,
					8,
					46,
					39,
					7,
					3,
					1,
					3,
					21,
					2,
					6,
					2,
					1,
					2,
					4,
					4,
					0,
					19,
					0,
					13,
					4,
					31,
					9,
					2,
					0,
					3,
					0,
					2,
					37,
					2,
					0,
					26,
					0,
					2,
					0,
					45,
					52,
					19,
					3,
					21,
					2,
					31,
					47,
					21,
					1,
					2,
					0,
					185,
					46,
					42,
					3,
					37,
					47,
					21,
					0,
					60,
					42,
					14,
					0,
					72,
					26,
					38,
					6,
					186,
					43,
					117,
					63,
					32,
					7,
					3,
					0,
					3,
					7,
					2,
					1,
					2,
					23,
					16,
					0,
					2,
					0,
					95,
					7,
					3,
					38,
					17,
					0,
					2,
					0,
					29,
					0,
					11,
					39,
					8,
					0,
					22,
					0,
					12,
					45,
					20,
					0,
					19,
					72,
					200,
					32,
					32,
					8,
					2,
					36,
					18,
					0,
					50,
					29,
					113,
					6,
					2,
					1,
					2,
					37,
					22,
					0,
					26,
					5,
					2,
					1,
					2,
					31,
					15,
					0,
					328,
					18,
					16,
					0,
					2,
					12,
					2,
					33,
					125,
					0,
					80,
					921,
					103,
					110,
					18,
					195,
					2637,
					96,
					16,
					1071,
					18,
					5,
					26,
					3994,
					6,
					582,
					6842,
					29,
					1763,
					568,
					8,
					30,
					18,
					78,
					18,
					29,
					19,
					47,
					17,
					3,
					32,
					20,
					6,
					18,
					433,
					44,
					212,
					63,
					129,
					74,
					6,
					0,
					67,
					12,
					65,
					1,
					2,
					0,
					29,
					6135,
					9,
					1237,
					42,
					9,
					8936,
					3,
					2,
					6,
					2,
					1,
					2,
					290,
					16,
					0,
					30,
					2,
					3,
					0,
					15,
					3,
					9,
					395,
					2309,
					106,
					6,
					12,
					4,
					8,
					8,
					9,
					5991,
					84,
					2,
					70,
					2,
					1,
					3,
					0,
					3,
					1,
					3,
					3,
					2,
					11,
					2,
					0,
					2,
					6,
					2,
					64,
					2,
					3,
					3,
					7,
					2,
					6,
					2,
					27,
					2,
					3,
					2,
					4,
					2,
					0,
					4,
					6,
					2,
					339,
					3,
					24,
					2,
					24,
					2,
					30,
					2,
					24,
					2,
					30,
					2,
					24,
					2,
					30,
					2,
					24,
					2,
					30,
					2,
					24,
					2,
					7,
					1845,
					30,
					7,
					5,
					262,
					61,
					147,
					44,
					11,
					6,
					17,
					0,
					322,
					29,
					19,
					43,
					485,
					27,
					229,
					29,
					3,
					0,
					496,
					6,
					2,
					3,
					2,
					1,
					2,
					14,
					2,
					196,
					60,
					67,
					8,
					0,
					1205,
					3,
					2,
					26,
					2,
					1,
					2,
					0,
					3,
					0,
					2,
					9,
					2,
					3,
					2,
					0,
					2,
					0,
					7,
					0,
					5,
					0,
					2,
					0,
					2,
					0,
					2,
					2,
					2,
					1,
					2,
					0,
					3,
					0,
					2,
					0,
					2,
					0,
					2,
					0,
					2,
					0,
					2,
					1,
					2,
					0,
					3,
					3,
					2,
					6,
					2,
					3,
					2,
					3,
					2,
					0,
					2,
					9,
					2,
					16,
					6,
					2,
					2,
					4,
					2,
					16,
					4421,
					42719,
					33,
					4153,
					7,
					221,
					3,
					5761,
					15,
					7472,
					16,
					621,
					2467,
					541,
					1507,
					4938,
					6,
					4191
				], N = [
					509,
					0,
					227,
					0,
					150,
					4,
					294,
					9,
					1368,
					2,
					2,
					1,
					6,
					3,
					41,
					2,
					5,
					0,
					166,
					1,
					574,
					3,
					9,
					9,
					7,
					9,
					32,
					4,
					318,
					1,
					80,
					3,
					71,
					10,
					50,
					3,
					123,
					2,
					54,
					14,
					32,
					10,
					3,
					1,
					11,
					3,
					46,
					10,
					8,
					0,
					46,
					9,
					7,
					2,
					37,
					13,
					2,
					9,
					6,
					1,
					45,
					0,
					13,
					2,
					49,
					13,
					9,
					3,
					2,
					11,
					83,
					11,
					7,
					0,
					3,
					0,
					158,
					11,
					6,
					9,
					7,
					3,
					56,
					1,
					2,
					6,
					3,
					1,
					3,
					2,
					10,
					0,
					11,
					1,
					3,
					6,
					4,
					4,
					68,
					8,
					2,
					0,
					3,
					0,
					2,
					3,
					2,
					4,
					2,
					0,
					15,
					1,
					83,
					17,
					10,
					9,
					5,
					0,
					82,
					19,
					13,
					9,
					214,
					6,
					3,
					8,
					28,
					1,
					83,
					16,
					16,
					9,
					82,
					12,
					9,
					9,
					7,
					19,
					58,
					14,
					5,
					9,
					243,
					14,
					166,
					9,
					71,
					5,
					2,
					1,
					3,
					3,
					2,
					0,
					2,
					1,
					13,
					9,
					120,
					6,
					3,
					6,
					4,
					0,
					29,
					9,
					41,
					6,
					2,
					3,
					9,
					0,
					10,
					10,
					47,
					15,
					343,
					9,
					54,
					7,
					2,
					7,
					17,
					9,
					57,
					21,
					2,
					13,
					123,
					5,
					4,
					0,
					2,
					1,
					2,
					6,
					2,
					0,
					9,
					9,
					49,
					4,
					2,
					1,
					2,
					4,
					9,
					9,
					330,
					3,
					10,
					1,
					2,
					0,
					49,
					6,
					4,
					4,
					14,
					10,
					5350,
					0,
					7,
					14,
					11465,
					27,
					2343,
					9,
					87,
					9,
					39,
					4,
					60,
					6,
					26,
					9,
					535,
					9,
					470,
					0,
					2,
					54,
					8,
					3,
					82,
					0,
					12,
					1,
					19628,
					1,
					4178,
					9,
					519,
					45,
					3,
					22,
					543,
					4,
					4,
					5,
					9,
					7,
					3,
					6,
					31,
					3,
					149,
					2,
					1418,
					49,
					513,
					54,
					5,
					49,
					9,
					0,
					15,
					0,
					23,
					4,
					2,
					14,
					1361,
					6,
					2,
					16,
					3,
					6,
					2,
					1,
					2,
					4,
					101,
					0,
					161,
					6,
					10,
					9,
					357,
					0,
					62,
					13,
					499,
					13,
					245,
					1,
					2,
					9,
					726,
					6,
					110,
					6,
					6,
					9,
					4759,
					9,
					787719,
					239
				];
				function isInAstralSet(e, t) {
					let r = 65536;
					for (let n = 0, s = t.length; n < s; n += 2) {
						if (r += t[n], r > e) return !1;
						if (r += t[n + 1], r >= e) return !0;
					}
					return !1;
				}
				function isIdentifierStart(e) {
					return e < 65 ? 36 === e : e <= 90 || (e < 97 ? 95 === e : e <= 122 || (e <= 65535 ? e >= 170 && I.test(String.fromCharCode(e)) : isInAstralSet(e, k)));
				}
				function isIdentifierChar(e) {
					return e < 48 ? 36 === e : e < 58 || !(e < 65) && (e <= 90 || (e < 97 ? 95 === e : e <= 122 || (e <= 65535 ? e >= 170 && D.test(String.fromCharCode(e)) : isInAstralSet(e, k) || isInAstralSet(e, N))));
				}
				const O = [
					"implements",
					"interface",
					"let",
					"package",
					"private",
					"protected",
					"public",
					"static",
					"yield"
				], j = ["eval", "arguments"], F = new Set([
					"break",
					"case",
					"catch",
					"continue",
					"debugger",
					"default",
					"do",
					"else",
					"finally",
					"for",
					"function",
					"if",
					"return",
					"switch",
					"throw",
					"try",
					"var",
					"const",
					"while",
					"with",
					"new",
					"this",
					"super",
					"class",
					"extends",
					"export",
					"import",
					"null",
					"true",
					"false",
					"in",
					"instanceof",
					"typeof",
					"void",
					"delete"
				]), L = new Set(O), M = new Set(j);
				function isReservedWord(e, t) {
					return t && "await" === e || "enum" === e;
				}
				function isStrictReservedWord(e, t) {
					return isReservedWord(e, t) || L.has(e);
				}
				function isStrictBindOnlyReservedWord(e) {
					return M.has(e);
				}
				function isStrictBindReservedWord(e, t) {
					return isStrictReservedWord(e, t) || isStrictBindOnlyReservedWord(e);
				}
				const B = new Set([
					"break",
					"case",
					"catch",
					"continue",
					"debugger",
					"default",
					"do",
					"else",
					"finally",
					"for",
					"function",
					"if",
					"return",
					"switch",
					"throw",
					"try",
					"var",
					"const",
					"while",
					"with",
					"new",
					"this",
					"super",
					"class",
					"extends",
					"export",
					"import",
					"null",
					"true",
					"false",
					"in",
					"instanceof",
					"typeof",
					"void",
					"delete",
					"implements",
					"interface",
					"let",
					"package",
					"private",
					"protected",
					"public",
					"static",
					"yield",
					"eval",
					"arguments",
					"enum",
					"await"
				]);
				class Scope {
					constructor(e) {
						this.flags = 0, this.names = /* @__PURE__ */ new Map(), this.firstLexicalName = "", this.flags = e;
					}
				}
				class ScopeHandler {
					constructor(e, t) {
						this.parser = void 0, this.scopeStack = [], this.inModule = void 0, this.undefinedExports = /* @__PURE__ */ new Map(), this.parser = e, this.inModule = t;
					}
					get inTopLevel() {
						return (1 & this.currentScope().flags) > 0;
					}
					get inFunction() {
						return (2 & this.currentVarScopeFlags()) > 0;
					}
					get allowSuper() {
						return (16 & this.currentThisScopeFlags()) > 0;
					}
					get allowDirectSuper() {
						return (32 & this.currentThisScopeFlags()) > 0;
					}
					get allowNewTarget() {
						return (512 & this.currentThisScopeFlags()) > 0;
					}
					get inClass() {
						return (64 & this.currentThisScopeFlags()) > 0;
					}
					get inClassAndNotInNonArrowFunction() {
						const e = this.currentThisScopeFlags();
						return (64 & e) > 0 && !(2 & e);
					}
					get inStaticBlock() {
						for (let e = this.scopeStack.length - 1;; e--) {
							const { flags: t } = this.scopeStack[e];
							if (128 & t) return !0;
							if (1731 & t) return !1;
						}
					}
					get inNonArrowFunction() {
						return (2 & this.currentThisScopeFlags()) > 0;
					}
					get inBareCaseStatement() {
						return (256 & this.currentScope().flags) > 0;
					}
					get treatFunctionsAsVar() {
						return this.treatFunctionsAsVarInScope(this.currentScope());
					}
					createScope(e) {
						return new Scope(e);
					}
					enter(e) {
						this.scopeStack.push(this.createScope(e));
					}
					exit() {
						return this.scopeStack.pop().flags;
					}
					treatFunctionsAsVarInScope(e) {
						return !!(130 & e.flags || !this.parser.inModule && 1 & e.flags);
					}
					declareName(e, t, r) {
						let n = this.currentScope();
						if (8 & t || 16 & t) {
							this.checkRedeclarationInScope(n, e, t, r);
							let s = n.names.get(e) || 0;
							16 & t ? s |= 4 : (n.firstLexicalName || (n.firstLexicalName = e), s |= 2), n.names.set(e, s), 8 & t && this.maybeExportDefined(n, e);
						} else if (4 & t) for (let s = this.scopeStack.length - 1; s >= 0 && (n = this.scopeStack[s], this.checkRedeclarationInScope(n, e, t, r), n.names.set(e, 1 | (n.names.get(e) || 0)), this.maybeExportDefined(n, e), !(1667 & n.flags)); --s);
						this.parser.inModule && 1 & n.flags && this.undefinedExports.delete(e);
					}
					maybeExportDefined(e, t) {
						this.parser.inModule && 1 & e.flags && this.undefinedExports.delete(t);
					}
					checkRedeclarationInScope(e, t, r, n) {
						this.isRedeclaredInScope(e, t, r) && this.parser.raise(c.VarRedeclaration, n, { identifierName: t });
					}
					isRedeclaredInScope(e, t, r) {
						if (!(1 & r)) return !1;
						if (8 & r) return e.names.has(t);
						const n = e.names.get(t);
						return 16 & r ? (2 & n) > 0 || !this.treatFunctionsAsVarInScope(e) && (1 & n) > 0 : (2 & n) > 0 && !(8 & e.flags && e.firstLexicalName === t) || !this.treatFunctionsAsVarInScope(e) && (4 & n) > 0;
					}
					checkLocalExport(e) {
						const { name: t } = e;
						this.scopeStack[0].names.has(t) || this.undefinedExports.set(t, e.loc.start);
					}
					currentScope() {
						return this.scopeStack[this.scopeStack.length - 1];
					}
					currentVarScopeFlags() {
						for (let e = this.scopeStack.length - 1;; e--) {
							const { flags: t } = this.scopeStack[e];
							if (1667 & t) return t;
						}
					}
					currentThisScopeFlags() {
						for (let e = this.scopeStack.length - 1;; e--) {
							const { flags: t } = this.scopeStack[e];
							if (1731 & t && !(4 & t)) return t;
						}
					}
				}
				class FlowScope extends Scope {
					constructor(...e) {
						super(...e), this.declareFunctions = /* @__PURE__ */ new Set();
					}
				}
				class FlowScopeHandler extends ScopeHandler {
					createScope(e) {
						return new FlowScope(e);
					}
					declareName(e, t, r) {
						const n = this.currentScope();
						if (2048 & t) return this.checkRedeclarationInScope(n, e, t, r), this.maybeExportDefined(n, e), void n.declareFunctions.add(e);
						super.declareName(e, t, r);
					}
					isRedeclaredInScope(e, t, r) {
						if (super.isRedeclaredInScope(e, t, r)) return !0;
						if (2048 & r && !e.declareFunctions.has(t)) {
							const r = e.names.get(t);
							return (4 & r) > 0 || (2 & r) > 0;
						}
						return !1;
					}
					checkLocalExport(e) {
						this.scopeStack[0].declareFunctions.has(e.name) || super.checkLocalExport(e);
					}
				}
				const R = new Set([
					"_",
					"any",
					"bool",
					"boolean",
					"empty",
					"extends",
					"false",
					"interface",
					"mixed",
					"null",
					"number",
					"static",
					"string",
					"true",
					"typeof",
					"void"
				]), U = ParseErrorEnum`flow`({
					AmbiguousConditionalArrow: "Ambiguous expression: wrap the arrow functions in parentheses to disambiguate.",
					AmbiguousDeclareModuleKind: "Found both `declare module.exports` and `declare export` in the same module. Modules can only have 1 since they are either an ES module or they are a CommonJS module.",
					AssignReservedType: ({ reservedType: e }) => `Cannot overwrite reserved type ${e}.`,
					DeclareClassElement: "The `declare` modifier can only appear on class fields.",
					DeclareClassFieldInitializer: "Initializers are not allowed in fields with the `declare` modifier.",
					DuplicateDeclareModuleExports: "Duplicate `declare module.exports` statement.",
					EnumBooleanMemberNotInitialized: ({ memberName: e, enumName: t }) => `Boolean enum members need to be initialized. Use either \`${e} = true,\` or \`${e} = false,\` in enum \`${t}\`.`,
					EnumDuplicateMemberName: ({ memberName: e, enumName: t }) => `Enum member names need to be unique, but the name \`${e}\` has already been used before in enum \`${t}\`.`,
					EnumInconsistentMemberValues: ({ enumName: e }) => `Enum \`${e}\` has inconsistent member initializers. Either use no initializers, or consistently use literals (either booleans, numbers, or strings) for all member initializers.`,
					EnumInvalidExplicitType: ({ invalidEnumType: e, enumName: t }) => `Enum type \`${e}\` is not valid. Use one of \`boolean\`, \`number\`, \`string\`, or \`symbol\` in enum \`${t}\`.`,
					EnumInvalidExplicitTypeUnknownSupplied: ({ enumName: e }) => `Supplied enum type is not valid. Use one of \`boolean\`, \`number\`, \`string\`, or \`symbol\` in enum \`${e}\`.`,
					EnumInvalidMemberInitializerPrimaryType: ({ enumName: e, memberName: t, explicitType: r }) => `Enum \`${e}\` has type \`${r}\`, so the initializer of \`${t}\` needs to be a ${r} literal.`,
					EnumInvalidMemberInitializerSymbolType: ({ enumName: e, memberName: t }) => `Symbol enum members cannot be initialized. Use \`${t},\` in enum \`${e}\`.`,
					EnumInvalidMemberInitializerUnknownType: ({ enumName: e, memberName: t }) => `The enum member initializer for \`${t}\` needs to be a literal (either a boolean, number, or string) in enum \`${e}\`.`,
					EnumInvalidMemberName: ({ enumName: e, memberName: t, suggestion: r }) => `Enum member names cannot start with lowercase 'a' through 'z'. Instead of using \`${t}\`, consider using \`${r}\`, in enum \`${e}\`.`,
					EnumNumberMemberNotInitialized: ({ enumName: e, memberName: t }) => `Number enum members need to be initialized, e.g. \`${t} = 1\` in enum \`${e}\`.`,
					EnumStringMemberInconsistentlyInitialized: ({ enumName: e }) => `String enum members need to consistently either all use initializers, or use no initializers, in enum \`${e}\`.`,
					GetterMayNotHaveThisParam: "A getter cannot have a `this` parameter.",
					ImportReflectionHasImportType: "An `import module` declaration can not use `type` or `typeof` keyword.",
					ImportTypeShorthandOnlyInPureImport: "The `type` and `typeof` keywords on named imports can only be used on regular `import` statements. It cannot be used with `import type` or `import typeof` statements.",
					InexactInsideExact: "Explicit inexact syntax cannot appear inside an explicit exact object type.",
					InexactInsideNonObject: "Explicit inexact syntax cannot appear in class or interface definitions.",
					InexactVariance: "Explicit inexact syntax cannot have variance.",
					InvalidNonTypeImportInDeclareModule: "Imports within a `declare module` body must always be `import type` or `import typeof`.",
					MissingTypeParamDefault: "Type parameter declaration needs a default, since a preceding type parameter declaration has a default.",
					NestedDeclareModule: "`declare module` cannot be used inside another `declare module`.",
					NestedFlowComment: "Cannot have a flow comment inside another flow comment.",
					PatternIsOptional: Object.assign({ message: "A binding pattern parameter cannot be optional in an implementation signature." }, { reasonCode: "OptionalBindingPattern" }),
					SetterMayNotHaveThisParam: "A setter cannot have a `this` parameter.",
					SpreadVariance: "Spread properties cannot have variance.",
					ThisParamAnnotationRequired: "A type annotation is required for the `this` parameter.",
					ThisParamBannedInConstructor: "Constructors cannot have a `this` parameter; constructors don't bind `this` like other functions.",
					ThisParamMayNotBeOptional: "The `this` parameter cannot be optional.",
					ThisParamMustBeFirst: "The `this` parameter must be the first function parameter.",
					ThisParamNoDefault: "The `this` parameter may not have a default value.",
					TypeBeforeInitializer: "Type annotations must come before default assignments, e.g. instead of `age = 25: number` use `age: number = 25`.",
					TypeCastInPattern: "The type cast expression is expected to be wrapped with parenthesis.",
					UnexpectedExplicitInexactInObject: "Explicit inexact syntax must appear at the end of an inexact object.",
					UnexpectedReservedType: ({ reservedType: e }) => `Unexpected reserved type ${e}.`,
					UnexpectedReservedUnderscore: "`_` is only allowed as a type argument to call or new.",
					UnexpectedSpaceBetweenModuloChecks: "Spaces between `%` and `checks` are not allowed here.",
					UnexpectedSpreadType: "Spread operator cannot appear in class or interface definitions.",
					UnexpectedSubtractionOperand: "Unexpected token, expected \"number\" or \"bigint\".",
					UnexpectedTokenAfterTypeParameter: "Expected an arrow function after this type parameter declaration.",
					UnexpectedTypeParameterBeforeAsyncArrowFunction: "Type parameters must come after the async keyword, e.g. instead of `<T> async () => {}`, use `async <T>() => {}`.",
					UnsupportedDeclareExportKind: ({ unsupportedExportKind: e, suggestion: t }) => `\`declare export ${e}\` is not supported. Use \`${t}\` instead.`,
					UnsupportedStatementInDeclareModule: "Only declares and type imports are allowed inside declare module.",
					UnterminatedFlowComment: "Unterminated flow-comment."
				});
				function hasTypeImportKind(e) {
					return "type" === e.importKind || "typeof" === e.importKind;
				}
				const V = {
					const: "declare export var",
					let: "declare export var",
					type: "export type",
					interface: "export interface"
				};
				const $ = /\*?\s*@((?:no)?flow)\b/;
				const K = {
					__proto__: null,
					quot: "\"",
					amp: "&",
					apos: "'",
					lt: "<",
					gt: ">",
					nbsp: "\xA0",
					iexcl: "¡",
					cent: "¢",
					pound: "£",
					curren: "¤",
					yen: "¥",
					brvbar: "¦",
					sect: "§",
					uml: "¨",
					copy: "©",
					ordf: "ª",
					laquo: "«",
					not: "¬",
					shy: "­",
					reg: "®",
					macr: "¯",
					deg: "°",
					plusmn: "±",
					sup2: "²",
					sup3: "³",
					acute: "´",
					micro: "µ",
					para: "¶",
					middot: "·",
					cedil: "¸",
					sup1: "¹",
					ordm: "º",
					raquo: "»",
					frac14: "¼",
					frac12: "½",
					frac34: "¾",
					iquest: "¿",
					Agrave: "À",
					Aacute: "Á",
					Acirc: "Â",
					Atilde: "Ã",
					Auml: "Ä",
					Aring: "Å",
					AElig: "Æ",
					Ccedil: "Ç",
					Egrave: "È",
					Eacute: "É",
					Ecirc: "Ê",
					Euml: "Ë",
					Igrave: "Ì",
					Iacute: "Í",
					Icirc: "Î",
					Iuml: "Ï",
					ETH: "Ð",
					Ntilde: "Ñ",
					Ograve: "Ò",
					Oacute: "Ó",
					Ocirc: "Ô",
					Otilde: "Õ",
					Ouml: "Ö",
					times: "×",
					Oslash: "Ø",
					Ugrave: "Ù",
					Uacute: "Ú",
					Ucirc: "Û",
					Uuml: "Ü",
					Yacute: "Ý",
					THORN: "Þ",
					szlig: "ß",
					agrave: "à",
					aacute: "á",
					acirc: "â",
					atilde: "ã",
					auml: "ä",
					aring: "å",
					aelig: "æ",
					ccedil: "ç",
					egrave: "è",
					eacute: "é",
					ecirc: "ê",
					euml: "ë",
					igrave: "ì",
					iacute: "í",
					icirc: "î",
					iuml: "ï",
					eth: "ð",
					ntilde: "ñ",
					ograve: "ò",
					oacute: "ó",
					ocirc: "ô",
					otilde: "õ",
					ouml: "ö",
					divide: "÷",
					oslash: "ø",
					ugrave: "ù",
					uacute: "ú",
					ucirc: "û",
					uuml: "ü",
					yacute: "ý",
					thorn: "þ",
					yuml: "ÿ",
					OElig: "Œ",
					oelig: "œ",
					Scaron: "Š",
					scaron: "š",
					Yuml: "Ÿ",
					fnof: "ƒ",
					circ: "ˆ",
					tilde: "˜",
					Alpha: "Α",
					Beta: "Β",
					Gamma: "Γ",
					Delta: "Δ",
					Epsilon: "Ε",
					Zeta: "Ζ",
					Eta: "Η",
					Theta: "Θ",
					Iota: "Ι",
					Kappa: "Κ",
					Lambda: "Λ",
					Mu: "Μ",
					Nu: "Ν",
					Xi: "Ξ",
					Omicron: "Ο",
					Pi: "Π",
					Rho: "Ρ",
					Sigma: "Σ",
					Tau: "Τ",
					Upsilon: "Υ",
					Phi: "Φ",
					Chi: "Χ",
					Psi: "Ψ",
					Omega: "Ω",
					alpha: "α",
					beta: "β",
					gamma: "γ",
					delta: "δ",
					epsilon: "ε",
					zeta: "ζ",
					eta: "η",
					theta: "θ",
					iota: "ι",
					kappa: "κ",
					lambda: "λ",
					mu: "μ",
					nu: "ν",
					xi: "ξ",
					omicron: "ο",
					pi: "π",
					rho: "ρ",
					sigmaf: "ς",
					sigma: "σ",
					tau: "τ",
					upsilon: "υ",
					phi: "φ",
					chi: "χ",
					psi: "ψ",
					omega: "ω",
					thetasym: "ϑ",
					upsih: "ϒ",
					piv: "ϖ",
					ensp: " ",
					emsp: " ",
					thinsp: " ",
					zwnj: "‌",
					zwj: "‍",
					lrm: "‎",
					rlm: "‏",
					ndash: "–",
					mdash: "—",
					lsquo: "‘",
					rsquo: "’",
					sbquo: "‚",
					ldquo: "“",
					rdquo: "”",
					bdquo: "„",
					dagger: "†",
					Dagger: "‡",
					bull: "•",
					hellip: "…",
					permil: "‰",
					prime: "′",
					Prime: "″",
					lsaquo: "‹",
					rsaquo: "›",
					oline: "‾",
					frasl: "⁄",
					euro: "€",
					image: "ℑ",
					weierp: "℘",
					real: "ℜ",
					trade: "™",
					alefsym: "ℵ",
					larr: "←",
					uarr: "↑",
					rarr: "→",
					darr: "↓",
					harr: "↔",
					crarr: "↵",
					lArr: "⇐",
					uArr: "⇑",
					rArr: "⇒",
					dArr: "⇓",
					hArr: "⇔",
					forall: "∀",
					part: "∂",
					exist: "∃",
					empty: "∅",
					nabla: "∇",
					isin: "∈",
					notin: "∉",
					ni: "∋",
					prod: "∏",
					sum: "∑",
					minus: "−",
					lowast: "∗",
					radic: "√",
					prop: "∝",
					infin: "∞",
					ang: "∠",
					and: "∧",
					or: "∨",
					cap: "∩",
					cup: "∪",
					int: "∫",
					there4: "∴",
					sim: "∼",
					cong: "≅",
					asymp: "≈",
					ne: "≠",
					equiv: "≡",
					le: "≤",
					ge: "≥",
					sub: "⊂",
					sup: "⊃",
					nsub: "⊄",
					sube: "⊆",
					supe: "⊇",
					oplus: "⊕",
					otimes: "⊗",
					perp: "⊥",
					sdot: "⋅",
					lceil: "⌈",
					rceil: "⌉",
					lfloor: "⌊",
					rfloor: "⌋",
					lang: "〈",
					rang: "〉",
					loz: "◊",
					spades: "♠",
					clubs: "♣",
					hearts: "♥",
					diams: "♦"
				}, W = new RegExp(/\r\n|[\r\n\u2028\u2029]/.source, "g");
				function isNewLine(e) {
					switch (e) {
						case 10:
						case 13:
						case 8232:
						case 8233: return !0;
						default: return !1;
					}
				}
				function hasNewLine(e, t, r) {
					for (let n = t; n < r; n++) if (isNewLine(e.charCodeAt(n))) return !0;
					return !1;
				}
				const q = /(?:\s|\/\/.*|\/\*[^]*?\*\/)*/g, H = /(?:[^\S\n\r\u2028\u2029]|\/\/.*|\/\*.*?\*\/)*/g;
				function isWhitespace(e) {
					switch (e) {
						case 9:
						case 11:
						case 12:
						case 32:
						case 160:
						case 5760:
						case 8192:
						case 8193:
						case 8194:
						case 8195:
						case 8196:
						case 8197:
						case 8198:
						case 8199:
						case 8200:
						case 8201:
						case 8202:
						case 8239:
						case 8287:
						case 12288:
						case 65279: return !0;
						default: return !1;
					}
				}
				const z = ParseErrorEnum`jsx`({
					AttributeIsEmpty: "JSX attributes must only be assigned a non-empty expression.",
					MissingClosingTagElement: ({ openingTagName: e }) => `Expected corresponding JSX closing tag for <${e}>.`,
					MissingClosingTagFragment: "Expected corresponding JSX closing tag for <>.",
					UnexpectedSequenceExpression: "Sequence expressions cannot be directly nested inside JSX. Did you mean to wrap it in parentheses (...)?",
					UnexpectedToken: ({ unexpected: e, HTMLEntity: t }) => `Unexpected token \`${e}\`. Did you mean \`${t}\` or \`{'${e}'}\`?`,
					UnsupportedJsxValue: "JSX value should be either an expression or a quoted JSX text.",
					UnterminatedJsxContent: "Unterminated JSX contents.",
					UnwrappedAdjacentJSXElements: "Adjacent JSX elements must be wrapped in an enclosing tag. Did you want a JSX fragment <>...</>?"
				});
				function isFragment(e) {
					return !!e && ("JSXOpeningFragment" === e.type || "JSXClosingFragment" === e.type);
				}
				function getQualifiedJSXName(e) {
					if ("JSXIdentifier" === e.type) return e.name;
					if ("JSXNamespacedName" === e.type) return e.namespace.name + ":" + e.name.name;
					if ("JSXMemberExpression" === e.type) return getQualifiedJSXName(e.object) + "." + getQualifiedJSXName(e.property);
					throw new Error("Node had unexpected type: " + e.type);
				}
				class TypeScriptScope extends Scope {
					constructor(...e) {
						super(...e), this.tsNames = /* @__PURE__ */ new Map();
					}
				}
				class TypeScriptScopeHandler extends ScopeHandler {
					constructor(...e) {
						super(...e), this.importsStack = [];
					}
					createScope(e) {
						return this.importsStack.push(/* @__PURE__ */ new Set()), new TypeScriptScope(e);
					}
					enter(e) {
						1024 === e && this.importsStack.push(/* @__PURE__ */ new Set()), super.enter(e);
					}
					exit() {
						const e = super.exit();
						return 1024 === e && this.importsStack.pop(), e;
					}
					hasImport(e, t) {
						const r = this.importsStack.length;
						if (this.importsStack[r - 1].has(e)) return !0;
						if (!t && r > 1) {
							for (let t = 0; t < r - 1; t++) if (this.importsStack[t].has(e)) return !0;
						}
						return !1;
					}
					declareName(e, t, r) {
						if (4096 & t) return this.hasImport(e, !0) && this.parser.raise(c.VarRedeclaration, r, { identifierName: e }), void this.importsStack[this.importsStack.length - 1].add(e);
						const n = this.currentScope();
						let s = n.tsNames.get(e) || 0;
						if (1024 & t) return this.maybeExportDefined(n, e), void n.tsNames.set(e, 16 | s);
						super.declareName(e, t, r), 2 & t && (1 & t || (this.checkRedeclarationInScope(n, e, t, r), this.maybeExportDefined(n, e)), s |= 1), 256 & t && (s |= 2), 512 & t && (s |= 4), 128 & t && (s |= 8), s && n.tsNames.set(e, s);
					}
					isRedeclaredInScope(e, t, r) {
						const n = e.tsNames.get(t);
						if ((2 & n) > 0) {
							if (256 & r) return !!(512 & r) !== (4 & n) > 0;
							return !0;
						}
						return 128 & r && (8 & n) > 0 ? !!(2 & e.names.get(t)) && !!(1 & r) : !!(2 & r && (1 & n) > 0) || super.isRedeclaredInScope(e, t, r);
					}
					checkLocalExport(e) {
						const { name: t } = e;
						if (this.hasImport(t)) return;
						for (let e = this.scopeStack.length - 1; e >= 0; e--) {
							const r = this.scopeStack[e].tsNames.get(t);
							if ((1 & r) > 0 || (16 & r) > 0) return;
						}
						super.checkLocalExport(e);
					}
				}
				class ProductionParameterHandler {
					constructor() {
						this.stacks = [];
					}
					enter(e) {
						this.stacks.push(e);
					}
					exit() {
						this.stacks.pop();
					}
					currentFlags() {
						return this.stacks[this.stacks.length - 1];
					}
					get hasAwait() {
						return (2 & this.currentFlags()) > 0;
					}
					get hasYield() {
						return (1 & this.currentFlags()) > 0;
					}
					get hasReturn() {
						return (4 & this.currentFlags()) > 0;
					}
					get hasIn() {
						return (8 & this.currentFlags()) > 0;
					}
				}
				function functionFlags(e, t) {
					return (e ? 2 : 0) | (t ? 1 : 0);
				}
				class BaseParser {
					constructor() {
						this.sawUnambiguousESM = !1, this.ambiguousScriptDifferentAst = !1;
					}
					sourceToOffsetPos(e) {
						return e + this.startIndex;
					}
					offsetToSourcePos(e) {
						return e - this.startIndex;
					}
					hasPlugin(e) {
						if ("string" == typeof e) return this.plugins.has(e);
						{
							const [t, r] = e;
							if (!this.hasPlugin(t)) return !1;
							const n = this.plugins.get(t);
							for (const e of Object.keys(r)) if ((null == n ? void 0 : n[e]) !== r[e]) return !1;
							return !0;
						}
					}
					getPluginOption(e, t) {
						var r;
						return null == (r = this.plugins.get(e)) ? void 0 : r[t];
					}
				}
				function setTrailingComments(e, t) {
					void 0 === e.trailingComments ? e.trailingComments = t : e.trailingComments.unshift(...t);
				}
				function setInnerComments(e, t) {
					void 0 === e.innerComments ? e.innerComments = t : e.innerComments.unshift(...t);
				}
				function adjustInnerComments(e, t, r) {
					let n = null, s = t.length;
					for (; null === n && s > 0;) n = t[--s];
					null === n || n.start > r.start ? setInnerComments(e, r.comments) : setTrailingComments(n, r.comments);
				}
				class CommentsParser extends BaseParser {
					addComment(e) {
						this.filename && (e.loc.filename = this.filename);
						const { commentsLen: t } = this.state;
						this.comments.length !== t && (this.comments.length = t), this.comments.push(e), this.state.commentsLen++;
					}
					processComment(e) {
						const { commentStack: t } = this.state, r = t.length;
						if (0 === r) return;
						let n = r - 1;
						const s = t[n];
						s.start === e.end && (s.leadingNode = e, n--);
						const { start: i } = e;
						for (; n >= 0; n--) {
							const r = t[n], s = r.end;
							if (!(s > i)) {
								s === i && (r.trailingNode = e);
								break;
							}
							r.containingNode = e, this.finalizeComment(r), t.splice(n, 1);
						}
					}
					finalizeComment(e) {
						var t;
						const { comments: r } = e;
						if (null !== e.leadingNode || null !== e.trailingNode) null !== e.leadingNode && setTrailingComments(e.leadingNode, r), null !== e.trailingNode && function(e, t) {
							void 0 === e.leadingComments ? e.leadingComments = t : e.leadingComments.unshift(...t);
						}(e.trailingNode, r);
						else {
							const { containingNode: n, start: s } = e;
							if (44 === this.input.charCodeAt(this.offsetToSourcePos(s) - 1)) switch (n.type) {
								case "ObjectExpression":
								case "ObjectPattern":
								case "RecordExpression":
									adjustInnerComments(n, n.properties, e);
									break;
								case "CallExpression":
								case "OptionalCallExpression":
									adjustInnerComments(n, n.arguments, e);
									break;
								case "ImportExpression":
									adjustInnerComments(n, [n.source, null != (t = n.options) ? t : null], e);
									break;
								case "FunctionDeclaration":
								case "FunctionExpression":
								case "ArrowFunctionExpression":
								case "ObjectMethod":
								case "ClassMethod":
								case "ClassPrivateMethod":
									adjustInnerComments(n, n.params, e);
									break;
								case "ArrayExpression":
								case "ArrayPattern":
								case "TupleExpression":
									adjustInnerComments(n, n.elements, e);
									break;
								case "ExportNamedDeclaration":
								case "ImportDeclaration":
									adjustInnerComments(n, n.specifiers, e);
									break;
								case "TSEnumDeclaration":
								case "TSEnumBody":
									adjustInnerComments(n, n.members, e);
									break;
								default: setInnerComments(n, r);
							}
							else setInnerComments(n, r);
						}
					}
					finalizeRemainingComments() {
						const { commentStack: e } = this.state;
						for (let t = e.length - 1; t >= 0; t--) this.finalizeComment(e[t]);
						this.state.commentStack = [];
					}
					resetPreviousNodeTrailingComments(e) {
						const { commentStack: t } = this.state, { length: r } = t;
						if (0 === r) return;
						const n = t[r - 1];
						n.leadingNode === e && (n.leadingNode = null);
					}
					takeSurroundingComments(e, t, r) {
						const { commentStack: n } = this.state, s = n.length;
						if (0 === s) return;
						let i = s - 1;
						for (; i >= 0; i--) {
							const s = n[i], o = s.end;
							if (s.start === r) s.leadingNode = e;
							else if (o === t) s.trailingNode = e;
							else if (o < t) break;
						}
					}
				}
				class State {
					constructor() {
						this.flags = 1024, this.startIndex = void 0, this.curLine = void 0, this.lineStart = void 0, this.startLoc = void 0, this.endLoc = void 0, this.errors = [], this.potentialArrowAt = -1, this.noArrowAt = [], this.noArrowParamsConversionAt = [], this.topicContext = {
							maxNumOfResolvableTopics: 0,
							maxTopicIndex: null
						}, this.labels = [], this.commentsLen = 0, this.commentStack = [], this.pos = 0, this.type = 140, this.value = null, this.start = 0, this.end = 0, this.lastTokEndLoc = null, this.lastTokStartLoc = null, this.context = [d.brace], this.firstInvalidTemplateEscapePos = null, this.strictErrors = /* @__PURE__ */ new Map(), this.tokensLength = 0;
					}
					get strict() {
						return (1 & this.flags) > 0;
					}
					set strict(e) {
						e ? this.flags |= 1 : this.flags &= -2;
					}
					init({ strictMode: e, sourceType: t, startIndex: r, startLine: n, startColumn: s }) {
						this.strict = !1 !== e && (!0 === e || "module" === t), this.startIndex = r, this.curLine = n, this.lineStart = -s, this.startLoc = this.endLoc = new Position(n, s, r);
					}
					get maybeInArrowParameters() {
						return (2 & this.flags) > 0;
					}
					set maybeInArrowParameters(e) {
						e ? this.flags |= 2 : this.flags &= -3;
					}
					get inType() {
						return (4 & this.flags) > 0;
					}
					set inType(e) {
						e ? this.flags |= 4 : this.flags &= -5;
					}
					get noAnonFunctionType() {
						return (8 & this.flags) > 0;
					}
					set noAnonFunctionType(e) {
						e ? this.flags |= 8 : this.flags &= -9;
					}
					get hasFlowComment() {
						return (16 & this.flags) > 0;
					}
					set hasFlowComment(e) {
						e ? this.flags |= 16 : this.flags &= -17;
					}
					get isAmbientContext() {
						return (32 & this.flags) > 0;
					}
					set isAmbientContext(e) {
						e ? this.flags |= 32 : this.flags &= -33;
					}
					get inAbstractClass() {
						return (64 & this.flags) > 0;
					}
					set inAbstractClass(e) {
						e ? this.flags |= 64 : this.flags &= -65;
					}
					get inDisallowConditionalTypesContext() {
						return (128 & this.flags) > 0;
					}
					set inDisallowConditionalTypesContext(e) {
						e ? this.flags |= 128 : this.flags &= -129;
					}
					get soloAwait() {
						return (256 & this.flags) > 0;
					}
					set soloAwait(e) {
						e ? this.flags |= 256 : this.flags &= -257;
					}
					get inFSharpPipelineDirectBody() {
						return (512 & this.flags) > 0;
					}
					set inFSharpPipelineDirectBody(e) {
						e ? this.flags |= 512 : this.flags &= -513;
					}
					get canStartJSXElement() {
						return (1024 & this.flags) > 0;
					}
					set canStartJSXElement(e) {
						e ? this.flags |= 1024 : this.flags &= -1025;
					}
					get containsEsc() {
						return (2048 & this.flags) > 0;
					}
					set containsEsc(e) {
						e ? this.flags |= 2048 : this.flags &= -2049;
					}
					get hasTopLevelAwait() {
						return (4096 & this.flags) > 0;
					}
					set hasTopLevelAwait(e) {
						e ? this.flags |= 4096 : this.flags &= -4097;
					}
					curPosition() {
						return new Position(this.curLine, this.pos - this.lineStart, this.pos + this.startIndex);
					}
					clone() {
						const e = new State();
						return e.flags = this.flags, e.startIndex = this.startIndex, e.curLine = this.curLine, e.lineStart = this.lineStart, e.startLoc = this.startLoc, e.endLoc = this.endLoc, e.errors = this.errors.slice(), e.potentialArrowAt = this.potentialArrowAt, e.noArrowAt = this.noArrowAt.slice(), e.noArrowParamsConversionAt = this.noArrowParamsConversionAt.slice(), e.topicContext = this.topicContext, e.labels = this.labels.slice(), e.commentsLen = this.commentsLen, e.commentStack = this.commentStack.slice(), e.pos = this.pos, e.type = this.type, e.value = this.value, e.start = this.start, e.end = this.end, e.lastTokEndLoc = this.lastTokEndLoc, e.lastTokStartLoc = this.lastTokStartLoc, e.context = this.context.slice(), e.firstInvalidTemplateEscapePos = this.firstInvalidTemplateEscapePos, e.strictErrors = this.strictErrors, e.tokensLength = this.tokensLength, e;
					}
				}
				var _isDigit = function(e) {
					return e >= 48 && e <= 57;
				};
				const G = {
					decBinOct: new Set([
						46,
						66,
						69,
						79,
						95,
						98,
						101,
						111
					]),
					hex: new Set([
						46,
						88,
						95,
						120
					])
				}, X = {
					bin: (e) => 48 === e || 49 === e,
					oct: (e) => e >= 48 && e <= 55,
					dec: (e) => e >= 48 && e <= 57,
					hex: (e) => e >= 48 && e <= 57 || e >= 65 && e <= 70 || e >= 97 && e <= 102
				};
				function readStringContents(e, t, r, n, s, i) {
					const o = r, a = n, l = s;
					let p = "", c = null, u = r;
					const { length: d } = t;
					for (;;) {
						if (r >= d) {
							i.unterminated(o, a, l), p += t.slice(u, r);
							break;
						}
						const h = t.charCodeAt(r);
						if (isStringEnd(e, h, t, r)) {
							p += t.slice(u, r);
							break;
						}
						if (92 === h) {
							p += t.slice(u, r);
							const o = readEscapedChar(t, r, n, s, "template" === e, i);
							null !== o.ch || c ? p += o.ch : c = {
								pos: r,
								lineStart: n,
								curLine: s
							}, {pos: r, lineStart: n, curLine: s} = o, u = r;
						} else 8232 === h || 8233 === h ? (++s, n = ++r) : 10 === h || 13 === h ? "template" === e ? (p += t.slice(u, r) + "\n", ++r, 13 === h && 10 === t.charCodeAt(r) && ++r, ++s, u = n = r) : i.unterminated(o, a, l) : ++r;
					}
					return {
						pos: r,
						str: p,
						firstInvalidLoc: c,
						lineStart: n,
						curLine: s,
						containsInvalid: !!c
					};
				}
				function isStringEnd(e, t, r, n) {
					return "template" === e ? 96 === t || 36 === t && 123 === r.charCodeAt(n + 1) : t === ("double" === e ? 34 : 39);
				}
				function readEscapedChar(e, t, r, n, s, i) {
					const o = !s;
					t++;
					const res = (e) => ({
						pos: t,
						ch: e,
						lineStart: r,
						curLine: n
					}), a = e.charCodeAt(t++);
					switch (a) {
						case 110: return res("\n");
						case 114: return res("\r");
						case 120: {
							let s;
							return {code: s, pos: t} = readHexChar(e, t, r, n, 2, !1, o, i), res(null === s ? null : String.fromCharCode(s));
						}
						case 117: {
							let s;
							return {code: s, pos: t} = readCodePoint(e, t, r, n, o, i), res(null === s ? null : String.fromCodePoint(s));
						}
						case 116: return res("	");
						case 98: return res("\b");
						case 118: return res("\v");
						case 102: return res("\f");
						case 13: 10 === e.charCodeAt(t) && ++t;
						case 10: r = t, ++n;
						case 8232:
						case 8233: return res("");
						case 56:
						case 57:
							if (s) return res(null);
							i.strictNumericEscape(t - 1, r, n);
						default:
							if (a >= 48 && a <= 55) {
								const o = t - 1;
								let a = /^[0-7]+/.exec(e.slice(o, t + 2))[0], l = parseInt(a, 8);
								l > 255 && (a = a.slice(0, -1), l = parseInt(a, 8)), t += a.length - 1;
								const p = e.charCodeAt(t);
								if ("0" !== a || 56 === p || 57 === p) {
									if (s) return res(null);
									i.strictNumericEscape(o, r, n);
								}
								return res(String.fromCharCode(l));
							}
							return res(String.fromCharCode(a));
					}
				}
				function readHexChar(e, t, r, n, s, i, o, a) {
					const l = t;
					let p;
					return {n: p, pos: t} = readInt(e, t, r, n, 16, s, i, !1, a, !o), null === p && (o ? a.invalidEscapeSequence(l, r, n) : t = l - 1), {
						code: p,
						pos: t
					};
				}
				function readInt(e, t, r, n, s, i, o, a, l, p) {
					const c = t, u = 16 === s ? G.hex : G.decBinOct, d = 16 === s ? X.hex : 10 === s ? X.dec : 8 === s ? X.oct : X.bin;
					let h = !1, m = 0;
					for (let c = 0, f = null == i ? Infinity : i; c < f; ++c) {
						const i = e.charCodeAt(t);
						let c;
						if (95 === i && "bail" !== a) {
							const s = e.charCodeAt(t - 1), i = e.charCodeAt(t + 1);
							if (a) {
								if (Number.isNaN(i) || !d(i) || u.has(s) || u.has(i)) {
									if (p) return {
										n: null,
										pos: t
									};
									l.unexpectedNumericSeparator(t, r, n);
								}
							} else {
								if (p) return {
									n: null,
									pos: t
								};
								l.numericSeparatorInEscapeSequence(t, r, n);
							}
							++t;
							continue;
						}
						if (c = i >= 97 ? i - 97 + 10 : i >= 65 ? i - 65 + 10 : _isDigit(i) ? i - 48 : Infinity, c >= s) {
							if (c <= 9 && p) return {
								n: null,
								pos: t
							};
							if (c <= 9 && l.invalidDigit(t, r, n, s)) c = 0;
							else {
								if (!o) break;
								c = 0, h = !0;
							}
						}
						++t, m = m * s + c;
					}
					return t === c || null != i && t - c !== i || h ? {
						n: null,
						pos: t
					} : {
						n: m,
						pos: t
					};
				}
				function readCodePoint(e, t, r, n, s, i) {
					let o;
					if (123 === e.charCodeAt(t)) {
						if (++t, {code: o, pos: t} = readHexChar(e, t, r, n, e.indexOf("}", t) - t, !0, s, i), ++t, null !== o && o > 1114111) {
							if (!s) return {
								code: null,
								pos: t
							};
							i.invalidCodePoint(t, r, n);
						}
					} else ({code: o, pos: t} = readHexChar(e, t, r, n, 4, !1, s, i));
					return {
						code: o,
						pos: t
					};
				}
				function buildPosition(e, t, r) {
					return new Position(r, e - t, e);
				}
				const J = new Set([
					103,
					109,
					115,
					105,
					121,
					117,
					100,
					118
				]);
				class Token {
					constructor(e) {
						const t = e.startIndex || 0;
						this.type = e.type, this.value = e.value, this.start = t + e.start, this.end = t + e.end, this.loc = new SourceLocation(e.startLoc, e.endLoc);
					}
				}
				class Tokenizer extends CommentsParser {
					constructor(e, t) {
						super(), this.isLookahead = void 0, this.tokens = [], this.errorHandlers_readInt = {
							invalidDigit: (e, t, r, n) => !!(2048 & this.optionFlags) && (this.raise(c.InvalidDigit, buildPosition(e, t, r), { radix: n }), !0),
							numericSeparatorInEscapeSequence: this.errorBuilder(c.NumericSeparatorInEscapeSequence),
							unexpectedNumericSeparator: this.errorBuilder(c.UnexpectedNumericSeparator)
						}, this.errorHandlers_readCodePoint = Object.assign({}, this.errorHandlers_readInt, {
							invalidEscapeSequence: this.errorBuilder(c.InvalidEscapeSequence),
							invalidCodePoint: this.errorBuilder(c.InvalidCodePoint)
						}), this.errorHandlers_readStringContents_string = Object.assign({}, this.errorHandlers_readCodePoint, {
							strictNumericEscape: (e, t, r) => {
								this.recordStrictModeErrors(c.StrictNumericEscape, buildPosition(e, t, r));
							},
							unterminated: (e, t, r) => {
								throw this.raise(c.UnterminatedString, buildPosition(e - 1, t, r));
							}
						}), this.errorHandlers_readStringContents_template = Object.assign({}, this.errorHandlers_readCodePoint, {
							strictNumericEscape: this.errorBuilder(c.StrictNumericEscape),
							unterminated: (e, t, r) => {
								throw this.raise(c.UnterminatedTemplate, buildPosition(e, t, r));
							}
						}), this.state = new State(), this.state.init(e), this.input = t, this.length = t.length, this.comments = [], this.isLookahead = !1;
					}
					pushToken(e) {
						this.tokens.length = this.state.tokensLength, this.tokens.push(e), ++this.state.tokensLength;
					}
					next() {
						this.checkKeywordEscapes(), 256 & this.optionFlags && this.pushToken(new Token(this.state)), this.state.lastTokEndLoc = this.state.endLoc, this.state.lastTokStartLoc = this.state.startLoc, this.nextToken();
					}
					eat(e) {
						return !!this.match(e) && (this.next(), !0);
					}
					match(e) {
						return this.state.type === e;
					}
					createLookaheadState(e) {
						return {
							pos: e.pos,
							value: null,
							type: e.type,
							start: e.start,
							end: e.end,
							context: [this.curContext()],
							inType: e.inType,
							startLoc: e.startLoc,
							lastTokEndLoc: e.lastTokEndLoc,
							curLine: e.curLine,
							lineStart: e.lineStart,
							curPosition: e.curPosition
						};
					}
					lookahead() {
						const e = this.state;
						this.state = this.createLookaheadState(e), this.isLookahead = !0, this.nextToken(), this.isLookahead = !1;
						const t = this.state;
						return this.state = e, t;
					}
					nextTokenStart() {
						return this.nextTokenStartSince(this.state.pos);
					}
					nextTokenStartSince(e) {
						return q.lastIndex = e, q.test(this.input) ? q.lastIndex : e;
					}
					lookaheadCharCode() {
						return this.lookaheadCharCodeSince(this.state.pos);
					}
					lookaheadCharCodeSince(e) {
						return this.input.charCodeAt(this.nextTokenStartSince(e));
					}
					nextTokenInLineStart() {
						return this.nextTokenInLineStartSince(this.state.pos);
					}
					nextTokenInLineStartSince(e) {
						return H.lastIndex = e, H.test(this.input) ? H.lastIndex : e;
					}
					lookaheadInLineCharCode() {
						return this.input.charCodeAt(this.nextTokenInLineStart());
					}
					codePointAtPos(e) {
						let t = this.input.charCodeAt(e);
						if (55296 == (64512 & t) && ++e < this.input.length) {
							const r = this.input.charCodeAt(e);
							56320 == (64512 & r) && (t = 65536 + ((1023 & t) << 10) + (1023 & r));
						}
						return t;
					}
					setStrict(e) {
						this.state.strict = e, e && (this.state.strictErrors.forEach(([e, t]) => this.raise(e, t)), this.state.strictErrors.clear());
					}
					curContext() {
						return this.state.context[this.state.context.length - 1];
					}
					nextToken() {
						this.skipSpace(), this.state.start = this.state.pos, this.isLookahead || (this.state.startLoc = this.state.curPosition()), this.state.pos >= this.length ? this.finishToken(140) : this.getTokenFromCode(this.codePointAtPos(this.state.pos));
					}
					skipBlockComment(e) {
						let t;
						this.isLookahead || (t = this.state.curPosition());
						const r = this.state.pos, n = this.input.indexOf(e, r + 2);
						if (-1 === n) throw this.raise(c.UnterminatedComment, this.state.curPosition());
						for (this.state.pos = n + e.length, W.lastIndex = r + 2; W.test(this.input) && W.lastIndex <= n;) ++this.state.curLine, this.state.lineStart = W.lastIndex;
						if (this.isLookahead) return;
						const s = {
							type: "CommentBlock",
							value: this.input.slice(r + 2, n),
							start: this.sourceToOffsetPos(r),
							end: this.sourceToOffsetPos(n + e.length),
							loc: new SourceLocation(t, this.state.curPosition())
						};
						return 256 & this.optionFlags && this.pushToken(s), s;
					}
					skipLineComment(e) {
						const t = this.state.pos;
						let r;
						this.isLookahead || (r = this.state.curPosition());
						let n = this.input.charCodeAt(this.state.pos += e);
						if (this.state.pos < this.length) for (; !isNewLine(n) && ++this.state.pos < this.length;) n = this.input.charCodeAt(this.state.pos);
						if (this.isLookahead) return;
						const s = this.state.pos, i = {
							type: "CommentLine",
							value: this.input.slice(t + e, s),
							start: this.sourceToOffsetPos(t),
							end: this.sourceToOffsetPos(s),
							loc: new SourceLocation(r, this.state.curPosition())
						};
						return 256 & this.optionFlags && this.pushToken(i), i;
					}
					skipSpace() {
						const e = this.state.pos, t = 4096 & this.optionFlags ? [] : null;
						e: for (; this.state.pos < this.length;) {
							const r = this.input.charCodeAt(this.state.pos);
							switch (r) {
								case 32:
								case 160:
								case 9:
									++this.state.pos;
									break;
								case 13: 10 === this.input.charCodeAt(this.state.pos + 1) && ++this.state.pos;
								case 10:
								case 8232:
								case 8233:
									++this.state.pos, ++this.state.curLine, this.state.lineStart = this.state.pos;
									break;
								case 47:
									switch (this.input.charCodeAt(this.state.pos + 1)) {
										case 42: {
											const e = this.skipBlockComment("*/");
											void 0 !== e && (this.addComment(e), t?.push(e));
											break;
										}
										case 47: {
											const e = this.skipLineComment(2);
											void 0 !== e && (this.addComment(e), t?.push(e));
											break;
										}
										default: break e;
									}
									break;
								default: if (isWhitespace(r)) ++this.state.pos;
								else if (45 === r && !this.inModule && 8192 & this.optionFlags) {
									const r = this.state.pos;
									if (45 !== this.input.charCodeAt(r + 1) || 62 !== this.input.charCodeAt(r + 2) || !(0 === e || this.state.lineStart > e)) break e;
									{
										const e = this.skipLineComment(3);
										void 0 !== e && (this.addComment(e), t?.push(e));
									}
								} else {
									if (60 !== r || this.inModule || !(8192 & this.optionFlags)) break e;
									{
										const e = this.state.pos;
										if (33 !== this.input.charCodeAt(e + 1) || 45 !== this.input.charCodeAt(e + 2) || 45 !== this.input.charCodeAt(e + 3)) break e;
										{
											const e = this.skipLineComment(4);
											void 0 !== e && (this.addComment(e), t?.push(e));
										}
									}
								}
							}
						}
						if ((null == t ? void 0 : t.length) > 0) {
							const r = this.state.pos, n = {
								start: this.sourceToOffsetPos(e),
								end: this.sourceToOffsetPos(r),
								comments: t,
								leadingNode: null,
								trailingNode: null,
								containingNode: null
							};
							this.state.commentStack.push(n);
						}
					}
					finishToken(e, t) {
						this.state.end = this.state.pos, this.state.endLoc = this.state.curPosition();
						const r = this.state.type;
						this.state.type = e, this.state.value = t, this.isLookahead || this.updateContext(r);
					}
					replaceToken(e) {
						this.state.type = e, this.updateContext();
					}
					readToken_numberSign() {
						if (0 === this.state.pos && this.readToken_interpreter()) return;
						const e = this.state.pos + 1, t = this.codePointAtPos(e);
						if (t >= 48 && t <= 57) throw this.raise(c.UnexpectedDigitAfterHash, this.state.curPosition());
						if (123 === t || 91 === t && this.hasPlugin("recordAndTuple")) {
							if (this.expectPlugin("recordAndTuple"), "bar" === this.getPluginOption("recordAndTuple", "syntaxType")) throw this.raise(123 === t ? c.RecordExpressionHashIncorrectStartSyntaxType : c.TupleExpressionHashIncorrectStartSyntaxType, this.state.curPosition());
							this.state.pos += 2, 123 === t ? this.finishToken(7) : this.finishToken(1);
						} else isIdentifierStart(t) ? (++this.state.pos, this.finishToken(139, this.readWord1(t))) : 92 === t ? (++this.state.pos, this.finishToken(139, this.readWord1())) : this.finishOp(27, 1);
					}
					readToken_dot() {
						const e = this.input.charCodeAt(this.state.pos + 1);
						e >= 48 && e <= 57 ? this.readNumber(!0) : 46 === e && 46 === this.input.charCodeAt(this.state.pos + 2) ? (this.state.pos += 3, this.finishToken(21)) : (++this.state.pos, this.finishToken(16));
					}
					readToken_slash() {
						61 === this.input.charCodeAt(this.state.pos + 1) ? this.finishOp(31, 2) : this.finishOp(56, 1);
					}
					readToken_interpreter() {
						if (0 !== this.state.pos || this.length < 2) return !1;
						let e = this.input.charCodeAt(this.state.pos + 1);
						if (33 !== e) return !1;
						const t = this.state.pos;
						for (this.state.pos += 1; !isNewLine(e) && ++this.state.pos < this.length;) e = this.input.charCodeAt(this.state.pos);
						const r = this.input.slice(t + 2, this.state.pos);
						return this.finishToken(28, r), !0;
					}
					readToken_mult_modulo(e) {
						let t = 42 === e ? 55 : 54, r = 1, n = this.input.charCodeAt(this.state.pos + 1);
						42 === e && 42 === n && (r++, n = this.input.charCodeAt(this.state.pos + 2), t = 57), 61 !== n || this.state.inType || (r++, t = 37 === e ? 33 : 30), this.finishOp(t, r);
					}
					readToken_pipe_amp(e) {
						const t = this.input.charCodeAt(this.state.pos + 1);
						if (t !== e) {
							if (124 === e) {
								if (62 === t) return void this.finishOp(39, 2);
								if (this.hasPlugin("recordAndTuple") && 125 === t) {
									if ("bar" !== this.getPluginOption("recordAndTuple", "syntaxType")) throw this.raise(c.RecordExpressionBarIncorrectEndSyntaxType, this.state.curPosition());
									this.state.pos += 2, this.finishToken(9);
									return;
								}
								if (this.hasPlugin("recordAndTuple") && 93 === t) {
									if ("bar" !== this.getPluginOption("recordAndTuple", "syntaxType")) throw this.raise(c.TupleExpressionBarIncorrectEndSyntaxType, this.state.curPosition());
									this.state.pos += 2, this.finishToken(4);
									return;
								}
							}
							61 !== t ? this.finishOp(124 === e ? 43 : 45, 1) : this.finishOp(30, 2);
						} else 61 === this.input.charCodeAt(this.state.pos + 2) ? this.finishOp(30, 3) : this.finishOp(124 === e ? 41 : 42, 2);
					}
					readToken_caret() {
						const e = this.input.charCodeAt(this.state.pos + 1);
						if (61 !== e || this.state.inType) if (94 === e && this.hasPlugin(["pipelineOperator", {
							proposal: "hack",
							topicToken: "^^"
						}])) {
							this.finishOp(37, 2);
							94 === this.input.codePointAt(this.state.pos) && this.unexpected();
						} else this.finishOp(44, 1);
						else this.finishOp(32, 2);
					}
					readToken_atSign() {
						64 === this.input.charCodeAt(this.state.pos + 1) && this.hasPlugin(["pipelineOperator", {
							proposal: "hack",
							topicToken: "@@"
						}]) ? this.finishOp(38, 2) : this.finishOp(26, 1);
					}
					readToken_plus_min(e) {
						const t = this.input.charCodeAt(this.state.pos + 1);
						t !== e ? 61 === t ? this.finishOp(30, 2) : this.finishOp(53, 1) : this.finishOp(34, 2);
					}
					readToken_lt() {
						const { pos: e } = this.state, t = this.input.charCodeAt(e + 1);
						if (60 === t) return 61 === this.input.charCodeAt(e + 2) ? void this.finishOp(30, 3) : void this.finishOp(51, 2);
						61 !== t ? this.finishOp(47, 1) : this.finishOp(49, 2);
					}
					readToken_gt() {
						const { pos: e } = this.state, t = this.input.charCodeAt(e + 1);
						if (62 === t) {
							const t = 62 === this.input.charCodeAt(e + 2) ? 3 : 2;
							61 === this.input.charCodeAt(e + t) ? this.finishOp(30, t + 1) : this.finishOp(52, t);
							return;
						}
						61 !== t ? this.finishOp(48, 1) : this.finishOp(49, 2);
					}
					readToken_eq_excl(e) {
						const t = this.input.charCodeAt(this.state.pos + 1);
						if (61 !== t) return 61 === e && 62 === t ? (this.state.pos += 2, void this.finishToken(19)) : void this.finishOp(61 === e ? 29 : 35, 1);
						this.finishOp(46, 61 === this.input.charCodeAt(this.state.pos + 2) ? 3 : 2);
					}
					readToken_question() {
						const e = this.input.charCodeAt(this.state.pos + 1), t = this.input.charCodeAt(this.state.pos + 2);
						63 === e ? 61 === t ? this.finishOp(30, 3) : this.finishOp(40, 2) : 46 !== e || t >= 48 && t <= 57 ? (++this.state.pos, this.finishToken(17)) : (this.state.pos += 2, this.finishToken(18));
					}
					getTokenFromCode(e) {
						switch (e) {
							case 46:
								this.readToken_dot();
								return;
							case 40:
								++this.state.pos, this.finishToken(10);
								return;
							case 41:
								++this.state.pos, this.finishToken(11);
								return;
							case 59:
								++this.state.pos, this.finishToken(13);
								return;
							case 44:
								++this.state.pos, this.finishToken(12);
								return;
							case 91:
								if (this.hasPlugin("recordAndTuple") && 124 === this.input.charCodeAt(this.state.pos + 1)) {
									if ("bar" !== this.getPluginOption("recordAndTuple", "syntaxType")) throw this.raise(c.TupleExpressionBarIncorrectStartSyntaxType, this.state.curPosition());
									this.state.pos += 2, this.finishToken(2);
								} else ++this.state.pos, this.finishToken(0);
								return;
							case 93:
								++this.state.pos, this.finishToken(3);
								return;
							case 123:
								if (this.hasPlugin("recordAndTuple") && 124 === this.input.charCodeAt(this.state.pos + 1)) {
									if ("bar" !== this.getPluginOption("recordAndTuple", "syntaxType")) throw this.raise(c.RecordExpressionBarIncorrectStartSyntaxType, this.state.curPosition());
									this.state.pos += 2, this.finishToken(6);
								} else ++this.state.pos, this.finishToken(5);
								return;
							case 125:
								++this.state.pos, this.finishToken(8);
								return;
							case 58:
								this.hasPlugin("functionBind") && 58 === this.input.charCodeAt(this.state.pos + 1) ? this.finishOp(15, 2) : (++this.state.pos, this.finishToken(14));
								return;
							case 63:
								this.readToken_question();
								return;
							case 96:
								this.readTemplateToken();
								return;
							case 48: {
								const e = this.input.charCodeAt(this.state.pos + 1);
								if (120 === e || 88 === e) return void this.readRadixNumber(16);
								if (111 === e || 79 === e) return void this.readRadixNumber(8);
								if (98 === e || 66 === e) return void this.readRadixNumber(2);
							}
							case 49:
							case 50:
							case 51:
							case 52:
							case 53:
							case 54:
							case 55:
							case 56:
							case 57:
								this.readNumber(!1);
								return;
							case 34:
							case 39:
								this.readString(e);
								return;
							case 47:
								this.readToken_slash();
								return;
							case 37:
							case 42:
								this.readToken_mult_modulo(e);
								return;
							case 124:
							case 38:
								this.readToken_pipe_amp(e);
								return;
							case 94:
								this.readToken_caret();
								return;
							case 43:
							case 45:
								this.readToken_plus_min(e);
								return;
							case 60:
								this.readToken_lt();
								return;
							case 62:
								this.readToken_gt();
								return;
							case 61:
							case 33:
								this.readToken_eq_excl(e);
								return;
							case 126:
								this.finishOp(36, 1);
								return;
							case 64:
								this.readToken_atSign();
								return;
							case 35:
								this.readToken_numberSign();
								return;
							case 92:
								this.readWord();
								return;
							default: if (isIdentifierStart(e)) return void this.readWord(e);
						}
						throw this.raise(c.InvalidOrUnexpectedToken, this.state.curPosition(), { unexpected: String.fromCodePoint(e) });
					}
					finishOp(e, t) {
						const r = this.input.slice(this.state.pos, this.state.pos + t);
						this.state.pos += t, this.finishToken(e, r);
					}
					readRegexp() {
						const e = this.state.startLoc, t = this.state.start + 1;
						let r, n, { pos: s } = this.state;
						for (;; ++s) {
							if (s >= this.length) throw this.raise(c.UnterminatedRegExp, createPositionWithColumnOffset(e, 1));
							const t = this.input.charCodeAt(s);
							if (isNewLine(t)) throw this.raise(c.UnterminatedRegExp, createPositionWithColumnOffset(e, 1));
							if (r) r = !1;
							else {
								if (91 === t) n = !0;
								else if (93 === t && n) n = !1;
								else if (47 === t && !n) break;
								r = 92 === t;
							}
						}
						const i = this.input.slice(t, s);
						++s;
						let o = "";
						const nextPos = () => createPositionWithColumnOffset(e, s + 2 - t);
						for (; s < this.length;) {
							const e = this.codePointAtPos(s), t = String.fromCharCode(e);
							if (J.has(e)) 118 === e ? o.includes("u") && this.raise(c.IncompatibleRegExpUVFlags, nextPos()) : 117 === e && o.includes("v") && this.raise(c.IncompatibleRegExpUVFlags, nextPos()), o.includes(t) && this.raise(c.DuplicateRegExpFlags, nextPos());
							else {
								if (!isIdentifierChar(e) && 92 !== e) break;
								this.raise(c.MalformedRegExpFlags, nextPos());
							}
							++s, o += t;
						}
						this.state.pos = s, this.finishToken(138, {
							pattern: i,
							flags: o
						});
					}
					readInt(e, t, r = !1, n = !0) {
						const { n: s, pos: i } = readInt(this.input, this.state.pos, this.state.lineStart, this.state.curLine, e, t, r, n, this.errorHandlers_readInt, !1);
						return this.state.pos = i, s;
					}
					readRadixNumber(e) {
						const t = this.state.pos, r = this.state.curPosition();
						let n = !1;
						this.state.pos += 2;
						const s = this.readInt(e);
						s ?? this.raise(c.InvalidDigit, createPositionWithColumnOffset(r, 2), { radix: e });
						const i = this.input.charCodeAt(this.state.pos);
						if (110 === i) ++this.state.pos, n = !0;
						else if (109 === i) throw this.raise(c.InvalidDecimal, r);
						if (isIdentifierStart(this.codePointAtPos(this.state.pos))) throw this.raise(c.NumberIdentifier, this.state.curPosition());
						if (n) {
							const e = this.input.slice(t, this.state.pos).replace(/[_n]/g, "");
							this.finishToken(136, e);
							return;
						}
						this.finishToken(135, s);
					}
					readNumber(e) {
						const t = this.state.pos, r = this.state.curPosition();
						let n = !1, s = !1, i = !1, o = !1;
						e || null !== this.readInt(10) || this.raise(c.InvalidNumber, this.state.curPosition());
						const a = this.state.pos - t >= 2 && 48 === this.input.charCodeAt(t);
						if (a) {
							const e = this.input.slice(t, this.state.pos);
							if (this.recordStrictModeErrors(c.StrictOctalLiteral, r), !this.state.strict) {
								const t = e.indexOf("_");
								t > 0 && this.raise(c.ZeroDigitNumericSeparator, createPositionWithColumnOffset(r, t));
							}
							o = a && !/[89]/.test(e);
						}
						let l = this.input.charCodeAt(this.state.pos);
						if (46 !== l || o || (++this.state.pos, this.readInt(10), n = !0, l = this.input.charCodeAt(this.state.pos)), 69 !== l && 101 !== l || o || (l = this.input.charCodeAt(++this.state.pos), 43 !== l && 45 !== l || ++this.state.pos, null === this.readInt(10) && this.raise(c.InvalidOrMissingExponent, r), n = !0, i = !0, l = this.input.charCodeAt(this.state.pos)), 110 === l && ((n || a) && this.raise(c.InvalidBigIntLiteral, r), ++this.state.pos, s = !0), 109 === l) {
							this.expectPlugin("decimal", this.state.curPosition()), (i || a) && this.raise(c.InvalidDecimal, r), ++this.state.pos;
							var p = !0;
						}
						if (isIdentifierStart(this.codePointAtPos(this.state.pos))) throw this.raise(c.NumberIdentifier, this.state.curPosition());
						const u = this.input.slice(t, this.state.pos).replace(/[_mn]/g, "");
						if (s) return void this.finishToken(136, u);
						if (p) return void this.finishToken(137, u);
						const d = o ? parseInt(u, 8) : parseFloat(u);
						this.finishToken(135, d);
					}
					readCodePoint(e) {
						const { code: t, pos: r } = readCodePoint(this.input, this.state.pos, this.state.lineStart, this.state.curLine, e, this.errorHandlers_readCodePoint);
						return this.state.pos = r, t;
					}
					readString(e) {
						const { str: t, pos: r, curLine: n, lineStart: s } = readStringContents(34 === e ? "double" : "single", this.input, this.state.pos + 1, this.state.lineStart, this.state.curLine, this.errorHandlers_readStringContents_string);
						this.state.pos = r + 1, this.state.lineStart = s, this.state.curLine = n, this.finishToken(134, t);
					}
					readTemplateContinuation() {
						this.match(8) || this.unexpected(null, 8), this.state.pos--, this.readTemplateToken();
					}
					readTemplateToken() {
						const e = this.input[this.state.pos], { str: t, firstInvalidLoc: r, pos: n, curLine: s, lineStart: i } = readStringContents("template", this.input, this.state.pos + 1, this.state.lineStart, this.state.curLine, this.errorHandlers_readStringContents_template);
						this.state.pos = n + 1, this.state.lineStart = i, this.state.curLine = s, r && (this.state.firstInvalidTemplateEscapePos = new Position(r.curLine, r.pos - r.lineStart, this.sourceToOffsetPos(r.pos))), 96 === this.input.codePointAt(n) ? this.finishToken(24, r ? null : e + t + "`") : (this.state.pos++, this.finishToken(25, r ? null : e + t + "${"));
					}
					recordStrictModeErrors(e, t) {
						const r = t.index;
						this.state.strict && !this.state.strictErrors.has(r) ? this.raise(e, t) : this.state.strictErrors.set(r, [e, t]);
					}
					readWord1(e) {
						this.state.containsEsc = !1;
						let t = "";
						const r = this.state.pos;
						let n = this.state.pos;
						for (void 0 !== e && (this.state.pos += e <= 65535 ? 1 : 2); this.state.pos < this.length;) {
							const e = this.codePointAtPos(this.state.pos);
							if (isIdentifierChar(e)) this.state.pos += e <= 65535 ? 1 : 2;
							else {
								if (92 !== e) break;
								{
									this.state.containsEsc = !0, t += this.input.slice(n, this.state.pos);
									const e = this.state.curPosition(), s = this.state.pos === r ? isIdentifierStart : isIdentifierChar;
									if (117 !== this.input.charCodeAt(++this.state.pos)) {
										this.raise(c.MissingUnicodeEscape, this.state.curPosition()), n = this.state.pos - 1;
										continue;
									}
									++this.state.pos;
									const i = this.readCodePoint(!0);
									null !== i && (s(i) || this.raise(c.EscapedCharNotAnIdentifier, e), t += String.fromCodePoint(i)), n = this.state.pos;
								}
							}
						}
						return t + this.input.slice(n, this.state.pos);
					}
					readWord(e) {
						const t = this.readWord1(e), r = g.get(t);
						void 0 !== r ? this.finishToken(r, tokenLabelName(r)) : this.finishToken(132, t);
					}
					checkKeywordEscapes() {
						const { type: e } = this.state;
						tokenIsKeyword(e) && this.state.containsEsc && this.raise(c.InvalidEscapedReservedWord, this.state.startLoc, { reservedWord: tokenLabelName(e) });
					}
					raise(e, t, r = {}) {
						const n = e(t instanceof Position ? t : t.loc.start, r);
						if (!(2048 & this.optionFlags)) throw n;
						return this.isLookahead || this.state.errors.push(n), n;
					}
					raiseOverwrite(e, t, r = {}) {
						const n = t instanceof Position ? t : t.loc.start, s = n.index, i = this.state.errors;
						for (let t = i.length - 1; t >= 0; t--) {
							const o = i[t];
							if (o.loc.index === s) return i[t] = e(n, r);
							if (o.loc.index < s) break;
						}
						return this.raise(e, t, r);
					}
					updateContext(e) {}
					unexpected(e, t) {
						throw this.raise(c.UnexpectedToken, null != e ? e : this.state.startLoc, { expected: t ? tokenLabelName(t) : null });
					}
					expectPlugin(e, t) {
						if (this.hasPlugin(e)) return !0;
						throw this.raise(c.MissingPlugin, null != t ? t : this.state.startLoc, { missingPlugin: [e] });
					}
					expectOnePlugin(e) {
						if (!e.some((e) => this.hasPlugin(e))) throw this.raise(c.MissingOneOfPlugins, this.state.startLoc, { missingPlugin: e });
					}
					errorBuilder(e) {
						return (t, r, n) => {
							this.raise(e, buildPosition(t, r, n));
						};
					}
				}
				class ClassScope {
					constructor() {
						this.privateNames = /* @__PURE__ */ new Set(), this.loneAccessors = /* @__PURE__ */ new Map(), this.undefinedPrivateNames = /* @__PURE__ */ new Map();
					}
				}
				class ClassScopeHandler {
					constructor(e) {
						this.parser = void 0, this.stack = [], this.undefinedPrivateNames = /* @__PURE__ */ new Map(), this.parser = e;
					}
					current() {
						return this.stack[this.stack.length - 1];
					}
					enter() {
						this.stack.push(new ClassScope());
					}
					exit() {
						const e = this.stack.pop(), t = this.current();
						for (const [r, n] of Array.from(e.undefinedPrivateNames)) t ? t.undefinedPrivateNames.has(r) || t.undefinedPrivateNames.set(r, n) : this.parser.raise(c.InvalidPrivateFieldResolution, n, { identifierName: r });
					}
					declarePrivateName(e, t, r) {
						const { privateNames: n, loneAccessors: s, undefinedPrivateNames: i } = this.current();
						let o = n.has(e);
						if (3 & t) {
							const r = o && s.get(e);
							if (r) o = (3 & r) === (3 & t) || (4 & r) !== (4 & t), o || s.delete(e);
							else o || s.set(e, t);
						}
						o && this.parser.raise(c.PrivateNameRedeclaration, r, { identifierName: e }), n.add(e), i.delete(e);
					}
					usePrivateName(e, t) {
						let r;
						for (r of this.stack) if (r.privateNames.has(e)) return;
						r ? r.undefinedPrivateNames.set(e, t) : this.parser.raise(c.InvalidPrivateFieldResolution, t, { identifierName: e });
					}
				}
				class ExpressionScope {
					constructor(e = 0) {
						this.type = e;
					}
					canBeArrowParameterDeclaration() {
						return 2 === this.type || 1 === this.type;
					}
					isCertainlyParameterDeclaration() {
						return 3 === this.type;
					}
				}
				class ArrowHeadParsingScope extends ExpressionScope {
					constructor(e) {
						super(e), this.declarationErrors = /* @__PURE__ */ new Map();
					}
					recordDeclarationError(e, t) {
						const r = t.index;
						this.declarationErrors.set(r, [e, t]);
					}
					clearDeclarationError(e) {
						this.declarationErrors.delete(e);
					}
					iterateErrors(e) {
						this.declarationErrors.forEach(e);
					}
				}
				class ExpressionScopeHandler {
					constructor(e) {
						this.parser = void 0, this.stack = [new ExpressionScope()], this.parser = e;
					}
					enter(e) {
						this.stack.push(e);
					}
					exit() {
						this.stack.pop();
					}
					recordParameterInitializerError(e, t) {
						const r = t.loc.start, { stack: n } = this;
						let s = n.length - 1, i = n[s];
						for (; !i.isCertainlyParameterDeclaration();) {
							if (!i.canBeArrowParameterDeclaration()) return;
							i.recordDeclarationError(e, r), i = n[--s];
						}
						this.parser.raise(e, r);
					}
					recordArrowParameterBindingError(e, t) {
						const { stack: r } = this, n = r[r.length - 1], s = t.loc.start;
						if (n.isCertainlyParameterDeclaration()) this.parser.raise(e, s);
						else {
							if (!n.canBeArrowParameterDeclaration()) return;
							n.recordDeclarationError(e, s);
						}
					}
					recordAsyncArrowParametersError(e) {
						const { stack: t } = this;
						let r = t.length - 1, n = t[r];
						for (; n.canBeArrowParameterDeclaration();) 2 === n.type && n.recordDeclarationError(c.AwaitBindingIdentifier, e), n = t[--r];
					}
					validateAsPattern() {
						const { stack: e } = this, t = e[e.length - 1];
						t.canBeArrowParameterDeclaration() && t.iterateErrors(([t, r]) => {
							this.parser.raise(t, r);
							let n = e.length - 2, s = e[n];
							for (; s.canBeArrowParameterDeclaration();) s.clearDeclarationError(r.index), s = e[--n];
						});
					}
				}
				function newExpressionScope() {
					return new ExpressionScope();
				}
				class UtilParser extends Tokenizer {
					addExtra(e, t, r, n = !0) {
						if (!e) return;
						let { extra: s } = e;
						s ?? (s = {}, e.extra = s), n ? s[t] = r : Object.defineProperty(s, t, {
							enumerable: n,
							value: r
						});
					}
					isContextual(e) {
						return this.state.type === e && !this.state.containsEsc;
					}
					isUnparsedContextual(e, t) {
						if (this.input.startsWith(t, e)) {
							const r = this.input.charCodeAt(e + t.length);
							return !(isIdentifierChar(r) || 55296 == (64512 & r));
						}
						return !1;
					}
					isLookaheadContextual(e) {
						const t = this.nextTokenStart();
						return this.isUnparsedContextual(t, e);
					}
					eatContextual(e) {
						return !!this.isContextual(e) && (this.next(), !0);
					}
					expectContextual(e, t) {
						if (!this.eatContextual(e)) {
							if (null != t) throw this.raise(t, this.state.startLoc);
							this.unexpected(null, e);
						}
					}
					canInsertSemicolon() {
						return this.match(140) || this.match(8) || this.hasPrecedingLineBreak();
					}
					hasPrecedingLineBreak() {
						return hasNewLine(this.input, this.offsetToSourcePos(this.state.lastTokEndLoc.index), this.state.start);
					}
					hasFollowingLineBreak() {
						return hasNewLine(this.input, this.state.end, this.nextTokenStart());
					}
					isLineTerminator() {
						return this.eat(13) || this.canInsertSemicolon();
					}
					semicolon(e = !0) {
						(e ? this.isLineTerminator() : this.eat(13)) || this.raise(c.MissingSemicolon, this.state.lastTokEndLoc);
					}
					expect(e, t) {
						this.eat(e) || this.unexpected(t, e);
					}
					tryParse(e, t = this.state.clone()) {
						const r = { node: null };
						try {
							const n = e((e = null) => {
								throw r.node = e, r;
							});
							if (this.state.errors.length > t.errors.length) {
								const e = this.state;
								return this.state = t, this.state.tokensLength = e.tokensLength, {
									node: n,
									error: e.errors[t.errors.length],
									thrown: !1,
									aborted: !1,
									failState: e
								};
							}
							return {
								node: n,
								error: null,
								thrown: !1,
								aborted: !1,
								failState: null
							};
						} catch (e) {
							const n = this.state;
							if (this.state = t, e instanceof SyntaxError) return {
								node: null,
								error: e,
								thrown: !0,
								aborted: !1,
								failState: n
							};
							if (e === r) return {
								node: r.node,
								error: null,
								thrown: !1,
								aborted: !0,
								failState: n
							};
							throw e;
						}
					}
					checkExpressionErrors(e, t) {
						if (!e) return !1;
						const { shorthandAssignLoc: r, doubleProtoLoc: n, privateKeyLoc: s, optionalParametersLoc: i, voidPatternLoc: o } = e;
						if (!t) return !!(r || n || i || s || o);
						null != r && this.raise(c.InvalidCoverInitializedName, r), null != n && this.raise(c.DuplicateProto, n), null != s && this.raise(c.UnexpectedPrivateField, s), null != i && this.unexpected(i), null != o && this.raise(c.InvalidCoverDiscardElement, o);
					}
					isLiteralPropertyName() {
						return tokenIsLiteralPropertyName(this.state.type);
					}
					isPrivateName(e) {
						return "PrivateName" === e.type;
					}
					getPrivateNameSV(e) {
						return e.id.name;
					}
					hasPropertyAsPrivateName(e) {
						return ("MemberExpression" === e.type || "OptionalMemberExpression" === e.type) && this.isPrivateName(e.property);
					}
					isObjectProperty(e) {
						return "ObjectProperty" === e.type;
					}
					isObjectMethod(e) {
						return "ObjectMethod" === e.type;
					}
					initializeScopes(e = "module" === this.options.sourceType) {
						const t = this.state.labels;
						this.state.labels = [];
						const r = this.exportedIdentifiers;
						this.exportedIdentifiers = /* @__PURE__ */ new Set();
						const n = this.inModule;
						this.inModule = e;
						const s = this.scope;
						this.scope = new (this.getScopeHandler())(this, e);
						const o = this.prodParam;
						this.prodParam = new ProductionParameterHandler();
						const a = this.classScope;
						this.classScope = new ClassScopeHandler(this);
						const l = this.expressionScope;
						return this.expressionScope = new ExpressionScopeHandler(this), () => {
							this.state.labels = t, this.exportedIdentifiers = r, this.inModule = n, this.scope = s, this.prodParam = o, this.classScope = a, this.expressionScope = l;
						};
					}
					enterInitialScopes() {
						let e = 0;
						(this.inModule || 1 & this.optionFlags) && (e |= 2), 32 & this.optionFlags && (e |= 1);
						const t = !this.inModule && "commonjs" === this.options.sourceType;
						(t || 2 & this.optionFlags) && (e |= 4), this.prodParam.enter(e);
						let r = t ? 514 : 1;
						4 & this.optionFlags && (r |= 512), this.scope.enter(r);
					}
					checkDestructuringPrivate(e) {
						const { privateKeyLoc: t } = e;
						null !== t && this.expectPlugin("destructuringPrivate", t);
					}
				}
				class ExpressionErrors {
					constructor() {
						this.shorthandAssignLoc = null, this.doubleProtoLoc = null, this.privateKeyLoc = null, this.optionalParametersLoc = null, this.voidPatternLoc = null;
					}
				}
				class Node {
					constructor(e, t, r) {
						this.type = "", this.start = t, this.end = 0, this.loc = new SourceLocation(r), 128 & (null == e ? void 0 : e.optionFlags) && (this.range = [t, 0]), null != e && e.filename && (this.loc.filename = e.filename);
					}
				}
				const Y = Node.prototype;
				Y.__clone = function() {
					const e = new Node(void 0, this.start, this.loc.start), t = Object.keys(this);
					for (let r = 0, n = t.length; r < n; r++) {
						const n = t[r];
						"leadingComments" !== n && "trailingComments" !== n && "innerComments" !== n && (e[n] = this[n]);
					}
					return e;
				};
				class NodeUtils extends UtilParser {
					startNode() {
						const e = this.state.startLoc;
						return new Node(this, e.index, e);
					}
					startNodeAt(e) {
						return new Node(this, e.index, e);
					}
					startNodeAtNode(e) {
						return this.startNodeAt(e.loc.start);
					}
					finishNode(e, t) {
						return this.finishNodeAt(e, t, this.state.lastTokEndLoc);
					}
					finishNodeAt(e, t, r) {
						return e.type = t, e.end = r.index, e.loc.end = r, 128 & this.optionFlags && (e.range[1] = r.index), 4096 & this.optionFlags && this.processComment(e), e;
					}
					resetStartLocation(e, t) {
						e.start = t.index, e.loc.start = t, 128 & this.optionFlags && (e.range[0] = t.index);
					}
					resetEndLocation(e, t = this.state.lastTokEndLoc) {
						e.end = t.index, e.loc.end = t, 128 & this.optionFlags && (e.range[1] = t.index);
					}
					resetStartLocationFromNode(e, t) {
						this.resetStartLocation(e, t.loc.start);
					}
					castNodeTo(e, t) {
						return e.type = t, e;
					}
					cloneIdentifier(e) {
						const { type: t, start: r, end: n, loc: s, range: i, name: o } = e, a = Object.create(Y);
						return a.type = t, a.start = r, a.end = n, a.loc = s, a.range = i, a.name = o, e.extra && (a.extra = e.extra), a;
					}
					cloneStringLiteral(e) {
						const { type: t, start: r, end: n, loc: s, range: i, extra: o } = e, a = Object.create(Y);
						return a.type = t, a.start = r, a.end = n, a.loc = s, a.range = i, a.extra = o, a.value = e.value, a;
					}
				}
				const unwrapParenthesizedExpression = (e) => "ParenthesizedExpression" === e.type ? unwrapParenthesizedExpression(e.expression) : e;
				class LValParser extends NodeUtils {
					toAssignable(e, t = !1) {
						var r, n;
						let s;
						switch (("ParenthesizedExpression" === e.type || null != (r = e.extra) && r.parenthesized) && (s = unwrapParenthesizedExpression(e), t ? "Identifier" === s.type ? this.expressionScope.recordArrowParameterBindingError(c.InvalidParenthesizedAssignment, e) : "MemberExpression" === s.type || this.isOptionalMemberExpression(s) || this.raise(c.InvalidParenthesizedAssignment, e) : this.raise(c.InvalidParenthesizedAssignment, e)), e.type) {
							case "Identifier":
							case "ObjectPattern":
							case "ArrayPattern":
							case "AssignmentPattern":
							case "RestElement":
							case "VoidPattern": break;
							case "ObjectExpression":
								this.castNodeTo(e, "ObjectPattern");
								for (let r = 0, n = e.properties.length, s = n - 1; r < n; r++) {
									var i;
									const n = e.properties[r], o = r === s;
									this.toAssignableObjectExpressionProp(n, o, t), o && "RestElement" === n.type && null != (i = e.extra) && i.trailingCommaLoc && this.raise(c.RestTrailingComma, e.extra.trailingCommaLoc);
								}
								break;
							case "ObjectProperty": {
								const { key: r, value: n } = e;
								this.isPrivateName(r) && this.classScope.usePrivateName(this.getPrivateNameSV(r), r.loc.start), this.toAssignable(n, t);
								break;
							}
							case "SpreadElement": throw new Error("Internal @babel/parser error (this is a bug, please report it). SpreadElement should be converted by .toAssignable's caller.");
							case "ArrayExpression":
								this.castNodeTo(e, "ArrayPattern"), this.toAssignableList(e.elements, null == (n = e.extra) ? void 0 : n.trailingCommaLoc, t);
								break;
							case "AssignmentExpression":
								"=" !== e.operator && this.raise(c.MissingEqInAssignment, e.left.loc.end), this.castNodeTo(e, "AssignmentPattern"), delete e.operator, "VoidPattern" === e.left.type && this.raise(c.VoidPatternInitializer, e.left), this.toAssignable(e.left, t);
								break;
							case "ParenthesizedExpression": this.toAssignable(s, t);
						}
					}
					toAssignableObjectExpressionProp(e, t, r) {
						if ("ObjectMethod" === e.type) this.raise("get" === e.kind || "set" === e.kind ? c.PatternHasAccessor : c.PatternHasMethod, e.key);
						else if ("SpreadElement" === e.type) {
							this.castNodeTo(e, "RestElement");
							const n = e.argument;
							this.checkToRestConversion(n, !1), this.toAssignable(n, r), t || this.raise(c.RestTrailingComma, e);
						} else this.toAssignable(e, r);
					}
					toAssignableList(e, t, r) {
						const n = e.length - 1;
						for (let s = 0; s <= n; s++) {
							const i = e[s];
							i && (this.toAssignableListItem(e, s, r), "RestElement" === i.type && (s < n ? this.raise(c.RestTrailingComma, i) : t && this.raise(c.RestTrailingComma, t)));
						}
					}
					toAssignableListItem(e, t, r) {
						const n = e[t];
						if ("SpreadElement" === n.type) {
							this.castNodeTo(n, "RestElement");
							const e = n.argument;
							this.checkToRestConversion(e, !0), this.toAssignable(e, r);
						} else this.toAssignable(n, r);
					}
					isAssignable(e, t) {
						switch (e.type) {
							case "Identifier":
							case "ObjectPattern":
							case "ArrayPattern":
							case "AssignmentPattern":
							case "RestElement":
							case "VoidPattern": return !0;
							case "ObjectExpression": {
								const t = e.properties.length - 1;
								return e.properties.every((e, r) => "ObjectMethod" !== e.type && (r === t || "SpreadElement" !== e.type) && this.isAssignable(e));
							}
							case "ObjectProperty": return this.isAssignable(e.value);
							case "SpreadElement": return this.isAssignable(e.argument);
							case "ArrayExpression": return e.elements.every((e) => null === e || this.isAssignable(e));
							case "AssignmentExpression": return "=" === e.operator;
							case "ParenthesizedExpression": return this.isAssignable(e.expression);
							case "MemberExpression":
							case "OptionalMemberExpression": return !t;
							default: return !1;
						}
					}
					toReferencedList(e, t) {
						return e;
					}
					toReferencedListDeep(e, t) {
						this.toReferencedList(e, t);
						for (const t of e) "ArrayExpression" === (null == t ? void 0 : t.type) && this.toReferencedListDeep(t.elements);
					}
					parseSpread(e) {
						const t = this.startNode();
						return this.next(), t.argument = this.parseMaybeAssignAllowIn(e, void 0), this.finishNode(t, "SpreadElement");
					}
					parseRestBinding() {
						const e = this.startNode();
						this.next();
						const t = this.parseBindingAtom();
						return "VoidPattern" === t.type && this.raise(c.UnexpectedVoidPattern, t), e.argument = t, this.finishNode(e, "RestElement");
					}
					parseBindingAtom() {
						switch (this.state.type) {
							case 0: {
								const e = this.startNode();
								return this.next(), e.elements = this.parseBindingList(3, 93, 1), this.finishNode(e, "ArrayPattern");
							}
							case 5: return this.parseObjectLike(8, !0);
							case 88: return this.parseVoidPattern(null);
						}
						return this.parseIdentifier();
					}
					parseBindingList(e, t, r) {
						const n = 1 & r, s = [];
						let i = !0;
						for (; !this.eat(e);) if (i ? i = !1 : this.expect(12), n && this.match(12)) s.push(null);
						else {
							if (this.eat(e)) break;
							if (this.match(21)) {
								let n = this.parseRestBinding();
								if ((this.hasPlugin("flow") || 2 & r) && (n = this.parseFunctionParamType(n)), s.push(n), !this.checkCommaAfterRest(t)) {
									this.expect(e);
									break;
								}
							} else {
								const e = [];
								if (2 & r) for (this.match(26) && this.hasPlugin("decorators") && this.raise(c.UnsupportedParameterDecorator, this.state.startLoc); this.match(26);) e.push(this.parseDecorator());
								s.push(this.parseBindingElement(r, e));
							}
						}
						return s;
					}
					parseBindingRestProperty(e) {
						return this.next(), this.hasPlugin("discardBinding") && this.match(88) ? (e.argument = this.parseVoidPattern(null), this.raise(c.UnexpectedVoidPattern, e.argument)) : e.argument = this.parseIdentifier(), this.checkCommaAfterRest(125), this.finishNode(e, "RestElement");
					}
					parseBindingProperty() {
						const { type: e, startLoc: t } = this.state;
						if (21 === e) return this.parseBindingRestProperty(this.startNode());
						const r = this.startNode();
						return 139 === e ? (this.expectPlugin("destructuringPrivate", t), this.classScope.usePrivateName(this.state.value, t), r.key = this.parsePrivateName()) : this.parsePropertyName(r), r.method = !1, this.parseObjPropValue(r, t, !1, !1, !0, !1);
					}
					parseBindingElement(e, t) {
						const r = this.parseMaybeDefault();
						(this.hasPlugin("flow") || 2 & e) && this.parseFunctionParamType(r), t.length && (r.decorators = t, this.resetStartLocationFromNode(r, t[0]));
						return this.parseMaybeDefault(r.loc.start, r);
					}
					parseFunctionParamType(e) {
						return e;
					}
					parseMaybeDefault(e, t) {
						if (e ?? (e = this.state.startLoc), t = null != t ? t : this.parseBindingAtom(), !this.eat(29)) return t;
						const r = this.startNodeAt(e);
						return "VoidPattern" === t.type && this.raise(c.VoidPatternInitializer, t), r.left = t, r.right = this.parseMaybeAssignAllowIn(), this.finishNode(r, "AssignmentPattern");
					}
					isValidLVal(e, t, r) {
						switch (e) {
							case "AssignmentPattern": return "left";
							case "RestElement": return "argument";
							case "ObjectProperty": return "value";
							case "ParenthesizedExpression": return "expression";
							case "ArrayPattern": return "elements";
							case "ObjectPattern": return "properties";
							case "VoidPattern": return !0;
						}
						return !1;
					}
					isOptionalMemberExpression(e) {
						return "OptionalMemberExpression" === e.type;
					}
					checkLVal(e, t, r = 64, n = !1, s = !1, i = !1) {
						var o;
						const a = e.type;
						if (this.isObjectMethod(e)) return;
						const l = this.isOptionalMemberExpression(e);
						if (l || "MemberExpression" === a) return l && (this.expectPlugin("optionalChainingAssign", e.loc.start), "AssignmentExpression" !== t.type && this.raise(c.InvalidLhsOptionalChaining, e, { ancestor: t })), void (64 !== r && this.raise(c.InvalidPropertyBindingPattern, e));
						if ("Identifier" === a) {
							this.checkIdentifier(e, r, s);
							const { name: t } = e;
							n && (n.has(t) ? this.raise(c.ParamDupe, e) : n.add(t));
							return;
						}
						"VoidPattern" === a && "CatchClause" === t.type && this.raise(c.VoidPatternCatchClauseParam, e);
						const p = this.isValidLVal(a, !(i || null != (o = e.extra) && o.parenthesized) && "AssignmentExpression" === t.type, r);
						if (!0 === p) return;
						if (!1 === p) {
							const n = 64 === r ? c.InvalidLhs : c.InvalidLhsBinding;
							this.raise(n, e, { ancestor: t });
							return;
						}
						let u, d;
						"string" == typeof p ? (u = p, d = "ParenthesizedExpression" === a) : [u, d] = p;
						const h = "ArrayPattern" === a || "ObjectPattern" === a ? { type: a } : t, m = e[u];
						if (Array.isArray(m)) for (const e of m) e && this.checkLVal(e, h, r, n, s, d);
						else m && this.checkLVal(m, h, r, n, s, d);
					}
					checkIdentifier(e, t, r = !1) {
						this.state.strict && (r ? isStrictBindReservedWord(e.name, this.inModule) : isStrictBindOnlyReservedWord(e.name)) && (64 === t ? this.raise(c.StrictEvalArguments, e, { referenceName: e.name }) : this.raise(c.StrictEvalArgumentsBinding, e, { bindingName: e.name })), 8192 & t && "let" === e.name && this.raise(c.LetInLexicalBinding, e), 64 & t || this.declareNameFromIdentifier(e, t);
					}
					declareNameFromIdentifier(e, t) {
						this.scope.declareName(e.name, t, e.loc.start);
					}
					checkToRestConversion(e, t) {
						switch (e.type) {
							case "ParenthesizedExpression":
								this.checkToRestConversion(e.expression, t);
								break;
							case "Identifier":
							case "MemberExpression": break;
							case "ArrayExpression":
							case "ObjectExpression": if (t) break;
							default: this.raise(c.InvalidRestAssignmentPattern, e);
						}
					}
					checkCommaAfterRest(e) {
						return !!this.match(12) && (this.raise(this.lookaheadCharCode() === e ? c.RestTrailingComma : c.ElementAfterRest, this.state.startLoc), !0);
					}
				}
				function assert(e) {
					if (!e) throw new Error("Assert fail");
				}
				const Q = ParseErrorEnum`typescript`({
					AbstractMethodHasImplementation: ({ methodName: e }) => `Method '${e}' cannot have an implementation because it is marked abstract.`,
					AbstractPropertyHasInitializer: ({ propertyName: e }) => `Property '${e}' cannot have an initializer because it is marked abstract.`,
					AccessorCannotBeOptional: "An 'accessor' property cannot be declared optional.",
					AccessorCannotDeclareThisParameter: "'get' and 'set' accessors cannot declare 'this' parameters.",
					AccessorCannotHaveTypeParameters: "An accessor cannot have type parameters.",
					ClassMethodHasDeclare: "Class methods cannot have the 'declare' modifier.",
					ClassMethodHasReadonly: "Class methods cannot have the 'readonly' modifier.",
					ConstInitializerMustBeStringOrNumericLiteralOrLiteralEnumReference: "A 'const' initializer in an ambient context must be a string or numeric literal or literal enum reference.",
					ConstructorHasTypeParameters: "Type parameters cannot appear on a constructor declaration.",
					DeclareAccessor: ({ kind: e }) => `'declare' is not allowed in ${e}ters.`,
					DeclareClassFieldHasInitializer: "Initializers are not allowed in ambient contexts.",
					DeclareFunctionHasImplementation: "An implementation cannot be declared in ambient contexts.",
					DuplicateAccessibilityModifier: ({ modifier: e }) => `Accessibility modifier already seen: '${e}'.`,
					DuplicateModifier: ({ modifier: e }) => `Duplicate modifier: '${e}'.`,
					EmptyHeritageClauseType: ({ token: e }) => `'${e}' list cannot be empty.`,
					EmptyTypeArguments: "Type argument list cannot be empty.",
					EmptyTypeParameters: "Type parameter list cannot be empty.",
					ExpectedAmbientAfterExportDeclare: "'export declare' must be followed by an ambient declaration.",
					ImportAliasHasImportType: "An import alias can not use 'import type'.",
					ImportReflectionHasImportType: "An `import module` declaration can not use `type` modifier",
					IncompatibleModifiers: ({ modifiers: e }) => `'${e[0]}' modifier cannot be used with '${e[1]}' modifier.`,
					IndexSignatureHasAbstract: "Index signatures cannot have the 'abstract' modifier.",
					IndexSignatureHasAccessibility: ({ modifier: e }) => `Index signatures cannot have an accessibility modifier ('${e}').`,
					IndexSignatureHasDeclare: "Index signatures cannot have the 'declare' modifier.",
					IndexSignatureHasOverride: "'override' modifier cannot appear on an index signature.",
					IndexSignatureHasStatic: "Index signatures cannot have the 'static' modifier.",
					InitializerNotAllowedInAmbientContext: "Initializers are not allowed in ambient contexts.",
					InvalidHeritageClauseType: ({ token: e }) => `'${e}' list can only include identifiers or qualified-names with optional type arguments.`,
					InvalidModifierOnAwaitUsingDeclaration: (e) => `'${e}' modifier cannot appear on an await using declaration.`,
					InvalidModifierOnTypeMember: ({ modifier: e }) => `'${e}' modifier cannot appear on a type member.`,
					InvalidModifierOnTypeParameter: ({ modifier: e }) => `'${e}' modifier cannot appear on a type parameter.`,
					InvalidModifierOnTypeParameterPositions: ({ modifier: e }) => `'${e}' modifier can only appear on a type parameter of a class, interface or type alias.`,
					InvalidModifierOnUsingDeclaration: (e) => `'${e}' modifier cannot appear on a using declaration.`,
					InvalidModifiersOrder: ({ orderedModifiers: e }) => `'${e[0]}' modifier must precede '${e[1]}' modifier.`,
					InvalidPropertyAccessAfterInstantiationExpression: "Invalid property access after an instantiation expression. You can either wrap the instantiation expression in parentheses, or delete the type arguments.",
					InvalidTupleMemberLabel: "Tuple members must be labeled with a simple identifier.",
					MissingInterfaceName: "'interface' declarations must be followed by an identifier.",
					NonAbstractClassHasAbstractMethod: "Abstract methods can only appear within an abstract class.",
					NonClassMethodPropertyHasAbstractModifier: "'abstract' modifier can only appear on a class, method, or property declaration.",
					OptionalTypeBeforeRequired: "A required element cannot follow an optional element.",
					OverrideNotInSubClass: "This member cannot have an 'override' modifier because its containing class does not extend another class.",
					PatternIsOptional: "A binding pattern parameter cannot be optional in an implementation signature.",
					PrivateElementHasAbstract: "Private elements cannot have the 'abstract' modifier.",
					PrivateElementHasAccessibility: ({ modifier: e }) => `Private elements cannot have an accessibility modifier ('${e}').`,
					ReadonlyForMethodSignature: "'readonly' modifier can only appear on a property declaration or index signature.",
					ReservedArrowTypeParam: "This syntax is reserved in files with the .mts or .cts extension. Add a trailing comma, as in `<T,>() => ...`.",
					ReservedTypeAssertion: "This syntax is reserved in files with the .mts or .cts extension. Use an `as` expression instead.",
					SetAccessorCannotHaveOptionalParameter: "A 'set' accessor cannot have an optional parameter.",
					SetAccessorCannotHaveRestParameter: "A 'set' accessor cannot have rest parameter.",
					SetAccessorCannotHaveReturnType: "A 'set' accessor cannot have a return type annotation.",
					SingleTypeParameterWithoutTrailingComma: ({ typeParameterName: e }) => `Single type parameter ${e} should have a trailing comma. Example usage: <${e},>.`,
					StaticBlockCannotHaveModifier: "Static class blocks cannot have any modifier.",
					TupleOptionalAfterType: "A labeled tuple optional element must be declared using a question mark after the name and before the colon (`name?: type`), rather than after the type (`name: type?`).",
					TypeAnnotationAfterAssign: "Type annotations must come before default assignments, e.g. instead of `age = 25: number` use `age: number = 25`.",
					TypeImportCannotSpecifyDefaultAndNamed: "A type-only import can specify a default import or named bindings, but not both.",
					TypeModifierIsUsedInTypeExports: "The 'type' modifier cannot be used on a named export when 'export type' is used on its export statement.",
					TypeModifierIsUsedInTypeImports: "The 'type' modifier cannot be used on a named import when 'import type' is used on its import statement.",
					UnexpectedParameterModifier: "A parameter property is only allowed in a constructor implementation.",
					UnexpectedReadonly: "'readonly' type modifier is only permitted on array and tuple literal types.",
					UnexpectedTypeAnnotation: "Did not expect a type annotation here.",
					UnexpectedTypeCastInParameter: "Unexpected type cast in parameter position.",
					UnsupportedImportTypeArgument: "Argument in a type import must be a string literal.",
					UnsupportedParameterPropertyKind: "A parameter property may not be declared using a binding pattern.",
					UnsupportedSignatureParameterKind: ({ type: e }) => `Name in a signature must be an Identifier, ObjectPattern or ArrayPattern, instead got ${e}.`,
					UsingDeclarationInAmbientContext: (e) => `'${e}' declarations are not allowed in ambient contexts.`
				});
				function tsIsAccessModifier(e) {
					return "private" === e || "public" === e || "protected" === e;
				}
				function tsIsVarianceAnnotations(e) {
					return "in" === e || "out" === e;
				}
				function isPossiblyLiteralEnum(e) {
					if ("MemberExpression" !== e.type) return !1;
					const { computed: t, property: r } = e;
					return (!t || "StringLiteral" === r.type || !("TemplateLiteral" !== r.type || r.expressions.length > 0)) && isUncomputedMemberExpressionChain(e.object);
				}
				function isValidAmbientConstInitializer(e, t) {
					var r;
					const { type: n } = e;
					if (null != (r = e.extra) && r.parenthesized) return !1;
					if (t) {
						if ("Literal" === n) {
							const { value: t } = e;
							if ("string" == typeof t || "boolean" == typeof t) return !0;
						}
					} else if ("StringLiteral" === n || "BooleanLiteral" === n) return !0;
					return !(!isNumber(e, t) && !function(e, t) {
						if ("UnaryExpression" === e.type) {
							const { operator: r, argument: n } = e;
							if ("-" === r && isNumber(n, t)) return !0;
						}
						return !1;
					}(e, t)) || "TemplateLiteral" === n && 0 === e.expressions.length || !!isPossiblyLiteralEnum(e);
				}
				function isNumber(e, t) {
					return t ? "Literal" === e.type && ("number" == typeof e.value || "bigint" in e) : "NumericLiteral" === e.type || "BigIntLiteral" === e.type;
				}
				function isUncomputedMemberExpressionChain(e) {
					return "Identifier" === e.type || "MemberExpression" === e.type && !e.computed && isUncomputedMemberExpressionChain(e.object);
				}
				const Z = ParseErrorEnum`placeholders`({
					ClassNameIsRequired: "A class name is required.",
					UnexpectedSpace: "Unexpected space in placeholder."
				});
				const ee = [
					"minimal",
					"fsharp",
					"hack",
					"smart"
				], te = [
					"^^",
					"@@",
					"^",
					"%",
					"#"
				];
				const re = {
					estree: (e) => class extends e {
						parse() {
							const e = toESTreeLocation(super.parse());
							return 256 & this.optionFlags && (e.tokens = e.tokens.map(toESTreeLocation)), e;
						}
						parseRegExpLiteral({ pattern: e, flags: t }) {
							let r = null;
							try {
								r = new RegExp(e, t);
							} catch (e) {}
							const n = this.estreeParseLiteral(r);
							return n.regex = {
								pattern: e,
								flags: t
							}, n;
						}
						parseBigIntLiteral(e) {
							let t;
							try {
								t = BigInt(e);
							} catch (e) {
								t = null;
							}
							const r = this.estreeParseLiteral(t);
							return r.bigint = String(r.value || e), r;
						}
						parseDecimalLiteral(e) {
							const t = this.estreeParseLiteral(null);
							return t.decimal = String(t.value || e), t;
						}
						estreeParseLiteral(e) {
							return this.parseLiteral(e, "Literal");
						}
						parseStringLiteral(e) {
							return this.estreeParseLiteral(e);
						}
						parseNumericLiteral(e) {
							return this.estreeParseLiteral(e);
						}
						parseNullLiteral() {
							return this.estreeParseLiteral(null);
						}
						parseBooleanLiteral(e) {
							return this.estreeParseLiteral(e);
						}
						estreeParseChainExpression(e, t) {
							const r = this.startNodeAtNode(e);
							return r.expression = e, this.finishNodeAt(r, "ChainExpression", t);
						}
						directiveToStmt(e) {
							const t = e.value;
							delete e.value, this.castNodeTo(t, "Literal"), t.raw = t.extra.raw, t.value = t.extra.expressionValue;
							const r = this.castNodeTo(e, "ExpressionStatement");
							return r.expression = t, r.directive = t.extra.rawValue, delete t.extra, r;
						}
						fillOptionalPropertiesForTSESLint(e) {}
						cloneEstreeStringLiteral(e) {
							const { start: t, end: r, loc: n, range: s, raw: i, value: o } = e, a = Object.create(e.constructor.prototype);
							return a.type = "Literal", a.start = t, a.end = r, a.loc = n, a.range = s, a.raw = i, a.value = o, a;
						}
						initFunction(e, t) {
							super.initFunction(e, t), e.expression = !1;
						}
						checkDeclaration(e) {
							null != e && this.isObjectProperty(e) ? this.checkDeclaration(e.value) : super.checkDeclaration(e);
						}
						getObjectOrClassMethodParams(e) {
							return e.value.params;
						}
						isValidDirective(e) {
							var t;
							return "ExpressionStatement" === e.type && "Literal" === e.expression.type && "string" == typeof e.expression.value && !(null != (t = e.expression.extra) && t.parenthesized);
						}
						parseBlockBody(e, t, r, n, s) {
							super.parseBlockBody(e, t, r, n, s);
							e.body = e.directives.map((e) => this.directiveToStmt(e)).concat(e.body), delete e.directives;
						}
						parsePrivateName() {
							const e = super.parsePrivateName();
							return this.getPluginOption("estree", "classFeatures") ? this.convertPrivateNameToPrivateIdentifier(e) : e;
						}
						convertPrivateNameToPrivateIdentifier(e) {
							const t = super.getPrivateNameSV(e);
							return delete e.id, e.name = t, this.castNodeTo(e, "PrivateIdentifier");
						}
						isPrivateName(e) {
							return this.getPluginOption("estree", "classFeatures") ? "PrivateIdentifier" === e.type : super.isPrivateName(e);
						}
						getPrivateNameSV(e) {
							return this.getPluginOption("estree", "classFeatures") ? e.name : super.getPrivateNameSV(e);
						}
						parseLiteral(e, t) {
							const r = super.parseLiteral(e, t);
							return r.raw = r.extra.raw, delete r.extra, r;
						}
						parseFunctionBody(e, t, r = !1) {
							super.parseFunctionBody(e, t, r), e.expression = "BlockStatement" !== e.body.type;
						}
						parseMethod(e, t, r, n, s, i, o = !1) {
							let a = this.startNode();
							a.kind = e.kind, a = super.parseMethod(a, t, r, n, s, i, o), delete a.kind;
							const { typeParameters: l } = e;
							l && (delete e.typeParameters, a.typeParameters = l, this.resetStartLocationFromNode(a, l));
							return e.value = this.castNodeTo(a, "FunctionExpression"), "ClassPrivateMethod" === i && (e.computed = !1), "ObjectMethod" === i ? ("method" === e.kind && (e.kind = "init"), e.shorthand = !1, this.finishNode(e, "Property")) : this.finishNode(e, "MethodDefinition");
						}
						nameIsConstructor(e) {
							return "Literal" === e.type ? "constructor" === e.value : super.nameIsConstructor(e);
						}
						parseClassProperty(...e) {
							const t = super.parseClassProperty(...e);
							return this.getPluginOption("estree", "classFeatures") ? (this.castNodeTo(t, "PropertyDefinition"), t) : t;
						}
						parseClassPrivateProperty(...e) {
							const t = super.parseClassPrivateProperty(...e);
							return this.getPluginOption("estree", "classFeatures") ? (this.castNodeTo(t, "PropertyDefinition"), t.computed = !1, t) : t;
						}
						parseClassAccessorProperty(e) {
							const t = super.parseClassAccessorProperty(e);
							return this.getPluginOption("estree", "classFeatures") ? (t.abstract && this.hasPlugin("typescript") ? (delete t.abstract, this.castNodeTo(t, "TSAbstractAccessorProperty")) : this.castNodeTo(t, "AccessorProperty"), t) : t;
						}
						parseObjectProperty(e, t, r, n) {
							const s = super.parseObjectProperty(e, t, r, n);
							return s && (s.kind = "init", this.castNodeTo(s, "Property")), s;
						}
						finishObjectProperty(e) {
							return e.kind = "init", this.finishNode(e, "Property");
						}
						isValidLVal(e, t, r) {
							return "Property" === e ? "value" : super.isValidLVal(e, t, r);
						}
						isAssignable(e, t) {
							return null != e && this.isObjectProperty(e) ? this.isAssignable(e.value, t) : super.isAssignable(e, t);
						}
						toAssignable(e, t = !1) {
							if (null != e && this.isObjectProperty(e)) {
								const { key: r, value: n } = e;
								this.isPrivateName(r) && this.classScope.usePrivateName(this.getPrivateNameSV(r), r.loc.start), this.toAssignable(n, t);
							} else super.toAssignable(e, t);
						}
						toAssignableObjectExpressionProp(e, t, r) {
							"Property" !== e.type || "get" !== e.kind && "set" !== e.kind ? "Property" === e.type && e.method ? this.raise(c.PatternHasMethod, e.key) : super.toAssignableObjectExpressionProp(e, t, r) : this.raise(c.PatternHasAccessor, e.key);
						}
						finishCallExpression(e, t) {
							const r = super.finishCallExpression(e, t);
							var n, s;
							"Import" === r.callee.type ? (this.castNodeTo(r, "ImportExpression"), r.source = r.arguments[0], r.options = null != (n = r.arguments[1]) ? n : null, r.attributes = null != (s = r.arguments[1]) ? s : null, delete r.arguments, delete r.callee) : "OptionalCallExpression" === r.type ? this.castNodeTo(r, "CallExpression") : r.optional = !1;
							return r;
						}
						toReferencedArguments(e) {
							"ImportExpression" !== e.type && super.toReferencedArguments(e);
						}
						parseExport(e, t) {
							const r = this.state.lastTokStartLoc, n = super.parseExport(e, t);
							switch (n.type) {
								case "ExportAllDeclaration":
									n.exported = null;
									break;
								case "ExportNamedDeclaration": 1 === n.specifiers.length && "ExportNamespaceSpecifier" === n.specifiers[0].type && (this.castNodeTo(n, "ExportAllDeclaration"), n.exported = n.specifiers[0].exported, delete n.specifiers);
								case "ExportDefaultDeclaration": {
									var s;
									const { declaration: e } = n;
									"ClassDeclaration" === (null == e ? void 0 : e.type) && (null == (s = e.decorators) ? void 0 : s.length) > 0 && e.start === n.start && this.resetStartLocation(n, r);
								}
							}
							return n;
						}
						stopParseSubscript(e, t) {
							const r = super.stopParseSubscript(e, t);
							return t.optionalChainMember ? this.estreeParseChainExpression(r, e.loc.end) : r;
						}
						parseMember(e, t, r, n, s) {
							const i = super.parseMember(e, t, r, n, s);
							return "OptionalMemberExpression" === i.type ? this.castNodeTo(i, "MemberExpression") : i.optional = !1, i;
						}
						isOptionalMemberExpression(e) {
							return "ChainExpression" === e.type ? "MemberExpression" === e.expression.type : super.isOptionalMemberExpression(e);
						}
						hasPropertyAsPrivateName(e) {
							return "ChainExpression" === e.type && (e = e.expression), super.hasPropertyAsPrivateName(e);
						}
						isObjectProperty(e) {
							return "Property" === e.type && "init" === e.kind && !e.method;
						}
						isObjectMethod(e) {
							return "Property" === e.type && (e.method || "get" === e.kind || "set" === e.kind);
						}
						castNodeTo(e, t) {
							const r = super.castNodeTo(e, t);
							return this.fillOptionalPropertiesForTSESLint(r), r;
						}
						cloneIdentifier(e) {
							const t = super.cloneIdentifier(e);
							return this.fillOptionalPropertiesForTSESLint(t), t;
						}
						cloneStringLiteral(e) {
							return "Literal" === e.type ? this.cloneEstreeStringLiteral(e) : super.cloneStringLiteral(e);
						}
						finishNodeAt(e, t, r) {
							return toESTreeLocation(super.finishNodeAt(e, t, r));
						}
						finishNode(e, t) {
							const r = super.finishNode(e, t);
							return this.fillOptionalPropertiesForTSESLint(r), r;
						}
						resetStartLocation(e, t) {
							super.resetStartLocation(e, t), toESTreeLocation(e);
						}
						resetEndLocation(e, t = this.state.lastTokEndLoc) {
							super.resetEndLocation(e, t), toESTreeLocation(e);
						}
					},
					jsx: (e) => class extends e {
						jsxReadToken() {
							let e = "", t = this.state.pos;
							for (;;) {
								if (this.state.pos >= this.length) throw this.raise(z.UnterminatedJsxContent, this.state.startLoc);
								const r = this.input.charCodeAt(this.state.pos);
								switch (r) {
									case 60:
									case 123:
										this.state.pos === this.state.start ? 60 === r && this.state.canStartJSXElement ? (++this.state.pos, this.finishToken(143)) : super.getTokenFromCode(r) : (e += this.input.slice(t, this.state.pos), this.finishToken(142, e));
										return;
									case 38:
										e += this.input.slice(t, this.state.pos), e += this.jsxReadEntity(), t = this.state.pos;
										break;
									default: isNewLine(r) ? (e += this.input.slice(t, this.state.pos), e += this.jsxReadNewLine(!0), t = this.state.pos) : ++this.state.pos;
								}
							}
						}
						jsxReadNewLine(e) {
							const t = this.input.charCodeAt(this.state.pos);
							let r;
							return ++this.state.pos, 13 === t && 10 === this.input.charCodeAt(this.state.pos) ? (++this.state.pos, r = e ? "\n" : "\r\n") : r = String.fromCharCode(t), ++this.state.curLine, this.state.lineStart = this.state.pos, r;
						}
						jsxReadString(e) {
							let t = "", r = ++this.state.pos;
							for (;;) {
								if (this.state.pos >= this.length) throw this.raise(c.UnterminatedString, this.state.startLoc);
								const n = this.input.charCodeAt(this.state.pos);
								if (n === e) break;
								38 === n ? (t += this.input.slice(r, this.state.pos), t += this.jsxReadEntity(), r = this.state.pos) : isNewLine(n) ? (t += this.input.slice(r, this.state.pos), t += this.jsxReadNewLine(!1), r = this.state.pos) : ++this.state.pos;
							}
							t += this.input.slice(r, this.state.pos++), this.finishToken(134, t);
						}
						jsxReadEntity() {
							const e = ++this.state.pos;
							if (35 === this.codePointAtPos(this.state.pos)) {
								++this.state.pos;
								let e = 10;
								120 === this.codePointAtPos(this.state.pos) && (e = 16, ++this.state.pos);
								const t = this.readInt(e, void 0, !1, "bail");
								if (null !== t && 59 === this.codePointAtPos(this.state.pos)) return ++this.state.pos, String.fromCodePoint(t);
							} else {
								let t = 0, r = !1;
								for (; t++ < 10 && this.state.pos < this.length && !(r = 59 === this.codePointAtPos(this.state.pos));) ++this.state.pos;
								if (r) {
									const r = K[this.input.slice(e, this.state.pos)];
									if (++this.state.pos, r) return r;
								}
							}
							return this.state.pos = e, "&";
						}
						jsxReadWord() {
							let e;
							const t = this.state.pos;
							do
								e = this.input.charCodeAt(++this.state.pos);
							while (isIdentifierChar(e) || 45 === e);
							this.finishToken(141, this.input.slice(t, this.state.pos));
						}
						jsxParseIdentifier() {
							const e = this.startNode();
							return this.match(141) ? e.name = this.state.value : tokenIsKeyword(this.state.type) ? e.name = tokenLabelName(this.state.type) : this.unexpected(), this.next(), this.finishNode(e, "JSXIdentifier");
						}
						jsxParseNamespacedName() {
							const e = this.state.startLoc, t = this.jsxParseIdentifier();
							if (!this.eat(14)) return t;
							const r = this.startNodeAt(e);
							return r.namespace = t, r.name = this.jsxParseIdentifier(), this.finishNode(r, "JSXNamespacedName");
						}
						jsxParseElementName() {
							const e = this.state.startLoc;
							let t = this.jsxParseNamespacedName();
							if ("JSXNamespacedName" === t.type) return t;
							for (; this.eat(16);) {
								const r = this.startNodeAt(e);
								r.object = t, r.property = this.jsxParseIdentifier(), t = this.finishNode(r, "JSXMemberExpression");
							}
							return t;
						}
						jsxParseAttributeValue() {
							let e;
							switch (this.state.type) {
								case 5: return e = this.startNode(), this.setContext(d.brace), this.next(), e = this.jsxParseExpressionContainer(e, d.j_oTag), "JSXEmptyExpression" === e.expression.type && this.raise(z.AttributeIsEmpty, e), e;
								case 143:
								case 134: return this.parseExprAtom();
								default: throw this.raise(z.UnsupportedJsxValue, this.state.startLoc);
							}
						}
						jsxParseEmptyExpression() {
							const e = this.startNodeAt(this.state.lastTokEndLoc);
							return this.finishNodeAt(e, "JSXEmptyExpression", this.state.startLoc);
						}
						jsxParseSpreadChild(e) {
							return this.next(), e.expression = this.parseExpression(), this.setContext(d.j_expr), this.state.canStartJSXElement = !0, this.expect(8), this.finishNode(e, "JSXSpreadChild");
						}
						jsxParseExpressionContainer(e, t) {
							if (this.match(8)) e.expression = this.jsxParseEmptyExpression();
							else e.expression = this.parseExpression();
							return this.setContext(t), this.state.canStartJSXElement = !0, this.expect(8), this.finishNode(e, "JSXExpressionContainer");
						}
						jsxParseAttribute() {
							const e = this.startNode();
							return this.match(5) ? (this.setContext(d.brace), this.next(), this.expect(21), e.argument = this.parseMaybeAssignAllowIn(), this.setContext(d.j_oTag), this.state.canStartJSXElement = !0, this.expect(8), this.finishNode(e, "JSXSpreadAttribute")) : (e.name = this.jsxParseNamespacedName(), e.value = this.eat(29) ? this.jsxParseAttributeValue() : null, this.finishNode(e, "JSXAttribute"));
						}
						jsxParseOpeningElementAt(e) {
							const t = this.startNodeAt(e);
							return this.eat(144) ? this.finishNode(t, "JSXOpeningFragment") : (t.name = this.jsxParseElementName(), this.jsxParseOpeningElementAfterName(t));
						}
						jsxParseOpeningElementAfterName(e) {
							const t = [];
							for (; !this.match(56) && !this.match(144);) t.push(this.jsxParseAttribute());
							return e.attributes = t, e.selfClosing = this.eat(56), this.expect(144), this.finishNode(e, "JSXOpeningElement");
						}
						jsxParseClosingElementAt(e) {
							const t = this.startNodeAt(e);
							return this.eat(144) ? this.finishNode(t, "JSXClosingFragment") : (t.name = this.jsxParseElementName(), this.expect(144), this.finishNode(t, "JSXClosingElement"));
						}
						jsxParseElementAt(e) {
							const t = this.startNodeAt(e), r = [], n = this.jsxParseOpeningElementAt(e);
							let s = null;
							if (!n.selfClosing) {
								e: for (;;) switch (this.state.type) {
									case 143:
										if (e = this.state.startLoc, this.next(), this.eat(56)) {
											s = this.jsxParseClosingElementAt(e);
											break e;
										}
										r.push(this.jsxParseElementAt(e));
										break;
									case 142:
										r.push(this.parseLiteral(this.state.value, "JSXText"));
										break;
									case 5: {
										const e = this.startNode();
										this.setContext(d.brace), this.next(), this.match(21) ? r.push(this.jsxParseSpreadChild(e)) : r.push(this.jsxParseExpressionContainer(e, d.j_expr));
										break;
									}
									default: this.unexpected();
								}
								isFragment(n) && !isFragment(s) && null !== s ? this.raise(z.MissingClosingTagFragment, s) : !isFragment(n) && isFragment(s) ? this.raise(z.MissingClosingTagElement, s, { openingTagName: getQualifiedJSXName(n.name) }) : isFragment(n) || isFragment(s) || getQualifiedJSXName(s.name) !== getQualifiedJSXName(n.name) && this.raise(z.MissingClosingTagElement, s, { openingTagName: getQualifiedJSXName(n.name) });
							}
							if (isFragment(n) ? (t.openingFragment = n, t.closingFragment = s) : (t.openingElement = n, t.closingElement = s), t.children = r, this.match(47)) throw this.raise(z.UnwrappedAdjacentJSXElements, this.state.startLoc);
							return isFragment(n) ? this.finishNode(t, "JSXFragment") : this.finishNode(t, "JSXElement");
						}
						jsxParseElement() {
							const e = this.state.startLoc;
							return this.next(), this.jsxParseElementAt(e);
						}
						setContext(e) {
							const { context: t } = this.state;
							t[t.length - 1] = e;
						}
						parseExprAtom(e) {
							return this.match(143) ? this.jsxParseElement() : this.match(47) && 33 !== this.input.charCodeAt(this.state.pos) ? (this.replaceToken(143), this.jsxParseElement()) : super.parseExprAtom(e);
						}
						skipSpace() {
							this.curContext().preserveSpace || super.skipSpace();
						}
						getTokenFromCode(e) {
							const t = this.curContext();
							if (t !== d.j_expr) {
								if (t === d.j_oTag || t === d.j_cTag) {
									if (isIdentifierStart(e)) return void this.jsxReadWord();
									if (62 === e) return ++this.state.pos, void this.finishToken(144);
									if ((34 === e || 39 === e) && t === d.j_oTag) return void this.jsxReadString(e);
								}
								if (60 === e && this.state.canStartJSXElement && 33 !== this.input.charCodeAt(this.state.pos + 1)) return ++this.state.pos, void this.finishToken(143);
								super.getTokenFromCode(e);
							} else this.jsxReadToken();
						}
						updateContext(e) {
							const { context: t, type: r } = this.state;
							if (56 === r && 143 === e) t.splice(-2, 2, d.j_cTag), this.state.canStartJSXElement = !1;
							else if (143 === r) t.push(d.j_oTag);
							else if (144 === r) {
								const r = t[t.length - 1];
								r === d.j_oTag && 56 === e || r === d.j_cTag ? (t.pop(), this.state.canStartJSXElement = t[t.length - 1] === d.j_expr) : (this.setContext(d.j_expr), this.state.canStartJSXElement = !0);
							} else this.state.canStartJSXElement = S[r];
						}
					},
					flow: (e) => class extends e {
						constructor(...e) {
							super(...e), this.flowPragma = void 0;
						}
						getScopeHandler() {
							return FlowScopeHandler;
						}
						shouldParseTypes() {
							return this.getPluginOption("flow", "all") || "flow" === this.flowPragma;
						}
						finishToken(e, t) {
							134 !== e && 13 !== e && 28 !== e && void 0 === this.flowPragma && (this.flowPragma = null), super.finishToken(e, t);
						}
						addComment(e) {
							if (void 0 === this.flowPragma) {
								const t = $.exec(e.value);
								if (t) if ("flow" === t[1]) this.flowPragma = "flow";
								else {
									if ("noflow" !== t[1]) throw new Error("Unexpected flow pragma");
									this.flowPragma = "noflow";
								}
							}
							super.addComment(e);
						}
						flowParseTypeInitialiser(e) {
							const t = this.state.inType;
							this.state.inType = !0, this.expect(e || 14);
							const r = this.flowParseType();
							return this.state.inType = t, r;
						}
						flowParsePredicate() {
							const e = this.startNode(), t = this.state.startLoc;
							return this.next(), this.expectContextual(110), this.state.lastTokStartLoc.index > t.index + 1 && this.raise(U.UnexpectedSpaceBetweenModuloChecks, t), this.eat(10) ? (e.value = super.parseExpression(), this.expect(11), this.finishNode(e, "DeclaredPredicate")) : this.finishNode(e, "InferredPredicate");
						}
						flowParseTypeAndPredicateInitialiser() {
							const e = this.state.inType;
							this.state.inType = !0, this.expect(14);
							let t = null, r = null;
							return this.match(54) ? (this.state.inType = e, r = this.flowParsePredicate()) : (t = this.flowParseType(), this.state.inType = e, this.match(54) && (r = this.flowParsePredicate())), [t, r];
						}
						flowParseDeclareClass(e) {
							return this.next(), this.flowParseInterfaceish(e, !0), this.finishNode(e, "DeclareClass");
						}
						flowParseDeclareFunction(e) {
							this.next();
							const t = e.id = this.parseIdentifier(), r = this.startNode(), n = this.startNode();
							this.match(47) ? r.typeParameters = this.flowParseTypeParameterDeclaration() : r.typeParameters = null, this.expect(10);
							const s = this.flowParseFunctionTypeParams();
							return r.params = s.params, r.rest = s.rest, r.this = s._this, this.expect(11), [r.returnType, e.predicate] = this.flowParseTypeAndPredicateInitialiser(), n.typeAnnotation = this.finishNode(r, "FunctionTypeAnnotation"), t.typeAnnotation = this.finishNode(n, "TypeAnnotation"), this.resetEndLocation(t), this.semicolon(), this.scope.declareName(e.id.name, 2048, e.id.loc.start), this.finishNode(e, "DeclareFunction");
						}
						flowParseDeclare(e, t) {
							return this.match(80) ? this.flowParseDeclareClass(e) : this.match(68) ? this.flowParseDeclareFunction(e) : this.match(74) ? this.flowParseDeclareVariable(e) : this.eatContextual(127) ? this.match(16) ? this.flowParseDeclareModuleExports(e) : (t && this.raise(U.NestedDeclareModule, this.state.lastTokStartLoc), this.flowParseDeclareModule(e)) : this.isContextual(130) ? this.flowParseDeclareTypeAlias(e) : this.isContextual(131) ? this.flowParseDeclareOpaqueType(e) : this.isContextual(129) ? this.flowParseDeclareInterface(e) : this.match(82) ? this.flowParseDeclareExportDeclaration(e, t) : void this.unexpected();
						}
						flowParseDeclareVariable(e) {
							return this.next(), e.id = this.flowParseTypeAnnotatableIdentifier(!0), this.scope.declareName(e.id.name, 5, e.id.loc.start), this.semicolon(), this.finishNode(e, "DeclareVariable");
						}
						flowParseDeclareModule(e) {
							this.scope.enter(0), this.match(134) ? e.id = super.parseExprAtom() : e.id = this.parseIdentifier();
							const t = e.body = this.startNode(), r = t.body = [];
							for (this.expect(5); !this.match(8);) {
								let e = this.startNode();
								this.match(83) ? (this.next(), this.isContextual(130) || this.match(87) || this.raise(U.InvalidNonTypeImportInDeclareModule, this.state.lastTokStartLoc), super.parseImport(e)) : (this.expectContextual(125, U.UnsupportedStatementInDeclareModule), e = this.flowParseDeclare(e, !0)), r.push(e);
							}
							this.scope.exit(), this.expect(8), this.finishNode(t, "BlockStatement");
							let n = null, s = !1;
							return r.forEach((e) => {
								!function(e) {
									return "DeclareExportAllDeclaration" === e.type || "DeclareExportDeclaration" === e.type && (!e.declaration || "TypeAlias" !== e.declaration.type && "InterfaceDeclaration" !== e.declaration.type);
								}(e) ? "DeclareModuleExports" === e.type && (s && this.raise(U.DuplicateDeclareModuleExports, e), "ES" === n && this.raise(U.AmbiguousDeclareModuleKind, e), n = "CommonJS", s = !0) : ("CommonJS" === n && this.raise(U.AmbiguousDeclareModuleKind, e), n = "ES");
							}), e.kind = n || "CommonJS", this.finishNode(e, "DeclareModule");
						}
						flowParseDeclareExportDeclaration(e, t) {
							if (this.expect(82), this.eat(65)) return this.match(68) || this.match(80) ? e.declaration = this.flowParseDeclare(this.startNode()) : (e.declaration = this.flowParseType(), this.semicolon()), e.default = !0, this.finishNode(e, "DeclareExportDeclaration");
							if (this.match(75) || this.isLet() || (this.isContextual(130) || this.isContextual(129)) && !t) {
								const e = this.state.value;
								throw this.raise(U.UnsupportedDeclareExportKind, this.state.startLoc, {
									unsupportedExportKind: e,
									suggestion: V[e]
								});
							}
							return this.match(74) || this.match(68) || this.match(80) || this.isContextual(131) ? (e.declaration = this.flowParseDeclare(this.startNode()), e.default = !1, this.finishNode(e, "DeclareExportDeclaration")) : this.match(55) || this.match(5) || this.isContextual(129) || this.isContextual(130) || this.isContextual(131) ? "ExportNamedDeclaration" === (e = this.parseExport(e, null)).type ? (e.default = !1, delete e.exportKind, this.castNodeTo(e, "DeclareExportDeclaration")) : this.castNodeTo(e, "DeclareExportAllDeclaration") : void this.unexpected();
						}
						flowParseDeclareModuleExports(e) {
							return this.next(), this.expectContextual(111), e.typeAnnotation = this.flowParseTypeAnnotation(), this.semicolon(), this.finishNode(e, "DeclareModuleExports");
						}
						flowParseDeclareTypeAlias(e) {
							this.next();
							const t = this.flowParseTypeAlias(e);
							return this.castNodeTo(t, "DeclareTypeAlias"), t;
						}
						flowParseDeclareOpaqueType(e) {
							this.next();
							const t = this.flowParseOpaqueType(e, !0);
							return this.castNodeTo(t, "DeclareOpaqueType"), t;
						}
						flowParseDeclareInterface(e) {
							return this.next(), this.flowParseInterfaceish(e, !1), this.finishNode(e, "DeclareInterface");
						}
						flowParseInterfaceish(e, t) {
							if (e.id = this.flowParseRestrictedIdentifier(!t, !0), this.scope.declareName(e.id.name, t ? 17 : 8201, e.id.loc.start), this.match(47) ? e.typeParameters = this.flowParseTypeParameterDeclaration() : e.typeParameters = null, e.extends = [], this.eat(81)) do
								e.extends.push(this.flowParseInterfaceExtends());
							while (!t && this.eat(12));
							if (t) {
								if (e.implements = [], e.mixins = [], this.eatContextual(117)) do
									e.mixins.push(this.flowParseInterfaceExtends());
								while (this.eat(12));
								if (this.eatContextual(113)) do
									e.implements.push(this.flowParseInterfaceExtends());
								while (this.eat(12));
							}
							e.body = this.flowParseObjectType({
								allowStatic: t,
								allowExact: !1,
								allowSpread: !1,
								allowProto: t,
								allowInexact: !1
							});
						}
						flowParseInterfaceExtends() {
							const e = this.startNode();
							return e.id = this.flowParseQualifiedTypeIdentifier(), this.match(47) ? e.typeParameters = this.flowParseTypeParameterInstantiation() : e.typeParameters = null, this.finishNode(e, "InterfaceExtends");
						}
						flowParseInterface(e) {
							return this.flowParseInterfaceish(e, !1), this.finishNode(e, "InterfaceDeclaration");
						}
						checkNotUnderscore(e) {
							"_" === e && this.raise(U.UnexpectedReservedUnderscore, this.state.startLoc);
						}
						checkReservedType(e, t, r) {
							R.has(e) && this.raise(r ? U.AssignReservedType : U.UnexpectedReservedType, t, { reservedType: e });
						}
						flowParseRestrictedIdentifier(e, t) {
							return this.checkReservedType(this.state.value, this.state.startLoc, t), this.parseIdentifier(e);
						}
						flowParseTypeAlias(e) {
							return e.id = this.flowParseRestrictedIdentifier(!1, !0), this.scope.declareName(e.id.name, 8201, e.id.loc.start), this.match(47) ? e.typeParameters = this.flowParseTypeParameterDeclaration() : e.typeParameters = null, e.right = this.flowParseTypeInitialiser(29), this.semicolon(), this.finishNode(e, "TypeAlias");
						}
						flowParseOpaqueType(e, t) {
							return this.expectContextual(130), e.id = this.flowParseRestrictedIdentifier(!0, !0), this.scope.declareName(e.id.name, 8201, e.id.loc.start), this.match(47) ? e.typeParameters = this.flowParseTypeParameterDeclaration() : e.typeParameters = null, e.supertype = null, this.match(14) && (e.supertype = this.flowParseTypeInitialiser(14)), e.impltype = null, t || (e.impltype = this.flowParseTypeInitialiser(29)), this.semicolon(), this.finishNode(e, "OpaqueType");
						}
						flowParseTypeParameter(e = !1) {
							const t = this.state.startLoc, r = this.startNode(), n = this.flowParseVariance(), s = this.flowParseTypeAnnotatableIdentifier();
							return r.name = s.name, r.variance = n, r.bound = s.typeAnnotation, this.match(29) ? (this.eat(29), r.default = this.flowParseType()) : e && this.raise(U.MissingTypeParamDefault, t), this.finishNode(r, "TypeParameter");
						}
						flowParseTypeParameterDeclaration() {
							const e = this.state.inType, t = this.startNode();
							t.params = [], this.state.inType = !0, this.match(47) || this.match(143) ? this.next() : this.unexpected();
							let r = !1;
							do {
								const e = this.flowParseTypeParameter(r);
								t.params.push(e), e.default && (r = !0), this.match(48) || this.expect(12);
							} while (!this.match(48));
							return this.expect(48), this.state.inType = e, this.finishNode(t, "TypeParameterDeclaration");
						}
						flowInTopLevelContext(e) {
							if (this.curContext() === d.brace) return e();
							{
								const t = this.state.context;
								this.state.context = [t[0]];
								try {
									return e();
								} finally {
									this.state.context = t;
								}
							}
						}
						flowParseTypeParameterInstantiationInExpression() {
							if (47 === this.reScan_lt()) return this.flowParseTypeParameterInstantiation();
						}
						flowParseTypeParameterInstantiation() {
							const e = this.startNode(), t = this.state.inType;
							return this.state.inType = !0, e.params = [], this.flowInTopLevelContext(() => {
								this.expect(47);
								const t = this.state.noAnonFunctionType;
								for (this.state.noAnonFunctionType = !1; !this.match(48);) e.params.push(this.flowParseType()), this.match(48) || this.expect(12);
								this.state.noAnonFunctionType = t;
							}), this.state.inType = t, this.state.inType || this.curContext() !== d.brace || this.reScan_lt_gt(), this.expect(48), this.finishNode(e, "TypeParameterInstantiation");
						}
						flowParseTypeParameterInstantiationCallOrNew() {
							if (47 !== this.reScan_lt()) return;
							const e = this.startNode(), t = this.state.inType;
							for (e.params = [], this.state.inType = !0, this.expect(47); !this.match(48);) e.params.push(this.flowParseTypeOrImplicitInstantiation()), this.match(48) || this.expect(12);
							return this.expect(48), this.state.inType = t, this.finishNode(e, "TypeParameterInstantiation");
						}
						flowParseInterfaceType() {
							const e = this.startNode();
							if (this.expectContextual(129), e.extends = [], this.eat(81)) do
								e.extends.push(this.flowParseInterfaceExtends());
							while (this.eat(12));
							return e.body = this.flowParseObjectType({
								allowStatic: !1,
								allowExact: !1,
								allowSpread: !1,
								allowProto: !1,
								allowInexact: !1
							}), this.finishNode(e, "InterfaceTypeAnnotation");
						}
						flowParseObjectPropertyKey() {
							return this.match(135) || this.match(134) ? super.parseExprAtom() : this.parseIdentifier(!0);
						}
						flowParseObjectTypeIndexer(e, t, r) {
							return e.static = t, 14 === this.lookahead().type ? (e.id = this.flowParseObjectPropertyKey(), e.key = this.flowParseTypeInitialiser()) : (e.id = null, e.key = this.flowParseType()), this.expect(3), e.value = this.flowParseTypeInitialiser(), e.variance = r, this.finishNode(e, "ObjectTypeIndexer");
						}
						flowParseObjectTypeInternalSlot(e, t) {
							return e.static = t, e.id = this.flowParseObjectPropertyKey(), this.expect(3), this.expect(3), this.match(47) || this.match(10) ? (e.method = !0, e.optional = !1, e.value = this.flowParseObjectTypeMethodish(this.startNodeAt(e.loc.start))) : (e.method = !1, this.eat(17) && (e.optional = !0), e.value = this.flowParseTypeInitialiser()), this.finishNode(e, "ObjectTypeInternalSlot");
						}
						flowParseObjectTypeMethodish(e) {
							for (e.params = [], e.rest = null, e.typeParameters = null, e.this = null, this.match(47) && (e.typeParameters = this.flowParseTypeParameterDeclaration()), this.expect(10), this.match(78) && (e.this = this.flowParseFunctionTypeParam(!0), e.this.name = null, this.match(11) || this.expect(12)); !this.match(11) && !this.match(21);) e.params.push(this.flowParseFunctionTypeParam(!1)), this.match(11) || this.expect(12);
							return this.eat(21) && (e.rest = this.flowParseFunctionTypeParam(!1)), this.expect(11), e.returnType = this.flowParseTypeInitialiser(), this.finishNode(e, "FunctionTypeAnnotation");
						}
						flowParseObjectTypeCallProperty(e, t) {
							const r = this.startNode();
							return e.static = t, e.value = this.flowParseObjectTypeMethodish(r), this.finishNode(e, "ObjectTypeCallProperty");
						}
						flowParseObjectType({ allowStatic: e, allowExact: t, allowSpread: r, allowProto: n, allowInexact: s }) {
							const i = this.state.inType;
							this.state.inType = !0;
							const o = this.startNode();
							let a, l;
							o.callProperties = [], o.properties = [], o.indexers = [], o.internalSlots = [];
							let p = !1;
							for (t && this.match(6) ? (this.expect(6), a = 9, l = !0) : (this.expect(5), a = 8, l = !1), o.exact = l; !this.match(a);) {
								let t = !1, i = null, a = null;
								const c = this.startNode();
								if (n && this.isContextual(118)) {
									const t = this.lookahead();
									14 !== t.type && 17 !== t.type && (this.next(), i = this.state.startLoc, e = !1);
								}
								if (e && this.isContextual(106)) {
									const e = this.lookahead();
									14 !== e.type && 17 !== e.type && (this.next(), t = !0);
								}
								const u = this.flowParseVariance();
								if (this.eat(0)) null != i && this.unexpected(i), this.eat(0) ? (u && this.unexpected(u.loc.start), o.internalSlots.push(this.flowParseObjectTypeInternalSlot(c, t))) : o.indexers.push(this.flowParseObjectTypeIndexer(c, t, u));
								else if (this.match(10) || this.match(47)) null != i && this.unexpected(i), u && this.unexpected(u.loc.start), o.callProperties.push(this.flowParseObjectTypeCallProperty(c, t));
								else {
									let e = "init";
									if (this.isContextual(99) || this.isContextual(104)) tokenIsLiteralPropertyName(this.lookahead().type) && (e = this.state.value, this.next());
									const n = this.flowParseObjectTypeProperty(c, t, i, u, e, r, null != s ? s : !l);
									null === n ? (p = !0, a = this.state.lastTokStartLoc) : o.properties.push(n);
								}
								this.flowObjectTypeSemicolon(), !a || this.match(8) || this.match(9) || this.raise(U.UnexpectedExplicitInexactInObject, a);
							}
							this.expect(a), r && (o.inexact = p);
							const c = this.finishNode(o, "ObjectTypeAnnotation");
							return this.state.inType = i, c;
						}
						flowParseObjectTypeProperty(e, t, r, n, s, i, o) {
							if (this.eat(21)) return this.match(12) || this.match(13) || this.match(8) || this.match(9) ? (i ? o || this.raise(U.InexactInsideExact, this.state.lastTokStartLoc) : this.raise(U.InexactInsideNonObject, this.state.lastTokStartLoc), n && this.raise(U.InexactVariance, n), null) : (i || this.raise(U.UnexpectedSpreadType, this.state.lastTokStartLoc), null != r && this.unexpected(r), n && this.raise(U.SpreadVariance, n), e.argument = this.flowParseType(), this.finishNode(e, "ObjectTypeSpreadProperty"));
							{
								e.key = this.flowParseObjectPropertyKey(), e.static = t, e.proto = null != r, e.kind = s;
								let o = !1;
								return this.match(47) || this.match(10) ? (e.method = !0, null != r && this.unexpected(r), n && this.unexpected(n.loc.start), e.value = this.flowParseObjectTypeMethodish(this.startNodeAt(e.loc.start)), "get" !== s && "set" !== s || this.flowCheckGetterSetterParams(e), !i && "constructor" === e.key.name && e.value.this && this.raise(U.ThisParamBannedInConstructor, e.value.this)) : ("init" !== s && this.unexpected(), e.method = !1, this.eat(17) && (o = !0), e.value = this.flowParseTypeInitialiser(), e.variance = n), e.optional = o, this.finishNode(e, "ObjectTypeProperty");
							}
						}
						flowCheckGetterSetterParams(e) {
							const t = "get" === e.kind ? 0 : 1, r = e.value.params.length + (e.value.rest ? 1 : 0);
							e.value.this && this.raise("get" === e.kind ? U.GetterMayNotHaveThisParam : U.SetterMayNotHaveThisParam, e.value.this), r !== t && this.raise("get" === e.kind ? c.BadGetterArity : c.BadSetterArity, e), "set" === e.kind && e.value.rest && this.raise(c.BadSetterRestParameter, e);
						}
						flowObjectTypeSemicolon() {
							this.eat(13) || this.eat(12) || this.match(8) || this.match(9) || this.unexpected();
						}
						flowParseQualifiedTypeIdentifier(e, t) {
							e ?? (e = this.state.startLoc);
							let r = t || this.flowParseRestrictedIdentifier(!0);
							for (; this.eat(16);) {
								const t = this.startNodeAt(e);
								t.qualification = r, t.id = this.flowParseRestrictedIdentifier(!0), r = this.finishNode(t, "QualifiedTypeIdentifier");
							}
							return r;
						}
						flowParseGenericType(e, t) {
							const r = this.startNodeAt(e);
							return r.typeParameters = null, r.id = this.flowParseQualifiedTypeIdentifier(e, t), this.match(47) && (r.typeParameters = this.flowParseTypeParameterInstantiation()), this.finishNode(r, "GenericTypeAnnotation");
						}
						flowParseTypeofType() {
							const e = this.startNode();
							return this.expect(87), e.argument = this.flowParsePrimaryType(), this.finishNode(e, "TypeofTypeAnnotation");
						}
						flowParseTupleType() {
							const e = this.startNode();
							for (e.types = [], this.expect(0); this.state.pos < this.length && !this.match(3) && (e.types.push(this.flowParseType()), !this.match(3));) this.expect(12);
							return this.expect(3), this.finishNode(e, "TupleTypeAnnotation");
						}
						flowParseFunctionTypeParam(e) {
							let t = null, r = !1, n = null;
							const s = this.startNode(), i = this.lookahead(), o = 78 === this.state.type;
							return 14 === i.type || 17 === i.type ? (o && !e && this.raise(U.ThisParamMustBeFirst, s), t = this.parseIdentifier(o), this.eat(17) && (r = !0, o && this.raise(U.ThisParamMayNotBeOptional, s)), n = this.flowParseTypeInitialiser()) : n = this.flowParseType(), s.name = t, s.optional = r, s.typeAnnotation = n, this.finishNode(s, "FunctionTypeParam");
						}
						reinterpretTypeAsFunctionTypeParam(e) {
							const t = this.startNodeAt(e.loc.start);
							return t.name = null, t.optional = !1, t.typeAnnotation = e, this.finishNode(t, "FunctionTypeParam");
						}
						flowParseFunctionTypeParams(e = []) {
							let t = null, r = null;
							for (this.match(78) && (r = this.flowParseFunctionTypeParam(!0), r.name = null, this.match(11) || this.expect(12)); !this.match(11) && !this.match(21);) e.push(this.flowParseFunctionTypeParam(!1)), this.match(11) || this.expect(12);
							return this.eat(21) && (t = this.flowParseFunctionTypeParam(!1)), {
								params: e,
								rest: t,
								_this: r
							};
						}
						flowIdentToTypeAnnotation(e, t, r) {
							switch (r.name) {
								case "any": return this.finishNode(t, "AnyTypeAnnotation");
								case "bool":
								case "boolean": return this.finishNode(t, "BooleanTypeAnnotation");
								case "mixed": return this.finishNode(t, "MixedTypeAnnotation");
								case "empty": return this.finishNode(t, "EmptyTypeAnnotation");
								case "number": return this.finishNode(t, "NumberTypeAnnotation");
								case "string": return this.finishNode(t, "StringTypeAnnotation");
								case "symbol": return this.finishNode(t, "SymbolTypeAnnotation");
								default: return this.checkNotUnderscore(r.name), this.flowParseGenericType(e, r);
							}
						}
						flowParsePrimaryType() {
							const e = this.state.startLoc, t = this.startNode();
							let r, n, s = !1;
							const i = this.state.noAnonFunctionType;
							switch (this.state.type) {
								case 5: return this.flowParseObjectType({
									allowStatic: !1,
									allowExact: !1,
									allowSpread: !0,
									allowProto: !1,
									allowInexact: !0
								});
								case 6: return this.flowParseObjectType({
									allowStatic: !1,
									allowExact: !0,
									allowSpread: !0,
									allowProto: !1,
									allowInexact: !1
								});
								case 0: return this.state.noAnonFunctionType = !1, n = this.flowParseTupleType(), this.state.noAnonFunctionType = i, n;
								case 47: {
									const e = this.startNode();
									return e.typeParameters = this.flowParseTypeParameterDeclaration(), this.expect(10), r = this.flowParseFunctionTypeParams(), e.params = r.params, e.rest = r.rest, e.this = r._this, this.expect(11), this.expect(19), e.returnType = this.flowParseType(), this.finishNode(e, "FunctionTypeAnnotation");
								}
								case 10: {
									const e = this.startNode();
									if (this.next(), !this.match(11) && !this.match(21)) if (tokenIsIdentifier(this.state.type) || this.match(78)) {
										const e = this.lookahead().type;
										s = 17 !== e && 14 !== e;
									} else s = !0;
									if (s) {
										if (this.state.noAnonFunctionType = !1, n = this.flowParseType(), this.state.noAnonFunctionType = i, this.state.noAnonFunctionType || !(this.match(12) || this.match(11) && 19 === this.lookahead().type)) return this.expect(11), n;
										this.eat(12);
									}
									return r = n ? this.flowParseFunctionTypeParams([this.reinterpretTypeAsFunctionTypeParam(n)]) : this.flowParseFunctionTypeParams(), e.params = r.params, e.rest = r.rest, e.this = r._this, this.expect(11), this.expect(19), e.returnType = this.flowParseType(), e.typeParameters = null, this.finishNode(e, "FunctionTypeAnnotation");
								}
								case 134: return this.parseLiteral(this.state.value, "StringLiteralTypeAnnotation");
								case 85:
								case 86: return t.value = this.match(85), this.next(), this.finishNode(t, "BooleanLiteralTypeAnnotation");
								case 53:
									if ("-" === this.state.value) {
										if (this.next(), this.match(135)) return this.parseLiteralAtNode(-this.state.value, "NumberLiteralTypeAnnotation", t);
										if (this.match(136)) return this.parseLiteralAtNode(-this.state.value, "BigIntLiteralTypeAnnotation", t);
										throw this.raise(U.UnexpectedSubtractionOperand, this.state.startLoc);
									}
									this.unexpected();
									return;
								case 135: return this.parseLiteral(this.state.value, "NumberLiteralTypeAnnotation");
								case 136: return this.parseLiteral(this.state.value, "BigIntLiteralTypeAnnotation");
								case 88: return this.next(), this.finishNode(t, "VoidTypeAnnotation");
								case 84: return this.next(), this.finishNode(t, "NullLiteralTypeAnnotation");
								case 78: return this.next(), this.finishNode(t, "ThisTypeAnnotation");
								case 55: return this.next(), this.finishNode(t, "ExistsTypeAnnotation");
								case 87: return this.flowParseTypeofType();
								default:
									if (tokenIsKeyword(this.state.type)) {
										const e = tokenLabelName(this.state.type);
										return this.next(), super.createIdentifier(t, e);
									}
									if (tokenIsIdentifier(this.state.type)) return this.isContextual(129) ? this.flowParseInterfaceType() : this.flowIdentToTypeAnnotation(e, t, this.parseIdentifier());
							}
							this.unexpected();
						}
						flowParsePostfixType() {
							const e = this.state.startLoc;
							let t = this.flowParsePrimaryType(), r = !1;
							for (; (this.match(0) || this.match(18)) && !this.canInsertSemicolon();) {
								const n = this.startNodeAt(e), s = this.eat(18);
								r = r || s, this.expect(0), !s && this.match(3) ? (n.elementType = t, this.next(), t = this.finishNode(n, "ArrayTypeAnnotation")) : (n.objectType = t, n.indexType = this.flowParseType(), this.expect(3), r ? (n.optional = s, t = this.finishNode(n, "OptionalIndexedAccessType")) : t = this.finishNode(n, "IndexedAccessType"));
							}
							return t;
						}
						flowParsePrefixType() {
							const e = this.startNode();
							return this.eat(17) ? (e.typeAnnotation = this.flowParsePrefixType(), this.finishNode(e, "NullableTypeAnnotation")) : this.flowParsePostfixType();
						}
						flowParseAnonFunctionWithoutParens() {
							const e = this.flowParsePrefixType();
							if (!this.state.noAnonFunctionType && this.eat(19)) {
								const t = this.startNodeAt(e.loc.start);
								return t.params = [this.reinterpretTypeAsFunctionTypeParam(e)], t.rest = null, t.this = null, t.returnType = this.flowParseType(), t.typeParameters = null, this.finishNode(t, "FunctionTypeAnnotation");
							}
							return e;
						}
						flowParseIntersectionType() {
							const e = this.startNode();
							this.eat(45);
							const t = this.flowParseAnonFunctionWithoutParens();
							for (e.types = [t]; this.eat(45);) e.types.push(this.flowParseAnonFunctionWithoutParens());
							return 1 === e.types.length ? t : this.finishNode(e, "IntersectionTypeAnnotation");
						}
						flowParseUnionType() {
							const e = this.startNode();
							this.eat(43);
							const t = this.flowParseIntersectionType();
							for (e.types = [t]; this.eat(43);) e.types.push(this.flowParseIntersectionType());
							return 1 === e.types.length ? t : this.finishNode(e, "UnionTypeAnnotation");
						}
						flowParseType() {
							const e = this.state.inType;
							this.state.inType = !0;
							const t = this.flowParseUnionType();
							return this.state.inType = e, t;
						}
						flowParseTypeOrImplicitInstantiation() {
							if (132 === this.state.type && "_" === this.state.value) {
								const e = this.state.startLoc, t = this.parseIdentifier();
								return this.flowParseGenericType(e, t);
							}
							return this.flowParseType();
						}
						flowParseTypeAnnotation() {
							const e = this.startNode();
							return e.typeAnnotation = this.flowParseTypeInitialiser(), this.finishNode(e, "TypeAnnotation");
						}
						flowParseTypeAnnotatableIdentifier(e) {
							const t = e ? this.parseIdentifier() : this.flowParseRestrictedIdentifier();
							return this.match(14) && (t.typeAnnotation = this.flowParseTypeAnnotation(), this.resetEndLocation(t)), t;
						}
						typeCastToParameter(e) {
							return e.expression.typeAnnotation = e.typeAnnotation, this.resetEndLocation(e.expression, e.typeAnnotation.loc.end), e.expression;
						}
						flowParseVariance() {
							let e = null;
							return this.match(53) ? (e = this.startNode(), "+" === this.state.value ? e.kind = "plus" : e.kind = "minus", this.next(), this.finishNode(e, "Variance")) : e;
						}
						parseFunctionBody(e, t, r = !1) {
							t ? this.forwardNoArrowParamsConversionAt(e, () => super.parseFunctionBody(e, !0, r)) : super.parseFunctionBody(e, !1, r);
						}
						parseFunctionBodyAndFinish(e, t, r = !1) {
							if (this.match(14)) {
								const t = this.startNode();
								[t.typeAnnotation, e.predicate] = this.flowParseTypeAndPredicateInitialiser(), e.returnType = t.typeAnnotation ? this.finishNode(t, "TypeAnnotation") : null;
							}
							return super.parseFunctionBodyAndFinish(e, t, r);
						}
						parseStatementLike(e) {
							if (this.state.strict && this.isContextual(129)) {
								if (tokenIsKeywordOrIdentifier(this.lookahead().type)) {
									const e = this.startNode();
									return this.next(), this.flowParseInterface(e);
								}
							} else if (this.isContextual(126)) {
								const e = this.startNode();
								return this.next(), this.flowParseEnumDeclaration(e);
							}
							const t = super.parseStatementLike(e);
							return void 0 !== this.flowPragma || this.isValidDirective(t) || (this.flowPragma = null), t;
						}
						parseExpressionStatement(e, t, r) {
							if ("Identifier" === t.type) {
								if ("declare" === t.name) {
									if (this.match(80) || tokenIsIdentifier(this.state.type) || this.match(68) || this.match(74) || this.match(82)) return this.flowParseDeclare(e);
								} else if (tokenIsIdentifier(this.state.type)) {
									if ("interface" === t.name) return this.flowParseInterface(e);
									if ("type" === t.name) return this.flowParseTypeAlias(e);
									if ("opaque" === t.name) return this.flowParseOpaqueType(e, !1);
								}
							}
							return super.parseExpressionStatement(e, t, r);
						}
						shouldParseExportDeclaration() {
							const { type: e } = this.state;
							return 126 === e || tokenIsFlowInterfaceOrTypeOrOpaque(e) ? !this.state.containsEsc : super.shouldParseExportDeclaration();
						}
						isExportDefaultSpecifier() {
							const { type: e } = this.state;
							return 126 === e || tokenIsFlowInterfaceOrTypeOrOpaque(e) ? this.state.containsEsc : super.isExportDefaultSpecifier();
						}
						parseExportDefaultExpression() {
							if (this.isContextual(126)) {
								const e = this.startNode();
								return this.next(), this.flowParseEnumDeclaration(e);
							}
							return super.parseExportDefaultExpression();
						}
						parseConditional(e, t, r) {
							if (!this.match(17)) return e;
							if (this.state.maybeInArrowParameters) {
								const t = this.lookaheadCharCode();
								if (44 === t || 61 === t || 58 === t || 41 === t) return this.setOptionalParametersError(r), e;
							}
							this.expect(17);
							const n = this.state.clone(), s = this.state.noArrowAt, i = this.startNodeAt(t);
							let { consequent: o, failed: a } = this.tryParseConditionalConsequent(), [l, p] = this.getArrowLikeExpressions(o);
							if (a || p.length > 0) {
								const e = [...s];
								if (p.length > 0) {
									this.state = n, this.state.noArrowAt = e;
									for (let t = 0; t < p.length; t++) e.push(p[t].start);
									({consequent: o, failed: a} = this.tryParseConditionalConsequent()), [l, p] = this.getArrowLikeExpressions(o);
								}
								a && l.length > 1 && this.raise(U.AmbiguousConditionalArrow, n.startLoc), a && 1 === l.length && (this.state = n, e.push(l[0].start), this.state.noArrowAt = e, {consequent: o, failed: a} = this.tryParseConditionalConsequent());
							}
							return this.getArrowLikeExpressions(o, !0), this.state.noArrowAt = s, this.expect(14), i.test = e, i.consequent = o, i.alternate = this.forwardNoArrowParamsConversionAt(i, () => this.parseMaybeAssign(void 0, void 0)), this.finishNode(i, "ConditionalExpression");
						}
						tryParseConditionalConsequent() {
							this.state.noArrowParamsConversionAt.push(this.state.start);
							const e = this.parseMaybeAssignAllowIn(), t = !this.match(14);
							return this.state.noArrowParamsConversionAt.pop(), {
								consequent: e,
								failed: t
							};
						}
						getArrowLikeExpressions(e, t) {
							const r = [e], n = [];
							for (; 0 !== r.length;) {
								const e = r.pop();
								"ArrowFunctionExpression" === e.type && "BlockStatement" !== e.body.type ? (e.typeParameters || !e.returnType ? this.finishArrowValidation(e) : n.push(e), r.push(e.body)) : "ConditionalExpression" === e.type && (r.push(e.consequent), r.push(e.alternate));
							}
							return t ? (n.forEach((e) => this.finishArrowValidation(e)), [n, []]) : function(e, t) {
								const r = [], n = [];
								for (let s = 0; s < e.length; s++) (t(e[s], s, e) ? r : n).push(e[s]);
								return [r, n];
							}(n, (e) => e.params.every((e) => this.isAssignable(e, !0)));
						}
						finishArrowValidation(e) {
							var t;
							this.toAssignableList(e.params, null == (t = e.extra) ? void 0 : t.trailingCommaLoc, !1), this.scope.enter(518), super.checkParams(e, !1, !0), this.scope.exit();
						}
						forwardNoArrowParamsConversionAt(e, t) {
							let r;
							return this.state.noArrowParamsConversionAt.includes(this.offsetToSourcePos(e.start)) ? (this.state.noArrowParamsConversionAt.push(this.state.start), r = t(), this.state.noArrowParamsConversionAt.pop()) : r = t(), r;
						}
						parseParenItem(e, t) {
							const r = super.parseParenItem(e, t);
							if (this.eat(17) && (r.optional = !0, this.resetEndLocation(e)), this.match(14)) {
								const e = this.startNodeAt(t);
								return e.expression = r, e.typeAnnotation = this.flowParseTypeAnnotation(), this.finishNode(e, "TypeCastExpression");
							}
							return r;
						}
						assertModuleNodeAllowed(e) {
							"ImportDeclaration" === e.type && ("type" === e.importKind || "typeof" === e.importKind) || "ExportNamedDeclaration" === e.type && "type" === e.exportKind || "ExportAllDeclaration" === e.type && "type" === e.exportKind || super.assertModuleNodeAllowed(e);
						}
						parseExportDeclaration(e) {
							if (this.isContextual(130)) {
								e.exportKind = "type";
								const t = this.startNode();
								return this.next(), this.match(5) ? (e.specifiers = this.parseExportSpecifiers(!0), super.parseExportFrom(e), null) : this.flowParseTypeAlias(t);
							}
							if (this.isContextual(131)) {
								e.exportKind = "type";
								const t = this.startNode();
								return this.next(), this.flowParseOpaqueType(t, !1);
							}
							if (this.isContextual(129)) {
								e.exportKind = "type";
								const t = this.startNode();
								return this.next(), this.flowParseInterface(t);
							}
							if (this.isContextual(126)) {
								e.exportKind = "value";
								const t = this.startNode();
								return this.next(), this.flowParseEnumDeclaration(t);
							}
							return super.parseExportDeclaration(e);
						}
						eatExportStar(e) {
							return !!super.eatExportStar(e) || !(!this.isContextual(130) || 55 !== this.lookahead().type) && (e.exportKind = "type", this.next(), this.next(), !0);
						}
						maybeParseExportNamespaceSpecifier(e) {
							const { startLoc: t } = this.state, r = super.maybeParseExportNamespaceSpecifier(e);
							return r && "type" === e.exportKind && this.unexpected(t), r;
						}
						parseClassId(e, t, r) {
							super.parseClassId(e, t, r), this.match(47) && (e.typeParameters = this.flowParseTypeParameterDeclaration());
						}
						parseClassMember(e, t, r) {
							const { startLoc: n } = this.state;
							if (this.isContextual(125)) {
								if (super.parseClassMemberFromModifier(e, t)) return;
								t.declare = !0;
							}
							super.parseClassMember(e, t, r), t.declare && ("ClassProperty" !== t.type && "ClassPrivateProperty" !== t.type && "PropertyDefinition" !== t.type ? this.raise(U.DeclareClassElement, n) : t.value && this.raise(U.DeclareClassFieldInitializer, t.value));
						}
						isIterator(e) {
							return "iterator" === e || "asyncIterator" === e;
						}
						readIterator() {
							const e = super.readWord1(), t = "@@" + e;
							this.isIterator(e) && this.state.inType || this.raise(c.InvalidIdentifier, this.state.curPosition(), { identifierName: t }), this.finishToken(132, t);
						}
						getTokenFromCode(e) {
							const t = this.input.charCodeAt(this.state.pos + 1);
							123 === e && 124 === t ? this.finishOp(6, 2) : !this.state.inType || 62 !== e && 60 !== e ? this.state.inType && 63 === e ? 46 === t ? this.finishOp(18, 2) : this.finishOp(17, 1) : !function(e, t, r) {
								return 64 === e && 64 === t && isIdentifierStart(r);
							}(e, t, this.input.charCodeAt(this.state.pos + 2)) ? super.getTokenFromCode(e) : (this.state.pos += 2, this.readIterator()) : this.finishOp(62 === e ? 48 : 47, 1);
						}
						isAssignable(e, t) {
							return "TypeCastExpression" === e.type ? this.isAssignable(e.expression, t) : super.isAssignable(e, t);
						}
						toAssignable(e, t = !1) {
							t || "AssignmentExpression" !== e.type || "TypeCastExpression" !== e.left.type || (e.left = this.typeCastToParameter(e.left)), super.toAssignable(e, t);
						}
						toAssignableList(e, t, r) {
							for (let t = 0; t < e.length; t++) {
								const r = e[t];
								"TypeCastExpression" === (null == r ? void 0 : r.type) && (e[t] = this.typeCastToParameter(r));
							}
							super.toAssignableList(e, t, r);
						}
						toReferencedList(e, t) {
							for (let n = 0; n < e.length; n++) {
								var r;
								const s = e[n];
								!s || "TypeCastExpression" !== s.type || null != (r = s.extra) && r.parenthesized || !(e.length > 1) && t || this.raise(U.TypeCastInPattern, s.typeAnnotation);
							}
							return e;
						}
						parseArrayLike(e, t, r, n) {
							const s = super.parseArrayLike(e, t, r, n);
							return t && !this.state.maybeInArrowParameters && this.toReferencedList(s.elements), s;
						}
						isValidLVal(e, t, r) {
							return "TypeCastExpression" === e || super.isValidLVal(e, t, r);
						}
						parseClassProperty(e) {
							return this.match(14) && (e.typeAnnotation = this.flowParseTypeAnnotation()), super.parseClassProperty(e);
						}
						parseClassPrivateProperty(e) {
							return this.match(14) && (e.typeAnnotation = this.flowParseTypeAnnotation()), super.parseClassPrivateProperty(e);
						}
						isClassMethod() {
							return this.match(47) || super.isClassMethod();
						}
						isClassProperty() {
							return this.match(14) || super.isClassProperty();
						}
						isNonstaticConstructor(e) {
							return !this.match(14) && super.isNonstaticConstructor(e);
						}
						pushClassMethod(e, t, r, n, s, i) {
							if (t.variance && this.unexpected(t.variance.loc.start), delete t.variance, this.match(47) && (t.typeParameters = this.flowParseTypeParameterDeclaration()), super.pushClassMethod(e, t, r, n, s, i), t.params && s) {
								const e = t.params;
								e.length > 0 && this.isThisParam(e[0]) && this.raise(U.ThisParamBannedInConstructor, t);
							} else if ("MethodDefinition" === t.type && s && t.value.params) {
								const e = t.value.params;
								e.length > 0 && this.isThisParam(e[0]) && this.raise(U.ThisParamBannedInConstructor, t);
							}
						}
						pushClassPrivateMethod(e, t, r, n) {
							t.variance && this.unexpected(t.variance.loc.start), delete t.variance, this.match(47) && (t.typeParameters = this.flowParseTypeParameterDeclaration()), super.pushClassPrivateMethod(e, t, r, n);
						}
						parseClassSuper(e) {
							if (super.parseClassSuper(e), e.superClass && (this.match(47) || this.match(51)) && (e.superTypeParameters = this.flowParseTypeParameterInstantiationInExpression()), this.isContextual(113)) {
								this.next();
								const t = e.implements = [];
								do {
									const e = this.startNode();
									e.id = this.flowParseRestrictedIdentifier(!0), this.match(47) ? e.typeParameters = this.flowParseTypeParameterInstantiation() : e.typeParameters = null, t.push(this.finishNode(e, "ClassImplements"));
								} while (this.eat(12));
							}
						}
						checkGetterSetterParams(e) {
							super.checkGetterSetterParams(e);
							const t = this.getObjectOrClassMethodParams(e);
							if (t.length > 0) {
								const r = t[0];
								this.isThisParam(r) && "get" === e.kind ? this.raise(U.GetterMayNotHaveThisParam, r) : this.isThisParam(r) && this.raise(U.SetterMayNotHaveThisParam, r);
							}
						}
						parsePropertyNamePrefixOperator(e) {
							e.variance = this.flowParseVariance();
						}
						parseObjPropValue(e, t, r, n, s, i, o) {
							let a;
							e.variance && this.unexpected(e.variance.loc.start), delete e.variance, this.match(47) && !i && (a = this.flowParseTypeParameterDeclaration(), this.match(10) || this.unexpected());
							const l = super.parseObjPropValue(e, t, r, n, s, i, o);
							return a && ((l.value || l).typeParameters = a), l;
						}
						parseFunctionParamType(e) {
							return this.eat(17) && ("Identifier" !== e.type && this.raise(U.PatternIsOptional, e), this.isThisParam(e) && this.raise(U.ThisParamMayNotBeOptional, e), e.optional = !0), this.match(14) ? e.typeAnnotation = this.flowParseTypeAnnotation() : this.isThisParam(e) && this.raise(U.ThisParamAnnotationRequired, e), this.match(29) && this.isThisParam(e) && this.raise(U.ThisParamNoDefault, e), this.resetEndLocation(e), e;
						}
						parseMaybeDefault(e, t) {
							const r = super.parseMaybeDefault(e, t);
							return "AssignmentPattern" === r.type && r.typeAnnotation && r.right.start < r.typeAnnotation.start && this.raise(U.TypeBeforeInitializer, r.typeAnnotation), r;
						}
						checkImportReflection(e) {
							super.checkImportReflection(e), e.module && "value" !== e.importKind && this.raise(U.ImportReflectionHasImportType, e.specifiers[0].loc.start);
						}
						parseImportSpecifierLocal(e, t, r) {
							t.local = hasTypeImportKind(e) ? this.flowParseRestrictedIdentifier(!0, !0) : this.parseIdentifier(), e.specifiers.push(this.finishImportSpecifier(t, r));
						}
						isPotentialImportPhase(e) {
							if (super.isPotentialImportPhase(e)) return !0;
							if (this.isContextual(130)) {
								if (!e) return !0;
								const t = this.lookaheadCharCode();
								return 123 === t || 42 === t;
							}
							return !e && this.isContextual(87);
						}
						applyImportPhase(e, t, r, n) {
							if (super.applyImportPhase(e, t, r, n), t) {
								if (!r && this.match(65)) return;
								e.exportKind = "type" === r ? r : "value";
							} else "type" === r && this.match(55) && this.unexpected(), e.importKind = "type" === r || "typeof" === r ? r : "value";
						}
						parseImportSpecifier(e, t, r, n, s) {
							const i = e.imported;
							let o = null;
							"Identifier" === i.type && ("type" === i.name ? o = "type" : "typeof" === i.name && (o = "typeof"));
							let a = !1;
							if (this.isContextual(93) && !this.isLookaheadContextual("as")) {
								const t = this.parseIdentifier(!0);
								null === o || tokenIsKeywordOrIdentifier(this.state.type) ? (e.imported = i, e.importKind = null, e.local = this.parseIdentifier()) : (e.imported = t, e.importKind = o, e.local = this.cloneIdentifier(t));
							} else {
								if (null !== o && tokenIsKeywordOrIdentifier(this.state.type)) e.imported = this.parseIdentifier(!0), e.importKind = o;
								else {
									if (t) throw this.raise(c.ImportBindingIsString, e, { importName: i.value });
									e.imported = i, e.importKind = null;
								}
								this.eatContextual(93) ? e.local = this.parseIdentifier() : (a = !0, e.local = this.cloneIdentifier(e.imported));
							}
							const l = hasTypeImportKind(e);
							return r && l && this.raise(U.ImportTypeShorthandOnlyInPureImport, e), (r || l) && this.checkReservedType(e.local.name, e.local.loc.start, !0), !a || r || l || this.checkReservedWord(e.local.name, e.loc.start, !0, !0), this.finishImportSpecifier(e, "ImportSpecifier");
						}
						parseBindingAtom() {
							return 78 === this.state.type ? this.parseIdentifier(!0) : super.parseBindingAtom();
						}
						parseFunctionParams(e, t) {
							const r = e.kind;
							"get" !== r && "set" !== r && this.match(47) && (e.typeParameters = this.flowParseTypeParameterDeclaration()), super.parseFunctionParams(e, t);
						}
						parseVarId(e, t) {
							super.parseVarId(e, t), this.match(14) && (e.id.typeAnnotation = this.flowParseTypeAnnotation(), this.resetEndLocation(e.id));
						}
						parseAsyncArrowFromCallExpression(e, t) {
							if (this.match(14)) {
								const t = this.state.noAnonFunctionType;
								this.state.noAnonFunctionType = !0, e.returnType = this.flowParseTypeAnnotation(), this.state.noAnonFunctionType = t;
							}
							return super.parseAsyncArrowFromCallExpression(e, t);
						}
						shouldParseAsyncArrow() {
							return this.match(14) || super.shouldParseAsyncArrow();
						}
						parseMaybeAssign(e, t) {
							var r;
							let n, s = null;
							if (this.hasPlugin("jsx") && (this.match(143) || this.match(47))) {
								if (s = this.state.clone(), n = this.tryParse(() => super.parseMaybeAssign(e, t), s), !n.error) return n.node;
								const { context: r } = this.state, i = r[r.length - 1];
								i !== d.j_oTag && i !== d.j_expr || r.pop();
							}
							if (null != (r = n) && r.error || this.match(47)) {
								var i, o;
								let r;
								s = s || this.state.clone();
								const a = this.tryParse((n) => {
									var s;
									r = this.flowParseTypeParameterDeclaration();
									const i = this.forwardNoArrowParamsConversionAt(r, () => {
										const n = super.parseMaybeAssign(e, t);
										return this.resetStartLocationFromNode(n, r), n;
									});
									null != (s = i.extra) && s.parenthesized && n();
									const o = this.maybeUnwrapTypeCastExpression(i);
									return "ArrowFunctionExpression" !== o.type && n(), o.typeParameters = r, this.resetStartLocationFromNode(o, r), i;
								}, s);
								let l = null;
								if (a.node && "ArrowFunctionExpression" === this.maybeUnwrapTypeCastExpression(a.node).type) {
									if (!a.error && !a.aborted) return a.node.async && this.raise(U.UnexpectedTypeParameterBeforeAsyncArrowFunction, r), a.node;
									l = a.node;
								}
								if (null != (i = n) && i.node) return this.state = n.failState, n.node;
								if (l) return this.state = a.failState, l;
								if (null != (o = n) && o.thrown) throw n.error;
								if (a.thrown) throw a.error;
								throw this.raise(U.UnexpectedTokenAfterTypeParameter, r);
							}
							return super.parseMaybeAssign(e, t);
						}
						parseArrow(e) {
							if (this.match(14)) {
								const t = this.tryParse(() => {
									const t = this.state.noAnonFunctionType;
									this.state.noAnonFunctionType = !0;
									const r = this.startNode();
									return [r.typeAnnotation, e.predicate] = this.flowParseTypeAndPredicateInitialiser(), this.state.noAnonFunctionType = t, this.canInsertSemicolon() && this.unexpected(), this.match(19) || this.unexpected(), r;
								});
								if (t.thrown) return null;
								t.error && (this.state = t.failState), e.returnType = t.node.typeAnnotation ? this.finishNode(t.node, "TypeAnnotation") : null;
							}
							return super.parseArrow(e);
						}
						shouldParseArrow(e) {
							return this.match(14) || super.shouldParseArrow(e);
						}
						setArrowFunctionParameters(e, t) {
							this.state.noArrowParamsConversionAt.includes(this.offsetToSourcePos(e.start)) ? e.params = t : super.setArrowFunctionParameters(e, t);
						}
						checkParams(e, t, r, n = !0) {
							if (!r || !this.state.noArrowParamsConversionAt.includes(this.offsetToSourcePos(e.start))) {
								for (let t = 0; t < e.params.length; t++) this.isThisParam(e.params[t]) && t > 0 && this.raise(U.ThisParamMustBeFirst, e.params[t]);
								super.checkParams(e, t, r, n);
							}
						}
						parseParenAndDistinguishExpression(e) {
							return super.parseParenAndDistinguishExpression(e && !this.state.noArrowAt.includes(this.sourceToOffsetPos(this.state.start)));
						}
						parseSubscripts(e, t, r) {
							if ("Identifier" === e.type && "async" === e.name && this.state.noArrowAt.includes(t.index)) {
								this.next();
								const r = this.startNodeAt(t);
								r.callee = e, r.arguments = super.parseCallExpressionArguments(), e = this.finishNode(r, "CallExpression");
							} else if ("Identifier" === e.type && "async" === e.name && this.match(47)) {
								const n = this.state.clone(), s = this.tryParse((e) => this.parseAsyncArrowWithTypeParameters(t) || e(), n);
								if (!s.error && !s.aborted) return s.node;
								const i = this.tryParse(() => super.parseSubscripts(e, t, r), n);
								if (i.node && !i.error) return i.node;
								if (s.node) return this.state = s.failState, s.node;
								if (i.node) return this.state = i.failState, i.node;
								throw s.error || i.error;
							}
							return super.parseSubscripts(e, t, r);
						}
						parseSubscript(e, t, r, n) {
							if (this.match(18) && this.isLookaheadToken_lt()) {
								if (n.optionalChainMember = !0, r) return n.stop = !0, e;
								this.next();
								const s = this.startNodeAt(t);
								return s.callee = e, s.typeArguments = this.flowParseTypeParameterInstantiationInExpression(), this.expect(10), s.arguments = this.parseCallExpressionArguments(), s.optional = !0, this.finishCallExpression(s, !0);
							}
							if (!r && this.shouldParseTypes() && (this.match(47) || this.match(51))) {
								const r = this.startNodeAt(t);
								r.callee = e;
								const s = this.tryParse(() => (r.typeArguments = this.flowParseTypeParameterInstantiationCallOrNew(), this.expect(10), r.arguments = super.parseCallExpressionArguments(), n.optionalChainMember && (r.optional = !1), this.finishCallExpression(r, n.optionalChainMember)));
								if (s.node) return s.error && (this.state = s.failState), s.node;
							}
							return super.parseSubscript(e, t, r, n);
						}
						parseNewCallee(e) {
							super.parseNewCallee(e);
							let t = null;
							this.shouldParseTypes() && this.match(47) && (t = this.tryParse(() => this.flowParseTypeParameterInstantiationCallOrNew()).node), e.typeArguments = t;
						}
						parseAsyncArrowWithTypeParameters(e) {
							const t = this.startNodeAt(e);
							if (this.parseFunctionParams(t, !1), this.parseArrow(t)) return super.parseArrowExpression(t, void 0, !0);
						}
						readToken_mult_modulo(e) {
							const t = this.input.charCodeAt(this.state.pos + 1);
							if (42 === e && 47 === t && this.state.hasFlowComment) return this.state.hasFlowComment = !1, this.state.pos += 2, void this.nextToken();
							super.readToken_mult_modulo(e);
						}
						readToken_pipe_amp(e) {
							const t = this.input.charCodeAt(this.state.pos + 1);
							124 !== e || 125 !== t ? super.readToken_pipe_amp(e) : this.finishOp(9, 2);
						}
						parseTopLevel(e, t) {
							const r = super.parseTopLevel(e, t);
							return this.state.hasFlowComment && this.raise(U.UnterminatedFlowComment, this.state.curPosition()), r;
						}
						skipBlockComment() {
							if (this.hasPlugin("flowComments") && this.skipFlowComment()) {
								if (this.state.hasFlowComment) throw this.raise(U.NestedFlowComment, this.state.startLoc);
								this.hasFlowCommentCompletion();
								const e = this.skipFlowComment();
								e && (this.state.pos += e, this.state.hasFlowComment = !0);
								return;
							}
							return super.skipBlockComment(this.state.hasFlowComment ? "*-/" : "*/");
						}
						skipFlowComment() {
							const { pos: e } = this.state;
							let t = 2;
							for (; [32, 9].includes(this.input.charCodeAt(e + t));) t++;
							const r = this.input.charCodeAt(t + e), n = this.input.charCodeAt(t + e + 1);
							return 58 === r && 58 === n ? t + 2 : "flow-include" === this.input.slice(t + e, t + e + 12) ? t + 12 : 58 === r && 58 !== n && t;
						}
						hasFlowCommentCompletion() {
							if (-1 === this.input.indexOf("*/", this.state.pos)) throw this.raise(c.UnterminatedComment, this.state.curPosition());
						}
						flowEnumErrorBooleanMemberNotInitialized(e, { enumName: t, memberName: r }) {
							this.raise(U.EnumBooleanMemberNotInitialized, e, {
								memberName: r,
								enumName: t
							});
						}
						flowEnumErrorInvalidMemberInitializer(e, t) {
							return this.raise(t.explicitType ? "symbol" === t.explicitType ? U.EnumInvalidMemberInitializerSymbolType : U.EnumInvalidMemberInitializerPrimaryType : U.EnumInvalidMemberInitializerUnknownType, e, t);
						}
						flowEnumErrorNumberMemberNotInitialized(e, t) {
							this.raise(U.EnumNumberMemberNotInitialized, e, t);
						}
						flowEnumErrorStringMemberInconsistentlyInitialized(e, t) {
							this.raise(U.EnumStringMemberInconsistentlyInitialized, e, t);
						}
						flowEnumMemberInit() {
							const e = this.state.startLoc, endOfInit = () => this.match(12) || this.match(8);
							switch (this.state.type) {
								case 135: {
									const t = this.parseNumericLiteral(this.state.value);
									return endOfInit() ? {
										type: "number",
										loc: t.loc.start,
										value: t
									} : {
										type: "invalid",
										loc: e
									};
								}
								case 134: {
									const t = this.parseStringLiteral(this.state.value);
									return endOfInit() ? {
										type: "string",
										loc: t.loc.start,
										value: t
									} : {
										type: "invalid",
										loc: e
									};
								}
								case 85:
								case 86: {
									const t = this.parseBooleanLiteral(this.match(85));
									return endOfInit() ? {
										type: "boolean",
										loc: t.loc.start,
										value: t
									} : {
										type: "invalid",
										loc: e
									};
								}
								default: return {
									type: "invalid",
									loc: e
								};
							}
						}
						flowEnumMemberRaw() {
							const e = this.state.startLoc;
							return {
								id: this.parseIdentifier(!0),
								init: this.eat(29) ? this.flowEnumMemberInit() : {
									type: "none",
									loc: e
								}
							};
						}
						flowEnumCheckExplicitTypeMismatch(e, t, r) {
							const { explicitType: n } = t;
							null !== n && n !== r && this.flowEnumErrorInvalidMemberInitializer(e, t);
						}
						flowEnumMembers({ enumName: e, explicitType: t }) {
							const r = /* @__PURE__ */ new Set(), n = {
								booleanMembers: [],
								numberMembers: [],
								stringMembers: [],
								defaultedMembers: []
							};
							let s = !1;
							for (; !this.match(8);) {
								if (this.eat(21)) {
									s = !0;
									break;
								}
								const i = this.startNode(), { id: o, init: a } = this.flowEnumMemberRaw(), l = o.name;
								if ("" === l) continue;
								/^[a-z]/.test(l) && this.raise(U.EnumInvalidMemberName, o, {
									memberName: l,
									suggestion: l[0].toUpperCase() + l.slice(1),
									enumName: e
								}), r.has(l) && this.raise(U.EnumDuplicateMemberName, o, {
									memberName: l,
									enumName: e
								}), r.add(l);
								const p = {
									enumName: e,
									explicitType: t,
									memberName: l
								};
								switch (i.id = o, a.type) {
									case "boolean":
										this.flowEnumCheckExplicitTypeMismatch(a.loc, p, "boolean"), i.init = a.value, n.booleanMembers.push(this.finishNode(i, "EnumBooleanMember"));
										break;
									case "number":
										this.flowEnumCheckExplicitTypeMismatch(a.loc, p, "number"), i.init = a.value, n.numberMembers.push(this.finishNode(i, "EnumNumberMember"));
										break;
									case "string":
										this.flowEnumCheckExplicitTypeMismatch(a.loc, p, "string"), i.init = a.value, n.stringMembers.push(this.finishNode(i, "EnumStringMember"));
										break;
									case "invalid": throw this.flowEnumErrorInvalidMemberInitializer(a.loc, p);
									case "none": switch (t) {
										case "boolean":
											this.flowEnumErrorBooleanMemberNotInitialized(a.loc, p);
											break;
										case "number":
											this.flowEnumErrorNumberMemberNotInitialized(a.loc, p);
											break;
										default: n.defaultedMembers.push(this.finishNode(i, "EnumDefaultedMember"));
									}
								}
								this.match(8) || this.expect(12);
							}
							return {
								members: n,
								hasUnknownMembers: s
							};
						}
						flowEnumStringMembers(e, t, { enumName: r }) {
							if (0 === e.length) return t;
							if (0 === t.length) return e;
							if (t.length > e.length) {
								for (const t of e) this.flowEnumErrorStringMemberInconsistentlyInitialized(t, { enumName: r });
								return t;
							}
							for (const e of t) this.flowEnumErrorStringMemberInconsistentlyInitialized(e, { enumName: r });
							return e;
						}
						flowEnumParseExplicitType({ enumName: e }) {
							if (!this.eatContextual(102)) return null;
							if (!tokenIsIdentifier(this.state.type)) throw this.raise(U.EnumInvalidExplicitTypeUnknownSupplied, this.state.startLoc, { enumName: e });
							const { value: t } = this.state;
							return this.next(), "boolean" !== t && "number" !== t && "string" !== t && "symbol" !== t && this.raise(U.EnumInvalidExplicitType, this.state.startLoc, {
								enumName: e,
								invalidEnumType: t
							}), t;
						}
						flowEnumBody(e, t) {
							const r = t.name, n = t.loc.start, s = this.flowEnumParseExplicitType({ enumName: r });
							this.expect(5);
							const { members: i, hasUnknownMembers: o } = this.flowEnumMembers({
								enumName: r,
								explicitType: s
							});
							switch (e.hasUnknownMembers = o, s) {
								case "boolean": return e.explicitType = !0, e.members = i.booleanMembers, this.expect(8), this.finishNode(e, "EnumBooleanBody");
								case "number": return e.explicitType = !0, e.members = i.numberMembers, this.expect(8), this.finishNode(e, "EnumNumberBody");
								case "string": return e.explicitType = !0, e.members = this.flowEnumStringMembers(i.stringMembers, i.defaultedMembers, { enumName: r }), this.expect(8), this.finishNode(e, "EnumStringBody");
								case "symbol": return e.members = i.defaultedMembers, this.expect(8), this.finishNode(e, "EnumSymbolBody");
								default: {
									const empty = () => (e.members = [], this.expect(8), this.finishNode(e, "EnumStringBody"));
									e.explicitType = !1;
									const t = i.booleanMembers.length, s = i.numberMembers.length, o = i.stringMembers.length, a = i.defaultedMembers.length;
									if (t || s || o || a) {
										if (t || s) {
											if (!s && !o && t >= a) {
												for (const e of i.defaultedMembers) this.flowEnumErrorBooleanMemberNotInitialized(e.loc.start, {
													enumName: r,
													memberName: e.id.name
												});
												return e.members = i.booleanMembers, this.expect(8), this.finishNode(e, "EnumBooleanBody");
											}
											if (!t && !o && s >= a) {
												for (const e of i.defaultedMembers) this.flowEnumErrorNumberMemberNotInitialized(e.loc.start, {
													enumName: r,
													memberName: e.id.name
												});
												return e.members = i.numberMembers, this.expect(8), this.finishNode(e, "EnumNumberBody");
											}
											return this.raise(U.EnumInconsistentMemberValues, n, { enumName: r }), empty();
										}
										return e.members = this.flowEnumStringMembers(i.stringMembers, i.defaultedMembers, { enumName: r }), this.expect(8), this.finishNode(e, "EnumStringBody");
									}
									return empty();
								}
							}
						}
						flowParseEnumDeclaration(e) {
							const t = this.parseIdentifier();
							return e.id = t, e.body = this.flowEnumBody(this.startNode(), t), this.finishNode(e, "EnumDeclaration");
						}
						jsxParseOpeningElementAfterName(e) {
							return this.shouldParseTypes() && (this.match(47) || this.match(51)) && (e.typeArguments = this.flowParseTypeParameterInstantiationInExpression()), super.jsxParseOpeningElementAfterName(e);
						}
						isLookaheadToken_lt() {
							const e = this.nextTokenStart();
							if (60 === this.input.charCodeAt(e)) {
								const t = this.input.charCodeAt(e + 1);
								return 60 !== t && 61 !== t;
							}
							return !1;
						}
						reScan_lt_gt() {
							const { type: e } = this.state;
							47 === e ? (this.state.pos -= 1, this.readToken_lt()) : 48 === e && (this.state.pos -= 1, this.readToken_gt());
						}
						reScan_lt() {
							const { type: e } = this.state;
							return 51 === e ? (this.state.pos -= 2, this.finishOp(47, 1), 47) : e;
						}
						maybeUnwrapTypeCastExpression(e) {
							return "TypeCastExpression" === e.type ? e.expression : e;
						}
					},
					typescript: (e) => class extends e {
						constructor(...e) {
							super(...e), this.tsParseInOutModifiers = this.tsParseModifiers.bind(this, {
								allowedModifiers: ["in", "out"],
								disallowedModifiers: [
									"const",
									"public",
									"private",
									"protected",
									"readonly",
									"declare",
									"abstract",
									"override"
								],
								errorTemplate: Q.InvalidModifierOnTypeParameter
							}), this.tsParseConstModifier = this.tsParseModifiers.bind(this, {
								allowedModifiers: ["const"],
								disallowedModifiers: ["in", "out"],
								errorTemplate: Q.InvalidModifierOnTypeParameterPositions
							}), this.tsParseInOutConstModifiers = this.tsParseModifiers.bind(this, {
								allowedModifiers: [
									"in",
									"out",
									"const"
								],
								disallowedModifiers: [
									"public",
									"private",
									"protected",
									"readonly",
									"declare",
									"abstract",
									"override"
								],
								errorTemplate: Q.InvalidModifierOnTypeParameter
							});
						}
						getScopeHandler() {
							return TypeScriptScopeHandler;
						}
						tsIsIdentifier() {
							return tokenIsIdentifier(this.state.type);
						}
						tsTokenCanFollowModifier() {
							return this.match(0) || this.match(5) || this.match(55) || this.match(21) || this.match(139) || this.isLiteralPropertyName();
						}
						tsNextTokenOnSameLineAndCanFollowModifier() {
							return this.next(), !this.hasPrecedingLineBreak() && this.tsTokenCanFollowModifier();
						}
						tsNextTokenCanFollowModifier() {
							return this.match(106) ? (this.next(), this.tsTokenCanFollowModifier()) : this.tsNextTokenOnSameLineAndCanFollowModifier();
						}
						tsParseModifier(e, t, r) {
							if (!tokenIsIdentifier(this.state.type) && 58 !== this.state.type && 75 !== this.state.type) return;
							const n = this.state.value;
							if (e.includes(n)) {
								if (r && this.match(106)) return;
								if (t && this.tsIsStartOfStaticBlocks()) return;
								if (this.tsTryParse(this.tsNextTokenCanFollowModifier.bind(this))) return n;
							}
						}
						tsParseModifiers({ allowedModifiers: e, disallowedModifiers: t, stopOnStartOfClassStaticBlock: r, errorTemplate: n = Q.InvalidModifierOnTypeMember }, s) {
							const enforceOrder = (e, t, r, n) => {
								t === r && s[n] && this.raise(Q.InvalidModifiersOrder, e, { orderedModifiers: [r, n] });
							}, incompatible = (e, t, r, n) => {
								(s[r] && t === n || s[n] && t === r) && this.raise(Q.IncompatibleModifiers, e, { modifiers: [r, n] });
							};
							for (;;) {
								const { startLoc: i } = this.state, o = this.tsParseModifier(e.concat(null != t ? t : []), r, s.static);
								if (!o) break;
								tsIsAccessModifier(o) ? s.accessibility ? this.raise(Q.DuplicateAccessibilityModifier, i, { modifier: o }) : (enforceOrder(i, o, o, "override"), enforceOrder(i, o, o, "static"), enforceOrder(i, o, o, "readonly"), s.accessibility = o) : tsIsVarianceAnnotations(o) ? (s[o] && this.raise(Q.DuplicateModifier, i, { modifier: o }), s[o] = !0, enforceOrder(i, o, "in", "out")) : (hasOwnProperty.call(s, o) ? this.raise(Q.DuplicateModifier, i, { modifier: o }) : (enforceOrder(i, o, "static", "readonly"), enforceOrder(i, o, "static", "override"), enforceOrder(i, o, "override", "readonly"), enforceOrder(i, o, "abstract", "override"), incompatible(i, o, "declare", "override"), incompatible(i, o, "static", "abstract")), s[o] = !0), null != t && t.includes(o) && this.raise(n, i, { modifier: o });
							}
						}
						tsIsListTerminator(e) {
							switch (e) {
								case "EnumMembers":
								case "TypeMembers": return this.match(8);
								case "HeritageClauseElement": return this.match(5);
								case "TupleElementTypes": return this.match(3);
								case "TypeParametersOrArguments": return this.match(48);
							}
						}
						tsParseList(e, t) {
							const r = [];
							for (; !this.tsIsListTerminator(e);) r.push(t());
							return r;
						}
						tsParseDelimitedList(e, t, r) {
							return function(e) {
								if (null == e) throw new Error(`Unexpected ${e} value.`);
								return e;
							}(this.tsParseDelimitedListWorker(e, t, !0, r));
						}
						tsParseDelimitedListWorker(e, t, r, n) {
							const s = [];
							let i = -1;
							for (; !this.tsIsListTerminator(e);) {
								i = -1;
								const n = t();
								if (null == n) return;
								if (s.push(n), !this.eat(12)) {
									if (this.tsIsListTerminator(e)) break;
									r && this.expect(12);
									return;
								}
								i = this.state.lastTokStartLoc.index;
							}
							return n && (n.value = i), s;
						}
						tsParseBracketedList(e, t, r, n, s) {
							n || (r ? this.expect(0) : this.expect(47));
							const i = this.tsParseDelimitedList(e, t, s);
							return r ? this.expect(3) : this.expect(48), i;
						}
						tsParseImportType() {
							const e = this.startNode();
							return this.expect(83), this.expect(10), this.match(134) ? e.argument = this.parseStringLiteral(this.state.value) : (this.raise(Q.UnsupportedImportTypeArgument, this.state.startLoc), e.argument = super.parseExprAtom()), this.eat(12) ? e.options = this.tsParseImportTypeOptions() : e.options = null, this.expect(11), this.eat(16) && (e.qualifier = this.tsParseEntityName(3)), this.match(47) && (e.typeParameters = this.tsParseTypeArguments()), this.finishNode(e, "TSImportType");
						}
						tsParseImportTypeOptions() {
							const e = this.startNode();
							this.expect(5);
							const t = this.startNode();
							return this.isContextual(76) ? (t.method = !1, t.key = this.parseIdentifier(!0), t.computed = !1, t.shorthand = !1) : this.unexpected(null, 76), this.expect(14), t.value = this.tsParseImportTypeWithPropertyValue(), e.properties = [this.finishObjectProperty(t)], this.eat(12), this.expect(8), this.finishNode(e, "ObjectExpression");
						}
						tsParseImportTypeWithPropertyValue() {
							const e = this.startNode(), t = [];
							for (this.expect(5); !this.match(8);) {
								const e = this.state.type;
								tokenIsIdentifier(e) || 134 === e ? t.push(super.parsePropertyDefinition(null)) : this.unexpected(), this.eat(12);
							}
							return e.properties = t, this.next(), this.finishNode(e, "ObjectExpression");
						}
						tsParseEntityName(e) {
							let t;
							if (1 & e && this.match(78)) if (2 & e) t = this.parseIdentifier(!0);
							else {
								const e = this.startNode();
								this.next(), t = this.finishNode(e, "ThisExpression");
							}
							else t = this.parseIdentifier(!!(1 & e));
							for (; this.eat(16);) {
								const r = this.startNodeAtNode(t);
								r.left = t, r.right = this.parseIdentifier(!!(1 & e)), t = this.finishNode(r, "TSQualifiedName");
							}
							return t;
						}
						tsParseTypeReference() {
							const e = this.startNode();
							return e.typeName = this.tsParseEntityName(1), !this.hasPrecedingLineBreak() && this.match(47) && (e.typeParameters = this.tsParseTypeArguments()), this.finishNode(e, "TSTypeReference");
						}
						tsParseThisTypePredicate(e) {
							this.next();
							const t = this.startNodeAtNode(e);
							return t.parameterName = e, t.typeAnnotation = this.tsParseTypeAnnotation(!1), t.asserts = !1, this.finishNode(t, "TSTypePredicate");
						}
						tsParseThisTypeNode() {
							const e = this.startNode();
							return this.next(), this.finishNode(e, "TSThisType");
						}
						tsParseTypeQuery() {
							const e = this.startNode();
							return this.expect(87), this.match(83) ? e.exprName = this.tsParseImportType() : e.exprName = this.tsParseEntityName(3), !this.hasPrecedingLineBreak() && this.match(47) && (e.typeParameters = this.tsParseTypeArguments()), this.finishNode(e, "TSTypeQuery");
						}
						tsParseTypeParameter(e) {
							const t = this.startNode();
							return e(t), t.name = this.tsParseTypeParameterName(), t.constraint = this.tsEatThenParseType(81), t.default = this.tsEatThenParseType(29), this.finishNode(t, "TSTypeParameter");
						}
						tsTryParseTypeParameters(e) {
							if (this.match(47)) return this.tsParseTypeParameters(e);
						}
						tsParseTypeParameters(e) {
							const t = this.startNode();
							this.match(47) || this.match(143) ? this.next() : this.unexpected();
							const r = { value: -1 };
							return t.params = this.tsParseBracketedList("TypeParametersOrArguments", this.tsParseTypeParameter.bind(this, e), !1, !0, r), 0 === t.params.length && this.raise(Q.EmptyTypeParameters, t), -1 !== r.value && this.addExtra(t, "trailingComma", r.value), this.finishNode(t, "TSTypeParameterDeclaration");
						}
						tsFillSignature(e, t) {
							const r = 19 === e, n = "typeAnnotation";
							t.typeParameters = this.tsTryParseTypeParameters(this.tsParseConstModifier), this.expect(10), t.parameters = this.tsParseBindingListForSignature(), (r || this.match(e)) && (t[n] = this.tsParseTypeOrTypePredicateAnnotation(e));
						}
						tsParseBindingListForSignature() {
							const e = super.parseBindingList(11, 41, 2);
							for (const t of e) {
								const { type: e } = t;
								"AssignmentPattern" !== e && "TSParameterProperty" !== e || this.raise(Q.UnsupportedSignatureParameterKind, t, { type: e });
							}
							return e;
						}
						tsParseTypeMemberSemicolon() {
							this.eat(12) || this.isLineTerminator() || this.expect(13);
						}
						tsParseSignatureMember(e, t) {
							return this.tsFillSignature(14, t), this.tsParseTypeMemberSemicolon(), this.finishNode(t, e);
						}
						tsIsUnambiguouslyIndexSignature() {
							return this.next(), !!tokenIsIdentifier(this.state.type) && (this.next(), this.match(14));
						}
						tsTryParseIndexSignature(e) {
							if (!this.match(0) || !this.tsLookAhead(this.tsIsUnambiguouslyIndexSignature.bind(this))) return;
							this.expect(0);
							const t = this.parseIdentifier();
							t.typeAnnotation = this.tsParseTypeAnnotation(), this.resetEndLocation(t), this.expect(3), e.parameters = [t];
							const r = this.tsTryParseTypeAnnotation();
							return r && (e.typeAnnotation = r), this.tsParseTypeMemberSemicolon(), this.finishNode(e, "TSIndexSignature");
						}
						tsParsePropertyOrMethodSignature(e, t) {
							if (this.eat(17) && (e.optional = !0), this.match(10) || this.match(47)) {
								t && this.raise(Q.ReadonlyForMethodSignature, e);
								const r = e;
								r.kind && this.match(47) && this.raise(Q.AccessorCannotHaveTypeParameters, this.state.curPosition()), this.tsFillSignature(14, r), this.tsParseTypeMemberSemicolon();
								const n = "parameters", s = "typeAnnotation";
								if ("get" === r.kind) r[n].length > 0 && (this.raise(c.BadGetterArity, this.state.curPosition()), this.isThisParam(r[n][0]) && this.raise(Q.AccessorCannotDeclareThisParameter, this.state.curPosition()));
								else if ("set" === r.kind) {
									if (1 !== r[n].length) this.raise(c.BadSetterArity, this.state.curPosition());
									else {
										const e = r[n][0];
										this.isThisParam(e) && this.raise(Q.AccessorCannotDeclareThisParameter, this.state.curPosition()), "Identifier" === e.type && e.optional && this.raise(Q.SetAccessorCannotHaveOptionalParameter, this.state.curPosition()), "RestElement" === e.type && this.raise(Q.SetAccessorCannotHaveRestParameter, this.state.curPosition());
									}
									r[s] && this.raise(Q.SetAccessorCannotHaveReturnType, r[s]);
								} else r.kind = "method";
								return this.finishNode(r, "TSMethodSignature");
							}
							{
								const r = e;
								t && (r.readonly = !0);
								const n = this.tsTryParseTypeAnnotation();
								return n && (r.typeAnnotation = n), this.tsParseTypeMemberSemicolon(), this.finishNode(r, "TSPropertySignature");
							}
						}
						tsParseTypeMember() {
							const e = this.startNode();
							if (this.match(10) || this.match(47)) return this.tsParseSignatureMember("TSCallSignatureDeclaration", e);
							if (this.match(77)) {
								const t = this.startNode();
								return this.next(), this.match(10) || this.match(47) ? this.tsParseSignatureMember("TSConstructSignatureDeclaration", e) : (e.key = this.createIdentifier(t, "new"), this.tsParsePropertyOrMethodSignature(e, !1));
							}
							this.tsParseModifiers({
								allowedModifiers: ["readonly"],
								disallowedModifiers: [
									"declare",
									"abstract",
									"private",
									"protected",
									"public",
									"static",
									"override"
								]
							}, e);
							return this.tsTryParseIndexSignature(e) || (super.parsePropertyName(e), e.computed || "Identifier" !== e.key.type || "get" !== e.key.name && "set" !== e.key.name || !this.tsTokenCanFollowModifier() || (e.kind = e.key.name, super.parsePropertyName(e), this.match(10) || this.match(47) || this.unexpected(null, 10)), this.tsParsePropertyOrMethodSignature(e, !!e.readonly));
						}
						tsParseTypeLiteral() {
							const e = this.startNode();
							return e.members = this.tsParseObjectTypeMembers(), this.finishNode(e, "TSTypeLiteral");
						}
						tsParseObjectTypeMembers() {
							this.expect(5);
							const e = this.tsParseList("TypeMembers", this.tsParseTypeMember.bind(this));
							return this.expect(8), e;
						}
						tsIsStartOfMappedType() {
							return this.next(), this.eat(53) ? this.isContextual(122) : (this.isContextual(122) && this.next(), !!this.match(0) && (this.next(), !!this.tsIsIdentifier() && (this.next(), this.match(58))));
						}
						tsParseMappedType() {
							const e = this.startNode();
							this.expect(5), this.match(53) ? (e.readonly = this.state.value, this.next(), this.expectContextual(122)) : this.eatContextual(122) && (e.readonly = !0), this.expect(0);
							{
								const t = this.startNode();
								t.name = this.tsParseTypeParameterName(), t.constraint = this.tsExpectThenParseType(58), e.typeParameter = this.finishNode(t, "TSTypeParameter");
							}
							return e.nameType = this.eatContextual(93) ? this.tsParseType() : null, this.expect(3), this.match(53) ? (e.optional = this.state.value, this.next(), this.expect(17)) : this.eat(17) && (e.optional = !0), e.typeAnnotation = this.tsTryParseType(), this.semicolon(), this.expect(8), this.finishNode(e, "TSMappedType");
						}
						tsParseTupleType() {
							const e = this.startNode();
							e.elementTypes = this.tsParseBracketedList("TupleElementTypes", this.tsParseTupleElementType.bind(this), !0, !1);
							let t = !1;
							return e.elementTypes.forEach((e) => {
								const { type: r } = e;
								!t || "TSRestType" === r || "TSOptionalType" === r || "TSNamedTupleMember" === r && e.optional || this.raise(Q.OptionalTypeBeforeRequired, e), t || (t = "TSNamedTupleMember" === r && e.optional || "TSOptionalType" === r);
							}), this.finishNode(e, "TSTupleType");
						}
						tsParseTupleElementType() {
							const e = this.state.startLoc, t = this.eat(21), { startLoc: r } = this.state;
							let n, s, i, o;
							const a = tokenIsKeywordOrIdentifier(this.state.type) ? this.lookaheadCharCode() : null;
							if (58 === a) n = !0, i = !1, s = this.parseIdentifier(!0), this.expect(14), o = this.tsParseType();
							else if (63 === a) {
								i = !0;
								const e = this.state.value, t = this.tsParseNonArrayType();
								58 === this.lookaheadCharCode() ? (n = !0, s = this.createIdentifier(this.startNodeAt(r), e), this.expect(17), this.expect(14), o = this.tsParseType()) : (n = !1, o = t, this.expect(17));
							} else o = this.tsParseType(), i = this.eat(17), n = this.eat(14);
							if (n) {
								let e;
								s ? (e = this.startNodeAt(r), e.optional = i, e.label = s, e.elementType = o, this.eat(17) && (e.optional = !0, this.raise(Q.TupleOptionalAfterType, this.state.lastTokStartLoc))) : (e = this.startNodeAt(r), e.optional = i, this.raise(Q.InvalidTupleMemberLabel, o), e.label = o, e.elementType = this.tsParseType()), o = this.finishNode(e, "TSNamedTupleMember");
							} else if (i) {
								const e = this.startNodeAt(r);
								e.typeAnnotation = o, o = this.finishNode(e, "TSOptionalType");
							}
							if (t) {
								const t = this.startNodeAt(e);
								t.typeAnnotation = o, o = this.finishNode(t, "TSRestType");
							}
							return o;
						}
						tsParseParenthesizedType() {
							const e = this.startNode();
							return this.expect(10), e.typeAnnotation = this.tsParseType(), this.expect(11), this.finishNode(e, "TSParenthesizedType");
						}
						tsParseFunctionOrConstructorType(e, t) {
							const r = this.startNode();
							return "TSConstructorType" === e && (r.abstract = !!t, t && this.next(), this.next()), this.tsInAllowConditionalTypesContext(() => this.tsFillSignature(19, r)), this.finishNode(r, e);
						}
						tsParseLiteralTypeNode() {
							const e = this.startNode();
							switch (this.state.type) {
								case 135:
								case 136:
								case 134:
								case 85:
								case 86:
									e.literal = super.parseExprAtom();
									break;
								default: this.unexpected();
							}
							return this.finishNode(e, "TSLiteralType");
						}
						tsParseTemplateLiteralType() {
							{
								const e = this.startNode();
								return e.literal = super.parseTemplate(!1), this.finishNode(e, "TSLiteralType");
							}
						}
						parseTemplateSubstitution() {
							return this.state.inType ? this.tsParseType() : super.parseTemplateSubstitution();
						}
						tsParseThisTypeOrThisTypePredicate() {
							const e = this.tsParseThisTypeNode();
							return this.isContextual(116) && !this.hasPrecedingLineBreak() ? this.tsParseThisTypePredicate(e) : e;
						}
						tsParseNonArrayType() {
							switch (this.state.type) {
								case 134:
								case 135:
								case 136:
								case 85:
								case 86: return this.tsParseLiteralTypeNode();
								case 53:
									if ("-" === this.state.value) {
										const e = this.startNode(), t = this.lookahead();
										return 135 !== t.type && 136 !== t.type && this.unexpected(), e.literal = this.parseMaybeUnary(), this.finishNode(e, "TSLiteralType");
									}
									break;
								case 78: return this.tsParseThisTypeOrThisTypePredicate();
								case 87: return this.tsParseTypeQuery();
								case 83: return this.tsParseImportType();
								case 5: return this.tsLookAhead(this.tsIsStartOfMappedType.bind(this)) ? this.tsParseMappedType() : this.tsParseTypeLiteral();
								case 0: return this.tsParseTupleType();
								case 10: return this.tsParseParenthesizedType();
								case 25:
								case 24: return this.tsParseTemplateLiteralType();
								default: {
									const { type: e } = this.state;
									if (tokenIsIdentifier(e) || 88 === e || 84 === e) {
										const t = 88 === e ? "TSVoidKeyword" : 84 === e ? "TSNullKeyword" : function(e) {
											switch (e) {
												case "any": return "TSAnyKeyword";
												case "boolean": return "TSBooleanKeyword";
												case "bigint": return "TSBigIntKeyword";
												case "never": return "TSNeverKeyword";
												case "number": return "TSNumberKeyword";
												case "object": return "TSObjectKeyword";
												case "string": return "TSStringKeyword";
												case "symbol": return "TSSymbolKeyword";
												case "undefined": return "TSUndefinedKeyword";
												case "unknown": return "TSUnknownKeyword";
												default: return;
											}
										}(this.state.value);
										if (void 0 !== t && 46 !== this.lookaheadCharCode()) {
											const e = this.startNode();
											return this.next(), this.finishNode(e, t);
										}
										return this.tsParseTypeReference();
									}
								}
							}
							this.unexpected();
						}
						tsParseArrayTypeOrHigher() {
							const { startLoc: e } = this.state;
							let t = this.tsParseNonArrayType();
							for (; !this.hasPrecedingLineBreak() && this.eat(0);) if (this.match(3)) {
								const r = this.startNodeAt(e);
								r.elementType = t, this.expect(3), t = this.finishNode(r, "TSArrayType");
							} else {
								const r = this.startNodeAt(e);
								r.objectType = t, r.indexType = this.tsParseType(), this.expect(3), t = this.finishNode(r, "TSIndexedAccessType");
							}
							return t;
						}
						tsParseTypeOperator() {
							const e = this.startNode(), t = this.state.value;
							return this.next(), e.operator = t, e.typeAnnotation = this.tsParseTypeOperatorOrHigher(), "readonly" === t && this.tsCheckTypeAnnotationForReadOnly(e), this.finishNode(e, "TSTypeOperator");
						}
						tsCheckTypeAnnotationForReadOnly(e) {
							switch (e.typeAnnotation.type) {
								case "TSTupleType":
								case "TSArrayType": return;
								default: this.raise(Q.UnexpectedReadonly, e);
							}
						}
						tsParseInferType() {
							const e = this.startNode();
							this.expectContextual(115);
							const t = this.startNode();
							return t.name = this.tsParseTypeParameterName(), t.constraint = this.tsTryParse(() => this.tsParseConstraintForInferType()), e.typeParameter = this.finishNode(t, "TSTypeParameter"), this.finishNode(e, "TSInferType");
						}
						tsParseConstraintForInferType() {
							if (this.eat(81)) {
								const e = this.tsInDisallowConditionalTypesContext(() => this.tsParseType());
								if (this.state.inDisallowConditionalTypesContext || !this.match(17)) return e;
							}
						}
						tsParseTypeOperatorOrHigher() {
							var e;
							return (e = this.state.type) >= 121 && e <= 123 && !this.state.containsEsc ? this.tsParseTypeOperator() : this.isContextual(115) ? this.tsParseInferType() : this.tsInAllowConditionalTypesContext(() => this.tsParseArrayTypeOrHigher());
						}
						tsParseUnionOrIntersectionType(e, t, r) {
							const n = this.startNode(), s = this.eat(r), i = [];
							do
								i.push(t());
							while (this.eat(r));
							return 1 !== i.length || s ? (n.types = i, this.finishNode(n, e)) : i[0];
						}
						tsParseIntersectionTypeOrHigher() {
							return this.tsParseUnionOrIntersectionType("TSIntersectionType", this.tsParseTypeOperatorOrHigher.bind(this), 45);
						}
						tsParseUnionTypeOrHigher() {
							return this.tsParseUnionOrIntersectionType("TSUnionType", this.tsParseIntersectionTypeOrHigher.bind(this), 43);
						}
						tsIsStartOfFunctionType() {
							return !!this.match(47) || this.match(10) && this.tsLookAhead(this.tsIsUnambiguouslyStartOfFunctionType.bind(this));
						}
						tsSkipParameterStart() {
							if (tokenIsIdentifier(this.state.type) || this.match(78)) return this.next(), !0;
							if (this.match(5)) {
								const { errors: e } = this.state, t = e.length;
								try {
									return this.parseObjectLike(8, !0), e.length === t;
								} catch (e) {
									return !1;
								}
							}
							if (this.match(0)) {
								this.next();
								const { errors: e } = this.state, t = e.length;
								try {
									return super.parseBindingList(3, 93, 1), e.length === t;
								} catch (e) {
									return !1;
								}
							}
							return !1;
						}
						tsIsUnambiguouslyStartOfFunctionType() {
							if (this.next(), this.match(11) || this.match(21)) return !0;
							if (this.tsSkipParameterStart()) {
								if (this.match(14) || this.match(12) || this.match(17) || this.match(29)) return !0;
								if (this.match(11) && (this.next(), this.match(19))) return !0;
							}
							return !1;
						}
						tsParseTypeOrTypePredicateAnnotation(e) {
							return this.tsInType(() => {
								const t = this.startNode();
								this.expect(e);
								const r = this.startNode(), n = !!this.tsTryParse(this.tsParseTypePredicateAsserts.bind(this));
								if (n && this.match(78)) {
									let e = this.tsParseThisTypeOrThisTypePredicate();
									return "TSThisType" === e.type ? (r.parameterName = e, r.asserts = !0, r.typeAnnotation = null, e = this.finishNode(r, "TSTypePredicate")) : (this.resetStartLocationFromNode(e, r), e.asserts = !0), t.typeAnnotation = e, this.finishNode(t, "TSTypeAnnotation");
								}
								const s = this.tsIsIdentifier() && this.tsTryParse(this.tsParseTypePredicatePrefix.bind(this));
								if (!s) return n ? (r.parameterName = this.parseIdentifier(), r.asserts = n, r.typeAnnotation = null, t.typeAnnotation = this.finishNode(r, "TSTypePredicate"), this.finishNode(t, "TSTypeAnnotation")) : this.tsParseTypeAnnotation(!1, t);
								const i = this.tsParseTypeAnnotation(!1);
								return r.parameterName = s, r.typeAnnotation = i, r.asserts = n, t.typeAnnotation = this.finishNode(r, "TSTypePredicate"), this.finishNode(t, "TSTypeAnnotation");
							});
						}
						tsTryParseTypeOrTypePredicateAnnotation() {
							if (this.match(14)) return this.tsParseTypeOrTypePredicateAnnotation(14);
						}
						tsTryParseTypeAnnotation() {
							if (this.match(14)) return this.tsParseTypeAnnotation();
						}
						tsTryParseType() {
							return this.tsEatThenParseType(14);
						}
						tsParseTypePredicatePrefix() {
							const e = this.parseIdentifier();
							if (this.isContextual(116) && !this.hasPrecedingLineBreak()) return this.next(), e;
						}
						tsParseTypePredicateAsserts() {
							if (109 !== this.state.type) return !1;
							const e = this.state.containsEsc;
							return this.next(), !(!tokenIsIdentifier(this.state.type) && !this.match(78)) && (e && this.raise(c.InvalidEscapedReservedWord, this.state.lastTokStartLoc, { reservedWord: "asserts" }), !0);
						}
						tsParseTypeAnnotation(e = !0, t = this.startNode()) {
							return this.tsInType(() => {
								e && this.expect(14), t.typeAnnotation = this.tsParseType();
							}), this.finishNode(t, "TSTypeAnnotation");
						}
						tsParseType() {
							assert(this.state.inType);
							const e = this.tsParseNonConditionalType();
							if (this.state.inDisallowConditionalTypesContext || this.hasPrecedingLineBreak() || !this.eat(81)) return e;
							const t = this.startNodeAtNode(e);
							return t.checkType = e, t.extendsType = this.tsInDisallowConditionalTypesContext(() => this.tsParseNonConditionalType()), this.expect(17), t.trueType = this.tsInAllowConditionalTypesContext(() => this.tsParseType()), this.expect(14), t.falseType = this.tsInAllowConditionalTypesContext(() => this.tsParseType()), this.finishNode(t, "TSConditionalType");
						}
						isAbstractConstructorSignature() {
							return this.isContextual(124) && this.isLookaheadContextual("new");
						}
						tsParseNonConditionalType() {
							return this.tsIsStartOfFunctionType() ? this.tsParseFunctionOrConstructorType("TSFunctionType") : this.match(77) ? this.tsParseFunctionOrConstructorType("TSConstructorType") : this.isAbstractConstructorSignature() ? this.tsParseFunctionOrConstructorType("TSConstructorType", !0) : this.tsParseUnionTypeOrHigher();
						}
						tsParseTypeAssertion() {
							this.getPluginOption("typescript", "disallowAmbiguousJSXLike") && this.raise(Q.ReservedTypeAssertion, this.state.startLoc);
							const e = this.startNode();
							return e.typeAnnotation = this.tsInType(() => (this.next(), this.match(75) ? this.tsParseTypeReference() : this.tsParseType())), this.expect(48), e.expression = this.parseMaybeUnary(), this.finishNode(e, "TSTypeAssertion");
						}
						tsParseHeritageClause(e) {
							const t = this.state.startLoc, r = this.tsParseDelimitedList("HeritageClauseElement", () => {
								{
									const e = this.startNode();
									return e.expression = this.tsParseEntityName(3), this.match(47) && (e.typeParameters = this.tsParseTypeArguments()), this.finishNode(e, "TSExpressionWithTypeArguments");
								}
							});
							return r.length || this.raise(Q.EmptyHeritageClauseType, t, { token: e }), r;
						}
						tsParseInterfaceDeclaration(e, t = {}) {
							if (this.hasFollowingLineBreak()) return null;
							this.expectContextual(129), t.declare && (e.declare = !0), tokenIsIdentifier(this.state.type) ? (e.id = this.parseIdentifier(), this.checkIdentifier(e.id, 130)) : (e.id = null, this.raise(Q.MissingInterfaceName, this.state.startLoc)), e.typeParameters = this.tsTryParseTypeParameters(this.tsParseInOutConstModifiers), this.eat(81) && (e.extends = this.tsParseHeritageClause("extends"));
							const r = this.startNode();
							return r.body = this.tsInType(this.tsParseObjectTypeMembers.bind(this)), e.body = this.finishNode(r, "TSInterfaceBody"), this.finishNode(e, "TSInterfaceDeclaration");
						}
						tsParseTypeAliasDeclaration(e) {
							return e.id = this.parseIdentifier(), this.checkIdentifier(e.id, 2), e.typeAnnotation = this.tsInType(() => {
								if (e.typeParameters = this.tsTryParseTypeParameters(this.tsParseInOutModifiers), this.expect(29), this.isContextual(114) && 46 !== this.lookaheadCharCode()) {
									const e = this.startNode();
									return this.next(), this.finishNode(e, "TSIntrinsicKeyword");
								}
								return this.tsParseType();
							}), this.semicolon(), this.finishNode(e, "TSTypeAliasDeclaration");
						}
						tsInTopLevelContext(e) {
							if (this.curContext() === d.brace) return e();
							{
								const t = this.state.context;
								this.state.context = [t[0]];
								try {
									return e();
								} finally {
									this.state.context = t;
								}
							}
						}
						tsInType(e) {
							const t = this.state.inType;
							this.state.inType = !0;
							try {
								return e();
							} finally {
								this.state.inType = t;
							}
						}
						tsInDisallowConditionalTypesContext(e) {
							const t = this.state.inDisallowConditionalTypesContext;
							this.state.inDisallowConditionalTypesContext = !0;
							try {
								return e();
							} finally {
								this.state.inDisallowConditionalTypesContext = t;
							}
						}
						tsInAllowConditionalTypesContext(e) {
							const t = this.state.inDisallowConditionalTypesContext;
							this.state.inDisallowConditionalTypesContext = !1;
							try {
								return e();
							} finally {
								this.state.inDisallowConditionalTypesContext = t;
							}
						}
						tsEatThenParseType(e) {
							if (this.match(e)) return this.tsNextThenParseType();
						}
						tsExpectThenParseType(e) {
							return this.tsInType(() => (this.expect(e), this.tsParseType()));
						}
						tsNextThenParseType() {
							return this.tsInType(() => (this.next(), this.tsParseType()));
						}
						tsParseEnumMember() {
							const e = this.startNode();
							return e.id = this.match(134) ? super.parseStringLiteral(this.state.value) : this.parseIdentifier(!0), this.eat(29) && (e.initializer = super.parseMaybeAssignAllowIn()), this.finishNode(e, "TSEnumMember");
						}
						tsParseEnumDeclaration(e, t = {}) {
							return t.const && (e.const = !0), t.declare && (e.declare = !0), this.expectContextual(126), e.id = this.parseIdentifier(), this.checkIdentifier(e.id, e.const ? 8971 : 8459), this.expect(5), e.members = this.tsParseDelimitedList("EnumMembers", this.tsParseEnumMember.bind(this)), this.expect(8), this.finishNode(e, "TSEnumDeclaration");
						}
						tsParseEnumBody() {
							const e = this.startNode();
							return this.expect(5), e.members = this.tsParseDelimitedList("EnumMembers", this.tsParseEnumMember.bind(this)), this.expect(8), this.finishNode(e, "TSEnumBody");
						}
						tsParseModuleBlock() {
							const e = this.startNode();
							return this.scope.enter(0), this.expect(5), super.parseBlockOrModuleBlockBody(e.body = [], void 0, !0, 8), this.scope.exit(), this.finishNode(e, "TSModuleBlock");
						}
						tsParseModuleOrNamespaceDeclaration(e, t = !1) {
							if (e.id = this.parseIdentifier(), t || this.checkIdentifier(e.id, 1024), this.eat(16)) {
								const t = this.startNode();
								this.tsParseModuleOrNamespaceDeclaration(t, !0), e.body = t;
							} else this.scope.enter(1024), this.prodParam.enter(0), e.body = this.tsParseModuleBlock(), this.prodParam.exit(), this.scope.exit();
							return this.finishNode(e, "TSModuleDeclaration");
						}
						tsParseAmbientExternalModuleDeclaration(e) {
							return this.isContextual(112) ? (e.kind = "global", e.global = !0, e.id = this.parseIdentifier()) : this.match(134) ? (e.kind = "module", e.id = super.parseStringLiteral(this.state.value)) : this.unexpected(), this.match(5) ? (this.scope.enter(1024), this.prodParam.enter(0), e.body = this.tsParseModuleBlock(), this.prodParam.exit(), this.scope.exit()) : this.semicolon(), this.finishNode(e, "TSModuleDeclaration");
						}
						tsParseImportEqualsDeclaration(e, t, r) {
							e.isExport = r || !1, e.id = t || this.parseIdentifier(), this.checkIdentifier(e.id, 4096), this.expect(29);
							const n = this.tsParseModuleReference();
							return "type" === e.importKind && "TSExternalModuleReference" !== n.type && this.raise(Q.ImportAliasHasImportType, n), e.moduleReference = n, this.semicolon(), this.finishNode(e, "TSImportEqualsDeclaration");
						}
						tsIsExternalModuleReference() {
							return this.isContextual(119) && 40 === this.lookaheadCharCode();
						}
						tsParseModuleReference() {
							return this.tsIsExternalModuleReference() ? this.tsParseExternalModuleReference() : this.tsParseEntityName(0);
						}
						tsParseExternalModuleReference() {
							const e = this.startNode();
							return this.expectContextual(119), this.expect(10), this.match(134) || this.unexpected(), e.expression = super.parseExprAtom(), this.expect(11), this.sawUnambiguousESM = !0, this.finishNode(e, "TSExternalModuleReference");
						}
						tsLookAhead(e) {
							const t = this.state.clone(), r = e();
							return this.state = t, r;
						}
						tsTryParseAndCatch(e) {
							const t = this.tryParse((t) => e() || t());
							if (!t.aborted && t.node) return t.error && (this.state = t.failState), t.node;
						}
						tsTryParse(e) {
							const t = this.state.clone(), r = e();
							if (void 0 !== r && !1 !== r) return r;
							this.state = t;
						}
						tsTryParseDeclare(e) {
							if (this.isLineTerminator()) return;
							const t = this.state.type;
							return this.tsInAmbientContext(() => {
								switch (t) {
									case 68: return e.declare = !0, super.parseFunctionStatement(e, !1, !1);
									case 80: return e.declare = !0, this.parseClass(e, !0, !1);
									case 126: return this.tsParseEnumDeclaration(e, { declare: !0 });
									case 112: return this.tsParseAmbientExternalModuleDeclaration(e);
									case 100: if (this.state.containsEsc) return;
									case 75:
									case 74: return this.match(75) && this.isLookaheadContextual("enum") ? (this.expect(75), this.tsParseEnumDeclaration(e, {
										const: !0,
										declare: !0
									})) : (e.declare = !0, this.parseVarStatement(e, this.state.value, !0));
									case 107:
										if (this.isUsing()) return this.raise(Q.InvalidModifierOnUsingDeclaration, this.state.startLoc, "declare"), e.declare = !0, this.parseVarStatement(e, "using", !0);
										break;
									case 96:
										if (this.isAwaitUsing()) return this.raise(Q.InvalidModifierOnAwaitUsingDeclaration, this.state.startLoc, "declare"), e.declare = !0, this.next(), this.parseVarStatement(e, "await using", !0);
										break;
									case 129: {
										const t = this.tsParseInterfaceDeclaration(e, { declare: !0 });
										if (t) return t;
									}
									default: if (tokenIsIdentifier(t)) return this.tsParseDeclaration(e, this.state.value, !0, null);
								}
							});
						}
						tsTryParseExportDeclaration() {
							return this.tsParseDeclaration(this.startNode(), this.state.value, !0, null);
						}
						tsParseExpressionStatement(e, t, r) {
							switch (t.name) {
								case "declare": {
									const t = this.tsTryParseDeclare(e);
									return t && (t.declare = !0), t;
								}
								case "global":
									if (this.match(5)) {
										this.scope.enter(1024), this.prodParam.enter(0);
										const r = e;
										return r.kind = "global", e.global = !0, r.id = t, r.body = this.tsParseModuleBlock(), this.scope.exit(), this.prodParam.exit(), this.finishNode(r, "TSModuleDeclaration");
									}
									break;
								default: return this.tsParseDeclaration(e, t.name, !1, r);
							}
						}
						tsParseDeclaration(e, t, r, n) {
							switch (t) {
								case "abstract":
									if (this.tsCheckLineTerminator(r) && (this.match(80) || tokenIsIdentifier(this.state.type))) return this.tsParseAbstractDeclaration(e, n);
									break;
								case "module":
									if (this.tsCheckLineTerminator(r)) {
										if (this.match(134)) return this.tsParseAmbientExternalModuleDeclaration(e);
										if (tokenIsIdentifier(this.state.type)) return e.kind = "module", this.tsParseModuleOrNamespaceDeclaration(e);
									}
									break;
								case "namespace":
									if (this.tsCheckLineTerminator(r) && tokenIsIdentifier(this.state.type)) return e.kind = "namespace", this.tsParseModuleOrNamespaceDeclaration(e);
									break;
								case "type": if (this.tsCheckLineTerminator(r) && tokenIsIdentifier(this.state.type)) return this.tsParseTypeAliasDeclaration(e);
							}
						}
						tsCheckLineTerminator(e) {
							return e ? !this.hasFollowingLineBreak() && (this.next(), !0) : !this.isLineTerminator();
						}
						tsTryParseGenericAsyncArrowFunction(e) {
							if (!this.match(47)) return;
							const t = this.state.maybeInArrowParameters;
							this.state.maybeInArrowParameters = !0;
							const r = this.tsTryParseAndCatch(() => {
								const t = this.startNodeAt(e);
								return t.typeParameters = this.tsParseTypeParameters(this.tsParseConstModifier), super.parseFunctionParams(t), t.returnType = this.tsTryParseTypeOrTypePredicateAnnotation(), this.expect(19), t;
							});
							return this.state.maybeInArrowParameters = t, r ? super.parseArrowExpression(r, null, !0) : void 0;
						}
						tsParseTypeArgumentsInExpression() {
							if (47 === this.reScan_lt()) return this.tsParseTypeArguments();
						}
						tsParseTypeArguments() {
							const e = this.startNode();
							return e.params = this.tsInType(() => this.tsInTopLevelContext(() => (this.expect(47), this.tsParseDelimitedList("TypeParametersOrArguments", this.tsParseType.bind(this))))), 0 === e.params.length ? this.raise(Q.EmptyTypeArguments, e) : this.state.inType || this.curContext() !== d.brace || this.reScan_lt_gt(), this.expect(48), this.finishNode(e, "TSTypeParameterInstantiation");
						}
						tsIsDeclarationStart() {
							return (e = this.state.type) >= 124 && e <= 130;
							var e;
						}
						isExportDefaultSpecifier() {
							return !this.tsIsDeclarationStart() && super.isExportDefaultSpecifier();
						}
						parseBindingElement(e, t) {
							const r = t.length ? t[0].loc.start : this.state.startLoc, n = {};
							this.tsParseModifiers({ allowedModifiers: [
								"public",
								"private",
								"protected",
								"override",
								"readonly"
							] }, n);
							const s = n.accessibility, i = n.override, o = n.readonly;
							4 & e || !(s || o || i) || this.raise(Q.UnexpectedParameterModifier, r);
							const a = this.parseMaybeDefault();
							2 & e && this.parseFunctionParamType(a);
							const l = this.parseMaybeDefault(a.loc.start, a);
							if (s || o || i) {
								const e = this.startNodeAt(r);
								return t.length && (e.decorators = t), s && (e.accessibility = s), o && (e.readonly = o), i && (e.override = i), "Identifier" !== l.type && "AssignmentPattern" !== l.type && this.raise(Q.UnsupportedParameterPropertyKind, e), e.parameter = l, this.finishNode(e, "TSParameterProperty");
							}
							return t.length && (a.decorators = t), l;
						}
						isSimpleParameter(e) {
							return "TSParameterProperty" === e.type && super.isSimpleParameter(e.parameter) || super.isSimpleParameter(e);
						}
						tsDisallowOptionalPattern(e) {
							for (const t of e.params) "Identifier" !== t.type && t.optional && !this.state.isAmbientContext && this.raise(Q.PatternIsOptional, t);
						}
						setArrowFunctionParameters(e, t, r) {
							super.setArrowFunctionParameters(e, t, r), this.tsDisallowOptionalPattern(e);
						}
						parseFunctionBodyAndFinish(e, t, r = !1) {
							this.match(14) && (e.returnType = this.tsParseTypeOrTypePredicateAnnotation(14));
							const n = "FunctionDeclaration" === t ? "TSDeclareFunction" : "ClassMethod" === t || "ClassPrivateMethod" === t ? "TSDeclareMethod" : void 0;
							return n && !this.match(5) && this.isLineTerminator() ? this.finishNode(e, n) : "TSDeclareFunction" === n && this.state.isAmbientContext && (this.raise(Q.DeclareFunctionHasImplementation, e), e.declare) ? super.parseFunctionBodyAndFinish(e, n, r) : (this.tsDisallowOptionalPattern(e), super.parseFunctionBodyAndFinish(e, t, r));
						}
						registerFunctionStatementId(e) {
							!e.body && e.id ? this.checkIdentifier(e.id, 1024) : super.registerFunctionStatementId(e);
						}
						tsCheckForInvalidTypeCasts(e) {
							e.forEach((e) => {
								"TSTypeCastExpression" === (null == e ? void 0 : e.type) && this.raise(Q.UnexpectedTypeAnnotation, e.typeAnnotation);
							});
						}
						toReferencedList(e, t) {
							return this.tsCheckForInvalidTypeCasts(e), e;
						}
						parseArrayLike(e, t, r, n) {
							const s = super.parseArrayLike(e, t, r, n);
							return "ArrayExpression" === s.type && this.tsCheckForInvalidTypeCasts(s.elements), s;
						}
						parseSubscript(e, t, r, n) {
							if (!this.hasPrecedingLineBreak() && this.match(35)) {
								this.state.canStartJSXElement = !1, this.next();
								const r = this.startNodeAt(t);
								return r.expression = e, this.finishNode(r, "TSNonNullExpression");
							}
							let s = !1;
							if (this.match(18) && 60 === this.lookaheadCharCode()) {
								if (r) return n.stop = !0, e;
								n.optionalChainMember = s = !0, this.next();
							}
							if (this.match(47) || this.match(51)) {
								let i;
								const o = this.tsTryParseAndCatch(() => {
									if (!r && this.atPossibleAsyncArrow(e)) {
										const e = this.tsTryParseGenericAsyncArrowFunction(t);
										if (e) return n.stop = !0, e;
									}
									const o = this.tsParseTypeArgumentsInExpression();
									if (!o) return;
									if (s && !this.match(10)) return void (i = this.state.curPosition());
									if (tokenIsTemplate(this.state.type)) {
										const r = super.parseTaggedTemplateExpression(e, t, n);
										return r.typeParameters = o, r;
									}
									if (!r && this.eat(10)) {
										const r = this.startNodeAt(t);
										return r.callee = e, r.arguments = this.parseCallExpressionArguments(), this.tsCheckForInvalidTypeCasts(r.arguments), r.typeParameters = o, n.optionalChainMember && (r.optional = s), this.finishCallExpression(r, n.optionalChainMember);
									}
									const a = this.state.type;
									if (48 === a || 52 === a || 10 !== a && tokenCanStartExpression(a) && !this.hasPrecedingLineBreak()) return;
									const l = this.startNodeAt(t);
									return l.expression = e, l.typeParameters = o, this.finishNode(l, "TSInstantiationExpression");
								});
								if (i && this.unexpected(i, 10), o) return "TSInstantiationExpression" === o.type && ((this.match(16) || this.match(18) && 40 !== this.lookaheadCharCode()) && this.raise(Q.InvalidPropertyAccessAfterInstantiationExpression, this.state.startLoc), this.match(16) || this.match(18) || (o.expression = super.stopParseSubscript(e, n))), o;
							}
							return super.parseSubscript(e, t, r, n);
						}
						parseNewCallee(e) {
							var t;
							super.parseNewCallee(e);
							const { callee: r } = e;
							"TSInstantiationExpression" !== r.type || null != (t = r.extra) && t.parenthesized || (e.typeParameters = r.typeParameters, e.callee = r.expression);
						}
						parseExprOp(e, t, r) {
							let n;
							if (tokenOperatorPrecedence(58) > r && !this.hasPrecedingLineBreak() && (this.isContextual(93) || (n = this.isContextual(120)))) {
								const s = this.startNodeAt(t);
								return s.expression = e, s.typeAnnotation = this.tsInType(() => (this.next(), this.match(75) ? (n && this.raise(c.UnexpectedKeyword, this.state.startLoc, { keyword: "const" }), this.tsParseTypeReference()) : this.tsParseType())), this.finishNode(s, n ? "TSSatisfiesExpression" : "TSAsExpression"), this.reScan_lt_gt(), this.parseExprOp(s, t, r);
							}
							return super.parseExprOp(e, t, r);
						}
						checkReservedWord(e, t, r, n) {
							this.state.isAmbientContext || super.checkReservedWord(e, t, r, n);
						}
						checkImportReflection(e) {
							super.checkImportReflection(e), e.module && "value" !== e.importKind && this.raise(Q.ImportReflectionHasImportType, e.specifiers[0].loc.start);
						}
						checkDuplicateExports() {}
						isPotentialImportPhase(e) {
							if (super.isPotentialImportPhase(e)) return !0;
							if (this.isContextual(130)) {
								const t = this.lookaheadCharCode();
								return e ? 123 === t || 42 === t : 61 !== t;
							}
							return !e && this.isContextual(87);
						}
						applyImportPhase(e, t, r, n) {
							super.applyImportPhase(e, t, r, n), t ? e.exportKind = "type" === r ? "type" : "value" : e.importKind = "type" === r || "typeof" === r ? r : "value";
						}
						parseImport(e) {
							if (this.match(134)) return e.importKind = "value", super.parseImport(e);
							let t;
							if (tokenIsIdentifier(this.state.type) && 61 === this.lookaheadCharCode()) return e.importKind = "value", this.tsParseImportEqualsDeclaration(e);
							if (this.isContextual(130)) {
								const r = this.parseMaybeImportPhase(e, !1);
								if (61 === this.lookaheadCharCode()) return this.tsParseImportEqualsDeclaration(e, r);
								t = super.parseImportSpecifiersAndAfter(e, r);
							} else t = super.parseImport(e);
							return "type" === t.importKind && t.specifiers.length > 1 && "ImportDefaultSpecifier" === t.specifiers[0].type && this.raise(Q.TypeImportCannotSpecifyDefaultAndNamed, t), t;
						}
						parseExport(e, t) {
							if (this.match(83)) {
								const t = e;
								this.next();
								let r = null;
								this.isContextual(130) && this.isPotentialImportPhase(!1) ? r = this.parseMaybeImportPhase(t, !1) : t.importKind = "value";
								return this.tsParseImportEqualsDeclaration(t, r, !0);
							}
							if (this.eat(29)) {
								const t = e;
								return t.expression = super.parseExpression(), this.semicolon(), this.sawUnambiguousESM = !0, this.finishNode(t, "TSExportAssignment");
							}
							if (this.eatContextual(93)) {
								const t = e;
								return this.expectContextual(128), t.id = this.parseIdentifier(), this.semicolon(), this.finishNode(t, "TSNamespaceExportDeclaration");
							}
							return super.parseExport(e, t);
						}
						isAbstractClass() {
							return this.isContextual(124) && this.isLookaheadContextual("class");
						}
						parseExportDefaultExpression() {
							if (this.isAbstractClass()) {
								const e = this.startNode();
								return this.next(), e.abstract = !0, this.parseClass(e, !0, !0);
							}
							if (this.match(129)) {
								const e = this.tsParseInterfaceDeclaration(this.startNode());
								if (e) return e;
							}
							return super.parseExportDefaultExpression();
						}
						parseVarStatement(e, t, r = !1) {
							const { isAmbientContext: n } = this.state, s = super.parseVarStatement(e, t, r || n);
							if (!n) return s;
							if (!e.declare && ("using" === t || "await using" === t)) return this.raiseOverwrite(Q.UsingDeclarationInAmbientContext, e, t), s;
							for (const { id: e, init: r } of s.declarations) r && ("var" === t || "let" === t || e.typeAnnotation ? this.raise(Q.InitializerNotAllowedInAmbientContext, r) : isValidAmbientConstInitializer(r, this.hasPlugin("estree")) || this.raise(Q.ConstInitializerMustBeStringOrNumericLiteralOrLiteralEnumReference, r));
							return s;
						}
						parseStatementContent(e, t) {
							if (this.match(75) && this.isLookaheadContextual("enum")) {
								const e = this.startNode();
								return this.expect(75), this.tsParseEnumDeclaration(e, { const: !0 });
							}
							if (this.isContextual(126)) return this.tsParseEnumDeclaration(this.startNode());
							if (this.isContextual(129)) {
								const e = this.tsParseInterfaceDeclaration(this.startNode());
								if (e) return e;
							}
							return super.parseStatementContent(e, t);
						}
						parseAccessModifier() {
							return this.tsParseModifier([
								"public",
								"protected",
								"private"
							]);
						}
						tsHasSomeModifiers(e, t) {
							return t.some((t) => tsIsAccessModifier(t) ? e.accessibility === t : !!e[t]);
						}
						tsIsStartOfStaticBlocks() {
							return this.isContextual(106) && 123 === this.lookaheadCharCode();
						}
						parseClassMember(e, t, r) {
							const n = [
								"declare",
								"private",
								"public",
								"protected",
								"override",
								"abstract",
								"readonly",
								"static"
							];
							this.tsParseModifiers({
								allowedModifiers: n,
								disallowedModifiers: ["in", "out"],
								stopOnStartOfClassStaticBlock: !0,
								errorTemplate: Q.InvalidModifierOnTypeParameterPositions
							}, t);
							const callParseClassMemberWithIsStatic = () => {
								this.tsIsStartOfStaticBlocks() ? (this.next(), this.next(), this.tsHasSomeModifiers(t, n) && this.raise(Q.StaticBlockCannotHaveModifier, this.state.curPosition()), super.parseClassStaticBlock(e, t)) : this.parseClassMemberWithIsStatic(e, t, r, !!t.static);
							};
							t.declare ? this.tsInAmbientContext(callParseClassMemberWithIsStatic) : callParseClassMemberWithIsStatic();
						}
						parseClassMemberWithIsStatic(e, t, r, n) {
							const s = this.tsTryParseIndexSignature(t);
							if (s) return e.body.push(s), t.abstract && this.raise(Q.IndexSignatureHasAbstract, t), t.accessibility && this.raise(Q.IndexSignatureHasAccessibility, t, { modifier: t.accessibility }), t.declare && this.raise(Q.IndexSignatureHasDeclare, t), void (t.override && this.raise(Q.IndexSignatureHasOverride, t));
							!this.state.inAbstractClass && t.abstract && this.raise(Q.NonAbstractClassHasAbstractMethod, t), t.override && (r.hadSuperClass || this.raise(Q.OverrideNotInSubClass, t)), super.parseClassMemberWithIsStatic(e, t, r, n);
						}
						parsePostMemberNameModifiers(e) {
							this.eat(17) && (e.optional = !0), e.readonly && this.match(10) && this.raise(Q.ClassMethodHasReadonly, e), e.declare && this.match(10) && this.raise(Q.ClassMethodHasDeclare, e);
						}
						parseExpressionStatement(e, t, r) {
							return ("Identifier" === t.type ? this.tsParseExpressionStatement(e, t, r) : void 0) || super.parseExpressionStatement(e, t, r);
						}
						shouldParseExportDeclaration() {
							return !!this.tsIsDeclarationStart() || super.shouldParseExportDeclaration();
						}
						parseConditional(e, t, r) {
							if (!this.match(17)) return e;
							if (this.state.maybeInArrowParameters) {
								const t = this.lookaheadCharCode();
								if (44 === t || 61 === t || 58 === t || 41 === t) return this.setOptionalParametersError(r), e;
							}
							return super.parseConditional(e, t, r);
						}
						parseParenItem(e, t) {
							const r = super.parseParenItem(e, t);
							if (this.eat(17) && (r.optional = !0, this.resetEndLocation(e)), this.match(14)) {
								const r = this.startNodeAt(t);
								return r.expression = e, r.typeAnnotation = this.tsParseTypeAnnotation(), this.finishNode(r, "TSTypeCastExpression");
							}
							return e;
						}
						parseExportDeclaration(e) {
							if (!this.state.isAmbientContext && this.isContextual(125)) return this.tsInAmbientContext(() => this.parseExportDeclaration(e));
							const t = this.state.startLoc, r = this.eatContextual(125);
							if (r && (this.isContextual(125) || !this.shouldParseExportDeclaration())) throw this.raise(Q.ExpectedAmbientAfterExportDeclare, this.state.startLoc);
							const n = tokenIsIdentifier(this.state.type) && this.tsTryParseExportDeclaration() || super.parseExportDeclaration(e);
							return n ? (("TSInterfaceDeclaration" === n.type || "TSTypeAliasDeclaration" === n.type || r) && (e.exportKind = "type"), r && "TSImportEqualsDeclaration" !== n.type && (this.resetStartLocation(n, t), n.declare = !0), n) : null;
						}
						parseClassId(e, t, r, n) {
							if ((!t || r) && this.isContextual(113)) return;
							super.parseClassId(e, t, r, e.declare ? 1024 : 8331);
							const s = this.tsTryParseTypeParameters(this.tsParseInOutConstModifiers);
							s && (e.typeParameters = s);
						}
						parseClassPropertyAnnotation(e) {
							e.optional || (this.eat(35) ? e.definite = !0 : this.eat(17) && (e.optional = !0));
							const t = this.tsTryParseTypeAnnotation();
							t && (e.typeAnnotation = t);
						}
						parseClassProperty(e) {
							if (this.parseClassPropertyAnnotation(e), this.state.isAmbientContext && (!e.readonly || e.typeAnnotation) && this.match(29) && this.raise(Q.DeclareClassFieldHasInitializer, this.state.startLoc), e.abstract && this.match(29)) {
								const { key: t } = e;
								this.raise(Q.AbstractPropertyHasInitializer, this.state.startLoc, { propertyName: "Identifier" !== t.type || e.computed ? `[${this.input.slice(this.offsetToSourcePos(t.start), this.offsetToSourcePos(t.end))}]` : t.name });
							}
							return super.parseClassProperty(e);
						}
						parseClassPrivateProperty(e) {
							return e.abstract && this.raise(Q.PrivateElementHasAbstract, e), e.accessibility && this.raise(Q.PrivateElementHasAccessibility, e, { modifier: e.accessibility }), this.parseClassPropertyAnnotation(e), super.parseClassPrivateProperty(e);
						}
						parseClassAccessorProperty(e) {
							return this.parseClassPropertyAnnotation(e), e.optional && this.raise(Q.AccessorCannotBeOptional, e), super.parseClassAccessorProperty(e);
						}
						pushClassMethod(e, t, r, n, s, i) {
							const o = this.tsTryParseTypeParameters(this.tsParseConstModifier);
							o && s && this.raise(Q.ConstructorHasTypeParameters, o);
							const { declare: a = !1, kind: l } = t;
							!a || "get" !== l && "set" !== l || this.raise(Q.DeclareAccessor, t, { kind: l }), o && (t.typeParameters = o), super.pushClassMethod(e, t, r, n, s, i);
						}
						pushClassPrivateMethod(e, t, r, n) {
							const s = this.tsTryParseTypeParameters(this.tsParseConstModifier);
							s && (t.typeParameters = s), super.pushClassPrivateMethod(e, t, r, n);
						}
						declareClassPrivateMethodInScope(e, t) {
							"TSDeclareMethod" !== e.type && ("MethodDefinition" === e.type && null == e.value.body || super.declareClassPrivateMethodInScope(e, t));
						}
						parseClassSuper(e) {
							super.parseClassSuper(e), e.superClass && (this.match(47) || this.match(51)) && (e.superTypeParameters = this.tsParseTypeArgumentsInExpression()), this.eatContextual(113) && (e.implements = this.tsParseHeritageClause("implements"));
						}
						parseObjPropValue(e, t, r, n, s, i, o) {
							const a = this.tsTryParseTypeParameters(this.tsParseConstModifier);
							return a && (e.typeParameters = a), super.parseObjPropValue(e, t, r, n, s, i, o);
						}
						parseFunctionParams(e, t) {
							const r = this.tsTryParseTypeParameters(this.tsParseConstModifier);
							r && (e.typeParameters = r), super.parseFunctionParams(e, t);
						}
						parseVarId(e, t) {
							super.parseVarId(e, t), "Identifier" === e.id.type && !this.hasPrecedingLineBreak() && this.eat(35) && (e.definite = !0);
							const r = this.tsTryParseTypeAnnotation();
							r && (e.id.typeAnnotation = r, this.resetEndLocation(e.id));
						}
						parseAsyncArrowFromCallExpression(e, t) {
							return this.match(14) && (e.returnType = this.tsParseTypeAnnotation()), super.parseAsyncArrowFromCallExpression(e, t);
						}
						parseMaybeAssign(e, t) {
							var r, n, s, i, o;
							let a, l, p, c;
							if (this.hasPlugin("jsx") && (this.match(143) || this.match(47))) {
								if (a = this.state.clone(), l = this.tryParse(() => super.parseMaybeAssign(e, t), a), !l.error) return l.node;
								const { context: r } = this.state, n = r[r.length - 1];
								n !== d.j_oTag && n !== d.j_expr || r.pop();
							}
							if (!(null != (r = l) && r.error || this.match(47))) return super.parseMaybeAssign(e, t);
							a && a !== this.state || (a = this.state.clone());
							const u = this.tryParse((r) => {
								var n, s;
								c = this.tsParseTypeParameters(this.tsParseConstModifier);
								const i = super.parseMaybeAssign(e, t);
								return ("ArrowFunctionExpression" !== i.type || null != (n = i.extra) && n.parenthesized) && r(), 0 !== (null == (s = c) ? void 0 : s.params.length) && this.resetStartLocationFromNode(i, c), i.typeParameters = c, i;
							}, a);
							if (!u.error && !u.aborted) return c && this.reportReservedArrowTypeParam(c), u.node;
							if (!l && (assert(!this.hasPlugin("jsx")), p = this.tryParse(() => super.parseMaybeAssign(e, t), a), !p.error)) return p.node;
							if (null != (n = l) && n.node) return this.state = l.failState, l.node;
							if (u.node) return this.state = u.failState, c && this.reportReservedArrowTypeParam(c), u.node;
							if (null != (s = p) && s.node) return this.state = p.failState, p.node;
							throw (null == (i = l) ? void 0 : i.error) || u.error || (null == (o = p) ? void 0 : o.error);
						}
						reportReservedArrowTypeParam(e) {
							var t;
							1 !== e.params.length || e.params[0].constraint || null != (t = e.extra) && t.trailingComma || !this.getPluginOption("typescript", "disallowAmbiguousJSXLike") || this.raise(Q.ReservedArrowTypeParam, e);
						}
						parseMaybeUnary(e, t) {
							return !this.hasPlugin("jsx") && this.match(47) ? this.tsParseTypeAssertion() : super.parseMaybeUnary(e, t);
						}
						parseArrow(e) {
							if (this.match(14)) {
								const t = this.tryParse((e) => {
									const t = this.tsParseTypeOrTypePredicateAnnotation(14);
									return !this.canInsertSemicolon() && this.match(19) || e(), t;
								});
								if (t.aborted) return;
								t.thrown || (t.error && (this.state = t.failState), e.returnType = t.node);
							}
							return super.parseArrow(e);
						}
						parseFunctionParamType(e) {
							this.eat(17) && (e.optional = !0);
							const t = this.tsTryParseTypeAnnotation();
							return t && (e.typeAnnotation = t), this.resetEndLocation(e), e;
						}
						isAssignable(e, t) {
							switch (e.type) {
								case "TSTypeCastExpression": return this.isAssignable(e.expression, t);
								case "TSParameterProperty": return !0;
								default: return super.isAssignable(e, t);
							}
						}
						toAssignable(e, t = !1) {
							switch (e.type) {
								case "ParenthesizedExpression":
									this.toAssignableParenthesizedExpression(e, t);
									break;
								case "TSAsExpression":
								case "TSSatisfiesExpression":
								case "TSNonNullExpression":
								case "TSTypeAssertion":
									t ? this.expressionScope.recordArrowParameterBindingError(Q.UnexpectedTypeCastInParameter, e) : this.raise(Q.UnexpectedTypeCastInParameter, e), this.toAssignable(e.expression, t);
									break;
								case "AssignmentExpression": t || "TSTypeCastExpression" !== e.left.type || (e.left = this.typeCastToParameter(e.left));
								default: super.toAssignable(e, t);
							}
						}
						toAssignableParenthesizedExpression(e, t) {
							switch (e.expression.type) {
								case "TSAsExpression":
								case "TSSatisfiesExpression":
								case "TSNonNullExpression":
								case "TSTypeAssertion":
								case "ParenthesizedExpression":
									this.toAssignable(e.expression, t);
									break;
								default: super.toAssignable(e, t);
							}
						}
						checkToRestConversion(e, t) {
							switch (e.type) {
								case "TSAsExpression":
								case "TSSatisfiesExpression":
								case "TSTypeAssertion":
								case "TSNonNullExpression":
									this.checkToRestConversion(e.expression, !1);
									break;
								default: super.checkToRestConversion(e, t);
							}
						}
						isValidLVal(e, t, r) {
							switch (e) {
								case "TSTypeCastExpression": return !0;
								case "TSParameterProperty": return "parameter";
								case "TSNonNullExpression": return "expression";
								case "TSAsExpression":
								case "TSSatisfiesExpression":
								case "TSTypeAssertion": return (64 !== r || !t) && ["expression", !0];
								default: return super.isValidLVal(e, t, r);
							}
						}
						parseBindingAtom() {
							return 78 === this.state.type ? this.parseIdentifier(!0) : super.parseBindingAtom();
						}
						parseMaybeDecoratorArguments(e, t) {
							if (this.match(47) || this.match(51)) {
								const r = this.tsParseTypeArgumentsInExpression();
								if (this.match(10)) {
									const n = super.parseMaybeDecoratorArguments(e, t);
									return n.typeParameters = r, n;
								}
								this.unexpected(null, 10);
							}
							return super.parseMaybeDecoratorArguments(e, t);
						}
						checkCommaAfterRest(e) {
							return this.state.isAmbientContext && this.match(12) && this.lookaheadCharCode() === e ? (this.next(), !1) : super.checkCommaAfterRest(e);
						}
						isClassMethod() {
							return this.match(47) || super.isClassMethod();
						}
						isClassProperty() {
							return this.match(35) || this.match(14) || super.isClassProperty();
						}
						parseMaybeDefault(e, t) {
							const r = super.parseMaybeDefault(e, t);
							return "AssignmentPattern" === r.type && r.typeAnnotation && r.right.start < r.typeAnnotation.start && this.raise(Q.TypeAnnotationAfterAssign, r.typeAnnotation), r;
						}
						getTokenFromCode(e) {
							if (this.state.inType) {
								if (62 === e) return void this.finishOp(48, 1);
								if (60 === e) return void this.finishOp(47, 1);
							}
							super.getTokenFromCode(e);
						}
						reScan_lt_gt() {
							const { type: e } = this.state;
							47 === e ? (this.state.pos -= 1, this.readToken_lt()) : 48 === e && (this.state.pos -= 1, this.readToken_gt());
						}
						reScan_lt() {
							const { type: e } = this.state;
							return 51 === e ? (this.state.pos -= 2, this.finishOp(47, 1), 47) : e;
						}
						toAssignableListItem(e, t, r) {
							const n = e[t];
							"TSTypeCastExpression" === n.type && (e[t] = this.typeCastToParameter(n)), super.toAssignableListItem(e, t, r);
						}
						typeCastToParameter(e) {
							return e.expression.typeAnnotation = e.typeAnnotation, this.resetEndLocation(e.expression, e.typeAnnotation.loc.end), e.expression;
						}
						shouldParseArrow(e) {
							return this.match(14) ? e.every((e) => this.isAssignable(e, !0)) : super.shouldParseArrow(e);
						}
						shouldParseAsyncArrow() {
							return this.match(14) || super.shouldParseAsyncArrow();
						}
						canHaveLeadingDecorator() {
							return super.canHaveLeadingDecorator() || this.isAbstractClass();
						}
						jsxParseOpeningElementAfterName(e) {
							if (this.match(47) || this.match(51)) {
								const t = this.tsTryParseAndCatch(() => this.tsParseTypeArgumentsInExpression());
								t && (e.typeParameters = t);
							}
							return super.jsxParseOpeningElementAfterName(e);
						}
						getGetterSetterExpectedParamCount(e) {
							const t = super.getGetterSetterExpectedParamCount(e), r = this.getObjectOrClassMethodParams(e)[0];
							return r && this.isThisParam(r) ? t + 1 : t;
						}
						parseCatchClauseParam() {
							const e = super.parseCatchClauseParam(), t = this.tsTryParseTypeAnnotation();
							return t && (e.typeAnnotation = t, this.resetEndLocation(e)), e;
						}
						tsInAmbientContext(e) {
							const { isAmbientContext: t, strict: r } = this.state;
							this.state.isAmbientContext = !0, this.state.strict = !1;
							try {
								return e();
							} finally {
								this.state.isAmbientContext = t, this.state.strict = r;
							}
						}
						parseClass(e, t, r) {
							const n = this.state.inAbstractClass;
							this.state.inAbstractClass = !!e.abstract;
							try {
								return super.parseClass(e, t, r);
							} finally {
								this.state.inAbstractClass = n;
							}
						}
						tsParseAbstractDeclaration(e, t) {
							if (this.match(80)) return e.abstract = !0, this.maybeTakeDecorators(t, this.parseClass(e, !0, !1));
							if (this.isContextual(129)) {
								if (!this.hasFollowingLineBreak()) return e.abstract = !0, this.raise(Q.NonClassMethodPropertyHasAbstractModifier, e), this.tsParseInterfaceDeclaration(e);
							} else this.unexpected(null, 80);
						}
						parseMethod(e, t, r, n, s, i, o) {
							const a = super.parseMethod(e, t, r, n, s, i, o);
							if (a.abstract || "TSAbstractMethodDefinition" === a.type) {
								if ((this.hasPlugin("estree") ? a.value : a).body) {
									const { key: e } = a;
									this.raise(Q.AbstractMethodHasImplementation, a, { methodName: "Identifier" !== e.type || a.computed ? `[${this.input.slice(this.offsetToSourcePos(e.start), this.offsetToSourcePos(e.end))}]` : e.name });
								}
							}
							return a;
						}
						tsParseTypeParameterName() {
							return this.parseIdentifier().name;
						}
						shouldParseAsAmbientContext() {
							return !!this.getPluginOption("typescript", "dts");
						}
						parse() {
							return this.shouldParseAsAmbientContext() && (this.state.isAmbientContext = !0), super.parse();
						}
						getExpression() {
							return this.shouldParseAsAmbientContext() && (this.state.isAmbientContext = !0), super.getExpression();
						}
						parseExportSpecifier(e, t, r, n) {
							return !t && n ? (this.parseTypeOnlyImportExportSpecifier(e, !1, r), this.finishNode(e, "ExportSpecifier")) : (e.exportKind = "value", super.parseExportSpecifier(e, t, r, n));
						}
						parseImportSpecifier(e, t, r, n, s) {
							return !t && n ? (this.parseTypeOnlyImportExportSpecifier(e, !0, r), this.finishNode(e, "ImportSpecifier")) : (e.importKind = "value", super.parseImportSpecifier(e, t, r, n, r ? 4098 : 4096));
						}
						parseTypeOnlyImportExportSpecifier(e, t, r) {
							const n = t ? "imported" : "local", s = t ? "local" : "exported";
							let i, o = e[n], a = !1, l = !0;
							const p = o.loc.start;
							if (this.isContextual(93)) {
								const e = this.parseIdentifier();
								if (this.isContextual(93)) {
									const r = this.parseIdentifier();
									tokenIsKeywordOrIdentifier(this.state.type) ? (a = !0, o = e, i = t ? this.parseIdentifier() : this.parseModuleExportName(), l = !1) : (i = r, l = !1);
								} else tokenIsKeywordOrIdentifier(this.state.type) ? (l = !1, i = t ? this.parseIdentifier() : this.parseModuleExportName()) : (a = !0, o = e);
							} else tokenIsKeywordOrIdentifier(this.state.type) && (a = !0, t ? (o = this.parseIdentifier(!0), this.isContextual(93) || this.checkReservedWord(o.name, o.loc.start, !0, !0)) : o = this.parseModuleExportName());
							a && r && this.raise(t ? Q.TypeModifierIsUsedInTypeImports : Q.TypeModifierIsUsedInTypeExports, p), e[n] = o, e[s] = i;
							e[t ? "importKind" : "exportKind"] = a ? "type" : "value", l && this.eatContextual(93) && (e[s] = t ? this.parseIdentifier() : this.parseModuleExportName()), e[s] || (e[s] = this.cloneIdentifier(e[n])), t && this.checkIdentifier(e[s], a ? 4098 : 4096);
						}
						fillOptionalPropertiesForTSESLint(e) {
							switch (e.type) {
								case "ExpressionStatement":
									e.directive ?? (e.directive = void 0);
									return;
								case "RestElement": e.value = void 0;
								case "Identifier":
								case "ArrayPattern":
								case "AssignmentPattern":
								case "ObjectPattern":
									e.decorators ?? (e.decorators = []), e.optional ?? (e.optional = !1), e.typeAnnotation ?? (e.typeAnnotation = void 0);
									return;
								case "TSParameterProperty":
									e.accessibility ?? (e.accessibility = void 0), e.decorators ?? (e.decorators = []), e.override ?? (e.override = !1), e.readonly ?? (e.readonly = !1), e.static ?? (e.static = !1);
									return;
								case "TSEmptyBodyFunctionExpression": e.body = null;
								case "TSDeclareFunction":
								case "FunctionDeclaration":
								case "FunctionExpression":
								case "ClassMethod":
								case "ClassPrivateMethod":
									e.declare ?? (e.declare = !1), e.returnType ?? (e.returnType = void 0), e.typeParameters ?? (e.typeParameters = void 0);
									return;
								case "Property":
									e.optional ?? (e.optional = !1);
									return;
								case "TSMethodSignature":
								case "TSPropertySignature": e.optional ?? (e.optional = !1);
								case "TSIndexSignature":
									e.accessibility ?? (e.accessibility = void 0), e.readonly ?? (e.readonly = !1), e.static ?? (e.static = !1);
									return;
								case "TSAbstractPropertyDefinition":
								case "PropertyDefinition":
								case "TSAbstractAccessorProperty":
								case "AccessorProperty": e.declare ?? (e.declare = !1), e.definite ?? (e.definite = !1), e.readonly ?? (e.readonly = !1), e.typeAnnotation ?? (e.typeAnnotation = void 0);
								case "TSAbstractMethodDefinition":
								case "MethodDefinition":
									e.accessibility ?? (e.accessibility = void 0), e.decorators ?? (e.decorators = []), e.override ?? (e.override = !1), e.optional ?? (e.optional = !1);
									return;
								case "ClassExpression": e.id ?? (e.id = null);
								case "ClassDeclaration":
									e.abstract ?? (e.abstract = !1), e.declare ?? (e.declare = !1), e.decorators ?? (e.decorators = []), e.implements ?? (e.implements = []), e.superTypeArguments ?? (e.superTypeArguments = void 0), e.typeParameters ?? (e.typeParameters = void 0);
									return;
								case "TSTypeAliasDeclaration":
								case "VariableDeclaration":
									e.declare ?? (e.declare = !1);
									return;
								case "VariableDeclarator":
									e.definite ?? (e.definite = !1);
									return;
								case "TSEnumDeclaration":
									e.const ?? (e.const = !1), e.declare ?? (e.declare = !1);
									return;
								case "TSEnumMember":
									e.computed ?? (e.computed = !1);
									return;
								case "TSImportType":
									e.qualifier ?? (e.qualifier = null), e.options ?? (e.options = null);
									return;
								case "TSInterfaceDeclaration":
									e.declare ?? (e.declare = !1), e.extends ?? (e.extends = []);
									return;
								case "TSMappedType":
									e.optional ?? (e.optional = !1), e.readonly ?? (e.readonly = void 0);
									return;
								case "TSModuleDeclaration":
									e.declare ?? (e.declare = !1), e.global ?? (e.global = "global" === e.kind);
									return;
								case "TSTypeParameter":
									e.const ?? (e.const = !1), e.in ?? (e.in = !1), e.out ?? (e.out = !1);
									return;
							}
						}
					},
					v8intrinsic: (e) => class extends e {
						parseV8Intrinsic() {
							if (this.match(54)) {
								const e = this.state.startLoc, t = this.startNode();
								if (this.next(), tokenIsIdentifier(this.state.type)) {
									const e = this.parseIdentifierName(), r = this.createIdentifier(t, e);
									if (this.castNodeTo(r, "V8IntrinsicIdentifier"), this.match(10)) return r;
								}
								this.unexpected(e);
							}
						}
						parseExprAtom(e) {
							return this.parseV8Intrinsic() || super.parseExprAtom(e);
						}
					},
					placeholders: (e) => class extends e {
						parsePlaceholder(e) {
							if (this.match(133)) {
								const t = this.startNode();
								return this.next(), this.assertNoSpace(), t.name = super.parseIdentifier(!0), this.assertNoSpace(), this.expect(133), this.finishPlaceholder(t, e);
							}
						}
						finishPlaceholder(e, t) {
							let r = e;
							return r.expectedNode && r.type || (r = this.finishNode(r, "Placeholder")), r.expectedNode = t, r;
						}
						getTokenFromCode(e) {
							37 === e && 37 === this.input.charCodeAt(this.state.pos + 1) ? this.finishOp(133, 2) : super.getTokenFromCode(e);
						}
						parseExprAtom(e) {
							return this.parsePlaceholder("Expression") || super.parseExprAtom(e);
						}
						parseIdentifier(e) {
							return this.parsePlaceholder("Identifier") || super.parseIdentifier(e);
						}
						checkReservedWord(e, t, r, n) {
							void 0 !== e && super.checkReservedWord(e, t, r, n);
						}
						cloneIdentifier(e) {
							const t = super.cloneIdentifier(e);
							return "Placeholder" === t.type && (t.expectedNode = e.expectedNode), t;
						}
						cloneStringLiteral(e) {
							return "Placeholder" === e.type ? this.cloneIdentifier(e) : super.cloneStringLiteral(e);
						}
						parseBindingAtom() {
							return this.parsePlaceholder("Pattern") || super.parseBindingAtom();
						}
						isValidLVal(e, t, r) {
							return "Placeholder" === e || super.isValidLVal(e, t, r);
						}
						toAssignable(e, t) {
							e && "Placeholder" === e.type && "Expression" === e.expectedNode ? e.expectedNode = "Pattern" : super.toAssignable(e, t);
						}
						chStartsBindingIdentifier(e, t) {
							if (super.chStartsBindingIdentifier(e, t)) return !0;
							const r = this.nextTokenStart();
							return 37 === this.input.charCodeAt(r) && 37 === this.input.charCodeAt(r + 1);
						}
						verifyBreakContinue(e, t) {
							e.label && "Placeholder" === e.label.type || super.verifyBreakContinue(e, t);
						}
						parseExpressionStatement(e, t) {
							var r;
							if ("Placeholder" !== t.type || null != (r = t.extra) && r.parenthesized) return super.parseExpressionStatement(e, t);
							if (this.match(14)) {
								const r = e;
								return r.label = this.finishPlaceholder(t, "Identifier"), this.next(), r.body = super.parseStatementOrSloppyAnnexBFunctionDeclaration(), this.finishNode(r, "LabeledStatement");
							}
							this.semicolon();
							const n = e;
							return n.name = t.name, this.finishPlaceholder(n, "Statement");
						}
						parseBlock(e, t, r) {
							return this.parsePlaceholder("BlockStatement") || super.parseBlock(e, t, r);
						}
						parseFunctionId(e) {
							return this.parsePlaceholder("Identifier") || super.parseFunctionId(e);
						}
						parseClass(e, t, r) {
							const n = t ? "ClassDeclaration" : "ClassExpression";
							this.next();
							const s = this.state.strict, i = this.parsePlaceholder("Identifier");
							if (i) {
								if (!(this.match(81) || this.match(133) || this.match(5))) {
									if (r || !t) return e.id = null, e.body = this.finishPlaceholder(i, "ClassBody"), this.finishNode(e, n);
									throw this.raise(Z.ClassNameIsRequired, this.state.startLoc);
								}
								e.id = i;
							} else this.parseClassId(e, t, r);
							return super.parseClassSuper(e), e.body = this.parsePlaceholder("ClassBody") || super.parseClassBody(!!e.superClass, s), this.finishNode(e, n);
						}
						parseExport(e, t) {
							const r = this.parsePlaceholder("Identifier");
							if (!r) return super.parseExport(e, t);
							const n = e;
							if (!this.isContextual(98) && !this.match(12)) return n.specifiers = [], n.source = null, n.declaration = this.finishPlaceholder(r, "Declaration"), this.finishNode(n, "ExportNamedDeclaration");
							this.expectPlugin("exportDefaultFrom");
							const s = this.startNode();
							return s.exported = r, n.specifiers = [this.finishNode(s, "ExportDefaultSpecifier")], super.parseExport(n, t);
						}
						isExportDefaultSpecifier() {
							if (this.match(65)) {
								const e = this.nextTokenStart();
								if (this.isUnparsedContextual(e, "from") && this.input.startsWith(tokenLabelName(133), this.nextTokenStartSince(e + 4))) return !0;
							}
							return super.isExportDefaultSpecifier();
						}
						maybeParseExportDefaultSpecifier(e, t) {
							var r;
							return !(null == (r = e.specifiers) || !r.length) || super.maybeParseExportDefaultSpecifier(e, t);
						}
						checkExport(e) {
							const { specifiers: t } = e;
							null != t && t.length && (e.specifiers = t.filter((e) => "Placeholder" === e.exported.type)), super.checkExport(e), e.specifiers = t;
						}
						parseImport(e) {
							const t = this.parsePlaceholder("Identifier");
							if (!t) return super.parseImport(e);
							if (e.specifiers = [], !this.isContextual(98) && !this.match(12)) return e.source = this.finishPlaceholder(t, "StringLiteral"), this.semicolon(), this.finishNode(e, "ImportDeclaration");
							const r = this.startNodeAtNode(t);
							if (r.local = t, e.specifiers.push(this.finishNode(r, "ImportDefaultSpecifier")), this.eat(12)) this.maybeParseStarImportSpecifier(e) || this.parseNamedImportSpecifiers(e);
							return this.expectContextual(98), e.source = this.parseImportSource(), this.semicolon(), this.finishNode(e, "ImportDeclaration");
						}
						parseImportSource() {
							return this.parsePlaceholder("StringLiteral") || super.parseImportSource();
						}
						assertNoSpace() {
							this.state.start > this.offsetToSourcePos(this.state.lastTokEndLoc.index) && this.raise(Z.UnexpectedSpace, this.state.lastTokEndLoc);
						}
					}
				}, ne = Object.keys(re);
				class ExpressionParser extends LValParser {
					checkProto(e, t, r, n) {
						if ("SpreadElement" === e.type || this.isObjectMethod(e) || e.computed || e.shorthand) return r;
						const s = e.key;
						return "__proto__" === ("Identifier" === s.type ? s.name : s.value) ? t ? (this.raise(c.RecordNoProto, s), !0) : (r && (n ? null === n.doubleProtoLoc && (n.doubleProtoLoc = s.loc.start) : this.raise(c.DuplicateProto, s)), !0) : r;
					}
					shouldExitDescending(e, t) {
						return "ArrowFunctionExpression" === e.type && this.offsetToSourcePos(e.start) === t;
					}
					getExpression() {
						if (this.enterInitialScopes(), this.nextToken(), this.match(140)) throw this.raise(c.ParseExpressionEmptyInput, this.state.startLoc);
						const e = this.parseExpression();
						if (!this.match(140)) throw this.raise(c.ParseExpressionExpectsEOF, this.state.startLoc, { unexpected: this.input.codePointAt(this.state.start) });
						return this.finalizeRemainingComments(), e.comments = this.comments, e.errors = this.state.errors, 256 & this.optionFlags && (e.tokens = this.tokens), e;
					}
					parseExpression(e, t) {
						return e ? this.disallowInAnd(() => this.parseExpressionBase(t)) : this.allowInAnd(() => this.parseExpressionBase(t));
					}
					parseExpressionBase(e) {
						const t = this.state.startLoc, r = this.parseMaybeAssign(e);
						if (this.match(12)) {
							const n = this.startNodeAt(t);
							for (n.expressions = [r]; this.eat(12);) n.expressions.push(this.parseMaybeAssign(e));
							return this.toReferencedList(n.expressions), this.finishNode(n, "SequenceExpression");
						}
						return r;
					}
					parseMaybeAssignDisallowIn(e, t) {
						return this.disallowInAnd(() => this.parseMaybeAssign(e, t));
					}
					parseMaybeAssignAllowIn(e, t) {
						return this.allowInAnd(() => this.parseMaybeAssign(e, t));
					}
					setOptionalParametersError(e) {
						e.optionalParametersLoc = this.state.startLoc;
					}
					parseMaybeAssign(e, t) {
						const r = this.state.startLoc, n = this.isContextual(108);
						if (n && this.prodParam.hasYield) {
							this.next();
							let e = this.parseYield(r);
							return t && (e = t.call(this, e, r)), e;
						}
						let s;
						e ? s = !1 : (e = new ExpressionErrors(), s = !0);
						const { type: i } = this.state;
						(10 === i || tokenIsIdentifier(i)) && (this.state.potentialArrowAt = this.state.start);
						let o = this.parseMaybeConditional(e);
						if (t && (o = t.call(this, o, r)), (a = this.state.type) >= 29 && a <= 33) {
							const t = this.startNodeAt(r);
							if (t.operator = this.state.value, this.match(29)) {
								this.toAssignable(o, !0), t.left = o;
								const n = r.index;
								null != e.doubleProtoLoc && e.doubleProtoLoc.index >= n && (e.doubleProtoLoc = null), null != e.shorthandAssignLoc && e.shorthandAssignLoc.index >= n && (e.shorthandAssignLoc = null), null != e.privateKeyLoc && e.privateKeyLoc.index >= n && (this.checkDestructuringPrivate(e), e.privateKeyLoc = null), null != e.voidPatternLoc && e.voidPatternLoc.index >= n && (e.voidPatternLoc = null);
							} else t.left = o;
							return this.next(), t.right = this.parseMaybeAssign(), this.checkLVal(o, this.finishNode(t, "AssignmentExpression")), t;
						}
						var a;
						if (s && this.checkExpressionErrors(e, !0), n) {
							const { type: e } = this.state;
							if ((this.hasPlugin("v8intrinsic") ? tokenCanStartExpression(e) : tokenCanStartExpression(e) && !this.match(54)) && !this.isAmbiguousPrefixOrIdentifier()) return this.raiseOverwrite(c.YieldNotInGeneratorFunction, r), this.parseYield(r);
						}
						return o;
					}
					parseMaybeConditional(e) {
						const t = this.state.startLoc, r = this.state.potentialArrowAt, n = this.parseExprOps(e);
						return this.shouldExitDescending(n, r) ? n : this.parseConditional(n, t, e);
					}
					parseConditional(e, t, r) {
						if (this.eat(17)) {
							const r = this.startNodeAt(t);
							return r.test = e, r.consequent = this.parseMaybeAssignAllowIn(), this.expect(14), r.alternate = this.parseMaybeAssign(), this.finishNode(r, "ConditionalExpression");
						}
						return e;
					}
					parseMaybeUnaryOrPrivate(e) {
						return this.match(139) ? this.parsePrivateName() : this.parseMaybeUnary(e);
					}
					parseExprOps(e) {
						const t = this.state.startLoc, r = this.state.potentialArrowAt, n = this.parseMaybeUnaryOrPrivate(e);
						return this.shouldExitDescending(n, r) ? n : this.parseExprOp(n, t, -1);
					}
					parseExprOp(e, t, r) {
						if (this.isPrivateName(e)) {
							const t = this.getPrivateNameSV(e);
							(r >= tokenOperatorPrecedence(58) || !this.prodParam.hasIn || !this.match(58)) && this.raise(c.PrivateInExpectedIn, e, { identifierName: t }), this.classScope.usePrivateName(t, e.loc.start);
						}
						const n = this.state.type;
						if ((s = n) >= 39 && s <= 59 && (this.prodParam.hasIn || !this.match(58))) {
							let s = tokenOperatorPrecedence(n);
							if (s > r) {
								if (39 === n) {
									if (this.expectPlugin("pipelineOperator"), this.state.inFSharpPipelineDirectBody) return e;
									this.checkPipelineAtInfixOperator(e, t);
								}
								const i = this.startNodeAt(t);
								i.left = e, i.operator = this.state.value;
								const o = 41 === n || 42 === n, a = 40 === n;
								if (a && (s = tokenOperatorPrecedence(42)), this.next(), 39 === n && this.hasPlugin(["pipelineOperator", { proposal: "minimal" }]) && 96 === this.state.type && this.prodParam.hasAwait) throw this.raise(c.UnexpectedAwaitAfterPipelineBody, this.state.startLoc);
								i.right = this.parseExprOpRightExpr(n, s);
								const l = this.finishNode(i, o || a ? "LogicalExpression" : "BinaryExpression"), p = this.state.type;
								if (a && (41 === p || 42 === p) || o && 40 === p) throw this.raise(c.MixingCoalesceWithLogical, this.state.startLoc);
								return this.parseExprOp(l, t, r);
							}
						}
						var s;
						return e;
					}
					parseExprOpRightExpr(e, t) {
						const r = this.state.startLoc;
						if (39 === e) {
							switch (this.getPluginOption("pipelineOperator", "proposal")) {
								case "hack": return this.withTopicBindingContext(() => this.parseHackPipeBody());
								case "fsharp": return this.withSoloAwaitPermittingContext(() => this.parseFSharpPipelineBody(t));
							}
							if ("smart" === this.getPluginOption("pipelineOperator", "proposal")) return this.withTopicBindingContext(() => {
								if (this.prodParam.hasYield && this.isContextual(108)) throw this.raise(c.PipeBodyIsTighter, this.state.startLoc);
								return this.parseSmartPipelineBodyInStyle(this.parseExprOpBaseRightExpr(e, t), r);
							});
						}
						return this.parseExprOpBaseRightExpr(e, t);
					}
					parseExprOpBaseRightExpr(e, t) {
						const r = this.state.startLoc;
						return this.parseExprOp(this.parseMaybeUnaryOrPrivate(), r, 57 === e ? t - 1 : t);
					}
					parseHackPipeBody() {
						var e;
						const { startLoc: t } = this.state, r = this.parseMaybeAssign();
						return !a.has(r.type) || null != (e = r.extra) && e.parenthesized || this.raise(c.PipeUnparenthesizedBody, t, { type: r.type }), this.topicReferenceWasUsedInCurrentContext() || this.raise(c.PipeTopicUnused, t), r;
					}
					checkExponentialAfterUnary(e) {
						this.match(57) && this.raise(c.UnexpectedTokenUnaryExponentiation, e.argument);
					}
					parseMaybeUnary(e, t) {
						const r = this.state.startLoc, n = this.isContextual(96);
						if (n && this.recordAwaitIfAllowed()) {
							this.next();
							const e = this.parseAwait(r);
							return t || this.checkExponentialAfterUnary(e), e;
						}
						const s = this.match(34), i = this.startNode();
						if (o = this.state.type, _[o]) {
							i.operator = this.state.value, i.prefix = !0, this.match(72) && this.expectPlugin("throwExpressions");
							const r = this.match(89);
							if (this.next(), i.argument = this.parseMaybeUnary(null, !0), this.checkExpressionErrors(e, !0), this.state.strict && r) {
								const e = i.argument;
								"Identifier" === e.type ? this.raise(c.StrictDelete, i) : this.hasPropertyAsPrivateName(e) && this.raise(c.DeletePrivateField, i);
							}
							if (!s) return t || this.checkExponentialAfterUnary(i), this.finishNode(i, "UnaryExpression");
						}
						var o;
						const a = this.parseUpdate(i, s, e);
						if (n) {
							const { type: e } = this.state;
							if ((this.hasPlugin("v8intrinsic") ? tokenCanStartExpression(e) : tokenCanStartExpression(e) && !this.match(54)) && !this.isAmbiguousPrefixOrIdentifier()) return this.raiseOverwrite(c.AwaitNotInAsyncContext, r), this.parseAwait(r);
						}
						return a;
					}
					parseUpdate(e, t, r) {
						if (t) {
							const t = e;
							return this.checkLVal(t.argument, this.finishNode(t, "UpdateExpression")), e;
						}
						const n = this.state.startLoc;
						let s = this.parseExprSubscripts(r);
						if (this.checkExpressionErrors(r, !1)) return s;
						for (; tokenIsPostfix(this.state.type) && !this.canInsertSemicolon();) {
							const e = this.startNodeAt(n);
							e.operator = this.state.value, e.prefix = !1, e.argument = s, this.next(), this.checkLVal(s, s = this.finishNode(e, "UpdateExpression"));
						}
						return s;
					}
					parseExprSubscripts(e) {
						const t = this.state.startLoc, r = this.state.potentialArrowAt, n = this.parseExprAtom(e);
						return this.shouldExitDescending(n, r) ? n : this.parseSubscripts(n, t);
					}
					parseSubscripts(e, t, r) {
						const n = {
							optionalChainMember: !1,
							maybeAsyncArrow: this.atPossibleAsyncArrow(e),
							stop: !1
						};
						do
							e = this.parseSubscript(e, t, r, n), n.maybeAsyncArrow = !1;
						while (!n.stop);
						return e;
					}
					parseSubscript(e, t, r, n) {
						const { type: s } = this.state;
						if (!r && 15 === s) return this.parseBind(e, t, r, n);
						if (tokenIsTemplate(s)) return this.parseTaggedTemplateExpression(e, t, n);
						let i = !1;
						if (18 === s) {
							if (r && (this.raise(c.OptionalChainingNoNew, this.state.startLoc), 40 === this.lookaheadCharCode())) return this.stopParseSubscript(e, n);
							n.optionalChainMember = i = !0, this.next();
						}
						if (!r && this.match(10)) return this.parseCoverCallAndAsyncArrowHead(e, t, n, i);
						{
							const r = this.eat(0);
							return r || i || this.eat(16) ? this.parseMember(e, t, n, r, i) : this.stopParseSubscript(e, n);
						}
					}
					stopParseSubscript(e, t) {
						return t.stop = !0, e;
					}
					parseMember(e, t, r, n, s) {
						const i = this.startNodeAt(t);
						return i.object = e, i.computed = n, n ? (i.property = this.parseExpression(), this.expect(3)) : this.match(139) ? ("Super" === e.type && this.raise(c.SuperPrivateField, t), this.classScope.usePrivateName(this.state.value, this.state.startLoc), i.property = this.parsePrivateName()) : i.property = this.parseIdentifier(!0), r.optionalChainMember ? (i.optional = s, this.finishNode(i, "OptionalMemberExpression")) : this.finishNode(i, "MemberExpression");
					}
					parseBind(e, t, r, n) {
						const s = this.startNodeAt(t);
						return s.object = e, this.next(), s.callee = this.parseNoCallExpr(), n.stop = !0, this.parseSubscripts(this.finishNode(s, "BindExpression"), t, r);
					}
					parseCoverCallAndAsyncArrowHead(e, t, r, n) {
						const s = this.state.maybeInArrowParameters;
						let i = null;
						this.state.maybeInArrowParameters = !0, this.next();
						const o = this.startNodeAt(t);
						o.callee = e;
						const { maybeAsyncArrow: a, optionalChainMember: l } = r;
						a && (this.expressionScope.enter(new ArrowHeadParsingScope(2)), i = new ExpressionErrors()), l && (o.optional = n), o.arguments = n ? this.parseCallExpressionArguments() : this.parseCallExpressionArguments("Super" !== e.type, o, i);
						let p = this.finishCallExpression(o, l);
						return a && this.shouldParseAsyncArrow() && !n ? (r.stop = !0, this.checkDestructuringPrivate(i), this.expressionScope.validateAsPattern(), this.expressionScope.exit(), p = this.parseAsyncArrowFromCallExpression(this.startNodeAt(t), p)) : (a && (this.checkExpressionErrors(i, !0), this.expressionScope.exit()), this.toReferencedArguments(p)), this.state.maybeInArrowParameters = s, p;
					}
					toReferencedArguments(e, t) {
						this.toReferencedListDeep(e.arguments, t);
					}
					parseTaggedTemplateExpression(e, t, r) {
						const n = this.startNodeAt(t);
						return n.tag = e, n.quasi = this.parseTemplate(!0), r.optionalChainMember && this.raise(c.OptionalChainingNoTemplate, t), this.finishNode(n, "TaggedTemplateExpression");
					}
					atPossibleAsyncArrow(e) {
						return "Identifier" === e.type && "async" === e.name && this.state.lastTokEndLoc.index === e.end && !this.canInsertSemicolon() && e.end - e.start === 5 && this.offsetToSourcePos(e.start) === this.state.potentialArrowAt;
					}
					finishCallExpression(e, t) {
						if ("Import" === e.callee.type) if (0 === e.arguments.length || e.arguments.length > 2) this.raise(c.ImportCallArity, e);
						else for (const t of e.arguments) "SpreadElement" === t.type && this.raise(c.ImportCallSpreadArgument, t);
						return this.finishNode(e, t ? "OptionalCallExpression" : "CallExpression");
					}
					parseCallExpressionArguments(e, t, r) {
						const n = [];
						let s = !0;
						const i = this.state.inFSharpPipelineDirectBody;
						for (this.state.inFSharpPipelineDirectBody = !1; !this.eat(11);) {
							if (s) s = !1;
							else if (this.expect(12), this.match(11)) {
								t && this.addTrailingCommaExtraToNode(t), this.next();
								break;
							}
							n.push(this.parseExprListItem(11, !1, r, e));
						}
						return this.state.inFSharpPipelineDirectBody = i, n;
					}
					shouldParseAsyncArrow() {
						return this.match(19) && !this.canInsertSemicolon();
					}
					parseAsyncArrowFromCallExpression(e, t) {
						var r;
						return this.resetPreviousNodeTrailingComments(t), this.expect(19), this.parseArrowExpression(e, t.arguments, !0, null == (r = t.extra) ? void 0 : r.trailingCommaLoc), t.innerComments && setInnerComments(e, t.innerComments), t.callee.trailingComments && setInnerComments(e, t.callee.trailingComments), e;
					}
					parseNoCallExpr() {
						const e = this.state.startLoc;
						return this.parseSubscripts(this.parseExprAtom(), e, !0);
					}
					parseExprAtom(e) {
						let t, r = null;
						const { type: n } = this.state;
						switch (n) {
							case 79: return this.parseSuper();
							case 83: return t = this.startNode(), this.next(), this.match(16) ? this.parseImportMetaPropertyOrPhaseCall(t) : this.match(10) ? 512 & this.optionFlags ? this.parseImportCall(t) : this.finishNode(t, "Import") : (this.raise(c.UnsupportedImport, this.state.lastTokStartLoc), this.finishNode(t, "Import"));
							case 78: return t = this.startNode(), this.next(), this.finishNode(t, "ThisExpression");
							case 90: return this.parseDo(this.startNode(), !1);
							case 56:
							case 31: return this.readRegexp(), this.parseRegExpLiteral(this.state.value);
							case 135: return this.parseNumericLiteral(this.state.value);
							case 136: return this.parseBigIntLiteral(this.state.value);
							case 134: return this.parseStringLiteral(this.state.value);
							case 84: return this.parseNullLiteral();
							case 85: return this.parseBooleanLiteral(!0);
							case 86: return this.parseBooleanLiteral(!1);
							case 10: {
								const e = this.state.potentialArrowAt === this.state.start;
								return this.parseParenAndDistinguishExpression(e);
							}
							case 0: return this.parseArrayLike(3, !0, !1, e);
							case 5: return this.parseObjectLike(8, !1, !1, e);
							case 68: return this.parseFunctionOrFunctionSent();
							case 26: r = this.parseDecorators();
							case 80: return this.parseClass(this.maybeTakeDecorators(r, this.startNode()), !1);
							case 77: return this.parseNewOrNewTarget();
							case 25:
							case 24: return this.parseTemplate(!1);
							case 15: {
								t = this.startNode(), this.next(), t.object = null;
								const e = t.callee = this.parseNoCallExpr();
								if ("MemberExpression" === e.type) return this.finishNode(t, "BindExpression");
								throw this.raise(c.UnsupportedBind, e);
							}
							case 139: return this.raise(c.PrivateInExpectedIn, this.state.startLoc, { identifierName: this.state.value }), this.parsePrivateName();
							case 33: return this.parseTopicReferenceThenEqualsSign(54, "%");
							case 32: return this.parseTopicReferenceThenEqualsSign(44, "^");
							case 37:
							case 38: return this.parseTopicReference("hack");
							case 44:
							case 54:
							case 27: {
								const e = this.getPluginOption("pipelineOperator", "proposal");
								if (e) return this.parseTopicReference(e);
								this.unexpected();
								break;
							}
							case 47: {
								const e = this.input.codePointAt(this.nextTokenStart());
								isIdentifierStart(e) || 62 === e ? this.expectOnePlugin([
									"jsx",
									"flow",
									"typescript"
								]) : this.unexpected();
								break;
							}
							default:
								if (137 === n) return this.parseDecimalLiteral(this.state.value);
								if (2 === n || 1 === n) return this.parseArrayLike(2 === this.state.type ? 4 : 3, !1, !0);
								if (6 === n || 7 === n) return this.parseObjectLike(6 === this.state.type ? 9 : 8, !1, !0);
								if (tokenIsIdentifier(n)) {
									if (this.isContextual(127) && 123 === this.lookaheadInLineCharCode()) return this.parseModuleExpression();
									const e = this.state.potentialArrowAt === this.state.start, t = this.state.containsEsc, r = this.parseIdentifier();
									if (!t && "async" === r.name && !this.canInsertSemicolon()) {
										const { type: e } = this.state;
										if (68 === e) return this.resetPreviousNodeTrailingComments(r), this.next(), this.parseAsyncFunctionExpression(this.startNodeAtNode(r));
										if (tokenIsIdentifier(e)) return 61 === this.lookaheadCharCode() ? this.parseAsyncArrowUnaryFunction(this.startNodeAtNode(r)) : r;
										if (90 === e) return this.resetPreviousNodeTrailingComments(r), this.parseDo(this.startNodeAtNode(r), !0);
									}
									return e && this.match(19) && !this.canInsertSemicolon() ? (this.next(), this.parseArrowExpression(this.startNodeAtNode(r), [r], !1)) : r;
								}
								this.unexpected();
						}
					}
					parseTopicReferenceThenEqualsSign(e, t) {
						const r = this.getPluginOption("pipelineOperator", "proposal");
						if (r) return this.state.type = e, this.state.value = t, this.state.pos--, this.state.end--, this.state.endLoc = createPositionWithColumnOffset(this.state.endLoc, -1), this.parseTopicReference(r);
						this.unexpected();
					}
					parseTopicReference(e) {
						const t = this.startNode(), r = this.state.startLoc, n = this.state.type;
						return this.next(), this.finishTopicReference(t, r, e, n);
					}
					finishTopicReference(e, t, r, n) {
						if (this.testTopicReferenceConfiguration(r, t, n)) return "hack" === r ? (this.topicReferenceIsAllowedInCurrentContext() || this.raise(c.PipeTopicUnbound, t), this.registerTopicReference(), this.finishNode(e, "TopicReference")) : (this.topicReferenceIsAllowedInCurrentContext() || this.raise(c.PrimaryTopicNotAllowed, t), this.registerTopicReference(), this.finishNode(e, "PipelinePrimaryTopicReference"));
						throw this.raise(c.PipeTopicUnconfiguredToken, t, { token: tokenLabelName(n) });
					}
					testTopicReferenceConfiguration(e, t, r) {
						switch (e) {
							case "hack": return this.hasPlugin(["pipelineOperator", { topicToken: tokenLabelName(r) }]);
							case "smart": return 27 === r;
							default: throw this.raise(c.PipeTopicRequiresHackPipes, t);
						}
					}
					parseAsyncArrowUnaryFunction(e) {
						this.prodParam.enter(functionFlags(!0, this.prodParam.hasYield));
						const t = [this.parseIdentifier()];
						return this.prodParam.exit(), this.hasPrecedingLineBreak() && this.raise(c.LineTerminatorBeforeArrow, this.state.curPosition()), this.expect(19), this.parseArrowExpression(e, t, !0);
					}
					parseDo(e, t) {
						this.expectPlugin("doExpressions"), t && this.expectPlugin("asyncDoExpressions"), e.async = t, this.next();
						const r = this.state.labels;
						return this.state.labels = [], t ? (this.prodParam.enter(2), e.body = this.parseBlock(), this.prodParam.exit()) : e.body = this.parseBlock(), this.state.labels = r, this.finishNode(e, "DoExpression");
					}
					parseSuper() {
						const e = this.startNode();
						return this.next(), !this.match(10) || this.scope.allowDirectSuper || 16 & this.optionFlags ? this.scope.allowSuper || 16 & this.optionFlags || this.raise(c.UnexpectedSuper, e) : this.raise(c.SuperNotAllowed, e), this.match(10) || this.match(0) || this.match(16) || this.raise(c.UnsupportedSuper, e), this.finishNode(e, "Super");
					}
					parsePrivateName() {
						const e = this.startNode(), t = this.startNodeAt(createPositionWithColumnOffset(this.state.startLoc, 1)), r = this.state.value;
						return this.next(), e.id = this.createIdentifier(t, r), this.finishNode(e, "PrivateName");
					}
					parseFunctionOrFunctionSent() {
						const e = this.startNode();
						if (this.next(), this.prodParam.hasYield && this.match(16)) {
							const t = this.createIdentifier(this.startNodeAtNode(e), "function");
							return this.next(), this.match(103) ? this.expectPlugin("functionSent") : this.hasPlugin("functionSent") || this.unexpected(), this.parseMetaProperty(e, t, "sent");
						}
						return this.parseFunction(e);
					}
					parseMetaProperty(e, t, r) {
						e.meta = t;
						const n = this.state.containsEsc;
						return e.property = this.parseIdentifier(!0), (e.property.name !== r || n) && this.raise(c.UnsupportedMetaProperty, e.property, {
							target: t.name,
							onlyValidPropertyName: r
						}), this.finishNode(e, "MetaProperty");
					}
					parseImportMetaPropertyOrPhaseCall(e) {
						if (this.next(), this.isContextual(105) || this.isContextual(97)) {
							const t = this.isContextual(105);
							return this.expectPlugin(t ? "sourcePhaseImports" : "deferredImportEvaluation"), this.next(), e.phase = t ? "source" : "defer", this.parseImportCall(e);
						}
						{
							const t = this.createIdentifierAt(this.startNodeAtNode(e), "import", this.state.lastTokStartLoc);
							return this.isContextual(101) && (this.inModule || this.raise(c.ImportMetaOutsideModule, t), this.sawUnambiguousESM = !0), this.parseMetaProperty(e, t, "meta");
						}
					}
					parseLiteralAtNode(e, t, r) {
						return this.addExtra(r, "rawValue", e), this.addExtra(r, "raw", this.input.slice(this.offsetToSourcePos(r.start), this.state.end)), r.value = e, this.next(), this.finishNode(r, t);
					}
					parseLiteral(e, t) {
						const r = this.startNode();
						return this.parseLiteralAtNode(e, t, r);
					}
					parseStringLiteral(e) {
						return this.parseLiteral(e, "StringLiteral");
					}
					parseNumericLiteral(e) {
						return this.parseLiteral(e, "NumericLiteral");
					}
					parseBigIntLiteral(e) {
						return this.parseLiteral(e, "BigIntLiteral");
					}
					parseDecimalLiteral(e) {
						return this.parseLiteral(e, "DecimalLiteral");
					}
					parseRegExpLiteral(e) {
						const t = this.startNode();
						return this.addExtra(t, "raw", this.input.slice(this.offsetToSourcePos(t.start), this.state.end)), t.pattern = e.pattern, t.flags = e.flags, this.next(), this.finishNode(t, "RegExpLiteral");
					}
					parseBooleanLiteral(e) {
						const t = this.startNode();
						return t.value = e, this.next(), this.finishNode(t, "BooleanLiteral");
					}
					parseNullLiteral() {
						const e = this.startNode();
						return this.next(), this.finishNode(e, "NullLiteral");
					}
					parseParenAndDistinguishExpression(e) {
						const t = this.state.startLoc;
						let r;
						this.next(), this.expressionScope.enter(new ArrowHeadParsingScope(1));
						const n = this.state.maybeInArrowParameters, s = this.state.inFSharpPipelineDirectBody;
						this.state.maybeInArrowParameters = !0, this.state.inFSharpPipelineDirectBody = !1;
						const i = this.state.startLoc, o = [], a = new ExpressionErrors();
						let l, p, c = !0;
						for (; !this.match(11);) {
							if (c) c = !1;
							else if (this.expect(12, null === a.optionalParametersLoc ? null : a.optionalParametersLoc), this.match(11)) {
								p = this.state.startLoc;
								break;
							}
							if (this.match(21)) {
								const e = this.state.startLoc;
								if (l = this.state.startLoc, o.push(this.parseParenItem(this.parseRestBinding(), e)), !this.checkCommaAfterRest(41)) break;
							} else o.push(this.parseMaybeAssignAllowInOrVoidPattern(11, a, this.parseParenItem));
						}
						const u = this.state.lastTokEndLoc;
						this.expect(11), this.state.maybeInArrowParameters = n, this.state.inFSharpPipelineDirectBody = s;
						let d = this.startNodeAt(t);
						return e && this.shouldParseArrow(o) && (d = this.parseArrow(d)) ? (this.checkDestructuringPrivate(a), this.expressionScope.validateAsPattern(), this.expressionScope.exit(), this.parseArrowExpression(d, o, !1), d) : (this.expressionScope.exit(), o.length || this.unexpected(this.state.lastTokStartLoc), p && this.unexpected(p), l && this.unexpected(l), this.checkExpressionErrors(a, !0), this.toReferencedListDeep(o, !0), o.length > 1 ? (r = this.startNodeAt(i), r.expressions = o, this.finishNode(r, "SequenceExpression"), this.resetEndLocation(r, u)) : r = o[0], this.wrapParenthesis(t, r));
					}
					wrapParenthesis(e, t) {
						if (!(1024 & this.optionFlags)) return this.addExtra(t, "parenthesized", !0), this.addExtra(t, "parenStart", e.index), this.takeSurroundingComments(t, e.index, this.state.lastTokEndLoc.index), t;
						const r = this.startNodeAt(e);
						return r.expression = t, this.finishNode(r, "ParenthesizedExpression");
					}
					shouldParseArrow(e) {
						return !this.canInsertSemicolon();
					}
					parseArrow(e) {
						if (this.eat(19)) return e;
					}
					parseParenItem(e, t) {
						return e;
					}
					parseNewOrNewTarget() {
						const e = this.startNode();
						if (this.next(), this.match(16)) {
							const t = this.createIdentifier(this.startNodeAtNode(e), "new");
							this.next();
							const r = this.parseMetaProperty(e, t, "target");
							return this.scope.allowNewTarget || this.raise(c.UnexpectedNewTarget, r), r;
						}
						return this.parseNew(e);
					}
					parseNew(e) {
						if (this.parseNewCallee(e), this.eat(10)) {
							const t = this.parseExprList(11);
							this.toReferencedList(t), e.arguments = t;
						} else e.arguments = [];
						return this.finishNode(e, "NewExpression");
					}
					parseNewCallee(e) {
						const t = this.match(83), r = this.parseNoCallExpr();
						e.callee = r, !t || "Import" !== r.type && "ImportExpression" !== r.type || this.raise(c.ImportCallNotNewExpression, r);
					}
					parseTemplateElement(e) {
						const { start: t, startLoc: r, end: n, value: s } = this.state, i = t + 1, o = this.startNodeAt(createPositionWithColumnOffset(r, 1));
						null === s && (e || this.raise(c.InvalidEscapeSequenceTemplate, createPositionWithColumnOffset(this.state.firstInvalidTemplateEscapePos, 1)));
						const a = this.match(24), l = a ? -1 : -2, p = n + l;
						o.value = {
							raw: this.input.slice(i, p).replace(/\r\n?/g, "\n"),
							cooked: null === s ? null : s.slice(1, l)
						}, o.tail = a, this.next();
						const u = this.finishNode(o, "TemplateElement");
						return this.resetEndLocation(u, createPositionWithColumnOffset(this.state.lastTokEndLoc, l)), u;
					}
					parseTemplate(e) {
						const t = this.startNode();
						let r = this.parseTemplateElement(e);
						const n = [r], s = [];
						for (; !r.tail;) s.push(this.parseTemplateSubstitution()), this.readTemplateContinuation(), n.push(r = this.parseTemplateElement(e));
						return t.expressions = s, t.quasis = n, this.finishNode(t, "TemplateLiteral");
					}
					parseTemplateSubstitution() {
						return this.parseExpression();
					}
					parseObjectLike(e, t, r, n) {
						r && this.expectPlugin("recordAndTuple");
						const s = this.state.inFSharpPipelineDirectBody;
						this.state.inFSharpPipelineDirectBody = !1;
						let i = !1, o = !0;
						const a = this.startNode();
						for (a.properties = [], this.next(); !this.match(e);) {
							if (o) o = !1;
							else if (this.expect(12), this.match(e)) {
								this.addTrailingCommaExtraToNode(a);
								break;
							}
							let s;
							t ? s = this.parseBindingProperty() : (s = this.parsePropertyDefinition(n), i = this.checkProto(s, r, i, n)), r && !this.isObjectProperty(s) && "SpreadElement" !== s.type && this.raise(c.InvalidRecordProperty, s), s.shorthand && this.addExtra(s, "shorthand", !0), a.properties.push(s);
						}
						this.next(), this.state.inFSharpPipelineDirectBody = s;
						let l = "ObjectExpression";
						return t ? l = "ObjectPattern" : r && (l = "RecordExpression"), this.finishNode(a, l);
					}
					addTrailingCommaExtraToNode(e) {
						this.addExtra(e, "trailingComma", this.state.lastTokStartLoc.index), this.addExtra(e, "trailingCommaLoc", this.state.lastTokStartLoc, !1);
					}
					maybeAsyncOrAccessorProp(e) {
						return !e.computed && "Identifier" === e.key.type && (this.isLiteralPropertyName() || this.match(0) || this.match(55));
					}
					parsePropertyDefinition(e) {
						let t = [];
						if (this.match(26)) for (this.hasPlugin("decorators") && this.raise(c.UnsupportedPropertyDecorator, this.state.startLoc); this.match(26);) t.push(this.parseDecorator());
						const r = this.startNode();
						let n, s = !1, i = !1;
						if (this.match(21)) return t.length && this.unexpected(), this.parseSpread();
						t.length && (r.decorators = t, t = []), r.method = !1, e && (n = this.state.startLoc);
						let o = this.eat(55);
						this.parsePropertyNamePrefixOperator(r);
						const a = this.state.containsEsc;
						if (this.parsePropertyName(r, e), !o && !a && this.maybeAsyncOrAccessorProp(r)) {
							const { key: e } = r, t = e.name;
							"async" !== t || this.hasPrecedingLineBreak() || (s = !0, this.resetPreviousNodeTrailingComments(e), o = this.eat(55), this.parsePropertyName(r)), "get" !== t && "set" !== t || (i = !0, this.resetPreviousNodeTrailingComments(e), r.kind = t, this.match(55) && (o = !0, this.raise(c.AccessorIsGenerator, this.state.curPosition(), { kind: t }), this.next()), this.parsePropertyName(r));
						}
						return this.parseObjPropValue(r, n, o, s, !1, i, e);
					}
					getGetterSetterExpectedParamCount(e) {
						return "get" === e.kind ? 0 : 1;
					}
					getObjectOrClassMethodParams(e) {
						return e.params;
					}
					checkGetterSetterParams(e) {
						var t;
						const r = this.getGetterSetterExpectedParamCount(e), n = this.getObjectOrClassMethodParams(e);
						n.length !== r && this.raise("get" === e.kind ? c.BadGetterArity : c.BadSetterArity, e), "set" === e.kind && "RestElement" === (null == (t = n[n.length - 1]) ? void 0 : t.type) && this.raise(c.BadSetterRestParameter, e);
					}
					parseObjectMethod(e, t, r, n, s) {
						if (s) {
							const r = this.parseMethod(e, t, !1, !1, !1, "ObjectMethod");
							return this.checkGetterSetterParams(r), r;
						}
						if (r || t || this.match(10)) return n && this.unexpected(), e.kind = "method", e.method = !0, this.parseMethod(e, t, r, !1, !1, "ObjectMethod");
					}
					parseObjectProperty(e, t, r, n) {
						if (e.shorthand = !1, this.eat(14)) return e.value = r ? this.parseMaybeDefault(this.state.startLoc) : this.parseMaybeAssignAllowInOrVoidPattern(8, n), this.finishObjectProperty(e);
						if (!e.computed && "Identifier" === e.key.type) {
							if (this.checkReservedWord(e.key.name, e.key.loc.start, !0, !1), r) e.value = this.parseMaybeDefault(t, this.cloneIdentifier(e.key));
							else if (this.match(29)) {
								const r = this.state.startLoc;
								null != n ? null === n.shorthandAssignLoc && (n.shorthandAssignLoc = r) : this.raise(c.InvalidCoverInitializedName, r), e.value = this.parseMaybeDefault(t, this.cloneIdentifier(e.key));
							} else e.value = this.cloneIdentifier(e.key);
							return e.shorthand = !0, this.finishObjectProperty(e);
						}
					}
					finishObjectProperty(e) {
						return this.finishNode(e, "ObjectProperty");
					}
					parseObjPropValue(e, t, r, n, s, i, o) {
						const a = this.parseObjectMethod(e, r, n, s, i) || this.parseObjectProperty(e, t, s, o);
						return a || this.unexpected(), a;
					}
					parsePropertyName(e, t) {
						if (this.eat(0)) e.computed = !0, e.key = this.parseMaybeAssignAllowIn(), this.expect(3);
						else {
							const { type: r, value: n } = this.state;
							let s;
							if (tokenIsKeywordOrIdentifier(r)) s = this.parseIdentifier(!0);
							else switch (r) {
								case 135:
									s = this.parseNumericLiteral(n);
									break;
								case 134:
									s = this.parseStringLiteral(n);
									break;
								case 136:
									s = this.parseBigIntLiteral(n);
									break;
								case 139: {
									const e = this.state.startLoc;
									null != t ? null === t.privateKeyLoc && (t.privateKeyLoc = e) : this.raise(c.UnexpectedPrivateField, e), s = this.parsePrivateName();
									break;
								}
								default:
									if (137 === r) {
										s = this.parseDecimalLiteral(n);
										break;
									}
									this.unexpected();
							}
							e.key = s, 139 !== r && (e.computed = !1);
						}
					}
					initFunction(e, t) {
						e.id = null, e.generator = !1, e.async = t;
					}
					parseMethod(e, t, r, n, s, i, o = !1) {
						this.initFunction(e, r), e.generator = t, this.scope.enter(530 | (o ? 576 : 0) | (s ? 32 : 0)), this.prodParam.enter(functionFlags(r, e.generator)), this.parseFunctionParams(e, n);
						const a = this.parseFunctionBodyAndFinish(e, i, !0);
						return this.prodParam.exit(), this.scope.exit(), a;
					}
					parseArrayLike(e, t, r, n) {
						r && this.expectPlugin("recordAndTuple");
						const s = this.state.inFSharpPipelineDirectBody;
						this.state.inFSharpPipelineDirectBody = !1;
						const i = this.startNode();
						return this.next(), i.elements = this.parseExprList(e, !r, n, i), this.state.inFSharpPipelineDirectBody = s, this.finishNode(i, r ? "TupleExpression" : "ArrayExpression");
					}
					parseArrowExpression(e, t, r, n) {
						this.scope.enter(518);
						let s = functionFlags(r, !1);
						!this.match(5) && this.prodParam.hasIn && (s |= 8), this.prodParam.enter(s), this.initFunction(e, r);
						const i = this.state.maybeInArrowParameters;
						return t && (this.state.maybeInArrowParameters = !0, this.setArrowFunctionParameters(e, t, n)), this.state.maybeInArrowParameters = !1, this.parseFunctionBody(e, !0), this.prodParam.exit(), this.scope.exit(), this.state.maybeInArrowParameters = i, this.finishNode(e, "ArrowFunctionExpression");
					}
					setArrowFunctionParameters(e, t, r) {
						this.toAssignableList(t, r, !1), e.params = t;
					}
					parseFunctionBodyAndFinish(e, t, r = !1) {
						return this.parseFunctionBody(e, !1, r), this.finishNode(e, t);
					}
					parseFunctionBody(e, t, r = !1) {
						const n = t && !this.match(5);
						if (this.expressionScope.enter(newExpressionScope()), n) e.body = this.parseMaybeAssign(), this.checkParams(e, !1, t, !1);
						else {
							const n = this.state.strict, s = this.state.labels;
							this.state.labels = [], this.prodParam.enter(4 | this.prodParam.currentFlags()), e.body = this.parseBlock(!0, !1, (s) => {
								const i = !this.isSimpleParamList(e.params);
								s && i && this.raise(c.IllegalLanguageModeDirective, "method" !== e.kind && "constructor" !== e.kind || !e.key ? e : e.key.loc.end);
								const o = !n && this.state.strict;
								this.checkParams(e, !(this.state.strict || t || r || i), t, o), this.state.strict && e.id && this.checkIdentifier(e.id, 65, o);
							}), this.prodParam.exit(), this.state.labels = s;
						}
						this.expressionScope.exit();
					}
					isSimpleParameter(e) {
						return "Identifier" === e.type;
					}
					isSimpleParamList(e) {
						for (let t = 0, r = e.length; t < r; t++) if (!this.isSimpleParameter(e[t])) return !1;
						return !0;
					}
					checkParams(e, t, r, n = !0) {
						const s = !t && /* @__PURE__ */ new Set(), i = { type: "FormalParameters" };
						for (const t of e.params) this.checkLVal(t, i, 5, s, n);
					}
					parseExprList(e, t, r, n) {
						const s = [];
						let i = !0;
						for (; !this.eat(e);) {
							if (i) i = !1;
							else if (this.expect(12), this.match(e)) {
								n && this.addTrailingCommaExtraToNode(n), this.next();
								break;
							}
							s.push(this.parseExprListItem(e, t, r));
						}
						return s;
					}
					parseExprListItem(e, t, r, n) {
						let s;
						if (this.match(12)) t || this.raise(c.UnexpectedToken, this.state.curPosition(), { unexpected: "," }), s = null;
						else if (this.match(21)) {
							const e = this.state.startLoc;
							s = this.parseParenItem(this.parseSpread(r), e);
						} else if (this.match(17)) {
							this.expectPlugin("partialApplication"), n || this.raise(c.UnexpectedArgumentPlaceholder, this.state.startLoc);
							const e = this.startNode();
							this.next(), s = this.finishNode(e, "ArgumentPlaceholder");
						} else s = this.parseMaybeAssignAllowInOrVoidPattern(e, r, this.parseParenItem);
						return s;
					}
					parseIdentifier(e) {
						const t = this.startNode(), r = this.parseIdentifierName(e);
						return this.createIdentifier(t, r);
					}
					createIdentifier(e, t) {
						return e.name = t, e.loc.identifierName = t, this.finishNode(e, "Identifier");
					}
					createIdentifierAt(e, t, r) {
						return e.name = t, e.loc.identifierName = t, this.finishNodeAt(e, "Identifier", r);
					}
					parseIdentifierName(e) {
						let t;
						const { startLoc: r, type: n } = this.state;
						tokenIsKeywordOrIdentifier(n) ? t = this.state.value : this.unexpected();
						const s = n <= 92;
						return e ? s && this.replaceToken(132) : this.checkReservedWord(t, r, s, !1), this.next(), t;
					}
					checkReservedWord(e, t, r, n) {
						if (e.length > 10) return;
						if (!function(e) {
							return B.has(e);
						}(e)) return;
						if (r && function(e) {
							return F.has(e);
						}(e)) return void this.raise(c.UnexpectedKeyword, t, { keyword: e });
						if ((this.state.strict ? n ? isStrictBindReservedWord : isStrictReservedWord : isReservedWord)(e, this.inModule)) this.raise(c.UnexpectedReservedWord, t, { reservedWord: e });
						else if ("yield" === e) {
							if (this.prodParam.hasYield) return void this.raise(c.YieldBindingIdentifier, t);
						} else if ("await" === e) {
							if (this.prodParam.hasAwait) return void this.raise(c.AwaitBindingIdentifier, t);
							if (this.scope.inStaticBlock) return void this.raise(c.AwaitBindingIdentifierInStaticBlock, t);
							this.expressionScope.recordAsyncArrowParametersError(t);
						} else if ("arguments" === e && this.scope.inClassAndNotInNonArrowFunction) return void this.raise(c.ArgumentsInClass, t);
					}
					recordAwaitIfAllowed() {
						const e = this.prodParam.hasAwait;
						return e && !this.scope.inFunction && (this.state.hasTopLevelAwait = !0), e;
					}
					parseAwait(e) {
						const t = this.startNodeAt(e);
						return this.expressionScope.recordParameterInitializerError(c.AwaitExpressionFormalParameter, t), this.eat(55) && this.raise(c.ObsoleteAwaitStar, t), this.scope.inFunction || 1 & this.optionFlags || (this.isAmbiguousPrefixOrIdentifier() ? this.ambiguousScriptDifferentAst = !0 : this.sawUnambiguousESM = !0), this.state.soloAwait || (t.argument = this.parseMaybeUnary(null, !0)), this.finishNode(t, "AwaitExpression");
					}
					isAmbiguousPrefixOrIdentifier() {
						if (this.hasPrecedingLineBreak()) return !0;
						const { type: e } = this.state;
						return 53 === e || 10 === e || 0 === e || tokenIsTemplate(e) || 102 === e && !this.state.containsEsc || 138 === e || 56 === e || this.hasPlugin("v8intrinsic") && 54 === e;
					}
					parseYield(e) {
						const t = this.startNodeAt(e);
						this.expressionScope.recordParameterInitializerError(c.YieldInParameter, t);
						let r = !1, n = null;
						if (!this.hasPrecedingLineBreak()) switch (r = this.eat(55), this.state.type) {
							case 13:
							case 140:
							case 8:
							case 11:
							case 3:
							case 9:
							case 14:
							case 12: if (!r) break;
							default: n = this.parseMaybeAssign();
						}
						return t.delegate = r, t.argument = n, this.finishNode(t, "YieldExpression");
					}
					parseImportCall(e) {
						if (this.next(), e.source = this.parseMaybeAssignAllowIn(), e.options = null, this.eat(12)) {
							if (this.match(11)) this.addTrailingCommaExtraToNode(e.source);
							else if (e.options = this.parseMaybeAssignAllowIn(), this.eat(12) && (this.addTrailingCommaExtraToNode(e.options), !this.match(11))) {
								do
									this.parseMaybeAssignAllowIn();
								while (this.eat(12) && !this.match(11));
								this.raise(c.ImportCallArity, e);
							}
						}
						return this.expect(11), this.finishNode(e, "ImportExpression");
					}
					checkPipelineAtInfixOperator(e, t) {
						this.hasPlugin(["pipelineOperator", { proposal: "smart" }]) && "SequenceExpression" === e.type && this.raise(c.PipelineHeadSequenceExpression, t);
					}
					parseSmartPipelineBodyInStyle(e, t) {
						if (this.isSimpleReference(e)) {
							const r = this.startNodeAt(t);
							return r.callee = e, this.finishNode(r, "PipelineBareFunction");
						}
						{
							const r = this.startNodeAt(t);
							return this.checkSmartPipeTopicBodyEarlyErrors(t), r.expression = e, this.finishNode(r, "PipelineTopicExpression");
						}
					}
					isSimpleReference(e) {
						switch (e.type) {
							case "MemberExpression": return !e.computed && this.isSimpleReference(e.object);
							case "Identifier": return !0;
							default: return !1;
						}
					}
					checkSmartPipeTopicBodyEarlyErrors(e) {
						if (this.match(19)) throw this.raise(c.PipelineBodyNoArrow, this.state.startLoc);
						this.topicReferenceWasUsedInCurrentContext() || this.raise(c.PipelineTopicUnused, e);
					}
					withTopicBindingContext(e) {
						const t = this.state.topicContext;
						this.state.topicContext = {
							maxNumOfResolvableTopics: 1,
							maxTopicIndex: null
						};
						try {
							return e();
						} finally {
							this.state.topicContext = t;
						}
					}
					withSmartMixTopicForbiddingContext(e) {
						if (!this.hasPlugin(["pipelineOperator", { proposal: "smart" }])) return e();
						{
							const t = this.state.topicContext;
							this.state.topicContext = {
								maxNumOfResolvableTopics: 0,
								maxTopicIndex: null
							};
							try {
								return e();
							} finally {
								this.state.topicContext = t;
							}
						}
					}
					withSoloAwaitPermittingContext(e) {
						const t = this.state.soloAwait;
						this.state.soloAwait = !0;
						try {
							return e();
						} finally {
							this.state.soloAwait = t;
						}
					}
					allowInAnd(e) {
						const t = this.prodParam.currentFlags();
						if (8 & ~t) {
							this.prodParam.enter(8 | t);
							try {
								return e();
							} finally {
								this.prodParam.exit();
							}
						}
						return e();
					}
					disallowInAnd(e) {
						const t = this.prodParam.currentFlags();
						if (8 & t) {
							this.prodParam.enter(-9 & t);
							try {
								return e();
							} finally {
								this.prodParam.exit();
							}
						}
						return e();
					}
					registerTopicReference() {
						this.state.topicContext.maxTopicIndex = 0;
					}
					topicReferenceIsAllowedInCurrentContext() {
						return this.state.topicContext.maxNumOfResolvableTopics >= 1;
					}
					topicReferenceWasUsedInCurrentContext() {
						return null != this.state.topicContext.maxTopicIndex && this.state.topicContext.maxTopicIndex >= 0;
					}
					parseFSharpPipelineBody(e) {
						const t = this.state.startLoc;
						this.state.potentialArrowAt = this.state.start;
						const r = this.state.inFSharpPipelineDirectBody;
						this.state.inFSharpPipelineDirectBody = !0;
						const n = this.parseExprOp(this.parseMaybeUnaryOrPrivate(), t, e);
						return this.state.inFSharpPipelineDirectBody = r, n;
					}
					parseModuleExpression() {
						this.expectPlugin("moduleBlocks");
						const e = this.startNode();
						this.next(), this.match(5) || this.unexpected(null, 5);
						const t = this.startNodeAt(this.state.endLoc);
						this.next();
						const r = this.initializeScopes(!0);
						this.enterInitialScopes();
						try {
							e.body = this.parseProgram(t, 8, "module");
						} finally {
							r();
						}
						return this.finishNode(e, "ModuleExpression");
					}
					parseVoidPattern(e) {
						this.expectPlugin("discardBinding");
						const t = this.startNode();
						return null != e && (e.voidPatternLoc = this.state.startLoc), this.next(), this.finishNode(t, "VoidPattern");
					}
					parseMaybeAssignAllowInOrVoidPattern(e, t, r) {
						if (null != t && this.match(88)) {
							const r = this.lookaheadCharCode();
							if (44 === r || r === (3 === e ? 93 : 8 === e ? 125 : 41) || 61 === r) return this.parseMaybeDefault(this.state.startLoc, this.parseVoidPattern(t));
						}
						return this.parseMaybeAssignAllowIn(t, r);
					}
					parsePropertyNamePrefixOperator(e) {}
				}
				const se = { kind: 1 }, ie = { kind: 2 }, oe = /[\uD800-\uDFFF]/u, ae = /in(?:stanceof)?/y;
				class StatementParser extends ExpressionParser {
					parseTopLevel(e, t) {
						return e.program = this.parseProgram(t, 140, "module" === this.options.sourceType ? "module" : "script"), e.comments = this.comments, 256 & this.optionFlags && (e.tokens = function(e, t, r) {
							for (let n = 0; n < e.length; n++) {
								const s = e[n], { type: i } = s;
								if ("number" == typeof i) {
									if (139 === i) {
										const { loc: t, start: r, value: i, end: o } = s, a = r + 1, l = createPositionWithColumnOffset(t.start, 1);
										e.splice(n, 1, new Token({
											type: getExportedToken(27),
											value: "#",
											start: r,
											end: a,
											startLoc: t.start,
											endLoc: l
										}), new Token({
											type: getExportedToken(132),
											value: i,
											start: a,
											end: o,
											startLoc: l,
											endLoc: t.end
										})), n++;
										continue;
									}
									if (tokenIsTemplate(i)) {
										const { loc: o, start: a, value: l, end: p } = s, c = a + 1, u = createPositionWithColumnOffset(o.start, 1);
										let d, h, m, f, y;
										d = 96 === t.charCodeAt(a - r) ? new Token({
											type: getExportedToken(22),
											value: "`",
											start: a,
											end: c,
											startLoc: o.start,
											endLoc: u
										}) : new Token({
											type: getExportedToken(8),
											value: "}",
											start: a,
											end: c,
											startLoc: o.start,
											endLoc: u
										}), 24 === i ? (m = p - 1, f = createPositionWithColumnOffset(o.end, -1), h = null === l ? null : l.slice(1, -1), y = new Token({
											type: getExportedToken(22),
											value: "`",
											start: m,
											end: p,
											startLoc: f,
											endLoc: o.end
										})) : (m = p - 2, f = createPositionWithColumnOffset(o.end, -2), h = null === l ? null : l.slice(1, -2), y = new Token({
											type: getExportedToken(23),
											value: "${",
											start: m,
											end: p,
											startLoc: f,
											endLoc: o.end
										})), e.splice(n, 1, d, new Token({
											type: getExportedToken(20),
											value: h,
											start: c,
											end: m,
											startLoc: u,
											endLoc: f
										}), y), n += 2;
										continue;
									}
									s.type = getExportedToken(i);
								}
							}
							return e;
						}(this.tokens, this.input, this.startIndex)), this.finishNode(e, "File");
					}
					parseProgram(e, t, r) {
						if (e.sourceType = r, e.interpreter = this.parseInterpreterDirective(), this.parseBlockBody(e, !0, !0, t), this.inModule) {
							if (!(64 & this.optionFlags) && this.scope.undefinedExports.size > 0) for (const [e, t] of Array.from(this.scope.undefinedExports)) this.raise(c.ModuleExportUndefined, t, { localName: e });
							this.addExtra(e, "topLevelAwait", this.state.hasTopLevelAwait);
						}
						let n;
						return n = 140 === t ? this.finishNode(e, "Program") : this.finishNodeAt(e, "Program", createPositionWithColumnOffset(this.state.startLoc, -1)), n;
					}
					stmtToDirective(e) {
						const t = this.castNodeTo(e, "Directive"), r = this.castNodeTo(e.expression, "DirectiveLiteral"), n = r.value, s = this.input.slice(this.offsetToSourcePos(r.start), this.offsetToSourcePos(r.end)), i = r.value = s.slice(1, -1);
						return this.addExtra(r, "raw", s), this.addExtra(r, "rawValue", i), this.addExtra(r, "expressionValue", n), t.value = r, delete e.expression, t;
					}
					parseInterpreterDirective() {
						if (!this.match(28)) return null;
						const e = this.startNode();
						return e.value = this.state.value, this.next(), this.finishNode(e, "InterpreterDirective");
					}
					isLet() {
						return !!this.isContextual(100) && this.hasFollowingBindingAtom();
					}
					isUsing() {
						if (!this.isContextual(107)) return !1;
						const e = this.nextTokenInLineStart(), t = this.codePointAtPos(e);
						return this.chStartsBindingIdentifier(t, e);
					}
					isForUsing() {
						if (!this.isContextual(107)) return !1;
						const e = this.nextTokenInLineStart(), t = this.codePointAtPos(e);
						if (this.isUnparsedContextual(e, "of")) {
							const t = this.lookaheadCharCodeSince(e + 2);
							if (61 !== t && 58 !== t && 59 !== t) return !1;
						}
						return !(!this.chStartsBindingIdentifier(t, e) && !this.isUnparsedContextual(e, "void"));
					}
					isAwaitUsing() {
						if (!this.isContextual(96)) return !1;
						let e = this.nextTokenInLineStart();
						if (this.isUnparsedContextual(e, "using")) {
							e = this.nextTokenInLineStartSince(e + 5);
							const t = this.codePointAtPos(e);
							if (this.chStartsBindingIdentifier(t, e)) return !0;
						}
						return !1;
					}
					chStartsBindingIdentifier(e, t) {
						if (isIdentifierStart(e)) {
							if (ae.lastIndex = t, ae.test(this.input)) {
								const e = this.codePointAtPos(ae.lastIndex);
								if (!isIdentifierChar(e) && 92 !== e) return !1;
							}
							return !0;
						}
						return 92 === e;
					}
					chStartsBindingPattern(e) {
						return 91 === e || 123 === e;
					}
					hasFollowingBindingAtom() {
						const e = this.nextTokenStart(), t = this.codePointAtPos(e);
						return this.chStartsBindingPattern(t) || this.chStartsBindingIdentifier(t, e);
					}
					hasInLineFollowingBindingIdentifierOrBrace() {
						const e = this.nextTokenInLineStart(), t = this.codePointAtPos(e);
						return 123 === t || this.chStartsBindingIdentifier(t, e);
					}
					allowsUsing() {
						return (this.scope.inModule || !this.scope.inTopLevel) && !this.scope.inBareCaseStatement;
					}
					parseModuleItem() {
						return this.parseStatementLike(15);
					}
					parseStatementListItem() {
						return this.parseStatementLike(6 | (!this.options.annexB || this.state.strict ? 0 : 8));
					}
					parseStatementOrSloppyAnnexBFunctionDeclaration(e = !1) {
						let t = 0;
						return this.options.annexB && !this.state.strict && (t |= 4, e && (t |= 8)), this.parseStatementLike(t);
					}
					parseStatement() {
						return this.parseStatementLike(0);
					}
					parseStatementLike(e) {
						let t = null;
						return this.match(26) && (t = this.parseDecorators(!0)), this.parseStatementContent(e, t);
					}
					parseStatementContent(e, t) {
						const r = this.state.type, n = this.startNode(), s = !!(2 & e), i = !!(4 & e), o = 1 & e;
						switch (r) {
							case 60: return this.parseBreakContinueStatement(n, !0);
							case 63: return this.parseBreakContinueStatement(n, !1);
							case 64: return this.parseDebuggerStatement(n);
							case 90: return this.parseDoWhileStatement(n);
							case 91: return this.parseForStatement(n);
							case 68:
								if (46 === this.lookaheadCharCode()) break;
								return i || this.raise(this.state.strict ? c.StrictFunction : this.options.annexB ? c.SloppyFunctionAnnexB : c.SloppyFunction, this.state.startLoc), this.parseFunctionStatement(n, !1, !s && i);
							case 80: return s || this.unexpected(), this.parseClass(this.maybeTakeDecorators(t, n), !0);
							case 69: return this.parseIfStatement(n);
							case 70: return this.parseReturnStatement(n);
							case 71: return this.parseSwitchStatement(n);
							case 72: return this.parseThrowStatement(n);
							case 73: return this.parseTryStatement(n);
							case 96:
								if (this.isAwaitUsing()) return this.allowsUsing() ? s ? this.recordAwaitIfAllowed() || this.raise(c.AwaitUsingNotInAsyncContext, n) : this.raise(c.UnexpectedLexicalDeclaration, n) : this.raise(c.UnexpectedUsingDeclaration, n), this.next(), this.parseVarStatement(n, "await using");
								break;
							case 107:
								if (this.state.containsEsc || !this.hasInLineFollowingBindingIdentifierOrBrace()) break;
								return this.allowsUsing() ? s || this.raise(c.UnexpectedLexicalDeclaration, this.state.startLoc) : this.raise(c.UnexpectedUsingDeclaration, this.state.startLoc), this.parseVarStatement(n, "using");
							case 100: {
								if (this.state.containsEsc) break;
								const e = this.nextTokenStart(), t = this.codePointAtPos(e);
								if (91 !== t) {
									if (!s && this.hasFollowingLineBreak()) break;
									if (!this.chStartsBindingIdentifier(t, e) && 123 !== t) break;
								}
							}
							case 75: s || this.raise(c.UnexpectedLexicalDeclaration, this.state.startLoc);
							case 74: {
								const e = this.state.value;
								return this.parseVarStatement(n, e);
							}
							case 92: return this.parseWhileStatement(n);
							case 76: return this.parseWithStatement(n);
							case 5: return this.parseBlock();
							case 13: return this.parseEmptyStatement(n);
							case 83: {
								const e = this.lookaheadCharCode();
								if (40 === e || 46 === e) break;
							}
							case 82: {
								let e;
								return 8 & this.optionFlags || o || this.raise(c.UnexpectedImportExport, this.state.startLoc), this.next(), e = 83 === r ? this.parseImport(n) : this.parseExport(n, t), this.assertModuleNodeAllowed(e), e;
							}
							default: if (this.isAsyncFunction()) return s || this.raise(c.AsyncFunctionInSingleStatementContext, this.state.startLoc), this.next(), this.parseFunctionStatement(n, !0, !s && i);
						}
						const a = this.state.value, l = this.parseExpression();
						return tokenIsIdentifier(r) && "Identifier" === l.type && this.eat(14) ? this.parseLabeledStatement(n, a, l, e) : this.parseExpressionStatement(n, l, t);
					}
					assertModuleNodeAllowed(e) {
						8 & this.optionFlags || this.inModule || this.raise(c.ImportOutsideModule, e);
					}
					decoratorsEnabledBeforeExport() {
						return !!this.hasPlugin("decorators-legacy") || this.hasPlugin("decorators") && !1 !== this.getPluginOption("decorators", "decoratorsBeforeExport");
					}
					maybeTakeDecorators(e, t, r) {
						var n;
						e && (null != (n = t.decorators) && n.length ? ("boolean" != typeof this.getPluginOption("decorators", "decoratorsBeforeExport") && this.raise(c.DecoratorsBeforeAfterExport, t.decorators[0]), t.decorators.unshift(...e)) : t.decorators = e, this.resetStartLocationFromNode(t, e[0]), r && this.resetStartLocationFromNode(r, t));
						return t;
					}
					canHaveLeadingDecorator() {
						return this.match(80);
					}
					parseDecorators(e) {
						const t = [];
						do
							t.push(this.parseDecorator());
						while (this.match(26));
						if (this.match(82)) e || this.unexpected(), this.decoratorsEnabledBeforeExport() || this.raise(c.DecoratorExportClass, this.state.startLoc);
						else if (!this.canHaveLeadingDecorator()) throw this.raise(c.UnexpectedLeadingDecorator, this.state.startLoc);
						return t;
					}
					parseDecorator() {
						this.expectOnePlugin(["decorators", "decorators-legacy"]);
						const e = this.startNode();
						if (this.next(), this.hasPlugin("decorators")) {
							const t = this.state.startLoc;
							let r;
							if (this.match(10)) {
								const t = this.state.startLoc;
								this.next(), r = this.parseExpression(), this.expect(11), r = this.wrapParenthesis(t, r);
								const n = this.state.startLoc;
								e.expression = this.parseMaybeDecoratorArguments(r, t), !1 === this.getPluginOption("decorators", "allowCallParenthesized") && e.expression !== r && this.raise(c.DecoratorArgumentsOutsideParentheses, n);
							} else {
								for (r = this.parseIdentifier(!1); this.eat(16);) {
									const e = this.startNodeAt(t);
									e.object = r, this.match(139) ? (this.classScope.usePrivateName(this.state.value, this.state.startLoc), e.property = this.parsePrivateName()) : e.property = this.parseIdentifier(!0), e.computed = !1, r = this.finishNode(e, "MemberExpression");
								}
								e.expression = this.parseMaybeDecoratorArguments(r, t);
							}
						} else e.expression = this.parseExprSubscripts();
						return this.finishNode(e, "Decorator");
					}
					parseMaybeDecoratorArguments(e, t) {
						if (this.eat(10)) {
							const r = this.startNodeAt(t);
							return r.callee = e, r.arguments = this.parseCallExpressionArguments(), this.toReferencedList(r.arguments), this.finishNode(r, "CallExpression");
						}
						return e;
					}
					parseBreakContinueStatement(e, t) {
						return this.next(), this.isLineTerminator() ? e.label = null : (e.label = this.parseIdentifier(), this.semicolon()), this.verifyBreakContinue(e, t), this.finishNode(e, t ? "BreakStatement" : "ContinueStatement");
					}
					verifyBreakContinue(e, t) {
						let r;
						for (r = 0; r < this.state.labels.length; ++r) {
							const n = this.state.labels[r];
							if (null == e.label || n.name === e.label.name) {
								if (null != n.kind && (t || 1 === n.kind)) break;
								if (e.label && t) break;
							}
						}
						if (r === this.state.labels.length) {
							const r = t ? "BreakStatement" : "ContinueStatement";
							this.raise(c.IllegalBreakContinue, e, { type: r });
						}
					}
					parseDebuggerStatement(e) {
						return this.next(), this.semicolon(), this.finishNode(e, "DebuggerStatement");
					}
					parseHeaderExpression() {
						this.expect(10);
						const e = this.parseExpression();
						return this.expect(11), e;
					}
					parseDoWhileStatement(e) {
						return this.next(), this.state.labels.push(se), e.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement()), this.state.labels.pop(), this.expect(92), e.test = this.parseHeaderExpression(), this.eat(13), this.finishNode(e, "DoWhileStatement");
					}
					parseForStatement(e) {
						this.next(), this.state.labels.push(se);
						let t = null;
						if (this.isContextual(96) && this.recordAwaitIfAllowed() && (t = this.state.startLoc, this.next()), this.scope.enter(0), this.expect(10), this.match(13)) return null !== t && this.unexpected(t), this.parseFor(e, null);
						const r = this.isContextual(100);
						{
							const n = this.isAwaitUsing(), s = n || this.isForUsing(), i = r && this.hasFollowingBindingAtom() || s;
							if (this.match(74) || this.match(75) || i) {
								const r = this.startNode();
								let i;
								n ? (i = "await using", this.recordAwaitIfAllowed() || this.raise(c.AwaitUsingNotInAsyncContext, this.state.startLoc), this.next()) : i = this.state.value, this.next(), this.parseVar(r, !0, i);
								const o = this.finishNode(r, "VariableDeclaration"), a = this.match(58);
								return a && s && this.raise(c.ForInUsing, o), (a || this.isContextual(102)) && 1 === o.declarations.length ? this.parseForIn(e, o, t) : (null !== t && this.unexpected(t), this.parseFor(e, o));
							}
						}
						const n = this.isContextual(95), s = new ExpressionErrors(), i = this.parseExpression(!0, s), o = this.isContextual(102);
						if (o && (r && this.raise(c.ForOfLet, i), null === t && n && "Identifier" === i.type && this.raise(c.ForOfAsync, i)), o || this.match(58)) {
							this.checkDestructuringPrivate(s), this.toAssignable(i, !0);
							const r = o ? "ForOfStatement" : "ForInStatement";
							return this.checkLVal(i, { type: r }), this.parseForIn(e, i, t);
						}
						return this.checkExpressionErrors(s, !0), null !== t && this.unexpected(t), this.parseFor(e, i);
					}
					parseFunctionStatement(e, t, r) {
						return this.next(), this.parseFunction(e, 1 | (r ? 2 : 0) | (t ? 8 : 0));
					}
					parseIfStatement(e) {
						return this.next(), e.test = this.parseHeaderExpression(), e.consequent = this.parseStatementOrSloppyAnnexBFunctionDeclaration(), e.alternate = this.eat(66) ? this.parseStatementOrSloppyAnnexBFunctionDeclaration() : null, this.finishNode(e, "IfStatement");
					}
					parseReturnStatement(e) {
						return this.prodParam.hasReturn || this.raise(c.IllegalReturn, this.state.startLoc), this.next(), this.isLineTerminator() ? e.argument = null : (e.argument = this.parseExpression(), this.semicolon()), this.finishNode(e, "ReturnStatement");
					}
					parseSwitchStatement(e) {
						this.next(), e.discriminant = this.parseHeaderExpression();
						const t = e.cases = [];
						let r;
						this.expect(5), this.state.labels.push(ie), this.scope.enter(256);
						for (let e; !this.match(8);) if (this.match(61) || this.match(65)) {
							const n = this.match(61);
							r && this.finishNode(r, "SwitchCase"), t.push(r = this.startNode()), r.consequent = [], this.next(), n ? r.test = this.parseExpression() : (e && this.raise(c.MultipleDefaultsInSwitch, this.state.lastTokStartLoc), e = !0, r.test = null), this.expect(14);
						} else r ? r.consequent.push(this.parseStatementListItem()) : this.unexpected();
						return this.scope.exit(), r && this.finishNode(r, "SwitchCase"), this.next(), this.state.labels.pop(), this.finishNode(e, "SwitchStatement");
					}
					parseThrowStatement(e) {
						return this.next(), this.hasPrecedingLineBreak() && this.raise(c.NewlineAfterThrow, this.state.lastTokEndLoc), e.argument = this.parseExpression(), this.semicolon(), this.finishNode(e, "ThrowStatement");
					}
					parseCatchClauseParam() {
						const e = this.parseBindingAtom();
						return this.scope.enter(this.options.annexB && "Identifier" === e.type ? 8 : 0), this.checkLVal(e, { type: "CatchClause" }, 9), e;
					}
					parseTryStatement(e) {
						if (this.next(), e.block = this.parseBlock(), e.handler = null, this.match(62)) {
							const t = this.startNode();
							this.next(), this.match(10) ? (this.expect(10), t.param = this.parseCatchClauseParam(), this.expect(11)) : (t.param = null, this.scope.enter(0)), t.body = this.withSmartMixTopicForbiddingContext(() => this.parseBlock(!1, !1)), this.scope.exit(), e.handler = this.finishNode(t, "CatchClause");
						}
						return e.finalizer = this.eat(67) ? this.parseBlock() : null, e.handler || e.finalizer || this.raise(c.NoCatchOrFinally, e), this.finishNode(e, "TryStatement");
					}
					parseVarStatement(e, t, r = !1) {
						return this.next(), this.parseVar(e, !1, t, r), this.semicolon(), this.finishNode(e, "VariableDeclaration");
					}
					parseWhileStatement(e) {
						return this.next(), e.test = this.parseHeaderExpression(), this.state.labels.push(se), e.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement()), this.state.labels.pop(), this.finishNode(e, "WhileStatement");
					}
					parseWithStatement(e) {
						return this.state.strict && this.raise(c.StrictWith, this.state.startLoc), this.next(), e.object = this.parseHeaderExpression(), e.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement()), this.finishNode(e, "WithStatement");
					}
					parseEmptyStatement(e) {
						return this.next(), this.finishNode(e, "EmptyStatement");
					}
					parseLabeledStatement(e, t, r, n) {
						for (const e of this.state.labels) e.name === t && this.raise(c.LabelRedeclaration, r, { labelName: t });
						const s = (i = this.state.type) >= 90 && i <= 92 ? 1 : this.match(71) ? 2 : null;
						var i;
						for (let t = this.state.labels.length - 1; t >= 0; t--) {
							const r = this.state.labels[t];
							if (r.statementStart !== e.start) break;
							r.statementStart = this.sourceToOffsetPos(this.state.start), r.kind = s;
						}
						return this.state.labels.push({
							name: t,
							kind: s,
							statementStart: this.sourceToOffsetPos(this.state.start)
						}), e.body = 8 & n ? this.parseStatementOrSloppyAnnexBFunctionDeclaration(!0) : this.parseStatement(), this.state.labels.pop(), e.label = r, this.finishNode(e, "LabeledStatement");
					}
					parseExpressionStatement(e, t, r) {
						return e.expression = t, this.semicolon(), this.finishNode(e, "ExpressionStatement");
					}
					parseBlock(e = !1, t = !0, r) {
						const n = this.startNode();
						return e && this.state.strictErrors.clear(), this.expect(5), t && this.scope.enter(0), this.parseBlockBody(n, e, !1, 8, r), t && this.scope.exit(), this.finishNode(n, "BlockStatement");
					}
					isValidDirective(e) {
						return "ExpressionStatement" === e.type && "StringLiteral" === e.expression.type && !e.expression.extra.parenthesized;
					}
					parseBlockBody(e, t, r, n, s) {
						const i = e.body = [], o = e.directives = [];
						this.parseBlockOrModuleBlockBody(i, t ? o : void 0, r, n, s);
					}
					parseBlockOrModuleBlockBody(e, t, r, n, s) {
						const i = this.state.strict;
						let o = !1, a = !1;
						for (; !this.match(n);) {
							const n = r ? this.parseModuleItem() : this.parseStatementListItem();
							if (t && !a) {
								if (this.isValidDirective(n)) {
									const e = this.stmtToDirective(n);
									t.push(e), o || "use strict" !== e.value.value || (o = !0, this.setStrict(!0));
									continue;
								}
								a = !0, this.state.strictErrors.clear();
							}
							e.push(n);
						}
						s?.call(this, o), i || this.setStrict(!1), this.next();
					}
					parseFor(e, t) {
						return e.init = t, this.semicolon(!1), e.test = this.match(13) ? null : this.parseExpression(), this.semicolon(!1), e.update = this.match(11) ? null : this.parseExpression(), this.expect(11), e.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement()), this.scope.exit(), this.state.labels.pop(), this.finishNode(e, "ForStatement");
					}
					parseForIn(e, t, r) {
						const n = this.match(58);
						return this.next(), n ? null !== r && this.unexpected(r) : e.await = null !== r, "VariableDeclaration" !== t.type || null == t.declarations[0].init || n && this.options.annexB && !this.state.strict && "var" === t.kind && "Identifier" === t.declarations[0].id.type || this.raise(c.ForInOfLoopInitializer, t, { type: n ? "ForInStatement" : "ForOfStatement" }), "AssignmentPattern" === t.type && this.raise(c.InvalidLhs, t, { ancestor: { type: "ForStatement" } }), e.left = t, e.right = n ? this.parseExpression() : this.parseMaybeAssignAllowIn(), this.expect(11), e.body = this.withSmartMixTopicForbiddingContext(() => this.parseStatement()), this.scope.exit(), this.state.labels.pop(), this.finishNode(e, n ? "ForInStatement" : "ForOfStatement");
					}
					parseVar(e, t, r, n = !1) {
						const s = e.declarations = [];
						for (e.kind = r;;) {
							const e = this.startNode();
							if (this.parseVarId(e, r), e.init = this.eat(29) ? t ? this.parseMaybeAssignDisallowIn() : this.parseMaybeAssignAllowIn() : null, null !== e.init || n || ("Identifier" === e.id.type || t && (this.match(58) || this.isContextual(102)) ? "const" !== r && "using" !== r && "await using" !== r || this.match(58) || this.isContextual(102) || this.raise(c.DeclarationMissingInitializer, this.state.lastTokEndLoc, { kind: r }) : this.raise(c.DeclarationMissingInitializer, this.state.lastTokEndLoc, { kind: "destructuring" })), s.push(this.finishNode(e, "VariableDeclarator")), !this.eat(12)) break;
						}
						return e;
					}
					parseVarId(e, t) {
						const r = this.parseBindingAtom();
						"using" === t || "await using" === t ? "ArrayPattern" !== r.type && "ObjectPattern" !== r.type || this.raise(c.UsingDeclarationHasBindingPattern, r.loc.start) : "VoidPattern" === r.type && this.raise(c.UnexpectedVoidPattern, r.loc.start), this.checkLVal(r, { type: "VariableDeclarator" }, "var" === t ? 5 : 8201), e.id = r;
					}
					parseAsyncFunctionExpression(e) {
						return this.parseFunction(e, 8);
					}
					parseFunction(e, t = 0) {
						const r = 2 & t, n = !!(1 & t), s = n && !(4 & t), i = !!(8 & t);
						this.initFunction(e, i), this.match(55) && (r && this.raise(c.GeneratorInSingleStatementContext, this.state.startLoc), this.next(), e.generator = !0), n && (e.id = this.parseFunctionId(s));
						const o = this.state.maybeInArrowParameters;
						return this.state.maybeInArrowParameters = !1, this.scope.enter(514), this.prodParam.enter(functionFlags(i, e.generator)), n || (e.id = this.parseFunctionId()), this.parseFunctionParams(e, !1), this.withSmartMixTopicForbiddingContext(() => {
							this.parseFunctionBodyAndFinish(e, n ? "FunctionDeclaration" : "FunctionExpression");
						}), this.prodParam.exit(), this.scope.exit(), n && !r && this.registerFunctionStatementId(e), this.state.maybeInArrowParameters = o, e;
					}
					parseFunctionId(e) {
						return e || tokenIsIdentifier(this.state.type) ? this.parseIdentifier() : null;
					}
					parseFunctionParams(e, t) {
						this.expect(10), this.expressionScope.enter(new ExpressionScope(3)), e.params = this.parseBindingList(11, 41, 2 | (t ? 4 : 0)), this.expressionScope.exit();
					}
					registerFunctionStatementId(e) {
						e.id && this.scope.declareName(e.id.name, !this.options.annexB || this.state.strict || e.generator || e.async ? this.scope.treatFunctionsAsVar ? 5 : 8201 : 17, e.id.loc.start);
					}
					parseClass(e, t, r) {
						this.next();
						const n = this.state.strict;
						return this.state.strict = !0, this.parseClassId(e, t, r), this.parseClassSuper(e), e.body = this.parseClassBody(!!e.superClass, n), this.finishNode(e, t ? "ClassDeclaration" : "ClassExpression");
					}
					isClassProperty() {
						return this.match(29) || this.match(13) || this.match(8);
					}
					isClassMethod() {
						return this.match(10);
					}
					nameIsConstructor(e) {
						return "Identifier" === e.type && "constructor" === e.name || "StringLiteral" === e.type && "constructor" === e.value;
					}
					isNonstaticConstructor(e) {
						return !e.computed && !e.static && this.nameIsConstructor(e.key);
					}
					parseClassBody(e, t) {
						this.classScope.enter();
						const r = {
							hadConstructor: !1,
							hadSuperClass: e
						};
						let n = [];
						const s = this.startNode();
						if (s.body = [], this.expect(5), this.withSmartMixTopicForbiddingContext(() => {
							for (; !this.match(8);) {
								if (this.eat(13)) {
									if (n.length > 0) throw this.raise(c.DecoratorSemicolon, this.state.lastTokEndLoc);
									continue;
								}
								if (this.match(26)) {
									n.push(this.parseDecorator());
									continue;
								}
								const e = this.startNode();
								n.length && (e.decorators = n, this.resetStartLocationFromNode(e, n[0]), n = []), this.parseClassMember(s, e, r), "constructor" === e.kind && e.decorators && e.decorators.length > 0 && this.raise(c.DecoratorConstructor, e);
							}
						}), this.state.strict = t, this.next(), n.length) throw this.raise(c.TrailingDecorator, this.state.startLoc);
						return this.classScope.exit(), this.finishNode(s, "ClassBody");
					}
					parseClassMemberFromModifier(e, t) {
						const r = this.parseIdentifier(!0);
						if (this.isClassMethod()) {
							const n = t;
							return n.kind = "method", n.computed = !1, n.key = r, n.static = !1, this.pushClassMethod(e, n, !1, !1, !1, !1), !0;
						}
						if (this.isClassProperty()) {
							const n = t;
							return n.computed = !1, n.key = r, n.static = !1, e.body.push(this.parseClassProperty(n)), !0;
						}
						return this.resetPreviousNodeTrailingComments(r), !1;
					}
					parseClassMember(e, t, r) {
						const n = this.isContextual(106);
						if (n) {
							if (this.parseClassMemberFromModifier(e, t)) return;
							if (this.eat(5)) return void this.parseClassStaticBlock(e, t);
						}
						this.parseClassMemberWithIsStatic(e, t, r, n);
					}
					parseClassMemberWithIsStatic(e, t, r, n) {
						const s = t, i = t, o = t, a = t, l = t, p = s, u = s;
						if (t.static = n, this.parsePropertyNamePrefixOperator(t), this.eat(55)) {
							p.kind = "method";
							const t = this.match(139);
							this.parseClassElementName(p), this.parsePostMemberNameModifiers(p), t ? this.pushClassPrivateMethod(e, i, !0, !1) : (this.isNonstaticConstructor(s) && this.raise(c.ConstructorIsGenerator, s.key), this.pushClassMethod(e, s, !0, !1, !1, !1));
							return;
						}
						const d = !this.state.containsEsc && tokenIsIdentifier(this.state.type), h = this.parseClassElementName(t), m = d ? h.name : null, f = this.isPrivateName(h), y = this.state.startLoc;
						if (this.parsePostMemberNameModifiers(u), this.isClassMethod()) {
							if (p.kind = "method", f) return void this.pushClassPrivateMethod(e, i, !1, !1);
							const n = this.isNonstaticConstructor(s);
							let o = !1;
							n && (s.kind = "constructor", r.hadConstructor && !this.hasPlugin("typescript") && this.raise(c.DuplicateConstructor, h), n && this.hasPlugin("typescript") && t.override && this.raise(c.OverrideOnConstructor, h), r.hadConstructor = !0, o = r.hadSuperClass), this.pushClassMethod(e, s, !1, !1, n, o);
						} else if (this.isClassProperty()) f ? this.pushClassPrivateProperty(e, a) : this.pushClassProperty(e, o);
						else if ("async" !== m || this.isLineTerminator()) if ("get" !== m && "set" !== m || this.match(55) && this.isLineTerminator()) if ("accessor" !== m || this.isLineTerminator()) this.isLineTerminator() ? f ? this.pushClassPrivateProperty(e, a) : this.pushClassProperty(e, o) : this.unexpected();
						else {
							this.expectPlugin("decoratorAutoAccessors"), this.resetPreviousNodeTrailingComments(h);
							const t = this.match(139);
							this.parseClassElementName(o), this.pushClassAccessorProperty(e, l, t);
						}
						else {
							this.resetPreviousNodeTrailingComments(h), p.kind = m;
							const t = this.match(139);
							this.parseClassElementName(s), t ? this.pushClassPrivateMethod(e, i, !1, !1) : (this.isNonstaticConstructor(s) && this.raise(c.ConstructorIsAccessor, s.key), this.pushClassMethod(e, s, !1, !1, !1, !1)), this.checkGetterSetterParams(s);
						}
						else {
							this.resetPreviousNodeTrailingComments(h);
							const t = this.eat(55);
							u.optional && this.unexpected(y), p.kind = "method";
							const r = this.match(139);
							this.parseClassElementName(p), this.parsePostMemberNameModifiers(u), r ? this.pushClassPrivateMethod(e, i, t, !0) : (this.isNonstaticConstructor(s) && this.raise(c.ConstructorIsAsync, s.key), this.pushClassMethod(e, s, t, !0, !1, !1));
						}
					}
					parseClassElementName(e) {
						const { type: t, value: r } = this.state;
						if (132 !== t && 134 !== t || !e.static || "prototype" !== r || this.raise(c.StaticPrototype, this.state.startLoc), 139 === t) {
							"constructor" === r && this.raise(c.ConstructorClassPrivateField, this.state.startLoc);
							const t = this.parsePrivateName();
							return e.key = t, t;
						}
						return this.parsePropertyName(e), e.key;
					}
					parseClassStaticBlock(e, t) {
						var r;
						this.scope.enter(720);
						const n = this.state.labels;
						this.state.labels = [], this.prodParam.enter(0);
						const s = t.body = [];
						this.parseBlockOrModuleBlockBody(s, void 0, !1, 8), this.prodParam.exit(), this.scope.exit(), this.state.labels = n, e.body.push(this.finishNode(t, "StaticBlock")), null != (r = t.decorators) && r.length && this.raise(c.DecoratorStaticBlock, t);
					}
					pushClassProperty(e, t) {
						!t.computed && this.nameIsConstructor(t.key) && this.raise(c.ConstructorClassField, t.key), e.body.push(this.parseClassProperty(t));
					}
					pushClassPrivateProperty(e, t) {
						const r = this.parseClassPrivateProperty(t);
						e.body.push(r), this.classScope.declarePrivateName(this.getPrivateNameSV(r.key), 0, r.key.loc.start);
					}
					pushClassAccessorProperty(e, t, r) {
						r || t.computed || !this.nameIsConstructor(t.key) || this.raise(c.ConstructorClassField, t.key);
						const n = this.parseClassAccessorProperty(t);
						e.body.push(n), r && this.classScope.declarePrivateName(this.getPrivateNameSV(n.key), 0, n.key.loc.start);
					}
					pushClassMethod(e, t, r, n, s, i) {
						e.body.push(this.parseMethod(t, r, n, s, i, "ClassMethod", !0));
					}
					pushClassPrivateMethod(e, t, r, n) {
						const s = this.parseMethod(t, r, n, !1, !1, "ClassPrivateMethod", !0);
						e.body.push(s);
						const i = "get" === s.kind ? s.static ? 6 : 2 : "set" === s.kind ? s.static ? 5 : 1 : 0;
						this.declareClassPrivateMethodInScope(s, i);
					}
					declareClassPrivateMethodInScope(e, t) {
						this.classScope.declarePrivateName(this.getPrivateNameSV(e.key), t, e.key.loc.start);
					}
					parsePostMemberNameModifiers(e) {}
					parseClassPrivateProperty(e) {
						return this.parseInitializer(e), this.semicolon(), this.finishNode(e, "ClassPrivateProperty");
					}
					parseClassProperty(e) {
						return this.parseInitializer(e), this.semicolon(), this.finishNode(e, "ClassProperty");
					}
					parseClassAccessorProperty(e) {
						return this.parseInitializer(e), this.semicolon(), this.finishNode(e, "ClassAccessorProperty");
					}
					parseInitializer(e) {
						this.scope.enter(592), this.expressionScope.enter(newExpressionScope()), this.prodParam.enter(0), e.value = this.eat(29) ? this.parseMaybeAssignAllowIn() : null, this.expressionScope.exit(), this.prodParam.exit(), this.scope.exit();
					}
					parseClassId(e, t, r, n = 8331) {
						if (tokenIsIdentifier(this.state.type)) e.id = this.parseIdentifier(), t && this.declareNameFromIdentifier(e.id, n);
						else {
							if (!r && t) throw this.raise(c.MissingClassName, this.state.startLoc);
							e.id = null;
						}
					}
					parseClassSuper(e) {
						e.superClass = this.eat(81) ? this.parseExprSubscripts() : null;
					}
					parseExport(e, t) {
						const r = this.parseMaybeImportPhase(e, !0), n = this.maybeParseExportDefaultSpecifier(e, r), s = !n || this.eat(12), i = s && this.eatExportStar(e), o = i && this.maybeParseExportNamespaceSpecifier(e), a = s && (!o || this.eat(12)), l = n || i;
						if (i && !o) {
							if (n && this.unexpected(), t) throw this.raise(c.UnsupportedDecoratorExport, e);
							return this.parseExportFrom(e, !0), this.sawUnambiguousESM = !0, this.finishNode(e, "ExportAllDeclaration");
						}
						const p = this.maybeParseExportNamedSpecifiers(e);
						let u;
						if (n && s && !i && !p && this.unexpected(null, 5), o && a && this.unexpected(null, 98), l || p) {
							if (u = !1, t) throw this.raise(c.UnsupportedDecoratorExport, e);
							this.parseExportFrom(e, l);
						} else u = this.maybeParseExportDeclaration(e);
						if (l || p || u) {
							var d;
							const r = e;
							if (this.checkExport(r, !0, !1, !!r.source), "ClassDeclaration" === (null == (d = r.declaration) ? void 0 : d.type)) this.maybeTakeDecorators(t, r.declaration, r);
							else if (t) throw this.raise(c.UnsupportedDecoratorExport, e);
							return this.sawUnambiguousESM = !0, this.finishNode(r, "ExportNamedDeclaration");
						}
						if (this.eat(65)) {
							const r = e, n = this.parseExportDefaultExpression();
							if (r.declaration = n, "ClassDeclaration" === n.type) this.maybeTakeDecorators(t, n, r);
							else if (t) throw this.raise(c.UnsupportedDecoratorExport, e);
							return this.checkExport(r, !0, !0), this.sawUnambiguousESM = !0, this.finishNode(r, "ExportDefaultDeclaration");
						}
						this.unexpected(null, 5);
					}
					eatExportStar(e) {
						return this.eat(55);
					}
					maybeParseExportDefaultSpecifier(e, t) {
						if (t || this.isExportDefaultSpecifier()) {
							this.expectPlugin("exportDefaultFrom", null == t ? void 0 : t.loc.start);
							const r = t || this.parseIdentifier(!0), n = this.startNodeAtNode(r);
							return n.exported = r, e.specifiers = [this.finishNode(n, "ExportDefaultSpecifier")], !0;
						}
						return !1;
					}
					maybeParseExportNamespaceSpecifier(e) {
						if (this.isContextual(93)) {
							var t;
							(t = e).specifiers ?? (t.specifiers = []);
							const r = this.startNodeAt(this.state.lastTokStartLoc);
							return this.next(), r.exported = this.parseModuleExportName(), e.specifiers.push(this.finishNode(r, "ExportNamespaceSpecifier")), !0;
						}
						return !1;
					}
					maybeParseExportNamedSpecifiers(e) {
						if (this.match(5)) {
							const t = e;
							t.specifiers || (t.specifiers = []);
							const r = "type" === t.exportKind;
							return t.specifiers.push(...this.parseExportSpecifiers(r)), t.source = null, this.hasPlugin("importAssertions") ? t.assertions = [] : t.attributes = [], t.declaration = null, !0;
						}
						return !1;
					}
					maybeParseExportDeclaration(e) {
						return !!this.shouldParseExportDeclaration() && (e.specifiers = [], e.source = null, this.hasPlugin("importAssertions") ? e.assertions = [] : e.attributes = [], e.declaration = this.parseExportDeclaration(e), !0);
					}
					isAsyncFunction() {
						if (!this.isContextual(95)) return !1;
						const e = this.nextTokenInLineStart();
						return this.isUnparsedContextual(e, "function");
					}
					parseExportDefaultExpression() {
						const e = this.startNode();
						if (this.match(68)) return this.next(), this.parseFunction(e, 5);
						if (this.isAsyncFunction()) return this.next(), this.next(), this.parseFunction(e, 13);
						if (this.match(80)) return this.parseClass(e, !0, !0);
						if (this.match(26)) return this.hasPlugin("decorators") && !0 === this.getPluginOption("decorators", "decoratorsBeforeExport") && this.raise(c.DecoratorBeforeExport, this.state.startLoc), this.parseClass(this.maybeTakeDecorators(this.parseDecorators(!1), this.startNode()), !0, !0);
						if (this.match(75) || this.match(74) || this.isLet() || this.isUsing() || this.isAwaitUsing()) throw this.raise(c.UnsupportedDefaultExport, this.state.startLoc);
						const t = this.parseMaybeAssignAllowIn();
						return this.semicolon(), t;
					}
					parseExportDeclaration(e) {
						if (this.match(80)) return this.parseClass(this.startNode(), !0, !1);
						return this.parseStatementListItem();
					}
					isExportDefaultSpecifier() {
						const { type: e } = this.state;
						if (tokenIsIdentifier(e)) {
							if (95 === e && !this.state.containsEsc || 100 === e) return !1;
							if ((130 === e || 129 === e) && !this.state.containsEsc) {
								const e = this.nextTokenStart(), t = this.input.charCodeAt(e);
								if (123 === t || this.chStartsBindingIdentifier(t, e) && !this.input.startsWith("from", e)) return this.expectOnePlugin(["flow", "typescript"]), !1;
							}
						} else if (!this.match(65)) return !1;
						const t = this.nextTokenStart(), r = this.isUnparsedContextual(t, "from");
						if (44 === this.input.charCodeAt(t) || tokenIsIdentifier(this.state.type) && r) return !0;
						if (this.match(65) && r) {
							const e = this.input.charCodeAt(this.nextTokenStartSince(t + 4));
							return 34 === e || 39 === e;
						}
						return !1;
					}
					parseExportFrom(e, t) {
						this.eatContextual(98) ? (e.source = this.parseImportSource(), this.checkExport(e), this.maybeParseImportAttributes(e), this.checkJSONModuleImport(e)) : t && this.unexpected(), this.semicolon();
					}
					shouldParseExportDeclaration() {
						const { type: e } = this.state;
						return 26 === e && (this.expectOnePlugin(["decorators", "decorators-legacy"]), this.hasPlugin("decorators")) ? (!0 === this.getPluginOption("decorators", "decoratorsBeforeExport") && this.raise(c.DecoratorBeforeExport, this.state.startLoc), !0) : this.isUsing() || this.isAwaitUsing() ? (this.raise(c.UsingDeclarationExport, this.state.startLoc), !0) : 74 === e || 75 === e || 68 === e || 80 === e || this.isLet() || this.isAsyncFunction();
					}
					checkExport(e, t, r, n) {
						var s;
						if (t) {
							if (r) {
								if (this.checkDuplicateExports(e, "default"), this.hasPlugin("exportDefaultFrom")) {
									var i;
									const t = e.declaration;
									"Identifier" !== t.type || "from" !== t.name || t.end - t.start !== 4 || null != (i = t.extra) && i.parenthesized || this.raise(c.ExportDefaultFromAsIdentifier, t);
								}
							} else if (null != (s = e.specifiers) && s.length) for (const t of e.specifiers) {
								const { exported: e } = t, r = "Identifier" === e.type ? e.name : e.value;
								if (this.checkDuplicateExports(t, r), !n && t.local) {
									const { local: e } = t;
									"Identifier" !== e.type ? this.raise(c.ExportBindingIsString, t, {
										localName: e.value,
										exportName: r
									}) : (this.checkReservedWord(e.name, e.loc.start, !0, !1), this.scope.checkLocalExport(e));
								}
							}
							else if (e.declaration) {
								const t = e.declaration;
								if ("FunctionDeclaration" === t.type || "ClassDeclaration" === t.type) {
									const { id: r } = t;
									if (!r) throw new Error("Assertion failure");
									this.checkDuplicateExports(e, r.name);
								} else if ("VariableDeclaration" === t.type) for (const e of t.declarations) this.checkDeclaration(e.id);
							}
						}
					}
					checkDeclaration(e) {
						if ("Identifier" === e.type) this.checkDuplicateExports(e, e.name);
						else if ("ObjectPattern" === e.type) for (const t of e.properties) this.checkDeclaration(t);
						else if ("ArrayPattern" === e.type) for (const t of e.elements) t && this.checkDeclaration(t);
						else "ObjectProperty" === e.type ? this.checkDeclaration(e.value) : "RestElement" === e.type ? this.checkDeclaration(e.argument) : "AssignmentPattern" === e.type && this.checkDeclaration(e.left);
					}
					checkDuplicateExports(e, t) {
						this.exportedIdentifiers.has(t) && ("default" === t ? this.raise(c.DuplicateDefaultExport, e) : this.raise(c.DuplicateExport, e, { exportName: t })), this.exportedIdentifiers.add(t);
					}
					parseExportSpecifiers(e) {
						const t = [];
						let r = !0;
						for (this.expect(5); !this.eat(8);) {
							if (r) r = !1;
							else if (this.expect(12), this.eat(8)) break;
							const n = this.isContextual(130), s = this.match(134), i = this.startNode();
							i.local = this.parseModuleExportName(), t.push(this.parseExportSpecifier(i, s, e, n));
						}
						return t;
					}
					parseExportSpecifier(e, t, r, n) {
						return this.eatContextual(93) ? e.exported = this.parseModuleExportName() : t ? e.exported = this.cloneStringLiteral(e.local) : e.exported || (e.exported = this.cloneIdentifier(e.local)), this.finishNode(e, "ExportSpecifier");
					}
					parseModuleExportName() {
						if (this.match(134)) {
							const e = this.parseStringLiteral(this.state.value), t = oe.exec(e.value);
							return t && this.raise(c.ModuleExportNameHasLoneSurrogate, e, { surrogateCharCode: t[0].charCodeAt(0) }), e;
						}
						return this.parseIdentifier(!0);
					}
					isJSONModuleImport(e) {
						return null != e.assertions && e.assertions.some(({ key: e, value: t }) => "json" === t.value && ("Identifier" === e.type ? "type" === e.name : "type" === e.value));
					}
					checkImportReflection(e) {
						const { specifiers: t } = e, r = 1 === t.length ? t[0].type : null;
						if ("source" === e.phase) "ImportDefaultSpecifier" !== r && this.raise(c.SourcePhaseImportRequiresDefault, t[0].loc.start);
						else if ("defer" === e.phase) "ImportNamespaceSpecifier" !== r && this.raise(c.DeferImportRequiresNamespace, t[0].loc.start);
						else if (e.module) {
							var n;
							"ImportDefaultSpecifier" !== r && this.raise(c.ImportReflectionNotBinding, t[0].loc.start), (null == (n = e.assertions) ? void 0 : n.length) > 0 && this.raise(c.ImportReflectionHasAssertion, t[0].loc.start);
						}
					}
					checkJSONModuleImport(e) {
						if (this.isJSONModuleImport(e) && "ExportAllDeclaration" !== e.type) {
							const { specifiers: t } = e;
							if (null != t) {
								const e = t.find((e) => {
									let t;
									if ("ExportSpecifier" === e.type ? t = e.local : "ImportSpecifier" === e.type && (t = e.imported), void 0 !== t) return "Identifier" === t.type ? "default" !== t.name : "default" !== t.value;
								});
								void 0 !== e && this.raise(c.ImportJSONBindingNotDefault, e.loc.start);
							}
						}
					}
					isPotentialImportPhase(e) {
						return !e && (this.isContextual(105) || this.isContextual(97) || this.isContextual(127));
					}
					applyImportPhase(e, t, r, n) {
						t || ("module" === r ? (this.expectPlugin("importReflection", n), e.module = !0) : this.hasPlugin("importReflection") && (e.module = !1), "source" === r ? (this.expectPlugin("sourcePhaseImports", n), e.phase = "source") : "defer" === r ? (this.expectPlugin("deferredImportEvaluation", n), e.phase = "defer") : this.hasPlugin("sourcePhaseImports") && (e.phase = null));
					}
					parseMaybeImportPhase(e, t) {
						if (!this.isPotentialImportPhase(t)) return this.applyImportPhase(e, t, null), null;
						const r = this.startNode(), n = this.parseIdentifierName(!0), { type: s } = this.state;
						return (tokenIsKeywordOrIdentifier(s) ? 98 !== s || 102 === this.lookaheadCharCode() : 12 !== s) ? (this.applyImportPhase(e, t, n, r.loc.start), null) : (this.applyImportPhase(e, t, null), this.createIdentifier(r, n));
					}
					isPrecedingIdImportPhase(e) {
						const { type: t } = this.state;
						return tokenIsIdentifier(t) ? 98 !== t || 102 === this.lookaheadCharCode() : 12 !== t;
					}
					parseImport(e) {
						return this.match(134) ? this.parseImportSourceAndAttributes(e) : this.parseImportSpecifiersAndAfter(e, this.parseMaybeImportPhase(e, !1));
					}
					parseImportSpecifiersAndAfter(e, t) {
						e.specifiers = [];
						const r = !this.maybeParseDefaultImportSpecifier(e, t) || this.eat(12), n = r && this.maybeParseStarImportSpecifier(e);
						return r && !n && this.parseNamedImportSpecifiers(e), this.expectContextual(98), this.parseImportSourceAndAttributes(e);
					}
					parseImportSourceAndAttributes(e) {
						return e.specifiers ?? (e.specifiers = []), e.source = this.parseImportSource(), this.maybeParseImportAttributes(e), this.checkImportReflection(e), this.checkJSONModuleImport(e), this.semicolon(), this.sawUnambiguousESM = !0, this.finishNode(e, "ImportDeclaration");
					}
					parseImportSource() {
						return this.match(134) || this.unexpected(), this.parseExprAtom();
					}
					parseImportSpecifierLocal(e, t, r) {
						t.local = this.parseIdentifier(), e.specifiers.push(this.finishImportSpecifier(t, r));
					}
					finishImportSpecifier(e, t, r = 8201) {
						return this.checkLVal(e.local, { type: t }, r), this.finishNode(e, t);
					}
					parseImportAttributes() {
						this.expect(5);
						const e = [], t = /* @__PURE__ */ new Set();
						do {
							if (this.match(8)) break;
							const r = this.startNode(), n = this.state.value;
							if (t.has(n) && this.raise(c.ModuleAttributesWithDuplicateKeys, this.state.startLoc, { key: n }), t.add(n), this.match(134) ? r.key = this.parseStringLiteral(n) : r.key = this.parseIdentifier(!0), this.expect(14), !this.match(134)) throw this.raise(c.ModuleAttributeInvalidValue, this.state.startLoc);
							r.value = this.parseStringLiteral(this.state.value), e.push(this.finishNode(r, "ImportAttribute"));
						} while (this.eat(12));
						return this.expect(8), e;
					}
					parseModuleAttributes() {
						const e = [], t = /* @__PURE__ */ new Set();
						do {
							const r = this.startNode();
							if (r.key = this.parseIdentifier(!0), "type" !== r.key.name && this.raise(c.ModuleAttributeDifferentFromType, r.key), t.has(r.key.name) && this.raise(c.ModuleAttributesWithDuplicateKeys, r.key, { key: r.key.name }), t.add(r.key.name), this.expect(14), !this.match(134)) throw this.raise(c.ModuleAttributeInvalidValue, this.state.startLoc);
							r.value = this.parseStringLiteral(this.state.value), e.push(this.finishNode(r, "ImportAttribute"));
						} while (this.eat(12));
						return e;
					}
					maybeParseImportAttributes(e) {
						let t;
						var r = !1;
						if (this.match(76)) {
							if (this.hasPrecedingLineBreak() && 40 === this.lookaheadCharCode()) return;
							this.next(), this.hasPlugin("moduleAttributes") ? (t = this.parseModuleAttributes(), this.addExtra(e, "deprecatedWithLegacySyntax", !0)) : t = this.parseImportAttributes(), r = !0;
						} else this.isContextual(94) && !this.hasPrecedingLineBreak() ? (this.hasPlugin("deprecatedImportAssert") || this.hasPlugin("importAssertions") || this.raise(c.ImportAttributesUseAssert, this.state.startLoc), this.hasPlugin("importAssertions") || this.addExtra(e, "deprecatedAssertSyntax", !0), this.next(), t = this.parseImportAttributes()) : t = [];
						!r && this.hasPlugin("importAssertions") ? e.assertions = t : e.attributes = t;
					}
					maybeParseDefaultImportSpecifier(e, t) {
						if (t) {
							const r = this.startNodeAtNode(t);
							return r.local = t, e.specifiers.push(this.finishImportSpecifier(r, "ImportDefaultSpecifier")), !0;
						}
						return !!tokenIsKeywordOrIdentifier(this.state.type) && (this.parseImportSpecifierLocal(e, this.startNode(), "ImportDefaultSpecifier"), !0);
					}
					maybeParseStarImportSpecifier(e) {
						if (this.match(55)) {
							const t = this.startNode();
							return this.next(), this.expectContextual(93), this.parseImportSpecifierLocal(e, t, "ImportNamespaceSpecifier"), !0;
						}
						return !1;
					}
					parseNamedImportSpecifiers(e) {
						let t = !0;
						for (this.expect(5); !this.eat(8);) {
							if (t) t = !1;
							else {
								if (this.eat(14)) throw this.raise(c.DestructureNamedImport, this.state.startLoc);
								if (this.expect(12), this.eat(8)) break;
							}
							const r = this.startNode(), n = this.match(134), s = this.isContextual(130);
							r.imported = this.parseModuleExportName();
							const i = this.parseImportSpecifier(r, n, "type" === e.importKind || "typeof" === e.importKind, s, void 0);
							e.specifiers.push(i);
						}
					}
					parseImportSpecifier(e, t, r, n, s) {
						if (this.eatContextual(93)) e.local = this.parseIdentifier();
						else {
							const { imported: r } = e;
							if (t) throw this.raise(c.ImportBindingIsString, e, { importName: r.value });
							this.checkReservedWord(r.name, e.loc.start, !0, !0), e.local || (e.local = this.cloneIdentifier(r));
						}
						return this.finishImportSpecifier(e, "ImportSpecifier", s);
					}
					isThisParam(e) {
						return "Identifier" === e.type && "this" === e.name;
					}
				}
				class Parser extends StatementParser {
					constructor(e, t, r) {
						super(e = function(e) {
							const t = {
								sourceType: "script",
								sourceFilename: void 0,
								startIndex: 0,
								startColumn: 0,
								startLine: 1,
								allowAwaitOutsideFunction: !1,
								allowReturnOutsideFunction: !1,
								allowNewTargetOutsideFunction: !1,
								allowImportExportEverywhere: !1,
								allowSuperOutsideMethod: !1,
								allowUndeclaredExports: !1,
								allowYieldOutsideFunction: !1,
								plugins: [],
								strictMode: null,
								ranges: !1,
								tokens: !1,
								createImportExpressions: !1,
								createParenthesizedExpressions: !1,
								errorRecovery: !1,
								attachComment: !0,
								annexB: !0
							};
							if (null == e) return t;
							if (null != e.annexB && !1 !== e.annexB) throw new Error("The `annexB` option can only be set to `false`.");
							for (const r of Object.keys(t)) null != e[r] && (t[r] = e[r]);
							if (1 === t.startLine) null == e.startIndex && t.startColumn > 0 ? t.startIndex = t.startColumn : null == e.startColumn && t.startIndex > 0 && (t.startColumn = t.startIndex);
							else if ((null == e.startColumn || null == e.startIndex) && null != e.startIndex) throw new Error("With a `startLine > 1` you must also specify `startIndex` and `startColumn`.");
							if ("commonjs" === t.sourceType) {
								if (null != e.allowAwaitOutsideFunction) throw new Error("The `allowAwaitOutsideFunction` option cannot be used with `sourceType: 'commonjs'`.");
								if (null != e.allowReturnOutsideFunction) throw new Error("`sourceType: 'commonjs'` implies `allowReturnOutsideFunction: true`, please remove the `allowReturnOutsideFunction` option or use `sourceType: 'script'`.");
								if (null != e.allowNewTargetOutsideFunction) throw new Error("`sourceType: 'commonjs'` implies `allowNewTargetOutsideFunction: true`, please remove the `allowNewTargetOutsideFunction` option or use `sourceType: 'script'`.");
							}
							return t;
						}(e), t), this.options = e, this.initializeScopes(), this.plugins = r, this.filename = e.sourceFilename, this.startIndex = e.startIndex;
						let n = 0;
						e.allowAwaitOutsideFunction && (n |= 1), e.allowReturnOutsideFunction && (n |= 2), e.allowImportExportEverywhere && (n |= 8), e.allowSuperOutsideMethod && (n |= 16), e.allowUndeclaredExports && (n |= 64), e.allowNewTargetOutsideFunction && (n |= 4), e.allowYieldOutsideFunction && (n |= 32), e.ranges && (n |= 128), e.tokens && (n |= 256), e.createImportExpressions && (n |= 512), e.createParenthesizedExpressions && (n |= 1024), e.errorRecovery && (n |= 2048), e.attachComment && (n |= 4096), e.annexB && (n |= 8192), this.optionFlags = n;
					}
					getScopeHandler() {
						return ScopeHandler;
					}
					parse() {
						this.enterInitialScopes();
						const e = this.startNode(), t = this.startNode();
						return this.nextToken(), e.errors = null, this.parseTopLevel(e, t), e.errors = this.state.errors, e.comments.length = this.state.commentsLen, e;
					}
				}
				const le = function(e) {
					const t = {};
					for (const r of Object.keys(e)) t[r] = getExportedToken(e[r]);
					return t;
				}(A);
				function getParser(e, t) {
					let r = Parser;
					const n = /* @__PURE__ */ new Map();
					if (null != e && e.plugins) {
						for (const t of e.plugins) {
							let e, r;
							"string" == typeof t ? e = t : [e, r] = t, n.has(e) || n.set(e, r || {});
						}
						(function(e) {
							if (e.has("decorators")) {
								if (e.has("decorators-legacy")) throw new Error("Cannot use the decorators and decorators-legacy plugin together");
								const t = e.get("decorators").decoratorsBeforeExport;
								if (null != t && "boolean" != typeof t) throw new Error("'decoratorsBeforeExport' must be a boolean, if specified.");
								const r = e.get("decorators").allowCallParenthesized;
								if (null != r && "boolean" != typeof r) throw new Error("'allowCallParenthesized' must be a boolean.");
							}
							if (e.has("flow") && e.has("typescript")) throw new Error("Cannot combine flow and typescript plugins.");
							if (e.has("placeholders") && e.has("v8intrinsic")) throw new Error("Cannot combine placeholders and v8intrinsic plugins.");
							if (e.has("pipelineOperator")) {
								var t;
								const n = e.get("pipelineOperator").proposal;
								if (!ee.includes(n)) {
									const e = ee.map((e) => `"${e}"`).join(", ");
									throw new Error(`"pipelineOperator" requires "proposal" option whose value must be one of: ${e}.`);
								}
								if ("hack" === n) {
									if (e.has("placeholders")) throw new Error("Cannot combine placeholders plugin and Hack-style pipes.");
									if (e.has("v8intrinsic")) throw new Error("Cannot combine v8intrinsic plugin and Hack-style pipes.");
									const t = e.get("pipelineOperator").topicToken;
									if (!te.includes(t)) {
										const e = te.map((e) => `"${e}"`).join(", ");
										throw new Error(`"pipelineOperator" in "proposal": "hack" mode also requires a "topicToken" option whose value must be one of: ${e}.`);
									}
									var r;
									if ("#" === t && "hash" === (null == (r = e.get("recordAndTuple")) ? void 0 : r.syntaxType)) throw new Error(`Plugin conflict between \`["pipelineOperator", { proposal: "hack", topicToken: "#" }]\` and \`${JSON.stringify(["recordAndTuple", e.get("recordAndTuple")])}\`.`);
								} else if ("smart" === n && "hash" === (null == (t = e.get("recordAndTuple")) ? void 0 : t.syntaxType)) throw new Error(`Plugin conflict between \`["pipelineOperator", { proposal: "smart" }]\` and \`${JSON.stringify(["recordAndTuple", e.get("recordAndTuple")])}\`.`);
							}
							if (e.has("moduleAttributes")) {
								if (e.has("deprecatedImportAssert") || e.has("importAssertions")) throw new Error("Cannot combine importAssertions, deprecatedImportAssert and moduleAttributes plugins.");
								if ("may-2020" !== e.get("moduleAttributes").version) throw new Error("The 'moduleAttributes' plugin requires a 'version' option, representing the last proposal update. Currently, the only supported value is 'may-2020'.");
							}
							if (e.has("importAssertions") && e.has("deprecatedImportAssert")) throw new Error("Cannot combine importAssertions and deprecatedImportAssert plugins.");
							if (!e.has("deprecatedImportAssert") && e.has("importAttributes") && e.get("importAttributes").deprecatedAssertSyntax && e.set("deprecatedImportAssert", {}), e.has("recordAndTuple")) {
								const t = e.get("recordAndTuple").syntaxType;
								if (null != t) {
									const e = ["hash", "bar"];
									if (!e.includes(t)) throw new Error("The 'syntaxType' option of the 'recordAndTuple' plugin must be one of: " + e.map((e) => `'${e}'`).join(", "));
								}
							}
							if (e.has("asyncDoExpressions") && !e.has("doExpressions")) {
								const e = /* @__PURE__ */ new Error("'asyncDoExpressions' requires 'doExpressions', please add 'doExpressions' to parser plugins.");
								throw e.missingPlugins = "doExpressions", e;
							}
							if (e.has("optionalChainingAssign") && "2023-07" !== e.get("optionalChainingAssign").version) throw new Error("The 'optionalChainingAssign' plugin requires a 'version' option, representing the last proposal update. Currently, the only supported value is '2023-07'.");
							if (e.has("discardBinding") && "void" !== e.get("discardBinding").syntaxType) throw new Error("The 'discardBinding' plugin requires a 'syntaxType' option. Currently the only supported value is 'void'.");
						})(n), r = function(e) {
							const t = [];
							for (const r of ne) e.has(r) && t.push(r);
							const r = t.join("|");
							let n = pe.get(r);
							if (!n) {
								n = Parser;
								for (const e of t) n = re[e](n);
								pe.set(r, n);
							}
							return n;
						}(n);
					}
					return new r(e, t, n);
				}
				const pe = /* @__PURE__ */ new Map();
				t.parse = function(e, t) {
					var r;
					if ("unambiguous" !== (null == (r = t) ? void 0 : r.sourceType)) return getParser(t, e).parse();
					t = Object.assign({}, t);
					try {
						t.sourceType = "module";
						const r = getParser(t, e), n = r.parse();
						if (r.sawUnambiguousESM) return n;
						if (r.ambiguousScriptDifferentAst) try {
							return t.sourceType = "script", getParser(t, e).parse();
						} catch (e) {}
						else n.program.sourceType = "script";
						return n;
					} catch (r) {
						try {
							return t.sourceType = "script", getParser(t, e).parse();
						} catch (e) {}
						throw r;
					}
				}, t.parseExpression = function(e, t) {
					const r = getParser(t, e);
					return r.options.strictMode && (r.state.strict = !0), r.getExpression();
				}, t.tokTypes = le;
			},
			"./node_modules/.pnpm/@babel+plugin-proposal-decorators@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-proposal-decorators/lib/index.js": function(e, t, r) {
				"use strict";
				t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js"), s = r("./node_modules/.pnpm/@babel+plugin-syntax-decorators@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-decorators/lib/index.js"), i = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/index.js"), o = r("./node_modules/.pnpm/@babel+plugin-proposal-decorators@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-proposal-decorators/lib/transformer-legacy.js");
				t.default = (0, n.declare)((e, t) => {
					e.assertVersion(7);
					var { legacy: r } = t;
					const { version: n } = t;
					if (r || "legacy" === n) return {
						name: "proposal-decorators",
						inherits: s.default,
						visitor: o.default
					};
					if (n && "2018-09" !== n && "2021-12" !== n && "2022-03" !== n && "2023-01" !== n && "2023-05" !== n && "2023-11" !== n) throw new Error("The '.version' option must be one of 'legacy', '2023-11', '2023-05', '2023-01', '2022-03', or '2021-12'.");
					return e.assertVersion("^7.0.2"), (0, i.createClassFeaturePlugin)({
						name: "proposal-decorators",
						api: e,
						feature: i.FEATURES.decorators,
						inherits: s.default,
						decoratorVersion: n
					});
				});
			},
			"./node_modules/.pnpm/@babel+plugin-proposal-decorators@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-proposal-decorators/lib/transformer-legacy.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js");
				const s = n.template.statement("\n  DECORATOR(CLASS_REF = INNER) || CLASS_REF;\n"), i = (0, n.template)("\n  CLASS_REF.prototype;\n"), o = (0, n.template)("\n    Object.getOwnPropertyDescriptor(TARGET, PROPERTY);\n"), a = (0, n.template)("\n    (TEMP = Object.getOwnPropertyDescriptor(TARGET, PROPERTY), (TEMP = TEMP ? TEMP.value : undefined), {\n        enumerable: true,\n        configurable: true,\n        writable: true,\n        initializer: function(){\n            return TEMP;\n        }\n    })\n"), l = /* @__PURE__ */ new WeakSet();
				function applyEnsureOrdering(e) {
					const t = (e.isClass() ? [e, ...e.get("body.body")] : e.get("properties")).reduce((e, t) => e.concat(t.node.decorators || []), []).filter((e) => !n.types.isIdentifier(e.expression));
					if (0 !== t.length) return n.types.sequenceExpression(t.map((t) => {
						const r = t.expression, s = t.expression = e.scope.generateDeclaredUidIdentifier("dec");
						return n.types.assignmentExpression("=", s, r);
					}).concat([e.node]));
				}
				function hasClassDecorators(e) {
					var t;
					return !(null == (t = e.decorators) || !t.length);
				}
				function hasMethodDecorators(e) {
					return e.some((e) => {
						var t;
						return null == (t = e.decorators) ? void 0 : t.length;
					});
				}
				function applyTargetDecorators(e, t, r) {
					const s = e.scope.generateDeclaredUidIdentifier(e.isClass() ? "class" : "obj"), p = r.reduce(function(r, p) {
						let c = [];
						if (null != p.decorators && (c = p.decorators, p.decorators = null), 0 === c.length) return r;
						if (p.computed) throw e.buildCodeFrameError("Computed method/property decorators are not yet supported.");
						const u = n.types.isLiteral(p.key) ? p.key : n.types.stringLiteral(p.key.name), d = e.isClass() && !p.static ? i({ CLASS_REF: s }).expression : s;
						if (n.types.isClassProperty(p, { static: !1 })) {
							const s = e.scope.generateDeclaredUidIdentifier("descriptor"), i = p.value ? n.types.functionExpression(null, [], n.types.blockStatement([n.types.returnStatement(p.value)])) : n.types.nullLiteral();
							p.value = n.types.callExpression(t.addHelper("initializerWarningHelper"), [s, n.types.thisExpression()]), l.add(p.value), r.push(n.types.assignmentExpression("=", n.types.cloneNode(s), n.types.callExpression(t.addHelper("applyDecoratedDescriptor"), [
								n.types.cloneNode(d),
								n.types.cloneNode(u),
								n.types.arrayExpression(c.map((e) => n.types.cloneNode(e.expression))),
								n.types.objectExpression([
									n.types.objectProperty(n.types.identifier("configurable"), n.types.booleanLiteral(!0)),
									n.types.objectProperty(n.types.identifier("enumerable"), n.types.booleanLiteral(!0)),
									n.types.objectProperty(n.types.identifier("writable"), n.types.booleanLiteral(!0)),
									n.types.objectProperty(n.types.identifier("initializer"), i)
								])
							])));
						} else r.push(n.types.callExpression(t.addHelper("applyDecoratedDescriptor"), [
							n.types.cloneNode(d),
							n.types.cloneNode(u),
							n.types.arrayExpression(c.map((e) => n.types.cloneNode(e.expression))),
							n.types.isObjectProperty(p) || n.types.isClassProperty(p, { static: !0 }) ? a({
								TEMP: e.scope.generateDeclaredUidIdentifier("init"),
								TARGET: n.types.cloneNode(d),
								PROPERTY: n.types.cloneNode(u)
							}).expression : o({
								TARGET: n.types.cloneNode(d),
								PROPERTY: n.types.cloneNode(u)
							}).expression,
							n.types.cloneNode(d)
						]));
						return r;
					}, []);
					return n.types.sequenceExpression([
						n.types.assignmentExpression("=", n.types.cloneNode(s), e.node),
						n.types.sequenceExpression(p),
						n.types.cloneNode(s)
					]);
				}
				function decoratedClassToExpression({ node: e, scope: t }) {
					if (!hasClassDecorators(e) && !hasMethodDecorators(e.body.body)) return;
					const r = e.id ? n.types.cloneNode(e.id) : t.generateUidIdentifier("class");
					return n.types.variableDeclaration("let", [n.types.variableDeclarator(r, n.types.toExpression(e))]);
				}
				t.default = {
					ExportDefaultDeclaration(e) {
						const t = e.get("declaration");
						if (!t.isClassDeclaration()) return;
						const r = decoratedClassToExpression(t);
						if (r) {
							const [s] = e.replaceWithMultiple([r, n.types.exportNamedDeclaration(null, [n.types.exportSpecifier(n.types.cloneNode(r.declarations[0].id), n.types.identifier("default"))])]);
							t.node.id || e.scope.registerDeclaration(s);
						}
					},
					ClassDeclaration(e) {
						const t = decoratedClassToExpression(e);
						if (t) {
							const [r] = e.replaceWith(t), n = r.get("declarations.0"), s = n.node.id, i = e.scope.getOwnBinding(s.name);
							i.identifier = s, i.path = n;
						}
					},
					ClassExpression(e, t) {
						const r = applyEnsureOrdering(e) || function(e) {
							if (!hasClassDecorators(e.node)) return;
							const t = e.node.decorators || [];
							e.node.decorators = null;
							const r = e.scope.generateDeclaredUidIdentifier("class");
							return t.map((e) => e.expression).reverse().reduce(function(e, t) {
								return s({
									CLASS_REF: n.types.cloneNode(r),
									DECORATOR: n.types.cloneNode(t),
									INNER: e
								}).expression;
							}, e.node);
						}(e) || function(e, t) {
							if (hasMethodDecorators(e.node.body.body)) return applyTargetDecorators(e, t, e.node.body.body);
						}(e, t);
						r && e.replaceWith(r);
					},
					ObjectExpression(e, t) {
						const r = applyEnsureOrdering(e) || function(e, t) {
							if (hasMethodDecorators(e.node.properties)) return applyTargetDecorators(e, t, e.node.properties.filter((e) => "SpreadElement" !== e.type));
						}(e, t);
						r && e.replaceWith(r);
					},
					AssignmentExpression(e, t) {
						l.has(e.node.right) && e.replaceWith(n.types.callExpression(t.addHelper("initializerDefineProperty"), [
							n.types.cloneNode(e.get("left.object").node),
							n.types.stringLiteral(e.get("left.property").node.name || e.get("left.property").node.value),
							n.types.cloneNode(e.get("right.arguments")[0].node),
							n.types.cloneNode(e.get("right.arguments")[1].node)
						]));
					},
					CallExpression(e, t) {
						3 === e.node.arguments.length && l.has(e.node.arguments[2]) && e.node.callee.name === t.addHelper("defineProperty").name && e.replaceWith(n.types.callExpression(t.addHelper("initializerDefineProperty"), [
							n.types.cloneNode(e.get("arguments")[0].node),
							n.types.cloneNode(e.get("arguments")[1].node),
							n.types.cloneNode(e.get("arguments.2.arguments")[0].node),
							n.types.cloneNode(e.get("arguments.2.arguments")[1].node)
						]));
					}
				};
			},
			"./node_modules/.pnpm/@babel+plugin-syntax-decorators@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-decorators/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				t.default = (0, r("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js").declare)((e, t) => {
					e.assertVersion("^7.0.0-0 || >8.0.0-alpha <8.0.0-beta");
					let { version: r } = t;
					{
						const { legacy: e } = t;
						if (void 0 !== e) {
							if ("boolean" != typeof e) throw new Error(".legacy must be a boolean.");
							if (void 0 !== r) throw new Error("You can either use the .legacy or the .version option, not both.");
						}
						if (void 0 === r) r = e ? "legacy" : "2018-09";
						else if ("2023-11" !== r && "2023-05" !== r && "2023-01" !== r && "2022-03" !== r && "2021-12" !== r && "2018-09" !== r && "legacy" !== r) throw new Error("Unsupported decorators version: " + r);
						var { decoratorsBeforeExport: n } = t;
						if (void 0 === n) {
							if ("2021-12" === r || "2022-03" === r) n = !1;
							else if ("2018-09" === r) throw new Error("The decorators plugin, when .version is '2018-09' or not specified, requires a 'decoratorsBeforeExport' option, whose value must be a boolean.");
						} else {
							if ("legacy" === r || "2022-03" === r || "2023-01" === r) throw new Error(`'decoratorsBeforeExport' can't be used with ${r} decorators.`);
							if ("boolean" != typeof n) throw new Error("'decoratorsBeforeExport' must be a boolean.");
						}
					}
					return {
						name: "syntax-decorators",
						manipulateOptions({ generatorOpts: e }, t) {
							"legacy" === r ? t.plugins.push("decorators-legacy") : "2023-01" === r || "2023-05" === r || "2023-11" === r ? t.plugins.push(["decorators", { allowCallParenthesized: !1 }], "decoratorAutoAccessors") : "2022-03" === r ? t.plugins.push(["decorators", {
								decoratorsBeforeExport: !1,
								allowCallParenthesized: !1
							}], "decoratorAutoAccessors") : "2021-12" === r ? (t.plugins.push(["decorators", { decoratorsBeforeExport: n }], "decoratorAutoAccessors"), e.decoratorsBeforeExport = n) : "2018-09" === r && (t.plugins.push(["decorators", { decoratorsBeforeExport: n }]), e.decoratorsBeforeExport = n);
						}
					};
				});
			},
			"./node_modules/.pnpm/@babel+plugin-syntax-import-assertions@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-import-assertions/lib/index.js": function(e, t, r) {
				"use strict";
				t.default = void 0;
				t.default = (0, r("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js").declare)((e) => {
					e.assertVersion(7);
					const isPlugin = (e, t) => "plugin" === t || Array.isArray(e) && "plugin" === e[0], options = (e) => Array.isArray(e) && e.length > 1 ? e[1] : {};
					return {
						name: "syntax-import-assertions",
						manipulateOptions(e, { plugins: t }) {
							for (let e = 0; e < t.length; e++) {
								const r = t[e];
								if (isPlugin(r, "deprecatedImportAssert")) return;
								if (isPlugin(r, "importAttributes")) return void t.splice(e, 1, "deprecatedImportAssert", ["importAttributes", Object.assign({}, options(r), { deprecatedAssertSyntax: !0 })]);
							}
							t.push("importAssertions");
						}
					};
				});
			},
			"./node_modules/.pnpm/@babel+plugin-syntax-jsx@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-jsx/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				t.default = (0, r("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js").declare)((e) => (e.assertVersion(7), {
					name: "syntax-jsx",
					manipulateOptions(e, t) {
						t.plugins.some((e) => "typescript" === (Array.isArray(e) ? e[0] : e)) || t.plugins.push("jsx");
					}
				}));
			},
			"./node_modules/.pnpm/@babel+plugin-syntax-typescript@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-typescript/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js"), removePlugin = function(e, t) {
					const r = [];
					e.forEach((e, n) => {
						(Array.isArray(e) ? e[0] : e) === t && r.unshift(n);
					});
					for (const t of r) e.splice(t, 1);
				};
				t.default = (0, n.declare)((e, t) => {
					e.assertVersion(7);
					const { disallowAmbiguousJSXLike: r, dts: n } = t;
					var { isTSX: s } = t;
					return {
						name: "syntax-typescript",
						manipulateOptions(e, t) {
							{
								const { plugins: e } = t;
								removePlugin(e, "flow"), removePlugin(e, "jsx"), e.push("objectRestSpread", "classProperties"), s && e.push("jsx");
							}
							t.plugins.push(["typescript", {
								disallowAmbiguousJSXLike: r,
								dts: n
							}]);
						}
					};
				});
			},
			"./node_modules/.pnpm/@babel+plugin-transform-export-namespace-from@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-export-namespace-from/lib/index.js": function(e, t, r) {
				"use strict";
				t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js"), s = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js");
				t.default = (0, n.declare)((e) => (e.assertVersion(7), {
					name: "transform-export-namespace-from",
					manipulateOptions: (e, t) => t.plugins.push("exportNamespaceFrom"),
					visitor: { ExportNamedDeclaration(e) {
						var t;
						const { node: r, scope: n } = e, { specifiers: i } = r, o = s.types.isExportDefaultSpecifier(i[0]) ? 1 : 0;
						if (!s.types.isExportNamespaceSpecifier(i[o])) return;
						const a = [];
						1 === o && a.push(s.types.exportNamedDeclaration(null, [i.shift()], r.source));
						const { exported: p } = i.shift(), c = n.generateUidIdentifier(null != (t = p.name) ? t : p.value);
						a.push(s.types.importDeclaration([s.types.importNamespaceSpecifier(c)], s.types.cloneNode(r.source)), s.types.exportNamedDeclaration(null, [s.types.exportSpecifier(s.types.cloneNode(c), p)])), r.specifiers.length >= 1 && a.push(r);
						const [u] = e.replaceWithMultiple(a);
						e.scope.registerDeclaration(u);
					} }
				}));
			},
			"./node_modules/.pnpm/@babel+plugin-transform-modules-commonjs@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-modules-commonjs/lib/dynamic-import.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.transformDynamicImport = function(e, t, r) {
					const n = t ? requireNoInterop : requireInterop;
					e.replaceWith((0, s.buildDynamicImport)(e.node, !0, !1, (e) => n(e, r)));
				};
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), s = r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/index.js");
				const requireNoInterop = (e) => n.template.expression.ast`require(${e})`, requireInterop = (e, t) => n.types.callExpression(t.addHelper("interopRequireWildcard"), [requireNoInterop(e)]);
			},
			"./node_modules/.pnpm/@babel+plugin-transform-modules-commonjs@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-modules-commonjs/lib/hooks.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.defineCommonJSHook = function(e, t) {
					let n = e.get(r);
					n || e.set(r, n = []);
					n.push(t);
				}, t.makeInvokers = function(e) {
					const t = e.get(r);
					return {
						getWrapperPayload: (...e) => findMap(t, (t) => null == t.getWrapperPayload ? void 0 : t.getWrapperPayload(...e)),
						wrapReference: (...e) => findMap(t, (t) => null == t.wrapReference ? void 0 : t.wrapReference(...e)),
						buildRequireWrapper: (...e) => findMap(t, (t) => null == t.buildRequireWrapper ? void 0 : t.buildRequireWrapper(...e))
					};
				};
				const r = "@babel/plugin-transform-modules-commonjs/customWrapperPlugin";
				function findMap(e, t) {
					if (e) for (const r of e) {
						const e = t(r);
						if (null != e) return e;
					}
				}
			},
			"./node_modules/.pnpm/@babel+plugin-transform-modules-commonjs@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-modules-commonjs/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0, Object.defineProperty(t, "defineCommonJSHook", {
					enumerable: !0,
					get: function() {
						return l.defineCommonJSHook;
					}
				});
				var n = r("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js"), s = r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/index.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), o = r("./node_modules/.pnpm/@babel+plugin-transform-modules-commonjs@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-modules-commonjs/lib/dynamic-import.js"), a = r("./node_modules/.pnpm/@babel+plugin-transform-modules-commonjs@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-modules-commonjs/lib/lazy.js"), l = r("./node_modules/.pnpm/@babel+plugin-transform-modules-commonjs@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-modules-commonjs/lib/hooks.js");
				t.default = (0, n.declare)((e, t) => {
					var r, n, p;
					e.assertVersion(7);
					const { strictNamespace: c = !1, mjsStrictNamespace: u = c, allowTopLevelThis: d, strict: h, strictMode: m, noInterop: f, importInterop: y, lazy: b = !1, allowCommonJSExports: g = !0, loose: x = !1 } = t, v = null != (r = e.assumption("constantReexports")) ? r : x, E = null != (n = e.assumption("enumerableModuleMeta")) ? n : x, T = null != (p = e.assumption("noIncompleteNsImportDetection")) && p;
					if (!("boolean" == typeof b || "function" == typeof b || Array.isArray(b) && b.every((e) => "string" == typeof e))) throw new Error(".lazy must be a boolean, array of strings, or a function");
					if ("boolean" != typeof c) throw new Error(".strictNamespace must be a boolean, or undefined");
					if ("boolean" != typeof u) throw new Error(".mjsStrictNamespace must be a boolean, or undefined");
					const getAssertion = (e) => i.template.expression.ast`
    (function(){
      throw new Error(
        "The CommonJS '" + "${e}" + "' variable is not available in ES6 modules." +
        "Consider setting setting sourceType:script or sourceType:unambiguous in your " +
        "Babel config for this file.");
    })()
  `, S = {
						ReferencedIdentifier(e) {
							const t = e.node.name;
							if ("module" !== t && "exports" !== t) return;
							const r = e.scope.getBinding(t);
							this.scope.getBinding(t) !== r || e.parentPath.isObjectProperty({ value: e.node }) && e.parentPath.parentPath.isObjectPattern() || e.parentPath.isAssignmentExpression({ left: e.node }) || e.isAssignmentExpression({ left: e.node }) || e.replaceWith(getAssertion(t));
						},
						UpdateExpression(e) {
							const t = e.get("argument");
							if (!t.isIdentifier()) return;
							const r = t.node.name;
							if ("module" !== r && "exports" !== r) return;
							const n = e.scope.getBinding(r);
							this.scope.getBinding(r) === n && e.replaceWith(i.types.assignmentExpression(e.node.operator[0] + "=", t.node, getAssertion(r)));
						},
						AssignmentExpression(e) {
							const t = e.get("left");
							if (t.isIdentifier()) {
								const r = t.node.name;
								if ("module" !== r && "exports" !== r) return;
								const n = e.scope.getBinding(r);
								if (this.scope.getBinding(r) !== n) return;
								const s = e.get("right");
								s.replaceWith(i.types.sequenceExpression([s.node, getAssertion(r)]));
							} else if (t.isPattern()) {
								const r = t.getOuterBindingIdentifiers(), n = Object.keys(r).find((t) => ("module" === t || "exports" === t) && this.scope.getBinding(t) === e.scope.getBinding(t));
								if (n) {
									const t = e.get("right");
									t.replaceWith(i.types.sequenceExpression([t.node, getAssertion(n)]));
								}
							}
						}
					};
					return {
						name: "transform-modules-commonjs",
						pre() {
							this.file.set("@babel/plugin-transform-modules-*", "commonjs"), b && (0, l.defineCommonJSHook)(this.file, (0, a.lazyImportsHook)(b));
						},
						visitor: {
							["CallExpression" + (e.types.importExpression ? "|ImportExpression" : "")](e) {
								if (!this.file.has("@babel/plugin-proposal-dynamic-import")) return;
								if (e.isCallExpression() && !i.types.isImport(e.node.callee)) return;
								let { scope: t } = e;
								do
									t.rename("require");
								while (t = t.parent);
								(0, o.transformDynamicImport)(e, f, this.file);
							},
							Program: { exit(e, r) {
								if (!(0, s.isModule)(e)) return;
								e.scope.rename("exports"), e.scope.rename("module"), e.scope.rename("require"), e.scope.rename("__filename"), e.scope.rename("__dirname"), g || e.traverse(S, { scope: e.scope });
								let n = (0, s.getModuleName)(this.file.opts, t);
								n && (n = i.types.stringLiteral(n));
								const o = (0, l.makeInvokers)(this.file), { meta: a, headers: p } = (0, s.rewriteModuleStatementsAndPrepareHeader)(e, {
									exportName: "exports",
									constantReexports: v,
									enumerableModuleMeta: E,
									strict: h,
									strictMode: m,
									allowTopLevelThis: d,
									noInterop: f,
									importInterop: y,
									wrapReference: o.wrapReference,
									getWrapperPayload: o.getWrapperPayload,
									esNamespaceOnly: "string" == typeof r.filename && /\.mjs$/.test(r.filename) ? u : c,
									noIncompleteNsImportDetection: T,
									filename: this.file.opts.filename
								});
								for (const [t, r] of a.source) {
									const n = i.types.callExpression(i.types.identifier("require"), [i.types.stringLiteral(t)]);
									let l;
									if ((0, s.isSideEffectImport)(r)) {
										if (b && "function" === r.wrap) throw new Error("Assertion failure");
										l = i.types.expressionStatement(n);
									} else {
										const t = (0, s.wrapInterop)(e, n, r.interop) || n;
										if (r.wrap) {
											const e = o.buildRequireWrapper(r.name, t, r.wrap, r.referenced);
											if (!1 === e) continue;
											l = e;
										}
										l ?? (l = i.template.statement.ast`
                var ${r.name} = ${t};
              `);
									}
									l.loc = r.loc, p.push(l), p.push(...(0, s.buildNamespaceInitStatements)(a, r, v, o.wrapReference));
								}
								(0, s.ensureStatementsHoisted)(p), e.unshiftContainer("body", p), e.get("body").forEach((e) => {
									p.includes(e.node) && e.isVariableDeclaration() && e.scope.registerDeclaration(e);
								});
							} }
						}
					};
				});
			},
			"./node_modules/.pnpm/@babel+plugin-transform-modules-commonjs@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-modules-commonjs/lib/lazy.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.lazyImportsHook = void 0;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), s = r("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/index.js");
				t.lazyImportsHook = (e) => ({
					name: "@babel/plugin-transform-modules-commonjs/lazy",
					version: "7.27.1",
					getWrapperPayload: (t, r) => (0, s.isSideEffectImport)(r) || r.reexportAll ? null : !0 === e ? t.includes(".") ? null : "lazy/function" : Array.isArray(e) ? e.includes(t) ? "lazy/function" : null : "function" == typeof e ? e(t) ? "lazy/function" : null : void 0,
					buildRequireWrapper(e, t, r, s) {
						if ("lazy/function" === r) return !!s && n.template.statement.ast`
        function ${e}() {
          const data = ${t};
          ${e} = function(){ return data; };
          return data;
        }
      `;
					},
					wrapReference(e, t) {
						if ("lazy/function" === t) return n.types.callExpression(e, []);
					}
				});
			},
			"./node_modules/.pnpm/@babel+plugin-transform-react-jsx@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-react-jsx/lib/create-plugin.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function({ name: e, development: t }) {
					return (0, s.declare)((r, s) => {
						const { pure: h, throwIfNamespace: m = !0, filter: f, runtime: y = t ? "automatic" : "classic", importSource: b = l.importSource, pragma: g = l.pragma, pragmaFrag: x = l.pragmaFrag } = s;
						var { useSpread: v = !1, useBuiltIns: E = !1 } = s;
						if ("classic" === y) {
							if ("boolean" != typeof v) throw new Error("transform-react-jsx currently only accepts a boolean option for useSpread (defaults to false)");
							if ("boolean" != typeof E) throw new Error("transform-react-jsx currently only accepts a boolean option for useBuiltIns (defaults to false)");
							if (v && E) throw new Error("transform-react-jsx currently only accepts useBuiltIns or useSpread but not both");
						}
						const T = { JSXOpeningElement(e, t) {
							const r = [];
							(function(e) {
								do {
									const { path: t } = e;
									if (t.isFunctionParent() && !t.isArrowFunctionExpression()) return !t.isMethod() || "constructor" !== t.node.kind || !isDerivedClass(t.parentPath.parentPath);
									if (t.isTSModuleBlock()) return !1;
								} while (e = e.parent);
								return !0;
							})(e.scope) && r.push(i.types.jsxAttribute(i.types.jsxIdentifier("__self"), i.types.jsxExpressionContainer(i.types.thisExpression()))), r.push(i.types.jsxAttribute(i.types.jsxIdentifier("__source"), i.types.jsxExpressionContainer(function(e, t) {
								const r = e.node.loc;
								if (!r) return e.scope.buildUndefinedNode();
								if (!t.fileNameIdentifier) {
									const { filename: r = "" } = t, n = e.scope.generateUidIdentifier("_jsxFileName");
									e.scope.getProgramParent().push({
										id: n,
										init: i.types.stringLiteral(r)
									}), t.fileNameIdentifier = n;
								}
								return function(e, t, r) {
									const n = null != t ? i.types.numericLiteral(t) : i.types.nullLiteral(), s = null != r ? i.types.numericLiteral(r + 1) : i.types.nullLiteral();
									return i.template.expression.ast`{
    fileName: ${e},
    lineNumber: ${n},
    columnNumber: ${s},
  }`;
								}(i.types.cloneNode(t.fileNameIdentifier), r.start.line, r.start.column);
							}(e, t)))), e.pushContainer("attributes", r);
						} };
						return {
							name: e,
							inherits: n.default,
							visitor: {
								JSXNamespacedName(e) {
									if (m) throw e.buildCodeFrameError("Namespace tags are not supported by default. React's JSX doesn't support namespace tags. You can set `throwIfNamespace: false` to bypass this warning.");
								},
								JSXSpreadChild(e) {
									throw e.buildCodeFrameError("Spread children are not supported in React.");
								},
								Program: { enter(e, r) {
									const { file: n } = r;
									let a = y, h = b, m = g, f = x, v = !!s.importSource, E = !!s.pragma, S = !!s.pragmaFrag;
									if (n.ast.comments) for (const e of n.ast.comments) {
										const t = p.exec(e.value);
										t && (h = t[1], v = !0);
										const r = c.exec(e.value);
										r && (a = r[1]);
										const n = u.exec(e.value);
										n && (m = n[1], E = !0);
										const s = d.exec(e.value);
										s && (f = s[1], S = !0);
									}
									if (set(r, "runtime", a), "classic" === a) {
										if (v) throw e.buildCodeFrameError("importSource cannot be set when runtime is classic.");
										const t = toMemberExpression(m), n = toMemberExpression(f);
										set(r, "id/createElement", () => i.types.cloneNode(t)), set(r, "id/fragment", () => i.types.cloneNode(n)), set(r, "defaultPure", m === l.pragma);
									} else {
										if ("automatic" !== a) throw e.buildCodeFrameError("Runtime must be either \"classic\" or \"automatic\".");
										{
											if (E || S) throw e.buildCodeFrameError("pragma and pragmaFrag cannot be set when runtime is automatic.");
											const define = (n, s) => set(r, n, function(e, r, n, s) {
												return () => {
													const a = function(e, r) {
														switch (r) {
															case "Fragment": return `${e}/${t ? "jsx-dev-runtime" : "jsx-runtime"}`;
															case "jsxDEV": return `${e}/jsx-dev-runtime`;
															case "jsx":
															case "jsxs": return `${e}/jsx-runtime`;
															case "createElement": return e;
														}
													}(s, n);
													if ((0, o.isModule)(r)) {
														let t = get(e, `imports/${n}`);
														return t ? i.types.cloneNode(t) : (t = (0, o.addNamed)(r, n, a, {
															importedInterop: "uncompiled",
															importPosition: "after"
														}), set(e, `imports/${n}`, t), t);
													}
													{
														let t = get(e, `requires/${a}`);
														return t ? t = i.types.cloneNode(t) : (t = (0, o.addNamespace)(r, a, { importedInterop: "uncompiled" }), set(e, `requires/${a}`, t)), i.types.memberExpression(t, i.types.identifier(n));
													}
												};
											}(r, e, s, h));
											define("id/jsx", t ? "jsxDEV" : "jsx"), define("id/jsxs", t ? "jsxDEV" : "jsxs"), define("id/createElement", "createElement"), define("id/fragment", "Fragment"), set(r, "defaultPure", h === l.importSource);
										}
									}
									t && e.traverse(T, r);
								} },
								JSXFragment: { exit(e, r) {
									let n;
									n = "classic" === get(r, "runtime") ? function(e, t) {
										if (f && !f(e.node, t)) return;
										return call(t, "createElement", [
											get(t, "id/fragment")(),
											i.types.nullLiteral(),
											...i.types.react.buildChildren(e.node)
										]);
									}(e, r) : function(e, r) {
										const n = [get(r, "id/fragment")()], s = i.types.react.buildChildren(e.node);
										n.push(i.types.objectExpression(s.length > 0 ? [buildChildrenProperty(s)] : [])), t && n.push(e.scope.buildUndefinedNode(), i.types.booleanLiteral(s.length > 1));
										return call(r, s.length > 1 ? "jsxs" : "jsx", n);
									}(e, r), e.replaceWith(i.types.inherits(n, e.node));
								} },
								JSXElement: { exit(e, r) {
									let n;
									n = "classic" === get(r, "runtime") || function(e) {
										const r = e.get("openingElement").node.attributes;
										let n = !1;
										for (let e = 0; e < r.length; e++) {
											const t = r[e];
											if (n && i.types.isJSXAttribute(t) && "key" === t.name.name) return !0;
											i.types.isJSXSpreadAttribute(t) && (n = !0);
										}
										return !1;
									}(e) ? function(e, t) {
										const r = e.get("openingElement");
										return call(t, "createElement", [
											getTag(r),
											buildCreateElementOpeningElementAttributes(t, e, r.get("attributes")),
											...i.types.react.buildChildren(e.node)
										]);
									}(e, r) : function(e, r) {
										const n = e.get("openingElement"), s = [getTag(n)], o = [], a = Object.create(null);
										for (const t of n.get("attributes")) if (t.isJSXAttribute() && i.types.isJSXIdentifier(t.node.name)) {
											const { name: r } = t.node.name;
											switch (r) {
												case "__source":
												case "__self": if (a[r]) throw sourceSelfError(e, r);
												case "key": {
													const e = convertAttributeValue(t.node.value);
													if (null === e) throw t.buildCodeFrameError("Please provide an explicit key value. Using \"key\" as a shorthand for \"key={true}\" is not allowed.");
													a[r] = e;
													break;
												}
												default: o.push(t);
											}
										} else o.push(t);
										const l = i.types.react.buildChildren(e.node);
										let p;
										p = o.length || l.length ? function(e, t) {
											const r = e.reduce(accumulateAttribute, []);
											(null == t ? void 0 : t.length) > 0 && r.push(buildChildrenProperty(t));
											return i.types.objectExpression(r);
										}(o, l) : i.types.objectExpression([]);
										if (s.push(p), t) {
											var c;
											s.push(null != (c = a.key) ? c : e.scope.buildUndefinedNode(), i.types.booleanLiteral(l.length > 1)), a.__source ? (s.push(a.__source), a.__self && s.push(a.__self)) : a.__self && s.push(e.scope.buildUndefinedNode(), a.__self);
										} else void 0 !== a.key && s.push(a.key);
										return call(r, l.length > 1 ? "jsxs" : "jsx", s);
									}(e, r), e.replaceWith(i.types.inherits(n, e.node));
								} },
								JSXAttribute(e) {
									i.types.isJSXElement(e.node.value) && (e.node.value = i.types.jsxExpressionContainer(e.node.value));
								}
							}
						};
						function isDerivedClass(e) {
							return null !== e.node.superClass;
						}
						function call(e, t, r) {
							const n = i.types.callExpression(get(e, `id/${t}`)(), r);
							return (null != h ? h : get(e, "defaultPure")) && (0, a.default)(n), n;
						}
						function convertJSXIdentifier(e, t) {
							return i.types.isJSXIdentifier(e) ? "this" === e.name && i.types.isReferenced(e, t) ? i.types.thisExpression() : i.types.isValidIdentifier(e.name, !1) ? (e.type = "Identifier", e) : i.types.stringLiteral(e.name) : i.types.isJSXMemberExpression(e) ? i.types.memberExpression(convertJSXIdentifier(e.object, e), convertJSXIdentifier(e.property, e)) : i.types.isJSXNamespacedName(e) ? i.types.stringLiteral(`${e.namespace.name}:${e.name.name}`) : e;
						}
						function convertAttributeValue(e) {
							return i.types.isJSXExpressionContainer(e) ? e.expression : e;
						}
						function accumulateAttribute(e, t) {
							if (i.types.isJSXSpreadAttribute(t.node)) {
								const r = t.node.argument;
								return i.types.isObjectExpression(r) && !r.properties.some((e) => i.types.isObjectProperty(e, {
									computed: !1,
									shorthand: !1
								}) && (i.types.isIdentifier(e.key, { name: "__proto__" }) || i.types.isStringLiteral(e.key, { value: "__proto__" }))) ? e.push(...r.properties) : e.push(i.types.spreadElement(r)), e;
							}
							const r = convertAttributeValue("key" !== t.node.name.name ? t.node.value || i.types.booleanLiteral(!0) : t.node.value);
							if ("key" === t.node.name.name && null === r) throw t.buildCodeFrameError("Please provide an explicit key value. Using \"key\" as a shorthand for \"key={true}\" is not allowed.");
							var n;
							i.types.isStringLiteral(r) && !i.types.isJSXExpressionContainer(t.node.value) && (r.value = r.value.replace(/\n\s+/g, " "), null == (n = r.extra) || delete n.raw);
							return i.types.isJSXNamespacedName(t.node.name) ? t.node.name = i.types.stringLiteral(t.node.name.namespace.name + ":" + t.node.name.name.name) : i.types.isValidIdentifier(t.node.name.name, !1) ? t.node.name.type = "Identifier" : t.node.name = i.types.stringLiteral(t.node.name.name), e.push(i.types.inherits(i.types.objectProperty(t.node.name, r), t.node)), e;
						}
						function buildChildrenProperty(e) {
							let t;
							if (1 === e.length) t = e[0];
							else {
								if (!(e.length > 1)) return;
								t = i.types.arrayExpression(e);
							}
							return i.types.objectProperty(i.types.identifier("children"), t);
						}
						function getTag(e) {
							const t = convertJSXIdentifier(e.node.name, e.node);
							let r;
							return i.types.isIdentifier(t) ? r = t.name : i.types.isStringLiteral(t) && (r = t.value), i.types.react.isCompatTag(r) ? i.types.stringLiteral(r) : t;
						}
						function buildCreateElementOpeningElementAttributes(e, t, r) {
							const n = get(e, "runtime");
							if ("automatic" !== n) {
								const t = [], n = r.reduce(accumulateAttribute, []);
								if (v) n.length && t.push(i.types.objectExpression(n));
								else {
									let e = 0;
									n.forEach((r, s) => {
										i.types.isSpreadElement(r) && (s > e && t.push(i.types.objectExpression(n.slice(e, s))), t.push(r.argument), e = s + 1);
									}), n.length > e && t.push(i.types.objectExpression(n.slice(e)));
								}
								if (!t.length) return i.types.nullLiteral();
								if (!(1 !== t.length || i.types.isSpreadElement(n[0]) && i.types.isObjectExpression(n[0].argument))) return t[0];
								i.types.isObjectExpression(t[0]) || t.unshift(i.types.objectExpression([]));
								const s = E ? i.types.memberExpression(i.types.identifier("Object"), i.types.identifier("assign")) : e.addHelper("extends");
								return i.types.callExpression(s, t);
							}
							const s = [], o = Object.create(null);
							for (const e of r) {
								const { node: r } = e, a = i.types.isJSXAttribute(r) && i.types.isJSXIdentifier(r.name) && r.name.name;
								if ("automatic" === n && ("__source" === a || "__self" === a)) {
									if (o[a]) throw sourceSelfError(t, a);
									o[a] = !0;
								}
								accumulateAttribute(s, e);
							}
							return 1 === s.length && i.types.isSpreadElement(s[0]) && !i.types.isObjectExpression(s[0].argument) ? s[0].argument : s.length > 0 ? i.types.objectExpression(s) : i.types.nullLiteral();
						}
					});
				};
				var n = r("./node_modules/.pnpm/@babel+plugin-syntax-jsx@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-jsx/lib/index.js"), s = r("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js"), i = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), o = r("./node_modules/.pnpm/@babel+helper-module-imports@7.27.1/node_modules/@babel/helper-module-imports/lib/index.js"), a = r("./node_modules/.pnpm/@babel+helper-annotate-as-pure@7.27.3/node_modules/@babel/helper-annotate-as-pure/lib/index.js");
				const l = {
					importSource: "react",
					runtime: "automatic",
					pragma: "React.createElement",
					pragmaFrag: "React.Fragment"
				}, p = /^\s*(?:\*\s*)?@jsxImportSource\s+(\S+)\s*$/m, c = /^\s*(?:\*\s*)?@jsxRuntime\s+(\S+)\s*$/m, u = /^\s*(?:\*\s*)?@jsx\s+(\S+)\s*$/m, d = /^\s*(?:\*\s*)?@jsxFrag\s+(\S+)\s*$/m, get = (e, t) => e.get(`@babel/plugin-react-jsx/${t}`), set = (e, t, r) => e.set(`@babel/plugin-react-jsx/${t}`, r);
				function toMemberExpression(e) {
					return e.split(".").map((e) => i.types.identifier(e)).reduce((e, t) => i.types.memberExpression(e, t));
				}
				function sourceSelfError(e, t) {
					const r = `transform-react-jsx-${t.slice(2)}`;
					return e.buildCodeFrameError(`Duplicate ${t} prop found. You are most likely using the deprecated ${r} Babel plugin. Both __source and __self are automatically set when using the automatic runtime. Please remove transform-react-jsx-source and transform-react-jsx-self from your Babel config.`);
				}
			},
			"./node_modules/.pnpm/@babel+plugin-transform-react-jsx@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-react-jsx/lib/index.js": function(e, t, r) {
				"use strict";
				t.default = void 0;
				t.default = (0, r("./node_modules/.pnpm/@babel+plugin-transform-react-jsx@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-react-jsx/lib/create-plugin.js").default)({
					name: "transform-react-jsx",
					development: !1
				});
			},
			"./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/const-enum.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.EXPORTED_CONST_ENUMS_IN_NAMESPACE = void 0, t.default = function(e, t) {
					const { name: r } = e.node.id, i = e.parentPath.isExportNamedDeclaration();
					let o = i;
					!o && t.isProgram(e.parent) && (o = e.parent.body.some((e) => t.isExportNamedDeclaration(e) && "type" !== e.exportKind && !e.source && e.specifiers.some((e) => t.isExportSpecifier(e) && "type" !== e.exportKind && e.local.name === r)));
					const { enumValues: a } = (0, n.translateEnumValues)(e, t);
					if (o || s.has(e.node)) {
						const n = t.objectExpression(a.map(([e, r]) => t.objectProperty(t.isValidIdentifier(e) ? t.identifier(e) : t.stringLiteral(e), r)));
						e.scope.hasOwnBinding(r) ? (i ? e.parentPath : e).replaceWith(t.expressionStatement(t.callExpression(t.memberExpression(t.identifier("Object"), t.identifier("assign")), [e.node.id, n]))) : (e.replaceWith(t.variableDeclaration("var", [t.variableDeclarator(e.node.id, n)])), e.scope.registerDeclaration(e));
						return;
					}
					const l = new Map(a);
					e.scope.path.traverse({
						Scope(e) {
							e.scope.hasOwnBinding(r) && e.skip();
						},
						MemberExpression(e) {
							if (!t.isIdentifier(e.node.object, { name: r })) return;
							let n;
							if (e.node.computed) {
								if (!t.isStringLiteral(e.node.property)) return;
								n = e.node.property.value;
							} else {
								if (!t.isIdentifier(e.node.property)) return;
								n = e.node.property.name;
							}
							l.has(n) && e.replaceWith(t.cloneNode(l.get(n)));
						}
					}), e.remove();
				};
				var n = r("./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/enum.js");
				const s = t.EXPORTED_CONST_ENUMS_IN_NAMESPACE = /* @__PURE__ */ new WeakSet();
			},
			"./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/enum.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					const { node: r, parentPath: n } = e;
					if (r.declare) return void e.remove();
					const s = r.id.name, { fill: o, data: p, isPure: c } = function(e, t, r) {
						const { enumValues: n, data: s, isPure: i } = translateEnumValues(e, t), o = e.get("members"), a = [];
						for (let e = 0; e < o.length; e++) {
							const [s, i] = n[e];
							a.push(t.inheritsComments(buildEnumMember(isSyntacticallyString(i), {
								ENUM: t.cloneNode(r),
								NAME: s,
								VALUE: i
							}), o[e].node));
						}
						return {
							fill: {
								ID: t.cloneNode(r),
								ASSIGNMENTS: a
							},
							data: s,
							isPure: i
						};
					}(e, t, r.id);
					switch (n.type) {
						case "BlockStatement":
						case "ExportNamedDeclaration":
						case "Program": {
							const u = t.isProgram(e.parent), d = function seen(e) {
								if (e.isExportDeclaration()) return seen(e.parentPath);
								return !!e.getData(s) || (e.setData(s, !0), !1);
							}(n);
							let h = t.objectExpression([]);
							(d || u) && (h = t.logicalExpression("||", t.cloneNode(o.ID), h));
							const m = l(Object.assign({}, o, { INIT: h }));
							if (c && (0, i.default)(m), d) (n.isExportDeclaration() ? n : e).replaceWith(t.expressionStatement(t.assignmentExpression("=", t.cloneNode(r.id), m)));
							else e.scope.registerDeclaration(e.replaceWith(t.variableDeclaration(u ? "var" : "let", [t.variableDeclarator(r.id, m)]))[0]);
							a.set(e.scope.getBindingIdentifier(s), p);
							break;
						}
						default: throw new Error(`Unexpected enum parent '${e.parent.type}`);
					}
				}, t.isSyntacticallyString = isSyntacticallyString, t.translateEnumValues = translateEnumValues;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), s = r("assert"), i = r("./node_modules/.pnpm/@babel+helper-annotate-as-pure@7.27.3/node_modules/@babel/helper-annotate-as-pure/lib/index.js"), o = r("./node_modules/.pnpm/@babel+helper-skip-transparent-expression-wrappers@7.27.1/node_modules/@babel/helper-skip-transparent-expression-wrappers/lib/index.js");
				const a = /* @__PURE__ */ new WeakMap(), l = n.template.expression("\n    (function (ID) {\n      ASSIGNMENTS;\n      return ID;\n    })(INIT)\n  ");
				const p = n.template.statement("\n  ENUM[\"NAME\"] = VALUE;\n"), c = n.template.statement("\n  ENUM[ENUM[\"NAME\"] = VALUE] = \"NAME\";\n"), buildEnumMember = (e, t) => (e ? p : c)(t);
				function isSyntacticallyString(e) {
					switch ((e = (0, o.skipTransparentExprWrapperNodes)(e)).type) {
						case "BinaryExpression": {
							const t = e.left, r = e.right;
							return "+" === e.operator && (isSyntacticallyString(t) || isSyntacticallyString(r));
						}
						case "TemplateLiteral":
						case "StringLiteral": return !0;
					}
					return !1;
				}
				function ReferencedIdentifier(e, t) {
					const { seen: r, path: n, t: s } = t, i = e.node.name;
					if (r.has(i)) {
						for (let t = e.scope; t !== n.scope; t = t.parent) if (t.hasOwnBinding(i)) return;
						e.replaceWith(s.memberExpression(s.cloneNode(n.node.id), s.cloneNode(e.node))), e.skip();
					}
				}
				const u = { ReferencedIdentifier };
				function translateEnumValues(e, t) {
					var r;
					const n = e.scope.getBindingIdentifier(e.node.id.name), i = null != (r = a.get(n)) ? r : /* @__PURE__ */ new Map();
					let o, l = -1, p = !0;
					const c = e.get("members").map((r) => {
						const n = r.node, a = t.isIdentifier(n.id) ? n.id.name : n.id.value, c = r.get("initializer");
						let d;
						if (n.initializer) l = computeConstantValue(c, i), void 0 !== l ? (i.set(a, l), s("number" == typeof l || "string" == typeof l), d = l === Infinity || Number.isNaN(l) ? t.identifier(String(l)) : l === -Infinity ? t.unaryExpression("-", t.identifier("Infinity")) : t.valueToNode(l)) : (p && (p = c.isPure()), c.isReferencedIdentifier() ? ReferencedIdentifier(c, {
							t,
							seen: i,
							path: e
						}) : c.traverse(u, {
							t,
							seen: i,
							path: e
						}), d = c.node, i.set(a, void 0));
						else if ("number" == typeof l) l += 1, d = t.numericLiteral(l), i.set(a, l);
						else {
							if ("string" == typeof l) throw e.buildCodeFrameError("Enum member must have initializer.");
							{
								const r = t.memberExpression(t.cloneNode(e.node.id), t.stringLiteral(o), !0);
								d = t.binaryExpression("+", t.numericLiteral(1), r), i.set(a, void 0);
							}
						}
						return o = a, [a, d];
					});
					return {
						isPure: p,
						data: i,
						enumValues: c
					};
				}
				function computeConstantValue(e, t, r = /* @__PURE__ */ new Set()) {
					return evaluate(e);
					function evaluate(e) {
						const n = e.node;
						switch (n.type) {
							case "MemberExpression":
							case "Identifier": return evaluateRef(e, t, r);
							case "StringLiteral":
							case "NumericLiteral": return n.value;
							case "UnaryExpression": return function(e) {
								const t = evaluate(e.get("argument"));
								if (void 0 === t) return;
								switch (e.node.operator) {
									case "+": return t;
									case "-": return -t;
									case "~": return ~t;
									default: return;
								}
							}(e);
							case "BinaryExpression": return function(e) {
								const t = evaluate(e.get("left"));
								if (void 0 === t) return;
								const r = evaluate(e.get("right"));
								if (void 0 === r) return;
								switch (e.node.operator) {
									case "|": return t | r;
									case "&": return t & r;
									case ">>": return t >> r;
									case ">>>": return t >>> r;
									case "<<": return t << r;
									case "^": return t ^ r;
									case "*": return t * r;
									case "/": return t / r;
									case "+": return t + r;
									case "-": return t - r;
									case "%": return t % r;
									case "**": return Math.pow(t, r);
									default: return;
								}
							}(e);
							case "ParenthesizedExpression": return evaluate(e.get("expression"));
							case "TemplateLiteral": {
								if (1 === n.quasis.length) return n.quasis[0].value.cooked;
								const s = e.get("expressions"), i = n.quasis;
								let o = "";
								for (let e = 0; e < i.length; e++) if (o += i[e].value.cooked, e + 1 < i.length) {
									const n = evaluateRef(s[e], t, r);
									if (void 0 === n) return;
									o += n;
								}
								return o;
							}
							default: return;
						}
					}
					function evaluateRef(e, t, r) {
						if (e.isMemberExpression()) {
							const t = e.node, r = t.object, s = t.property;
							if (!n.types.isIdentifier(r) || (t.computed ? !n.types.isStringLiteral(s) : !n.types.isIdentifier(s))) return;
							const i = e.scope.getBindingIdentifier(r.name), o = a.get(i);
							if (!o) return;
							return o.get(s.computed ? s.value : s.name);
						}
						if (e.isIdentifier()) {
							const n = e.node.name;
							if (["Infinity", "NaN"].includes(n)) return Number(n);
							let s = null == t ? void 0 : t.get(n);
							if (void 0 !== s) return s;
							if (null != t && t.has(n)) return;
							if (r.has(e.node)) return;
							return r.add(e.node), s = computeConstantValue(e.resolve(), t, r), s;
						}
					}
				}
			},
			"./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/global-types.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.GLOBAL_TYPES = void 0, t.isGlobalType = function({ scope: e }, t) {
					return !e.hasBinding(t) && (!!r.get(e).has(t) || (console.warn(`The exported identifier "${t}" is not declared in Babel's scope tracker\nas a JavaScript value binding, and "@babel/plugin-transform-typescript"\nnever encountered it as a TypeScript type declaration.\nIt will be treated as a JavaScript value.\n\nThis problem is likely caused by another plugin injecting\n"${t}" without registering it in the scope tracker. If you are the author\n of that plugin, please use "scope.registerDeclaration(declarationPath)".`), !1));
				}, t.registerGlobalType = function(e, t) {
					r.get(e).add(t);
				};
				const r = t.GLOBAL_TYPES = /* @__PURE__ */ new WeakMap();
			},
			"./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js"), s = r("./node_modules/.pnpm/@babel+plugin-syntax-typescript@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-typescript/lib/index.js"), i = r("./node_modules/.pnpm/@babel+helper-create-class-features-plugin@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-create-class-features-plugin/lib/index.js"), o = r("./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/const-enum.js"), a = r("./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/enum.js"), l = r("./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/global-types.js"), p = r("./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/namespace.js");
				function isInType(e) {
					switch (e.parent.type) {
						case "TSTypeReference":
						case "TSExpressionWithTypeArguments":
						case "TSExpressionWithTypeArguments":
						case "TSTypeQuery": return !0;
						case "TSQualifiedName": return "TSImportEqualsDeclaration" !== e.parentPath.findParent((e) => "TSQualifiedName" !== e.type).type;
						case "ExportSpecifier": return "type" === e.parent.exportKind || "type" === e.parentPath.parent.exportKind;
						default: return !1;
					}
				}
				const c = /* @__PURE__ */ new WeakMap(), u = /* @__PURE__ */ new WeakSet();
				function safeRemove(e) {
					const t = e.getBindingIdentifiers();
					for (const r of Object.keys(t)) {
						const n = e.scope.getBinding(r);
						n && n.identifier === t[r] && n.scope.removeBinding(r);
					}
					e.opts.noScope = !0, e.remove(), e.opts.noScope = !1;
				}
				function assertCjsTransformEnabled(e, t, r, n, s = "") {
					if ("commonjs" !== t.file.get("@babel/plugin-transform-modules-*")) throw e.buildCodeFrameError(`\`${r}\` is only supported when compiling modules to CommonJS.\nPlease consider using \`${n}\`${s}, or add @babel/plugin-transform-modules-commonjs to your Babel config.`);
				}
				t.default = (0, n.declare)((e, t) => {
					const { types: r, template: n } = e;
					e.assertVersion(7);
					const d = /\*?\s*@jsx((?:Frag)?)\s+(\S+)/, { allowNamespaces: h = !0, jsxPragma: m = "React.createElement", jsxPragmaFrag: f = "React.Fragment", onlyRemoveTypeImports: y = !1, optimizeConstEnums: b = !1 } = t;
					var { allowDeclareFields: g = !1 } = t;
					const x = {
						field(e) {
							const { node: t } = e;
							if (!g && t.declare) throw e.buildCodeFrameError("The 'declare' modifier is only allowed when the 'allowDeclareFields' option of @babel/plugin-transform-typescript or @babel/preset-typescript is enabled.");
							if (t.declare) {
								if (t.value) throw e.buildCodeFrameError("Fields with the 'declare' modifier cannot be initialized here, but only in the constructor");
								t.decorators || e.remove();
							} else if (t.definite) {
								if (t.value) throw e.buildCodeFrameError("Definitely assigned fields cannot be initialized here, but only in the constructor");
								g || t.decorators || r.isClassPrivateProperty(t) || e.remove();
							} else t.abstract ? e.remove() : g || t.value || t.decorators || r.isClassPrivateProperty(t) || e.remove();
							t.accessibility && (t.accessibility = null), t.abstract && (t.abstract = null), t.readonly && (t.readonly = null), t.optional && (t.optional = null), t.typeAnnotation && (t.typeAnnotation = null), t.definite && (t.definite = null), t.declare && (t.declare = null), t.override && (t.override = null);
						},
						method({ node: e }) {
							e.accessibility && (e.accessibility = null), e.abstract && (e.abstract = null), e.optional && (e.optional = null), e.override && (e.override = null);
						},
						constructor(e, t) {
							e.node.accessibility && (e.node.accessibility = null);
							const s = [], { scope: o } = e;
							for (const t of e.get("params")) {
								const e = t.node;
								if ("TSParameterProperty" === e.type) {
									const i = e.parameter;
									if (u.has(i)) continue;
									let a;
									if (u.add(i), r.isIdentifier(i)) a = i;
									else {
										if (!r.isAssignmentPattern(i) || !r.isIdentifier(i.left)) throw t.buildCodeFrameError("Parameter properties can not be destructuring patterns.");
										a = i.left;
									}
									s.push(n.statement.ast`
              this.${r.cloneNode(a)} = ${r.cloneNode(a)}
            `), t.replaceWith(t.get("parameter")), o.registerBinding("param", t);
								}
							}
							(0, i.injectInitialization)(t, e, s);
						}
					};
					return {
						name: "transform-typescript",
						inherits: s.default,
						visitor: {
							Pattern: visitPattern,
							Identifier: visitPattern,
							RestElement: visitPattern,
							Program: {
								enter(e, t) {
									const { file: r } = t;
									let n = null, s = null;
									const i = e.scope;
									if (l.GLOBAL_TYPES.has(i) || l.GLOBAL_TYPES.set(i, /* @__PURE__ */ new Set()), r.ast.comments) for (const e of r.ast.comments) {
										const t = d.exec(e.value);
										t && (t[1] ? s = t[2] : n = t[2]);
									}
									let o = n || m;
									o && ([o] = o.split("."));
									let a = s || f;
									a && ([a] = a.split("."));
									for (let r of e.get("body")) {
										if (r.isImportDeclaration()) {
											if (c.has(t.file.ast.program) || c.set(t.file.ast.program, !0), "type" === r.node.importKind) {
												for (const e of r.node.specifiers) (0, l.registerGlobalType)(i, e.local.name);
												r.remove();
												continue;
											}
											const n = /* @__PURE__ */ new Set(), s = r.node.specifiers.length, isAllSpecifiersElided = () => s > 0 && s === n.size;
											for (const e of r.node.specifiers) if ("ImportSpecifier" === e.type && "type" === e.importKind) {
												(0, l.registerGlobalType)(i, e.local.name);
												const t = r.scope.getBinding(e.local.name);
												t && n.add(t.path);
											}
											if (y) c.set(e.node, !1);
											else {
												if (0 === r.node.specifiers.length) {
													c.set(e.node, !1);
													continue;
												}
												for (const t of r.node.specifiers) {
													const s = r.scope.getBinding(t.local.name);
													s && !n.has(s.path) && (isImportTypeOnly({
														binding: s,
														programPath: e,
														pragmaImportName: o,
														pragmaFragImportName: a
													}) ? n.add(s.path) : c.set(e.node, !1));
												}
											}
											if (isAllSpecifiersElided() && !y) r.remove();
											else for (const e of n) e.remove();
											continue;
										}
										if (!y && r.isTSImportEqualsDeclaration()) {
											const { id: t } = r.node, n = r.scope.getBinding(t.name);
											if (n && !r.node.isExport && isImportTypeOnly({
												binding: n,
												programPath: e,
												pragmaImportName: o,
												pragmaFragImportName: a
											})) {
												r.remove();
												continue;
											}
										}
										if (r.isExportDeclaration() && (r = r.get("declaration")), r.isVariableDeclaration({ declare: !0 })) for (const e of Object.keys(r.getBindingIdentifiers())) (0, l.registerGlobalType)(i, e);
										else (r.isTSTypeAliasDeclaration() || r.isTSDeclareFunction() && r.get("id").isIdentifier() || r.isTSInterfaceDeclaration() || r.isClassDeclaration({ declare: !0 }) || r.isTSEnumDeclaration({ declare: !0 }) || r.isTSModuleDeclaration({ declare: !0 }) && r.get("id").isIdentifier()) && (0, l.registerGlobalType)(i, r.node.id.name);
									}
								},
								exit(e) {
									"module" === e.node.sourceType && c.get(e.node) && e.pushContainer("body", r.exportNamedDeclaration());
								}
							},
							ExportNamedDeclaration(e, t) {
								if (c.has(t.file.ast.program) || c.set(t.file.ast.program, !0), "type" !== e.node.exportKind) if (e.node.source && e.node.specifiers.length > 0 && e.node.specifiers.every((e) => "ExportSpecifier" === e.type && "type" === e.exportKind)) e.remove();
								else if (!e.node.source && e.node.specifiers.length > 0 && e.node.specifiers.every((t) => r.isExportSpecifier(t) && (0, l.isGlobalType)(e, t.local.name))) e.remove();
								else {
									if (r.isTSModuleDeclaration(e.node.declaration)) {
										const t = e.node.declaration;
										if (!r.isStringLiteral(t.id)) {
											const n = (0, p.getFirstIdentifier)(t.id);
											if (e.scope.hasOwnBinding(n.name)) e.replaceWith(t);
											else {
												const [s] = e.replaceWithMultiple([r.exportNamedDeclaration(r.variableDeclaration("let", [r.variableDeclarator(r.cloneNode(n))])), t]);
												e.scope.registerDeclaration(s);
											}
										}
									}
									c.set(t.file.ast.program, !1);
								}
								else e.remove();
							},
							ExportAllDeclaration(e) {
								"type" === e.node.exportKind && e.remove();
							},
							ExportSpecifier(e) {
								(!e.parent.source && (0, l.isGlobalType)(e, e.node.local.name) || "type" === e.node.exportKind) && e.remove();
							},
							ExportDefaultDeclaration(e, t) {
								c.has(t.file.ast.program) || c.set(t.file.ast.program, !0), r.isIdentifier(e.node.declaration) && (0, l.isGlobalType)(e, e.node.declaration.name) ? e.remove() : c.set(t.file.ast.program, !1);
							},
							TSDeclareFunction(e) {
								safeRemove(e);
							},
							TSDeclareMethod(e) {
								safeRemove(e);
							},
							VariableDeclaration(e) {
								e.node.declare && safeRemove(e);
							},
							VariableDeclarator({ node: e }) {
								e.definite && (e.definite = null);
							},
							TSIndexSignature(e) {
								e.remove();
							},
							ClassDeclaration(e) {
								const { node: t } = e;
								t.declare && safeRemove(e);
							},
							Class(e) {
								const { node: t } = e;
								t.typeParameters && (t.typeParameters = null), t.superTypeParameters && (t.superTypeParameters = null), t.implements && (t.implements = null), t.abstract && (t.abstract = null), e.get("body.body").forEach((t) => {
									t.isClassMethod() || t.isClassPrivateMethod() ? "constructor" === t.node.kind ? x.constructor(t, e) : x.method(t) : (t.isClassProperty() || t.isClassPrivateProperty() || t.isClassAccessorProperty()) && x.field(t);
								});
							},
							Function(e) {
								const { node: t } = e;
								t.typeParameters && (t.typeParameters = null), t.returnType && (t.returnType = null);
								const n = t.params;
								n.length > 0 && r.isIdentifier(n[0], { name: "this" }) && n.shift();
							},
							TSModuleDeclaration(e) {
								(0, p.default)(e, h);
							},
							TSInterfaceDeclaration(e) {
								e.remove();
							},
							TSTypeAliasDeclaration(e) {
								e.remove();
							},
							TSEnumDeclaration(e) {
								b && e.node.const ? (0, o.default)(e, r) : (0, a.default)(e, r);
							},
							TSImportEqualsDeclaration(e, t) {
								const { id: n, moduleReference: s } = e.node;
								let i, o;
								r.isTSExternalModuleReference(s) ? (assertCjsTransformEnabled(e, t, `import ${n.name} = require(...);`, `import ${n.name} from '...';`, " alongside Typescript's --allowSyntheticDefaultImports option"), i = r.callExpression(r.identifier("require"), [s.expression]), o = "const") : (i = entityNameToExpr(s), o = "var");
								const a = r.variableDeclaration(o, [r.variableDeclarator(n, i)]);
								e.replaceWith(e.node.isExport ? r.exportNamedDeclaration(a) : a), e.scope.registerDeclaration(e);
							},
							TSExportAssignment(e, t) {
								assertCjsTransformEnabled(e, t, "export = <value>;", "export default <value>;"), e.replaceWith(n.statement.ast`module.exports = ${e.node.expression}`);
							},
							TSTypeAssertion(e) {
								e.replaceWith(e.node.expression);
							},
							["TSAsExpression" + (r.tsSatisfiesExpression ? "|TSSatisfiesExpression" : "")](e) {
								let { node: t } = e;
								do
									t = t.expression;
								while (r.isTSAsExpression(t) || null != r.isTSSatisfiesExpression && r.isTSSatisfiesExpression(t));
								e.replaceWith(t);
							},
							[e.types.tsInstantiationExpression ? "TSNonNullExpression|TSInstantiationExpression" : "TSNonNullExpression"](e) {
								e.replaceWith(e.node.expression);
							},
							CallExpression(e) {
								e.node.typeParameters = null;
							},
							OptionalCallExpression(e) {
								e.node.typeParameters = null;
							},
							NewExpression(e) {
								e.node.typeParameters = null;
							},
							JSXOpeningElement(e) {
								e.node.typeParameters = null;
							},
							TaggedTemplateExpression(e) {
								e.node.typeParameters = null;
							}
						}
					};
					function entityNameToExpr(e) {
						return r.isTSQualifiedName(e) ? r.memberExpression(entityNameToExpr(e.left), e.right) : e;
					}
					function visitPattern({ node: e }) {
						e.typeAnnotation && (e.typeAnnotation = null), r.isIdentifier(e) && e.optional && (e.optional = null);
					}
					function isImportTypeOnly({ binding: e, programPath: t, pragmaImportName: r, pragmaFragImportName: n }) {
						for (const t of e.referencePaths) if (!isInType(t)) return !1;
						if (e.identifier.name !== r && e.identifier.name !== n) return !0;
						let s = !1;
						return t.traverse({ "JSXElement|JSXFragment"(e) {
							s = !0, e.stop();
						} }), !s;
					}
				});
			},
			"./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/namespace.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					if (e.node.declare || "StringLiteral" === e.node.id.type) return void e.remove();
					if (!t) throw e.get("id").buildCodeFrameError("Namespace not marked type-only declare. Non-declarative namespaces are only supported experimentally in Babel. To enable and review caveats see: https://babeljs.io/docs/en/babel-plugin-transform-typescript");
					const r = getFirstIdentifier(e.node.id).name, n = handleNested(e, e.node);
					if (null === n) {
						const t = e.findParent((e) => e.isProgram());
						(0, s.registerGlobalType)(t.scope, r), e.remove();
					} else e.scope.hasOwnBinding(r) ? e.replaceWith(n) : e.scope.registerDeclaration(e.replaceWithMultiple([getDeclaration(r), n])[0]);
				}, t.getFirstIdentifier = getFirstIdentifier;
				var n = r("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), s = r("./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/global-types.js"), i = r("./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/const-enum.js");
				function getFirstIdentifier(e) {
					return n.types.isIdentifier(e) ? e : getFirstIdentifier(e.left);
				}
				function getDeclaration(e) {
					return n.types.variableDeclaration("let", [n.types.variableDeclarator(n.types.identifier(e))]);
				}
				function getMemberExpression(e, t) {
					return n.types.memberExpression(n.types.identifier(e), n.types.identifier(t));
				}
				function handleVariableDeclaration(e, t, r) {
					if ("const" !== e.kind) throw r.file.buildCodeFrameError(e, "Namespaces exporting non-const are not supported by Babel. Change to const or see: https://babeljs.io/docs/en/babel-plugin-transform-typescript");
					const { declarations: s } = e;
					if (s.every((e) => n.types.isIdentifier(e.id))) {
						for (const e of s) e.init = n.types.assignmentExpression("=", getMemberExpression(t, e.id.name), e.init);
						return [e];
					}
					const i = n.types.getBindingIdentifiers(e), o = [];
					for (const e in i) o.push(n.types.assignmentExpression("=", getMemberExpression(t, e), n.types.cloneNode(i[e])));
					return [e, n.types.expressionStatement(n.types.sequenceExpression(o))];
				}
				function buildNestedAmbientModuleError(e, t) {
					return e.hub.buildError(t, "Ambient modules cannot be nested in other modules or namespaces.", Error);
				}
				function handleNested(e, t, r) {
					const s = /* @__PURE__ */ new Set(), o = t.id, a = e.scope.generateUid(o.name), l = t.body;
					let p;
					t.id;
					p = n.types.isTSModuleBlock(l) ? l.body : [n.types.exportNamedDeclaration(l)];
					let c = !0;
					for (let t = 0; t < p.length; t++) {
						const r = p[t];
						switch (r.type) {
							case "TSModuleDeclaration": {
								if (!n.types.isIdentifier(r.id)) throw buildNestedAmbientModuleError(e, r);
								const i = handleNested(e, r);
								if (null !== i) {
									c = !1;
									const e = r.id.name;
									s.has(e) ? p[t] = i : (s.add(e), p.splice(t++, 1, getDeclaration(e), i));
								}
								continue;
							}
							case "TSEnumDeclaration":
							case "FunctionDeclaration":
							case "ClassDeclaration":
								c = !1, s.add(r.id.name);
								continue;
							case "VariableDeclaration":
								c = !1;
								for (const e in n.types.getBindingIdentifiers(r)) s.add(e);
								continue;
							default:
								c && (c = n.types.isTypeScript(r));
								continue;
							case "ExportNamedDeclaration":
						}
						if (!("declare" in r.declaration) || !r.declaration.declare) switch (r.declaration.type) {
							case "TSEnumDeclaration": i.EXPORTED_CONST_ENUMS_IN_NAMESPACE.add(r.declaration);
							case "FunctionDeclaration":
							case "ClassDeclaration": {
								c = !1;
								const e = r.declaration.id.name;
								s.add(e), p.splice(t++, 1, r.declaration, n.types.expressionStatement(n.types.assignmentExpression("=", getMemberExpression(a, e), n.types.identifier(e))));
								break;
							}
							case "VariableDeclaration": {
								c = !1;
								const n = handleVariableDeclaration(r.declaration, a, e.hub);
								p.splice(t, n.length, ...n), t += n.length - 1;
								break;
							}
							case "TSModuleDeclaration": {
								if (!n.types.isIdentifier(r.declaration.id)) throw buildNestedAmbientModuleError(e, r.declaration);
								const i = handleNested(e, r.declaration, n.types.identifier(a));
								if (null !== i) {
									c = !1;
									const e = r.declaration.id.name;
									s.has(e) ? p[t] = i : (s.add(e), p.splice(t++, 1, getDeclaration(e), i));
								} else p.splice(t, 1), t--;
							}
						}
					}
					if (c) return null;
					let u = n.types.objectExpression([]);
					if (r) {
						const e = n.types.memberExpression(r, o);
						u = n.template.expression.ast`
      ${n.types.cloneNode(e)} ||
        (${n.types.cloneNode(e)} = ${u})
    `;
					}
					return n.template.statement.ast`
    (function (${n.types.identifier(a)}) {
      ${p}
    })(${o} || (${n.types.cloneNode(o)} = ${u}));
  `;
				}
			},
			"./node_modules/.pnpm/@babel+preset-typescript@7.27.1_@babel+core@7.28.4/node_modules/@babel/preset-typescript/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 });
				var n = r("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js"), s = r("./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/index.js");
				r("./node_modules/.pnpm/@babel+plugin-syntax-jsx@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-jsx/lib/index.js");
				var i = r("./node_modules/.pnpm/@babel+plugin-transform-modules-commonjs@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-modules-commonjs/lib/index.js"), o = r("./node_modules/.pnpm/@babel+helper-validator-option@7.27.1/node_modules/@babel/helper-validator-option/lib/index.js");
				function _interopDefault(e) {
					return e && e.__esModule ? e : { default: e };
				}
				var a = _interopDefault(s), l = _interopDefault(i);
				const p = new o.OptionValidator("@babel/preset-typescript");
				var c = n.declare(function({ types: e, template: t }) {
					function maybeReplace(r, n, s) {
						r && (e.isStringLiteral(r) ? /^\.\.?\//.test(r.value) && (r.value = r.value.replace(/\.(tsx)$|((?:\.d)?)((?:\.[^./]+)?)\.([cm]?)ts$/i, function(e, t, r, n, s) {
							return t ? ".js" : !r || n && s ? r + n + "." + s.toLowerCase() + "js" : e;
						})) : s.availableHelper("tsRewriteRelativeImportExtensions") ? n.replaceWith(e.callExpression(s.addHelper("tsRewriteRelativeImportExtensions"), [r])) : n.replaceWith(t.expression.ast`(${r} + "").replace(/([\\/].*\.[mc]?)tsx?$/, "$1js")`));
					}
					return {
						name: "preset-typescript/plugin-rewrite-ts-imports",
						visitor: {
							"ImportDeclaration|ExportAllDeclaration|ExportNamedDeclaration"(t, r) {
								const n = t.node;
								"value" === (e.isImportDeclaration(n) ? n.importKind : n.exportKind) && maybeReplace(n.source, t.get("source"), r);
							},
							CallExpression(t, r) {
								e.isImport(t.node.callee) && maybeReplace(t.node.arguments[0], t.get("arguments.0"), r);
							},
							ImportExpression(e, t) {
								maybeReplace(e.node.source, e.get("source"), t);
							}
						}
					};
				});
				t.default = n.declarePreset((e, t) => {
					e.assertVersion(7);
					const { allExtensions: r, ignoreExtensions: n, allowNamespaces: s, disallowAmbiguousJSXLike: i, isTSX: o, jsxPragma: u, jsxPragmaFrag: d, onlyRemoveTypeImports: h, optimizeConstEnums: m, rewriteImportExtensions: f } = function(e = {}) {
						let { allowNamespaces: t = !0, jsxPragma: r, onlyRemoveTypeImports: n } = e;
						const s = "ignoreExtensions", i = "disallowAmbiguousJSXLike", o = "jsxPragmaFrag", a = "optimizeConstEnums", l = "rewriteImportExtensions", c = "allExtensions", u = "isTSX", d = p.validateStringOption(o, e.jsxPragmaFrag, "React.Fragment");
						var h = p.validateBooleanOption(c, e.allExtensions, !1), m = p.validateBooleanOption(u, e.isTSX, !1);
						m && p.invariant(h, "isTSX:true requires allExtensions:true");
						const f = p.validateBooleanOption(s, e.ignoreExtensions, !1), y = p.validateBooleanOption(i, e.disallowAmbiguousJSXLike, !1);
						y && p.invariant(h, "disallowAmbiguousJSXLike:true requires allExtensions:true");
						const b = {
							ignoreExtensions: f,
							allowNamespaces: t,
							disallowAmbiguousJSXLike: y,
							jsxPragma: r,
							jsxPragmaFrag: d,
							onlyRemoveTypeImports: n,
							optimizeConstEnums: p.validateBooleanOption(a, e.optimizeConstEnums, !1),
							rewriteImportExtensions: p.validateBooleanOption(l, e.rewriteImportExtensions, !1)
						};
						return b.allExtensions = h, b.isTSX = m, b;
					}(t), pluginOptions = (e) => ({
						allowDeclareFields: t.allowDeclareFields,
						allowNamespaces: s,
						disallowAmbiguousJSXLike: e,
						jsxPragma: u,
						jsxPragmaFrag: d,
						onlyRemoveTypeImports: h,
						optimizeConstEnums: m
					}), getPlugins = (e, t) => [[a.default, Object.assign({ isTSX: e }, pluginOptions(t))]];
					return {
						plugins: f ? [c] : [],
						overrides: r || n ? [{ plugins: getPlugins(o, i) }] : [
							{
								test: /\.ts$/,
								plugins: getPlugins(!1, !1)
							},
							{
								test: /\.mts$/,
								sourceType: "module",
								plugins: getPlugins(!1, !0)
							},
							{
								test: /\.cts$/,
								sourceType: "unambiguous",
								plugins: [[l.default, { allowTopLevelThis: !0 }], [a.default, pluginOptions(!0)]]
							},
							{
								test: /\.tsx$/,
								plugins: getPlugins(!0, !1)
							}
						]
					};
				});
			},
			"./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/builder.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function createTemplateBuilder(e, t) {
					const r = /* @__PURE__ */ new WeakMap(), a = /* @__PURE__ */ new WeakMap(), l = t || (0, n.validate)(null);
					return Object.assign((t, ...o) => {
						if ("string" == typeof t) {
							if (o.length > 1) throw new Error("Unexpected extra params.");
							return extendedTrace((0, s.default)(e, t, (0, n.merge)(l, (0, n.validate)(o[0]))));
						}
						if (Array.isArray(t)) {
							let n = r.get(t);
							return n || (n = (0, i.default)(e, t, l), r.set(t, n)), extendedTrace(n(o));
						}
						if ("object" == typeof t && t) {
							if (o.length > 0) throw new Error("Unexpected extra params.");
							return createTemplateBuilder(e, (0, n.merge)(l, (0, n.validate)(t)));
						}
						throw new Error("Unexpected template param " + typeof t);
					}, { ast: (t, ...r) => {
						if ("string" == typeof t) {
							if (r.length > 1) throw new Error("Unexpected extra params.");
							return (0, s.default)(e, t, (0, n.merge)((0, n.merge)(l, (0, n.validate)(r[0])), o))();
						}
						if (Array.isArray(t)) {
							let s = a.get(t);
							return s || (s = (0, i.default)(e, t, (0, n.merge)(l, o)), a.set(t, s)), s(r)();
						}
						throw new Error("Unexpected template param " + typeof t);
					} });
				};
				var n = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/options.js"), s = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/string.js"), i = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/literal.js");
				const o = (0, n.validate)({ placeholderPattern: !1 });
				function extendedTrace(e) {
					let t = "";
					try {
						throw new Error();
					} catch (e) {
						e.stack && (t = e.stack.split("\n").slice(3).join("\n"));
					}
					return (r) => {
						try {
							return e(r);
						} catch (e) {
							throw e.stack += `\n    =============\n${t}`, e;
						}
					};
				}
			},
			"./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/formatters.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.statements = t.statement = t.smart = t.program = t.expression = void 0;
				const { assertExpressionStatement: s } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
				function makeStatementFormatter(e) {
					return {
						code: (e) => `/* @babel/template */;\n${e}`,
						validate: () => {},
						unwrap: (t) => e(t.program.body.slice(1))
					};
				}
				t.smart = makeStatementFormatter((e) => e.length > 1 ? e : e[0]), t.statements = makeStatementFormatter((e) => e), t.statement = makeStatementFormatter((e) => {
					if (0 === e.length) throw new Error("Found nothing to return.");
					if (e.length > 1) throw new Error("Found multiple statements but wanted one");
					return e[0];
				});
				const i = t.expression = {
					code: (e) => `(\n${e}\n)`,
					validate: (e) => {
						if (e.program.body.length > 1) throw new Error("Found multiple statements but wanted one");
						if (0 === i.unwrap(e).start) throw new Error("Parse result included parens.");
					},
					unwrap: ({ program: e }) => {
						const [t] = e.body;
						return s(t), t.expression;
					}
				};
				t.program = {
					code: (e) => e,
					validate: () => {},
					unwrap: (e) => e.program
				};
			},
			"./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.statements = t.statement = t.smart = t.program = t.expression = t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/formatters.js"), s = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/builder.js");
				const i = t.smart = (0, s.default)(n.smart), o = t.statement = (0, s.default)(n.statement), a = t.statements = (0, s.default)(n.statements), l = t.expression = (0, s.default)(n.expression), p = t.program = (0, s.default)(n.program);
				t.default = Object.assign(i.bind(void 0), {
					smart: i,
					statement: o,
					statements: a,
					expression: l,
					program: p,
					ast: i.ast
				});
			},
			"./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/literal.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					const { metadata: o, names: a } = function(e, t, r) {
						let n = "BABEL_TPL$";
						const i = t.join("");
						do
							n = "$$" + n;
						while (i.includes(n));
						const { names: o, code: a } = function(e, t) {
							const r = [];
							let n = e[0];
							for (let s = 1; s < e.length; s++) {
								const i = `${t}${s - 1}`;
								r.push(i), n += i + e[s];
							}
							return {
								names: r,
								code: n
							};
						}(t, n);
						return {
							metadata: (0, s.default)(e, e.code(a), {
								parser: r.parser,
								placeholderWhitelist: new Set(o.concat(r.placeholderWhitelist ? Array.from(r.placeholderWhitelist) : [])),
								placeholderPattern: r.placeholderPattern,
								preserveComments: r.preserveComments,
								syntacticPlaceholders: r.syntacticPlaceholders
							}),
							names: o
						};
					}(e, t, r);
					return (t) => {
						const r = {};
						return t.forEach((e, t) => {
							r[a[t]] = e;
						}), (t) => {
							const s = (0, n.normalizeReplacements)(t);
							return s && Object.keys(s).forEach((e) => {
								if (hasOwnProperty.call(r, e)) throw new Error("Unexpected replacement overlap.");
							}), e.unwrap((0, i.default)(o, s ? Object.assign(s, r) : r));
						};
					};
				};
				var n = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/options.js"), s = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/parse.js"), i = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/populate.js");
			},
			"./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/options.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.merge = function(e, t) {
					const { placeholderWhitelist: r = e.placeholderWhitelist, placeholderPattern: n = e.placeholderPattern, preserveComments: s = e.preserveComments, syntacticPlaceholders: i = e.syntacticPlaceholders } = t;
					return {
						parser: Object.assign({}, e.parser, t.parser),
						placeholderWhitelist: r,
						placeholderPattern: n,
						preserveComments: s,
						syntacticPlaceholders: i
					};
				}, t.normalizeReplacements = function(e) {
					if (Array.isArray(e)) return e.reduce((e, t, r) => (e["$" + r] = t, e), {});
					if ("object" == typeof e || null == e) return e || void 0;
					throw new Error("Template replacements must be an array, object, null, or undefined");
				}, t.validate = function(e) {
					if (null != e && "object" != typeof e) throw new Error("Unknown template options.");
					const t = e || {}, { placeholderWhitelist: n, placeholderPattern: s, preserveComments: i, syntacticPlaceholders: o } = t, a = function(e, t) {
						if (null == e) return {};
						var r = {};
						for (var n in e) if ({}.hasOwnProperty.call(e, n)) {
							if (-1 !== t.indexOf(n)) continue;
							r[n] = e[n];
						}
						return r;
					}(t, r);
					if (null != n && !(n instanceof Set)) throw new Error("'.placeholderWhitelist' must be a Set, null, or undefined");
					if (null != s && !(s instanceof RegExp) && !1 !== s) throw new Error("'.placeholderPattern' must be a RegExp, false, null, or undefined");
					if (null != i && "boolean" != typeof i) throw new Error("'.preserveComments' must be a boolean, null, or undefined");
					if (null != o && "boolean" != typeof o) throw new Error("'.syntacticPlaceholders' must be a boolean, null, or undefined");
					if (!0 === o && (null != n || null != s)) throw new Error("'.placeholderWhitelist' and '.placeholderPattern' aren't compatible with '.syntacticPlaceholders: true'");
					return {
						parser: a,
						placeholderWhitelist: n || void 0,
						placeholderPattern: null == s ? void 0 : s,
						preserveComments: null == i ? void 0 : i,
						syntacticPlaceholders: null == o ? void 0 : o
					};
				};
				const r = [
					"placeholderWhitelist",
					"placeholderPattern",
					"preserveComments",
					"syntacticPlaceholders"
				];
			},
			"./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/parse.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					const { placeholderWhitelist: n, placeholderPattern: o, preserveComments: a, syntacticPlaceholders: l } = r, p = function(e, t, r) {
						const n = (t.plugins || []).slice();
						!1 !== r && n.push("placeholders");
						t = Object.assign({
							allowAwaitOutsideFunction: !0,
							allowReturnOutsideFunction: !0,
							allowNewTargetOutsideFunction: !0,
							allowSuperOutsideMethod: !0,
							allowYieldOutsideFunction: !0,
							sourceType: "module"
						}, t, { plugins: n });
						try {
							return (0, s.parse)(e, t);
						} catch (t) {
							const r = t.loc;
							throw r && (t.message += "\n" + (0, i.codeFrameColumns)(e, { start: r }), t.code = "BABEL_TEMPLATE_PARSE_ERROR"), t;
						}
					}(t, r.parser, l);
					f(p, { preserveComments: a }), e.validate(p);
					const c = {
						syntactic: {
							placeholders: [],
							placeholderNames: /* @__PURE__ */ new Set()
						},
						legacy: {
							placeholders: [],
							placeholderNames: /* @__PURE__ */ new Set()
						},
						placeholderWhitelist: n,
						placeholderPattern: o,
						syntacticPlaceholders: l
					};
					return y(p, placeholderVisitorHandler, c), Object.assign({ ast: p }, c.syntactic.placeholders.length ? c.syntactic : c.legacy);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = r("./node_modules/.pnpm/@babel+parser@7.28.4/node_modules/@babel/parser/lib/index.js"), i = r("./stubs/babel-codeframe.mjs");
				const { isCallExpression: o, isExpressionStatement: a, isFunction: l, isIdentifier: p, isJSXIdentifier: c, isNewExpression: u, isPlaceholder: d, isStatement: h, isStringLiteral: m, removePropertiesDeep: f, traverse: y } = n, b = /^[_$A-Z0-9]+$/;
				function placeholderVisitorHandler(e, t, r) {
					var n;
					let s, i = r.syntactic.placeholders.length > 0;
					if (d(e)) {
						if (!1 === r.syntacticPlaceholders) throw new Error("%%foo%%-style placeholders can't be used when '.syntacticPlaceholders' is false.");
						s = e.name.name, i = !0;
					} else {
						if (i || r.syntacticPlaceholders) return;
						if (p(e) || c(e)) s = e.name;
						else {
							if (!m(e)) return;
							s = e.value;
						}
					}
					if (i && (null != r.placeholderPattern || null != r.placeholderWhitelist)) throw new Error("'.placeholderWhitelist' and '.placeholderPattern' aren't compatible with '.syntacticPlaceholders: true'");
					if (!(i || !1 !== r.placeholderPattern && (r.placeholderPattern || b).test(s) || null != (n = r.placeholderWhitelist) && n.has(s))) return;
					t = t.slice();
					const { node: f, key: y } = t[t.length - 1];
					let g;
					m(e) || d(e, { expectedNode: "StringLiteral" }) ? g = "string" : u(f) && "arguments" === y || o(f) && "arguments" === y || l(f) && "params" === y ? g = "param" : a(f) && !d(e) ? (g = "statement", t = t.slice(0, -1)) : g = h(e) && d(e) ? "statement" : "other";
					const { placeholders: x, placeholderNames: v } = i ? r.syntactic : r.legacy;
					x.push({
						name: s,
						type: g,
						resolve: (e) => function(e, t) {
							let r = e;
							for (let e = 0; e < t.length - 1; e++) {
								const { key: n, index: s } = t[e];
								r = void 0 === s ? r[n] : r[n][s];
							}
							const { key: n, index: s } = t[t.length - 1];
							return {
								parent: r,
								key: n,
								index: s
							};
						}(e, t),
						isDuplicate: v.has(s)
					}), v.add(s);
				}
			},
			"./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/populate.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					const r = i(e.ast);
					t && (e.placeholders.forEach((e) => {
						if (!hasOwnProperty.call(t, e.name)) {
							const t = e.name;
							throw new Error(`Error: No substitution given for "${t}". If this is not meant to be a\n            placeholder you may want to consider passing one of the following options to @babel/template:\n            - { placeholderPattern: false, placeholderWhitelist: new Set(['${t}'])}\n            - { placeholderPattern: /^${t}$/ }`);
						}
					}), Object.keys(t).forEach((t) => {
						if (!e.placeholderNames.has(t)) throw new Error(`Unknown substitution "${t}" given`);
					}));
					return e.placeholders.slice().reverse().forEach((e) => {
						try {
							var n;
							(function(e, t, r) {
								e.isDuplicate && (Array.isArray(r) ? r = r.map((e) => i(e)) : "object" == typeof r && (r = i(r)));
								const { parent: n, key: h, index: m } = e.resolve(t);
								if ("string" === e.type) {
									if ("string" == typeof r && (r = u(r)), !r || !c(r)) throw new Error("Expected string substitution");
								} else if ("statement" === e.type) void 0 === m ? r ? Array.isArray(r) ? r = s(r) : "string" == typeof r ? r = a(l(r)) : p(r) || (r = a(r)) : r = o() : r && !Array.isArray(r) && ("string" == typeof r && (r = l(r)), p(r) || (r = a(r)));
								else if ("param" === e.type) {
									if ("string" == typeof r && (r = l(r)), void 0 === m) throw new Error("Assertion failure.");
								} else if ("string" == typeof r && (r = l(r)), Array.isArray(r)) throw new Error("Cannot replace single expression with an array.");
								function set(e, t, r) {
									const n = e[t];
									e[t] = r, "Identifier" !== n.type && "Placeholder" !== n.type || (n.typeAnnotation && (r.typeAnnotation = n.typeAnnotation), n.optional && (r.optional = n.optional), n.decorators && (r.decorators = n.decorators));
								}
								if (void 0 === m) d(n, h, r), set(n, h, r);
								else {
									const t = n[h].slice();
									"statement" === e.type || "param" === e.type ? null == r ? t.splice(m, 1) : Array.isArray(r) ? t.splice(m, 1, ...r) : set(t, m, r) : set(t, m, r), d(n, h, t), n[h] = t;
								}
							})(e, r, null != (n = t && t[e.name]) ? n : null);
						} catch (t) {
							throw t.message = `@babel/template placeholder "${e.name}": ${t.message}`, t;
						}
					}), r;
				};
				const { blockStatement: s, cloneNode: i, emptyStatement: o, expressionStatement: a, identifier: l, isStatement: p, isStringLiteral: c, stringLiteral: u, validate: d } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
			},
			"./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/string.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					let o;
					return t = e.code(t), (a) => {
						const l = (0, n.normalizeReplacements)(a);
						return o || (o = (0, s.default)(e, t, r)), e.unwrap((0, i.default)(o, l));
					};
				};
				var n = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/options.js"), s = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/parse.js"), i = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/populate.js");
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/cache.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.clear = function() {
					clearPath(), clearScope();
				}, t.clearPath = clearPath, t.clearScope = clearScope, t.getCachedPaths = function(e) {
					const { parent: t, parentPath: n } = e;
					return r.get(t);
				}, t.getOrCreateCachedPaths = function(e, t) {
					let n = r.get(e);
					n || r.set(e, n = /* @__PURE__ */ new Map());
					return n;
				}, t.scope = t.path = void 0;
				let r = t.path = /* @__PURE__ */ new WeakMap();
				t.scope = /* @__PURE__ */ new WeakMap();
				function clearPath() {
					t.path = r = /* @__PURE__ */ new WeakMap();
				}
				function clearScope() {
					t.scope = /* @__PURE__ */ new WeakMap();
				}
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/context.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), i = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/context.js");
				const { VISITOR_KEYS: o } = s;
				t.default = class {
					constructor(e, t, r, n) {
						this.queue = null, this.priorityQueue = null, this.parentPath = n, this.scope = e, this.state = r, this.opts = t;
					}
					shouldVisit(e) {
						const t = this.opts;
						if (t.enter || t.exit) return !0;
						if (t[e.type]) return !0;
						const r = o[e.type];
						if (null == r || !r.length) return !1;
						for (const t of r) if (e[t]) return !0;
						return !1;
					}
					create(e, t, r, s) {
						return n.default.get({
							parentPath: this.parentPath,
							parent: e,
							container: t,
							key: r,
							listKey: s
						});
					}
					maybeQueue(e, t) {
						this.queue && (t ? this.queue.push(e) : this.priorityQueue.push(e));
					}
					visitMultiple(e, t, r) {
						if (0 === e.length) return !1;
						const n = [];
						for (let s = 0; s < e.length; s++) {
							const i = e[s];
							i && this.shouldVisit(i) && n.push(this.create(t, e, s, r));
						}
						return this.visitQueue(n);
					}
					visitSingle(e, t) {
						return !!this.shouldVisit(e[t]) && this.visitQueue([this.create(e, e, t)]);
					}
					visitQueue(e) {
						this.queue = e, this.priorityQueue = [];
						const t = /* @__PURE__ */ new WeakSet();
						let r = !1, n = 0;
						for (; n < e.length;) {
							const s = e[n];
							if (n++, i.resync.call(s), 0 !== s.contexts.length && s.contexts[s.contexts.length - 1] === this || i.pushContext.call(s, this), null === s.key) continue;
							const { node: o } = s;
							if (!t.has(o)) {
								if (o && t.add(o), s.visit()) {
									r = !0;
									break;
								}
								if (this.priorityQueue.length && (r = this.visitQueue(this.priorityQueue), this.priorityQueue = [], this.queue = e, r)) break;
							}
						}
						for (let t = 0; t < n; t++) i.popContext.call(e[t]);
						return this.queue = null, r;
					}
					visit(e, t) {
						const r = e[t];
						return !!r && (Array.isArray(r) ? this.visitMultiple(r, e, t) : this.visitSingle(e, t));
					}
				};
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/hub.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				t.default = class {
					getCode() {}
					getScope() {}
					addHelper() {
						throw new Error("Helpers are not supported by the default hub.");
					}
					buildError(e, t, r = TypeError) {
						return new r(t);
					}
				};
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), Object.defineProperty(t, "Hub", {
					enumerable: !0,
					get: function() {
						return p.default;
					}
				}), Object.defineProperty(t, "NodePath", {
					enumerable: !0,
					get: function() {
						return a.default;
					}
				}), Object.defineProperty(t, "Scope", {
					enumerable: !0,
					get: function() {
						return l.default;
					}
				}), t.visitors = t.default = void 0, r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/context.js");
				var n = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/visitors.js");
				t.visitors = n;
				var s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), i = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/cache.js"), o = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/traverse-node.js"), a = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/index.js"), l = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/scope/index.js"), p = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/hub.js");
				const { VISITOR_KEYS: c, removeProperties: u, traverseFast: d } = s;
				function traverse(e, t = {}, r, s, i, a) {
					if (e) {
						if (!t.noScope && !r && "Program" !== e.type && "File" !== e.type) throw new Error(`You must pass a scope and parentPath unless traversing a Program/File. Instead of that you tried to traverse a ${e.type} node without passing scope and parentPath.`);
						if (!i && a) throw new Error("visitSelf can only be used when providing a NodePath.");
						c[e.type] && (n.explode(t), (0, o.traverseNode)(e, t, r, s, i, null, a));
					}
				}
				t.default = traverse;
				traverse.visitors = n, traverse.verify = n.verify, traverse.explode = n.explode, traverse.cheap = function(e, t) {
					d(e, t);
				}, traverse.node = function(e, t, r, n, s, i) {
					(0, o.traverseNode)(e, t, r, n, s, i);
				}, traverse.clearNode = function(e, t) {
					u(e, t);
				}, traverse.removeProperties = function(e, t) {
					return d(e, traverse.clearNode, t), e;
				}, traverse.hasType = function(e, t, r) {
					return (null == r || !r.includes(e.type)) && (e.type === t || d(e, function(e) {
						return null != r && r.includes(e.type) ? d.skip : e.type === t ? d.stop : void 0;
					}));
				}, traverse.cache = i;
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/ancestry.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.find = function(e) {
					let t = this;
					do
						if (e(t)) return t;
					while (t = t.parentPath);
					return null;
				}, t.findParent = function(e) {
					let t = this;
					for (; t = t.parentPath;) if (e(t)) return t;
					return null;
				}, t.getAncestry = function() {
					let e = this;
					const t = [];
					do
						t.push(e);
					while (e = e.parentPath);
					return t;
				}, t.getDeepestCommonAncestorFrom = function(e, t) {
					if (!e.length) return this;
					if (1 === e.length) return e[0];
					let r, n, s = Infinity;
					const i = e.map((e) => {
						const t = [];
						do
							t.unshift(e);
						while ((e = e.parentPath) && e !== this);
						return t.length < s && (s = t.length), t;
					}), o = i[0];
					e: for (let e = 0; e < s; e++) {
						const t = o[e];
						for (const r of i) if (r[e] !== t) break e;
						r = e, n = t;
					}
					if (n) return t ? t(n, r, i) : n;
					throw new Error("Couldn't find intersection");
				}, t.getEarliestCommonAncestorFrom = function(e) {
					return this.getDeepestCommonAncestorFrom(e, function(e, t, r) {
						let n;
						const i = s[e.type];
						for (const e of r) {
							const r = e[t + 1];
							if (!n) {
								n = r;
								continue;
							}
							if (r.listKey && n.listKey === r.listKey && r.key < n.key) {
								n = r;
								continue;
							}
							i.indexOf(n.parentKey) > i.indexOf(r.parentKey) && (n = r);
						}
						return n;
					});
				}, t.getFunctionParent = function() {
					return this.findParent((e) => e.isFunction());
				}, t.getStatementParent = function() {
					let e = this;
					do {
						if (!e.parentPath || Array.isArray(e.container) && e.isStatement()) break;
						e = e.parentPath;
					} while (e);
					if (e && (e.isProgram() || e.isFile())) throw new Error("File/Program node, we can't possibly find a statement parent to this");
					return e;
				}, t.inType = function(...e) {
					let t = this;
					for (; t;) {
						if (e.includes(t.node.type)) return !0;
						t = t.parentPath;
					}
					return !1;
				}, t.isAncestor = function(e) {
					return e.isDescendant(this);
				}, t.isDescendant = function(e) {
					return !!this.findParent((t) => t === e);
				};
				const { VISITOR_KEYS: s } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/comments.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.addComment = function(e, t, r) {
					s(this.node, e, t, r);
				}, t.addComments = function(e, t) {
					i(this.node, e, t);
				}, t.shareCommentsWithSiblings = function() {
					if ("string" == typeof this.key) return;
					const e = this.node;
					if (!e) return;
					const t = e.trailingComments, r = e.leadingComments;
					if (!t && !r) return;
					const n = this.getSibling(this.key - 1), s = this.getSibling(this.key + 1), i = Boolean(n.node), o = Boolean(s.node);
					i && (r && n.addComments("trailing", removeIfExisting(r, n.node.trailingComments)), t && !o && n.addComments("trailing", t));
					o && (t && s.addComments("leading", removeIfExisting(t, s.node.leadingComments)), r && !i && s.addComments("leading", r));
				};
				const { addComment: s, addComments: i } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
				function removeIfExisting(e, t) {
					if (null == t || !t.length) return e;
					const r = new Set(t);
					return e.filter((e) => !r.has(e));
				}
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/context.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t._call = _call, t._getQueueContexts = function() {
					let e = this, t = this.contexts;
					for (; !t.length && (e = e.parentPath, e);) t = e.contexts;
					return t;
				}, t._resyncKey = _resyncKey, t._resyncList = _resyncList, t._resyncParent = _resyncParent, t._resyncRemoved = function() {
					null != this.key && this.container && this.container[this.key] === this.node || i._markRemoved.call(this);
				}, t.call = call, t.isDenylisted = isDenylisted, t.popContext = function() {
					this.contexts.pop(), this.contexts.length > 0 ? this.setContext(this.contexts[this.contexts.length - 1]) : this.setContext(void 0);
				}, t.pushContext = function(e) {
					this.contexts.push(e), this.setContext(e);
				}, t.requeue = function(e = this) {
					if (e.removed) return;
					const t = this.contexts;
					for (const r of t) r.maybeQueue(e);
				}, t.requeueComputedKeyAndDecorators = function() {
					const { context: e, node: t } = this;
					!o.isPrivate(t) && t.computed && e.maybeQueue(this.get("key"));
					if (t.decorators) for (const t of this.get("decorators")) e.maybeQueue(t);
				}, t.resync = function() {
					if (this.removed) return;
					_resyncParent.call(this), _resyncList.call(this), _resyncKey.call(this);
				}, t.setContext = function(e) {
					null != this.skipKeys && (this.skipKeys = {});
					this._traverseFlags = 0, e && (this.context = e, this.state = e.state, this.opts = e.opts);
					return setScope.call(this), this;
				}, t.setKey = setKey, t.setScope = setScope, t.setup = function(e, t, r, n) {
					this.listKey = r, this.container = t, this.parentPath = e || this.parentPath, setKey.call(this, n);
				}, t.skip = function() {
					this.shouldSkip = !0;
				}, t.skipKey = function(e) {
					this.skipKeys ?? (this.skipKeys = {});
					this.skipKeys[e] = !0;
				}, t.stop = function() {
					this._traverseFlags |= s.SHOULD_SKIP | s.SHOULD_STOP;
				}, t.visit = function() {
					var e, t;
					if (!this.node) return !1;
					if (this.isDenylisted()) return !1;
					if (null != (e = (t = this.opts).shouldSkip) && e.call(t, this)) return !1;
					const r = this.context;
					if (this.shouldSkip || call.call(this, "enter")) return this.debug("Skip..."), this.shouldStop;
					return restoreContext(this, r), this.debug("Recursing into..."), this.shouldStop = (0, n.traverseNode)(this.node, this.opts, this.scope, this.state, this, this.skipKeys), restoreContext(this, r), call.call(this, "exit"), this.shouldStop;
				};
				var n = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/traverse-node.js"), s = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/index.js"), i = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/removal.js"), o = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
				function call(e) {
					const t = this.opts;
					return this.debug(e), !(!this.node || !_call.call(this, t[e])) || !!this.node && _call.call(this, null == (r = t[this.node.type]) ? void 0 : r[e]);
					var r;
				}
				function _call(e) {
					if (!e) return !1;
					for (const t of e) {
						if (!t) continue;
						const e = this.node;
						if (!e) return !0;
						const r = t.call(this.state, this, this.state);
						if (r && "object" == typeof r && "function" == typeof r.then) throw new Error("You appear to be using a plugin with an async traversal visitor, which your current version of Babel does not support. If you're using a published plugin, you may need to upgrade your @babel/core version.");
						if (r) throw new Error(`Unexpected return value from visitor method ${t}`);
						if (this.node !== e) return !0;
						if (this._traverseFlags > 0) return !0;
					}
					return !1;
				}
				function isDenylisted() {
					var e;
					const t = null != (e = this.opts.denylist) ? e : this.opts.blacklist;
					return null == t ? void 0 : t.includes(this.node.type);
				}
				function restoreContext(e, t) {
					e.context !== t && (e.context = t, e.state = t.state, e.opts = t.opts);
				}
				function setScope() {
					var e, t;
					if (null != (e = this.opts) && e.noScope) return;
					let r, n = this.parentPath;
					for ((("key" === this.key || "decorators" === this.listKey) && n.isMethod() || "discriminant" === this.key && n.isSwitchStatement()) && (n = n.parentPath); n && !r;) {
						var s;
						if (null != (s = n.opts) && s.noScope) return;
						r = n.scope, n = n.parentPath;
					}
					this.scope = this.getScope(r), null == (t = this.scope) || t.init();
				}
				function _resyncParent() {
					this.parentPath && (this.parent = this.parentPath.node);
				}
				function _resyncKey() {
					if (this.container && this.node !== this.container[this.key]) {
						if (Array.isArray(this.container)) {
							for (let e = 0; e < this.container.length; e++) if (this.container[e] === this.node) return void setKey.call(this, e);
						} else for (const e of Object.keys(this.container)) if (this.container[e] === this.node) return void setKey.call(this, e);
						this.key = null;
					}
				}
				function _resyncList() {
					if (!this.parent || !this.inList) return;
					const e = this.parent[this.listKey];
					this.container !== e && (this.container = e || null);
				}
				function setKey(e) {
					var t;
					this.key = e, this.node = this.container[this.key], this.type = null == (t = this.node) ? void 0 : t.type;
				}
				t.isBlacklisted = isDenylisted;
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/conversion.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.arrowFunctionToExpression = function({ allowInsertArrow: e = !0, allowInsertArrowWithRest: t = e, noNewArrows: r = !((e) => null == (e = arguments[0]) ? void 0 : e.specCompliant)() } = {}) {
					if (!this.isArrowFunctionExpression()) throw this.buildCodeFrameError("Cannot convert non-arrow function to a function expression.");
					let n = this;
					var s;
					r || (n = null != (s = n.ensureFunctionName(!1)) ? s : n);
					const { thisBinding: i, fnPath: o } = hoistFunctionEnvironment(n, r, e, t);
					if (o.ensureBlock(), function(e, t) {
						e.node.type = t;
					}(o, "FunctionExpression"), !r) {
						const e = i ? null : o.scope.generateUidIdentifier("arrowCheckId");
						return e && o.parentPath.scope.push({
							id: e,
							init: T([])
						}), o.get("body").unshiftContainer("body", h(u(this.hub.addHelper("newArrowCheck"), [I(), m(e ? e.name : i)]))), o.replaceWith(u(x(o.node, m("bind")), [e ? m(e.name) : I()])), o.get("callee.object");
					}
					return o;
				}, t.ensureBlock = function() {
					const e = this.get("body"), t = e.node;
					if (Array.isArray(e)) throw new Error("Can't convert array path to a block statement");
					if (!t) throw new Error("Can't convert node without a body");
					if (e.isBlockStatement()) return t;
					const r = [];
					let n, s, i = "body";
					e.isStatement() ? (s = "body", n = 0, r.push(e.node)) : (i += ".body.0", this.isFunction() ? (n = "argument", r.push(P(e.node))) : (n = "expression", r.push(h(e.node))));
					this.node.body = c(r);
					const a = this.get(i);
					return o.setup.call(e, a, s ? a.node[s] : a.node, s, n), this.node;
				}, t.ensureFunctionName = function(e) {
					if (this.node.id) return this;
					const t = L(this.node, this.parent);
					if (null == t) return this;
					let { name: r } = t;
					if (!e && /[\uD800-\uDFFF]/.test(r)) return null;
					if (r.startsWith("get ") || r.startsWith("set ")) return null;
					r = N(r.replace(/[/ ]/g, "_"));
					const n = m(r);
					$(n, t.originalNode);
					const i = {
						needsRename: !1,
						name: r
					}, { scope: o } = this, a = o.getOwnBinding(r);
					a ? "param" === a.kind && (i.needsRename = !0) : (o.parent.hasBinding(r) || o.hasGlobal(r)) && this.traverse(H, i);
					if (!i.needsRename) return this.node.id = n, o.getProgramParent().references[n.name] = !0, this;
					if (o.hasBinding(n.name) && !o.hasGlobal(n.name)) return o.rename(n.name), this.node.id = n, o.getProgramParent().references[n.name] = !0, this;
					if (!O(this.node)) return null;
					const l = o.generateUidIdentifier(n.name), p = [];
					for (let e = 0, t = function(e) {
						const t = e.params.findIndex((e) => j(e) || F(e));
						return -1 === t ? e.params.length : t;
					}(this.node); e < t; e++) p.push(o.generateUidIdentifier("x"));
					const c = s.default.expression.ast`
    (function (${l}) {
      function ${n}(${p}) {
        return ${M(l)}.apply(this, arguments);
      }

      ${M(n)}.toString = function () {
        return ${M(l)}.toString();
      }

      return ${M(n)};
    })(${D(this.node)})
  `;
					return this.replaceWith(c)[0].get("arguments.0");
				}, t.splitExportDeclaration = function() {
					if (!this.isExportDeclaration() || this.isExportAllDeclaration()) throw new Error("Only default and named export declarations can be split.");
					if (this.isExportNamedDeclaration() && this.get("specifiers").length > 0) throw new Error("It doesn't make sense to split exported specifiers.");
					const e = this.get("declaration");
					if (this.isExportDefaultDeclaration()) {
						const t = e.isFunctionDeclaration() || e.isClassDeclaration(), r = e.isFunctionExpression() || e.isClassExpression(), n = e.isScope() ? e.scope.parent : e.scope;
						let s = e.node.id, i = !1;
						s ? r && n.hasBinding(s.name) && (i = !0, s = n.generateUidIdentifier(s.name)) : (i = !0, s = n.generateUidIdentifier("default"), (t || r) && (e.node.id = M(s)));
						const o = t ? e.node : B("var", [R(M(s), e.node)]), a = U(null, [V(M(s), m("default"))]);
						return this.insertAfter(a), this.replaceWith(o), i && n.registerDeclaration(this), this;
					}
					if (this.get("specifiers").length > 0) throw new Error("It doesn't make sense to split exported specifiers.");
					const t = e.getOuterBindingIdentifiers(), n = U(null, Object.keys(t).map((e) => V(m(e), m(e))));
					return this.insertAfter(n), this.replaceWith(e.node), this;
				}, t.toComputedKey = function() {
					let e;
					if (this.isMemberExpression()) e = this.node.property;
					else {
						if (!this.isProperty() && !this.isMethod()) throw new ReferenceError("todo");
						e = this.node.key;
					}
					this.node.computed || f(e) && (e = C(e.name));
					return e;
				}, t.unwrapFunctionEnvironment = function() {
					if (!this.isArrowFunctionExpression() && !this.isFunctionExpression() && !this.isFunctionDeclaration()) throw this.buildCodeFrameError("Can only unwrap the environment of a function.");
					hoistFunctionEnvironment(this);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = r("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/index.js"), i = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/visitors.js"), o = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/context.js");
				const { arrowFunctionExpression: a, assignmentExpression: l, binaryExpression: p, blockStatement: c, callExpression: u, conditionalExpression: d, expressionStatement: h, identifier: m, isIdentifier: f, jsxIdentifier: y, logicalExpression: b, LOGICAL_OPERATORS: g, memberExpression: x, metaProperty: v, numericLiteral: E, objectExpression: T, restElement: S, returnStatement: P, sequenceExpression: _, spreadElement: A, stringLiteral: C, super: w, thisExpression: I, toExpression: D, unaryExpression: k, toBindingIdentifierName: N, isFunction: O, isAssignmentPattern: j, isRestElement: F, getFunctionName: L, cloneNode: M, variableDeclaration: B, variableDeclarator: R, exportNamedDeclaration: U, exportSpecifier: V, inherits: $ } = n;
				t.arrowFunctionToShadowed = function() {
					this.isArrowFunctionExpression() && this.arrowFunctionToExpression();
				};
				const K = (0, i.environmentVisitor)({ CallExpression(e, { allSuperCalls: t }) {
					e.get("callee").isSuper() && t.push(e);
				} });
				function hoistFunctionEnvironment(e, t = !0, r = !0, n = !0) {
					let s, i = e.findParent((e) => e.isArrowFunctionExpression() ? (s ?? (s = e), !1) : e.isFunction() || e.isProgram() || e.isClassProperty({ static: !1 }) || e.isClassPrivateProperty({ static: !1 }));
					const o = i.isClassMethod({ kind: "constructor" });
					if (i.isClassProperty() || i.isClassPrivateProperty()) if (s) i = s;
					else {
						if (!r) throw e.buildCodeFrameError("Unable to transform arrow inside class property");
						e.replaceWith(u(a([], D(e.node)), [])), i = e.get("callee"), e = i.get("body");
					}
					const { thisPaths: c, argumentsPaths: h, newTargetPaths: f, superProps: T, superCalls: P } = function(e) {
						const t = [], r = [], n = [], s = [], i = [];
						return e.traverse(q, {
							thisPaths: t,
							argumentsPaths: r,
							newTargetPaths: n,
							superProps: s,
							superCalls: i
						}), {
							thisPaths: t,
							argumentsPaths: r,
							newTargetPaths: n,
							superProps: s,
							superCalls: i
						};
					}(e);
					if (o && P.length > 0) {
						if (!r) throw P[0].buildCodeFrameError("When using '@babel/plugin-transform-arrow-functions', it's not possible to compile `super()` in an arrow function without compiling classes.\nPlease add '@babel/plugin-transform-classes' to your Babel configuration.");
						if (!n) throw P[0].buildCodeFrameError("When using '@babel/plugin-transform-parameters', it's not possible to compile `super()` in an arrow function with default or rest parameters without compiling classes.\nPlease add '@babel/plugin-transform-classes' to your Babel configuration.");
						const e = [];
						i.traverse(K, { allSuperCalls: e });
						const t = function(e) {
							return getBinding(e, "supercall", () => {
								const t = e.scope.generateUidIdentifier("args");
								return a([S(t)], u(w(), [A(m(t.name))]));
							});
						}(i);
						e.forEach((e) => {
							const r = m(t);
							r.loc = e.node.callee.loc, e.get("callee").replaceWith(r);
						});
					}
					if (h.length > 0) {
						const e = getBinding(i, "arguments", () => {
							const args = () => m("arguments");
							return i.scope.path.isProgram() ? d(p("===", k("typeof", args()), C("undefined")), i.scope.buildUndefinedNode(), args()) : args();
						});
						h.forEach((t) => {
							const r = m(e);
							r.loc = t.node.loc, t.replaceWith(r);
						});
					}
					if (f.length > 0) {
						const e = getBinding(i, "newtarget", () => v(m("new"), m("target")));
						f.forEach((t) => {
							const r = m(e);
							r.loc = t.node.loc, t.replaceWith(r);
						});
					}
					if (T.length > 0) {
						if (!r) throw T[0].buildCodeFrameError("When using '@babel/plugin-transform-arrow-functions', it's not possible to compile `super.prop` in an arrow function without compiling classes.\nPlease add '@babel/plugin-transform-classes' to your Babel configuration.");
						T.reduce((e, t) => e.concat(function(e) {
							if (e.parentPath.isAssignmentExpression() && "=" !== e.parentPath.node.operator) {
								const t = e.parentPath, r = t.node.operator.slice(0, -1), n = t.node.right, s = function(e) {
									return g.includes(e);
								}(r);
								if (e.node.computed) {
									const i = e.scope.generateDeclaredUidIdentifier("tmp"), o = e.node.object, a = e.node.property;
									t.get("left").replaceWith(x(o, l("=", i, a), !0)), t.get("right").replaceWith(rightExpression(s ? "=" : r, x(o, m(i.name), !0), n));
								} else {
									const i = e.node.object, o = e.node.property;
									t.get("left").replaceWith(x(i, o)), t.get("right").replaceWith(rightExpression(s ? "=" : r, x(i, m(o.name)), n));
								}
								return s ? t.replaceWith(b(r, t.node.left, t.node.right)) : t.node.operator = "=", [t.get("left"), t.get("right").get("left")];
							}
							if (e.parentPath.isUpdateExpression()) {
								const t = e.parentPath, r = e.scope.generateDeclaredUidIdentifier("tmp"), n = e.node.computed ? e.scope.generateDeclaredUidIdentifier("prop") : null, s = [l("=", r, x(e.node.object, n ? l("=", n, e.node.property) : e.node.property, e.node.computed)), l("=", x(e.node.object, n ? m(n.name) : e.node.property, e.node.computed), p(e.parentPath.node.operator[0], m(r.name), E(1)))];
								e.parentPath.node.prefix || s.push(m(r.name)), t.replaceWith(_(s));
								return [t.get("expressions.0.right"), t.get("expressions.1.left")];
							}
							return [e];
							function rightExpression(e, t, r) {
								return "=" === e ? l("=", t, r) : p(e, t, r);
							}
						}(t)), []).forEach((e) => {
							const t = e.node.computed ? "" : e.get("property").node.name, r = e.parentPath, n = r.isAssignmentExpression({ left: e.node }), s = r.isCallExpression({ callee: e.node }), o = r.isTaggedTemplateExpression({ tag: e.node }), p = function(e, t, r) {
								return getBinding(e, `superprop_${t ? "set" : "get"}:${r || ""}`, () => {
									const n = [];
									let s;
									if (r) s = x(w(), m(r));
									else {
										const t = e.scope.generateUidIdentifier("prop");
										n.unshift(t), s = x(w(), m(t.name), !0);
									}
									if (t) {
										const t = e.scope.generateUidIdentifier("value");
										n.push(t), s = l("=", s, m(t.name));
									}
									return a(n, s);
								});
							}(i, n, t), d = [];
							if (e.node.computed && d.push(e.get("property").node), n) {
								const e = r.node.right;
								d.push(e);
							}
							const h = u(m(p), d);
							s ? (r.unshiftContainer("arguments", I()), e.replaceWith(x(h, m("call"))), c.push(r.get("arguments.0"))) : n ? r.replaceWith(h) : o ? (e.replaceWith(u(x(h, m("bind"), !1), [I()])), c.push(e.get("arguments.0"))) : e.replaceWith(h);
						});
					}
					let N;
					return (c.length > 0 || !t) && (N = function(e, t) {
						return getBinding(e, "this", (r) => {
							if (!t || !hasSuperClass(e)) return I();
							e.traverse(W, {
								supers: /* @__PURE__ */ new WeakSet(),
								thisBinding: r
							});
						});
					}(i, o), (t || o && hasSuperClass(i)) && (c.forEach((e) => {
						const t = e.isJSX() ? y(N) : m(N);
						t.loc = e.node.loc, e.replaceWith(t);
					}), t || (N = null))), {
						thisBinding: N,
						fnPath: e
					};
				}
				function hasSuperClass(e) {
					return e.isClassMethod() && !!e.parentPath.parentPath.node.superClass;
				}
				const W = (0, i.environmentVisitor)({ CallExpression(e, { supers: t, thisBinding: r }) {
					e.get("callee").isSuper() && (t.has(e.node) || (t.add(e.node), e.replaceWithMultiple([e.node, l("=", m(r), m("this"))])));
				} });
				function getBinding(e, t, r) {
					const n = "binding:" + t;
					let s = e.getData(n);
					if (!s) {
						const i = e.scope.generateUidIdentifier(t);
						s = i.name, e.setData(n, s), e.scope.push({
							id: i,
							init: r(s)
						});
					}
					return s;
				}
				const q = (0, i.environmentVisitor)({
					ThisExpression(e, { thisPaths: t }) {
						t.push(e);
					},
					JSXIdentifier(e, { thisPaths: t }) {
						"this" === e.node.name && (e.parentPath.isJSXMemberExpression({ object: e.node }) || e.parentPath.isJSXOpeningElement({ name: e.node })) && t.push(e);
					},
					CallExpression(e, { superCalls: t }) {
						e.get("callee").isSuper() && t.push(e);
					},
					MemberExpression(e, { superProps: t }) {
						e.get("object").isSuper() && t.push(e);
					},
					Identifier(e, { argumentsPaths: t }) {
						if (!e.isReferencedIdentifier({ name: "arguments" })) return;
						let r = e.scope;
						do {
							if (r.hasOwnBinding("arguments")) return void r.rename("arguments");
							if (r.path.isFunction() && !r.path.isArrowFunctionExpression()) break;
						} while (r = r.parent);
						t.push(e);
					},
					MetaProperty(e, { newTargetPaths: t }) {
						e.get("meta").isIdentifier({ name: "new" }) && e.get("property").isIdentifier({ name: "target" }) && t.push(e);
					}
				});
				const H = {
					"ReferencedIdentifier|BindingIdentifier"(e, t) {
						e.node.name === t.name && (t.needsRename = !0, e.stop());
					},
					Scope(e, t) {
						e.scope.hasOwnBinding(t.name) && e.skip();
					}
				};
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/evaluation.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.evaluate = function() {
					const e = {
						confident: !0,
						deoptPath: null,
						seen: /* @__PURE__ */ new Map()
					};
					let t = evaluateCached(this, e);
					e.confident || (t = void 0);
					return {
						confident: e.confident,
						deopt: e.deoptPath,
						value: t
					};
				}, t.evaluateTruthy = function() {
					const e = this.evaluate();
					if (e.confident) return !!e.value;
				};
				const r = [
					"Number",
					"String",
					"Math"
				], n = [
					"isFinite",
					"isNaN",
					"parseFloat",
					"parseInt",
					"decodeURI",
					"decodeURIComponent",
					"encodeURI",
					"encodeURIComponent",
					null,
					null
				], s = ["random"];
				function isValidObjectCallee(e) {
					return r.includes(e);
				}
				function deopt(e, t) {
					t.confident && (t.deoptPath = e, t.confident = !1);
				}
				const i = new Map([
					["undefined", void 0],
					["Infinity", Infinity],
					["NaN", NaN]
				]);
				function evaluateCached(e, t) {
					const { node: r } = e, { seen: o } = t;
					if (o.has(r)) {
						const n = o.get(r);
						return n.resolved ? n.value : void deopt(e, t);
					}
					{
						const a = { resolved: !1 };
						o.set(r, a);
						const l = function(e, t) {
							if (!t.confident) return;
							if (e.isSequenceExpression()) {
								const r = e.get("expressions");
								return evaluateCached(r[r.length - 1], t);
							}
							if (e.isStringLiteral() || e.isNumericLiteral() || e.isBooleanLiteral()) return e.node.value;
							if (e.isNullLiteral()) return null;
							if (e.isTemplateLiteral()) return evaluateQuasis(e, e.node.quasis, t);
							if (e.isTaggedTemplateExpression() && e.get("tag").isMemberExpression()) {
								const r = e.get("tag.object"), { node: { name: n } } = r, s = e.get("tag.property");
								if (r.isIdentifier() && "String" === n && !e.scope.getBinding(n) && s.isIdentifier() && "raw" === s.node.name) return evaluateQuasis(e, e.node.quasi.quasis, t, !0);
							}
							if (e.isConditionalExpression()) {
								const r = evaluateCached(e.get("test"), t);
								if (!t.confident) return;
								return evaluateCached(r ? e.get("consequent") : e.get("alternate"), t);
							}
							if (e.isExpressionWrapper()) return evaluateCached(e.get("expression"), t);
							if (e.isMemberExpression() && !e.parentPath.isCallExpression({ callee: e.node })) {
								const r = e.get("property"), n = e.get("object");
								if (n.isLiteral()) {
									const s = n.node.value, i = typeof s;
									let o = null;
									if (e.node.computed) {
										if (o = evaluateCached(r, t), !t.confident) return;
									} else r.isIdentifier() && (o = r.node.name);
									if (!("number" !== i && "string" !== i || null == o || "number" != typeof o && "string" != typeof o)) return s[o];
								}
							}
							if (e.isReferencedIdentifier()) {
								const n = e.scope.getBinding(e.node.name);
								if (n) {
									if (n.constantViolations.length > 0 || e.node.start < n.path.node.end) return void deopt(n.path, t);
									const s = n.path.scope;
									if ("var" === n.kind && s !== n.scope) {
										let i = !s.path.parentPath.isBlockStatement();
										for (let o = s.parent; o; o = o.parent) {
											var r;
											if (o === e.scope) {
												if (i) return void deopt(n.path, t);
												break;
											}
											null != (r = o.path.parentPath) && r.isBlockStatement() && (i = !0);
										}
									}
									if (n.hasValue) return n.value;
								}
								const s = e.node.name;
								if (i.has(s)) return n ? void deopt(n.path, t) : i.get(s);
								const o = e.resolve();
								if (o === e) return void deopt(e, t);
								const a = evaluateCached(o, t);
								return "object" == typeof a && null !== a && n.references > 1 ? void deopt(o, t) : a;
							}
							if (e.isUnaryExpression({ prefix: !0 })) {
								if ("void" === e.node.operator) return;
								const r = e.get("argument");
								if ("typeof" === e.node.operator && (r.isFunction() || r.isClass())) return "function";
								const n = evaluateCached(r, t);
								if (!t.confident) return;
								switch (e.node.operator) {
									case "!": return !n;
									case "+": return +n;
									case "-": return -n;
									case "~": return ~n;
									case "typeof": return typeof n;
								}
							}
							if (e.isArrayExpression()) {
								const r = [], n = e.get("elements");
								for (const e of n) {
									const n = e.evaluate();
									if (!n.confident) return void deopt(n.deopt, t);
									r.push(n.value);
								}
								return r;
							}
							if (e.isObjectExpression()) {
								const r = {}, n = e.get("properties");
								for (const e of n) {
									if (e.isObjectMethod() || e.isSpreadElement()) return void deopt(e, t);
									const n = e.get("key");
									let s;
									if (e.node.computed) {
										if (s = n.evaluate(), !s.confident) return void deopt(s.deopt, t);
										s = s.value;
									} else s = n.isIdentifier() ? n.node.name : n.node.value;
									let i = e.get("value").evaluate();
									if (!i.confident) return void deopt(i.deopt, t);
									i = i.value, r[s] = i;
								}
								return r;
							}
							if (e.isLogicalExpression()) {
								const r = t.confident, n = evaluateCached(e.get("left"), t), s = t.confident;
								t.confident = r;
								const i = evaluateCached(e.get("right"), t), o = t.confident;
								switch (e.node.operator) {
									case "||":
										if (t.confident = s && (!!n || o), !t.confident) return;
										return n || i;
									case "&&":
										if (t.confident = s && (!n || o), !t.confident) return;
										return n && i;
									case "??":
										if (t.confident = s && (null != n || o), !t.confident) return;
										return null != n ? n : i;
								}
							}
							if (e.isBinaryExpression()) {
								const r = evaluateCached(e.get("left"), t);
								if (!t.confident) return;
								const n = evaluateCached(e.get("right"), t);
								if (!t.confident) return;
								switch (e.node.operator) {
									case "-": return r - n;
									case "+": return r + n;
									case "/": return r / n;
									case "*": return r * n;
									case "%": return r % n;
									case "**": return Math.pow(r, n);
									case "<": return r < n;
									case ">": return r > n;
									case "<=": return r <= n;
									case ">=": return r >= n;
									case "==": return r == n;
									case "!=": return r != n;
									case "===": return r === n;
									case "!==": return r !== n;
									case "|": return r | n;
									case "&": return r & n;
									case "^": return r ^ n;
									case "<<": return r << n;
									case ">>": return r >> n;
									case ">>>": return r >>> n;
								}
							}
							if (e.isCallExpression()) {
								const r = e.get("callee");
								let i, o;
								if (r.isIdentifier() && !e.scope.getBinding(r.node.name) && (isValidObjectCallee(r.node.name) || function(e) {
									return n.includes(e);
								}(r.node.name)) && (o = global[r.node.name]), r.isMemberExpression()) {
									const e = r.get("object"), t = r.get("property");
									if (e.isIdentifier() && t.isIdentifier() && isValidObjectCallee(e.node.name) && !function(e) {
										return s.includes(e);
									}(t.node.name)) {
										i = global[e.node.name];
										const r = t.node.name;
										hasOwnProperty.call(i, r) && (o = i[r]);
									}
									if (e.isLiteral() && t.isIdentifier()) {
										const r = typeof e.node.value;
										"string" !== r && "number" !== r || (i = e.node.value, o = i[t.node.name]);
									}
								}
								if (o) {
									const r = e.get("arguments").map((e) => evaluateCached(e, t));
									if (!t.confident) return;
									return o.apply(i, r);
								}
							}
							deopt(e, t);
						}(e, t);
						return t.confident && (a.resolved = !0, a.value = l), l;
					}
				}
				function evaluateQuasis(e, t, r, n = !1) {
					let s = "", i = 0;
					const o = e.isTemplateLiteral() ? e.get("expressions") : e.get("quasi.expressions");
					for (const e of t) {
						if (!r.confident) break;
						s += n ? e.value.raw : e.value.cooked;
						const t = o[i++];
						t && (s += String(evaluateCached(t, r)));
					}
					if (r.confident) return s;
				}
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/family.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t._getKey = _getKey, t._getPattern = _getPattern, t.get = function(e, t = !0) {
					!0 === t && (t = this.context);
					const r = e.split(".");
					return 1 === r.length ? _getKey.call(this, e, t) : _getPattern.call(this, r, t);
				}, t.getAllNextSiblings = function() {
					let e = this.key, t = this.getSibling(++e);
					const r = [];
					for (; t.node;) r.push(t), t = this.getSibling(++e);
					return r;
				}, t.getAllPrevSiblings = function() {
					let e = this.key, t = this.getSibling(--e);
					const r = [];
					for (; t.node;) r.push(t), t = this.getSibling(--e);
					return r;
				}, t.getAssignmentIdentifiers = function() {
					return i(this.node);
				}, t.getBindingIdentifierPaths = function(e = !1, t = !1) {
					const r = [this], n = Object.create(null);
					for (; r.length;) {
						const s = r.shift();
						if (!s) continue;
						if (!s.node) continue;
						const i = o.keys[s.node.type];
						if (s.isIdentifier()) if (e) (n[s.node.name] = n[s.node.name] || []).push(s);
						else n[s.node.name] = s;
						else {
							if (s.isExportDeclaration()) {
								const e = s.get("declaration");
								e.isDeclaration() && r.push(e);
								continue;
							}
							if (t) {
								if (s.isFunctionDeclaration()) {
									r.push(s.get("id"));
									continue;
								}
								if (s.isFunctionExpression()) continue;
							}
							if (i) for (let e = 0; e < i.length; e++) {
								const t = i[e], n = s.get(t);
								Array.isArray(n) ? r.push(...n) : n.node && r.push(n);
							}
						}
					}
					return n;
				}, t.getBindingIdentifiers = function(e) {
					return o(this.node, e);
				}, t.getCompletionRecords = function(e = !1) {
					return _getCompletionRecords(this, {
						canHaveBreak: !1,
						shouldPopulateBreak: !1,
						inCaseClause: !1,
						shouldPreserveBreak: e
					}).map((e) => e.path);
				}, t.getNextSibling = function() {
					return this.getSibling(this.key + 1);
				}, t.getOpposite = function() {
					if ("left" === this.key) return this.getSibling("right");
					if ("right" === this.key) return this.getSibling("left");
					return null;
				}, t.getOuterBindingIdentifierPaths = function(e = !1) {
					return this.getBindingIdentifierPaths(e, !0);
				}, t.getOuterBindingIdentifiers = function(e) {
					return a(this.node, e);
				}, t.getPrevSibling = function() {
					return this.getSibling(this.key - 1);
				}, t.getSibling = function(e) {
					return n.default.get({
						parentPath: this.parentPath,
						parent: this.parent,
						container: this.container,
						listKey: this.listKey,
						key: e
					}).setContext(this.context);
				};
				var n = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/index.js");
				const { getAssignmentIdentifiers: i, getBindingIdentifiers: o, getOuterBindingIdentifiers: a, numericLiteral: l, unaryExpression: p } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), c = 0, u = 1;
				function addCompletionRecords(e, t, r) {
					return e && t.push(..._getCompletionRecords(e, r)), t;
				}
				function normalCompletionToBreak(e) {
					e.forEach((e) => {
						e.type = u;
					});
				}
				function replaceBreakStatementInBreakCompletion(e, t) {
					e.forEach((e) => {
						e.path.isBreakStatement({ label: null }) && (t ? e.path.replaceWith(p("void", l(0))) : e.path.remove());
					});
				}
				function getStatementListCompletion(e, t) {
					const r = [];
					if (t.canHaveBreak) {
						let n = [];
						for (let s = 0; s < e.length; s++) {
							const i = e[s], o = Object.assign({}, t, { inCaseClause: !1 });
							i.isBlockStatement() && (t.inCaseClause || t.shouldPopulateBreak) ? o.shouldPopulateBreak = !0 : o.shouldPopulateBreak = !1;
							const a = _getCompletionRecords(i, o);
							if (a.length > 0 && a.every((e) => e.type === u)) {
								n.length > 0 && a.every((e) => e.path.isBreakStatement({ label: null })) ? (normalCompletionToBreak(n), r.push(...n), n.some((e) => e.path.isDeclaration()) && (r.push(...a), t.shouldPreserveBreak || replaceBreakStatementInBreakCompletion(a, !0)), t.shouldPreserveBreak || replaceBreakStatementInBreakCompletion(a, !1)) : (r.push(...a), t.shouldPopulateBreak || t.shouldPreserveBreak || replaceBreakStatementInBreakCompletion(a, !0));
								break;
							}
							if (s === e.length - 1) r.push(...a);
							else {
								n = [];
								for (let e = 0; e < a.length; e++) {
									const t = a[e];
									t.type === u && r.push(t), t.type === c && n.push(t);
								}
							}
						}
					} else if (e.length) for (let n = e.length - 1; n >= 0; n--) {
						const s = _getCompletionRecords(e[n], t);
						if (s.length > 1 || 1 === s.length && !s[0].path.isVariableDeclaration() && !s[0].path.isEmptyStatement()) {
							r.push(...s);
							break;
						}
					}
					return r;
				}
				function _getCompletionRecords(e, t) {
					let r = [];
					if (e.isIfStatement()) r = addCompletionRecords(e.get("consequent"), r, t), r = addCompletionRecords(e.get("alternate"), r, t);
					else {
						if (e.isDoExpression() || e.isFor() || e.isWhile() || e.isLabeledStatement()) return addCompletionRecords(e.get("body"), r, t);
						if (e.isProgram() || e.isBlockStatement()) return getStatementListCompletion(e.get("body"), t);
						if (e.isFunction()) return _getCompletionRecords(e.get("body"), t);
						if (e.isTryStatement()) r = addCompletionRecords(e.get("block"), r, t), r = addCompletionRecords(e.get("handler"), r, t);
						else {
							if (e.isCatchClause()) return addCompletionRecords(e.get("body"), r, t);
							if (e.isSwitchStatement()) return function(e, t, r) {
								let n = [];
								for (let s = 0; s < e.length; s++) {
									const i = _getCompletionRecords(e[s], r), o = [], a = [];
									for (const e of i) e.type === c && o.push(e), e.type === u && a.push(e);
									o.length && (n = o), t.push(...a);
								}
								return t.push(...n), t;
							}(e.get("cases"), r, t);
							if (e.isSwitchCase()) return getStatementListCompletion(e.get("consequent"), {
								canHaveBreak: !0,
								shouldPopulateBreak: !1,
								inCaseClause: !0,
								shouldPreserveBreak: t.shouldPreserveBreak
							});
							e.isBreakStatement() ? r.push(function(e) {
								return {
									type: u,
									path: e
								};
							}(e)) : r.push(function(e) {
								return {
									type: c,
									path: e
								};
							}(e));
						}
					}
					return r;
				}
				function _getKey(e, t) {
					const r = this.node, s = r[e];
					return Array.isArray(s) ? s.map((i, o) => n.default.get({
						listKey: e,
						parentPath: this,
						parent: r,
						container: s,
						key: o
					}).setContext(t)) : n.default.get({
						parentPath: this,
						parent: r,
						container: r,
						key: e
					}).setContext(t);
				}
				function _getPattern(e, t) {
					let r = this;
					for (const n of e) r = "." === n ? r.parentPath : Array.isArray(r) ? r[n] : r.get(n, t);
					return r;
				}
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = t.SHOULD_STOP = t.SHOULD_SKIP = t.REMOVED = void 0;
				var n = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/lib/virtual-types.js"), s = r("./node_modules/.pnpm/debug@4.4.3/node_modules/debug/src/index.js"), i = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js"), o = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/scope/index.js"), a = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), l = a, p = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/cache.js"), c = r("./node_modules/.pnpm/@babel+generator@7.28.3/node_modules/@babel/generator/lib/index.js"), u = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/ancestry.js"), d = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/inference/index.js"), h = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/replacement.js"), m = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/evaluation.js"), f = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/conversion.js"), y = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/introspection.js"), b = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/context.js"), g = b, x = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/removal.js"), v = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/modification.js"), E = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/family.js"), T = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/comments.js"), S = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/lib/virtual-types-validator.js");
				const { validate: P } = a, _ = s("babel"), A = (t.REMOVED = 1, t.SHOULD_STOP = 2, t.SHOULD_SKIP = 4, t.default = class NodePath {
					constructor(e, t) {
						this.contexts = [], this.state = null, this.opts = null, this._traverseFlags = 0, this.skipKeys = null, this.parentPath = null, this.container = null, this.listKey = null, this.key = null, this.node = null, this.type = null, this._store = null, this.parent = t, this.hub = e, this.data = null, this.context = null, this.scope = null;
					}
					get removed() {
						return (1 & this._traverseFlags) > 0;
					}
					set removed(e) {
						e ? this._traverseFlags |= 1 : this._traverseFlags &= -2;
					}
					get shouldStop() {
						return (2 & this._traverseFlags) > 0;
					}
					set shouldStop(e) {
						e ? this._traverseFlags |= 2 : this._traverseFlags &= -3;
					}
					get shouldSkip() {
						return (4 & this._traverseFlags) > 0;
					}
					set shouldSkip(e) {
						e ? this._traverseFlags |= 4 : this._traverseFlags &= -5;
					}
					static get({ hub: e, parentPath: t, parent: r, container: n, listKey: s, key: i }) {
						if (!e && t && (e = t.hub), !r) throw new Error("To get a node path the parent needs to exist");
						const o = n[i], a = p.getOrCreateCachedPaths(r, t);
						let l = a.get(o);
						return l || (l = new NodePath(e, r), o && a.set(o, l)), b.setup.call(l, t, n, s, i), l;
					}
					getScope(e) {
						return this.isScope() ? new o.default(this) : e;
					}
					setData(e, t) {
						return this.data ?? (this.data = Object.create(null)), this.data[e] = t;
					}
					getData(e, t) {
						this.data ?? (this.data = Object.create(null));
						let r = this.data[e];
						return void 0 === r && void 0 !== t && (r = this.data[e] = t), r;
					}
					hasNode() {
						return null != this.node;
					}
					buildCodeFrameError(e, t = SyntaxError) {
						return this.hub.buildError(this.node, e, t);
					}
					traverse(e, t) {
						(0, i.default)(this.node, e, this.scope, t, this);
					}
					set(e, t) {
						P(this.node, e, t), this.node[e] = t;
					}
					getPathLocation() {
						const e = [];
						let t = this;
						do {
							let r = t.key;
							t.inList && (r = `${t.listKey}[${r}]`), e.unshift(r);
						} while (t = t.parentPath);
						return e.join(".");
					}
					debug(e) {
						_.enabled && _(`${this.getPathLocation()} ${this.type}: ${e}`);
					}
					toString() {
						return (0, c.default)(this.node).code;
					}
					get inList() {
						return !!this.listKey;
					}
					set inList(e) {
						e || (this.listKey = null);
					}
					get parentKey() {
						return this.listKey || this.key;
					}
				}), C = {
					findParent: u.findParent,
					find: u.find,
					getFunctionParent: u.getFunctionParent,
					getStatementParent: u.getStatementParent,
					getEarliestCommonAncestorFrom: u.getEarliestCommonAncestorFrom,
					getDeepestCommonAncestorFrom: u.getDeepestCommonAncestorFrom,
					getAncestry: u.getAncestry,
					isAncestor: u.isAncestor,
					isDescendant: u.isDescendant,
					inType: u.inType,
					getTypeAnnotation: d.getTypeAnnotation,
					isBaseType: d.isBaseType,
					couldBeBaseType: d.couldBeBaseType,
					baseTypeStrictlyMatches: d.baseTypeStrictlyMatches,
					isGenericType: d.isGenericType,
					replaceWithMultiple: h.replaceWithMultiple,
					replaceWithSourceString: h.replaceWithSourceString,
					replaceWith: h.replaceWith,
					replaceExpressionWithStatements: h.replaceExpressionWithStatements,
					replaceInline: h.replaceInline,
					evaluateTruthy: m.evaluateTruthy,
					evaluate: m.evaluate,
					toComputedKey: f.toComputedKey,
					ensureBlock: f.ensureBlock,
					unwrapFunctionEnvironment: f.unwrapFunctionEnvironment,
					arrowFunctionToExpression: f.arrowFunctionToExpression,
					splitExportDeclaration: f.splitExportDeclaration,
					ensureFunctionName: f.ensureFunctionName,
					matchesPattern: y.matchesPattern,
					isStatic: y.isStatic,
					isNodeType: y.isNodeType,
					canHaveVariableDeclarationOrExpression: y.canHaveVariableDeclarationOrExpression,
					canSwapBetweenExpressionAndStatement: y.canSwapBetweenExpressionAndStatement,
					isCompletionRecord: y.isCompletionRecord,
					isStatementOrBlock: y.isStatementOrBlock,
					referencesImport: y.referencesImport,
					getSource: y.getSource,
					willIMaybeExecuteBefore: y.willIMaybeExecuteBefore,
					_guessExecutionStatusRelativeTo: y._guessExecutionStatusRelativeTo,
					resolve: y.resolve,
					isConstantExpression: y.isConstantExpression,
					isInStrictMode: y.isInStrictMode,
					isDenylisted: g.isDenylisted,
					visit: g.visit,
					skip: g.skip,
					skipKey: g.skipKey,
					stop: g.stop,
					setContext: g.setContext,
					requeue: g.requeue,
					requeueComputedKeyAndDecorators: g.requeueComputedKeyAndDecorators,
					remove: x.remove,
					insertBefore: v.insertBefore,
					insertAfter: v.insertAfter,
					unshiftContainer: v.unshiftContainer,
					pushContainer: v.pushContainer,
					getOpposite: E.getOpposite,
					getCompletionRecords: E.getCompletionRecords,
					getSibling: E.getSibling,
					getPrevSibling: E.getPrevSibling,
					getNextSibling: E.getNextSibling,
					getAllNextSiblings: E.getAllNextSiblings,
					getAllPrevSiblings: E.getAllPrevSiblings,
					get: E.get,
					getAssignmentIdentifiers: E.getAssignmentIdentifiers,
					getBindingIdentifiers: E.getBindingIdentifiers,
					getOuterBindingIdentifiers: E.getOuterBindingIdentifiers,
					getBindingIdentifierPaths: E.getBindingIdentifierPaths,
					getOuterBindingIdentifierPaths: E.getOuterBindingIdentifierPaths,
					shareCommentsWithSiblings: T.shareCommentsWithSiblings,
					addComment: T.addComment,
					addComments: T.addComments
				};
				Object.assign(A.prototype, C), A.prototype.arrowFunctionToShadowed = f[String("arrowFunctionToShadowed")], Object.assign(A.prototype, {
					has: y[String("has")],
					is: y[String("is")],
					isnt: y[String("isnt")],
					equals: y[String("equals")],
					hoist: v[String("hoist")],
					updateSiblingKeys: v.updateSiblingKeys,
					call: g.call,
					isBlacklisted: g[String("isBlacklisted")],
					setScope: g.setScope,
					resync: g.resync,
					popContext: g.popContext,
					pushContext: g.pushContext,
					setup: g.setup,
					setKey: g.setKey
				}), A.prototype._guessExecutionStatusRelativeToDifferentFunctions = y._guessExecutionStatusRelativeTo, A.prototype._guessExecutionStatusRelativeToDifferentFunctions = y._guessExecutionStatusRelativeTo, Object.assign(A.prototype, {
					_getTypeAnnotation: d._getTypeAnnotation,
					_replaceWith: h._replaceWith,
					_resolve: y._resolve,
					_call: g._call,
					_resyncParent: g._resyncParent,
					_resyncKey: g._resyncKey,
					_resyncList: g._resyncList,
					_resyncRemoved: g._resyncRemoved,
					_getQueueContexts: g._getQueueContexts,
					_removeFromScope: x._removeFromScope,
					_callRemovalHooks: x._callRemovalHooks,
					_remove: x._remove,
					_markRemoved: x._markRemoved,
					_assertUnremoved: x._assertUnremoved,
					_containerInsert: v._containerInsert,
					_containerInsertBefore: v._containerInsertBefore,
					_containerInsertAfter: v._containerInsertAfter,
					_verifyNodeList: v._verifyNodeList,
					_getKey: E._getKey,
					_getPattern: E._getPattern
				});
				for (const e of l.TYPES) {
					const t = `is${e}`, r = l[t];
					A.prototype[t] = function(e) {
						return r(this.node, e);
					}, A.prototype[`assert${e}`] = function(t) {
						if (!r(this.node, t)) throw new TypeError(`Expected node path of type ${e}`);
					};
				}
				Object.assign(A.prototype, S);
				for (const e of Object.keys(n)) "_" !== e[0] && (l.TYPES.includes(e) || l.TYPES.push(e));
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/inference/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t._getTypeAnnotation = _getTypeAnnotation, t.baseTypeStrictlyMatches = function(e) {
					const t = this.getTypeAnnotation(), r = e.getTypeAnnotation();
					if (!o(t) && c(t)) return r.type === t.type;
					return !1;
				}, t.couldBeBaseType = function(e) {
					const t = this.getTypeAnnotation();
					if (o(t)) return !0;
					if (E(t)) {
						for (const r of t.types) if (o(r) || _isBaseType(e, r, !0)) return !0;
						return !1;
					}
					return _isBaseType(e, t, !0);
				}, t.getTypeAnnotation = function() {
					let e = this.getData("typeAnnotation");
					if (null != e) return e;
					e = _getTypeAnnotation.call(this) || i(), (v(e) || b(e)) && (e = e.typeAnnotation);
					return this.setData("typeAnnotation", e), e;
				}, t.isBaseType = function(e, t) {
					return _isBaseType(e, this.getTypeAnnotation(), t);
				}, t.isGenericType = function(e) {
					const t = this.getTypeAnnotation();
					if ("Array" === e && (y(t) || a(t) || x(t))) return !0;
					return u(t) && d(t.id, { name: e }) || g(t) && d(t.typeName, { name: e });
				};
				var n = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/inference/inferers.js");
				const { anyTypeAnnotation: i, isAnyTypeAnnotation: o, isArrayTypeAnnotation: a, isBooleanTypeAnnotation: l, isEmptyTypeAnnotation: p, isFlowBaseAnnotation: c, isGenericTypeAnnotation: u, isIdentifier: d, isMixedTypeAnnotation: h, isNumberTypeAnnotation: m, isStringTypeAnnotation: f, isTSArrayType: y, isTSTypeAnnotation: b, isTSTypeReference: g, isTupleTypeAnnotation: x, isTypeAnnotation: v, isUnionTypeAnnotation: E, isVoidTypeAnnotation: T, stringTypeAnnotation: S, voidTypeAnnotation: P } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
				const _ = /* @__PURE__ */ new WeakSet();
				function _getTypeAnnotation() {
					const e = this.node;
					if (e) {
						if (e.typeAnnotation) return e.typeAnnotation;
						if (!_.has(e)) {
							_.add(e);
							try {
								var t;
								let r = n[e.type];
								if (r) return r.call(this, e);
								if (r = n[this.parentPath.type], null != (t = r) && t.validParent) return this.parentPath.getTypeAnnotation();
							} finally {
								_.delete(e);
							}
						}
					} else if ("init" === this.key && this.parentPath.isVariableDeclarator()) {
						const e = this.parentPath.parentPath, t = e.parentPath;
						return "left" === e.key && t.isForInStatement() ? S() : "left" === e.key && t.isForOfStatement() ? i() : P();
					}
				}
				function _isBaseType(e, t, r) {
					if ("string" === e) return f(t);
					if ("number" === e) return m(t);
					if ("boolean" === e) return l(t);
					if ("any" === e) return o(t);
					if ("mixed" === e) return h(t);
					if ("empty" === e) return p(t);
					if ("void" === e) return T(t);
					if (r) return !1;
					throw new Error(`Unknown base type ${e}`);
				}
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/inference/inferer-reference.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					if (!this.isReferenced()) return;
					const t = this.scope.getBinding(e.name);
					if (t) return t.identifier.typeAnnotation ? t.identifier.typeAnnotation : function(e, t, r) {
						const n = [], i = [];
						let o = getConstantViolationsBefore(e, t, i);
						const a = getConditionalAnnotation(e, t, r);
						if (a) {
							const t = getConstantViolationsBefore(e, a.ifStatement);
							o = o.filter((e) => !t.includes(e)), n.push(a.typeAnnotation);
						}
						if (o.length) {
							o.push(...i);
							for (const e of o) n.push(e.getTypeAnnotation());
						}
						if (!n.length) return;
						return (0, s.createUnionType)(n);
					}(t, this, e.name);
					if ("undefined" === e.name) return l();
					if ("NaN" === e.name || "Infinity" === e.name) return a();
					e.name;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/inference/util.js");
				const { BOOLEAN_NUMBER_BINARY_OPERATORS: i, createTypeAnnotationBasedOnTypeof: o, numberTypeAnnotation: a, voidTypeAnnotation: l } = n;
				function getConstantViolationsBefore(e, t, r) {
					const n = e.constantViolations.slice();
					return n.unshift(e.path), n.filter((e) => {
						const n = (e = e.resolve())._guessExecutionStatusRelativeTo(t);
						return r && "unknown" === n && r.push(e), "before" === n;
					});
				}
				function inferAnnotationFromBinaryExpression(e, t) {
					const r = t.node.operator, n = t.get("right").resolve(), s = t.get("left").resolve();
					let l, p, c;
					if (s.isIdentifier({ name: e }) ? l = n : n.isIdentifier({ name: e }) && (l = s), l) return "===" === r ? l.getTypeAnnotation() : i.includes(r) ? a() : void 0;
					if ("===" !== r && "==" !== r) return;
					if (s.isUnaryExpression({ operator: "typeof" }) ? (p = s, c = n) : n.isUnaryExpression({ operator: "typeof" }) && (p = n, c = s), !p) return;
					if (!p.get("argument").isIdentifier({ name: e })) return;
					if (c = c.resolve(), !c.isLiteral()) return;
					const u = c.node.value;
					return "string" == typeof u ? o(u) : void 0;
				}
				function getConditionalAnnotation(e, t, r) {
					const n = function(e, t, r) {
						let n;
						for (; n = t.parentPath;) {
							if (n.isIfStatement() || n.isConditionalExpression()) {
								if ("test" === t.key) return;
								return n;
							}
							if (n.isFunction() && n.parentPath.scope.getBinding(r) !== e) return;
							t = n;
						}
					}(e, t, r);
					if (!n) return;
					const i = [n.get("test")], o = [];
					for (let e = 0; e < i.length; e++) {
						const t = i[e];
						if (t.isLogicalExpression()) "&&" === t.node.operator && (i.push(t.get("left")), i.push(t.get("right")));
						else if (t.isBinaryExpression()) {
							const e = inferAnnotationFromBinaryExpression(r, t);
							e && o.push(e);
						}
					}
					return o.length ? {
						typeAnnotation: (0, s.createUnionType)(o),
						ifStatement: n
					} : getConditionalAnnotation(e, n, r);
				}
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/inference/inferers.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.ArrayExpression = ArrayExpression, t.AssignmentExpression = function() {
					return this.get("right").getTypeAnnotation();
				}, t.BinaryExpression = function(e) {
					const t = e.operator;
					if (l.includes(t)) return g();
					if (o.includes(t)) return h();
					if ("+" === t) {
						const e = this.get("right"), t = this.get("left");
						return t.isBaseType("number") && e.isBaseType("number") ? g() : t.isBaseType("string") || e.isBaseType("string") ? x() : E([x(), g()]);
					}
				}, t.BooleanLiteral = function() {
					return h();
				}, t.CallExpression = function() {
					const { callee: e } = this.node;
					if (_(e)) return d(x());
					if (P(e) || A(e) || S(e, { name: "Array" })) return d(u());
					if (C(e)) return d(v([x(), u()]));
					return resolveCall(this.get("callee"));
				}, t.ConditionalExpression = function() {
					const e = [this.get("consequent").getTypeAnnotation(), this.get("alternate").getTypeAnnotation()];
					return (0, i.createUnionType)(e);
				}, t.ClassDeclaration = t.ClassExpression = t.FunctionDeclaration = t.ArrowFunctionExpression = t.FunctionExpression = function() {
					return f(y("Function"));
				}, Object.defineProperty(t, "Identifier", {
					enumerable: !0,
					get: function() {
						return s.default;
					}
				}), t.LogicalExpression = function() {
					const e = [this.get("left").getTypeAnnotation(), this.get("right").getTypeAnnotation()];
					return (0, i.createUnionType)(e);
				}, t.NewExpression = function(e) {
					if ("Identifier" === e.callee.type) return f(e.callee);
				}, t.NullLiteral = function() {
					return b();
				}, t.NumericLiteral = function() {
					return g();
				}, t.ObjectExpression = function() {
					return f(y("Object"));
				}, t.ParenthesizedExpression = function() {
					return this.get("expression").getTypeAnnotation();
				}, t.RegExpLiteral = function() {
					return f(y("RegExp"));
				}, t.RestElement = RestElement, t.SequenceExpression = function() {
					return this.get("expressions").pop().getTypeAnnotation();
				}, t.StringLiteral = function() {
					return x();
				}, t.TSAsExpression = TSAsExpression, t.TSNonNullExpression = function() {
					return this.get("expression").getTypeAnnotation();
				}, t.TaggedTemplateExpression = function() {
					return resolveCall(this.get("tag"));
				}, t.TemplateLiteral = function() {
					return x();
				}, t.TypeCastExpression = TypeCastExpression, t.UnaryExpression = function(e) {
					const t = e.operator;
					if ("void" === t) return T();
					if (p.includes(t)) return g();
					if (c.includes(t)) return x();
					if (a.includes(t)) return h();
				}, t.UpdateExpression = function(e) {
					const t = e.operator;
					if ("++" === t || "--" === t) return g();
				}, t.VariableDeclarator = function() {
					if (!this.get("id").isIdentifier()) return;
					return this.get("init").getTypeAnnotation();
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/inference/inferer-reference.js"), i = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/inference/util.js");
				const { BOOLEAN_BINARY_OPERATORS: o, BOOLEAN_UNARY_OPERATORS: a, NUMBER_BINARY_OPERATORS: l, NUMBER_UNARY_OPERATORS: p, STRING_UNARY_OPERATORS: c, anyTypeAnnotation: u, arrayTypeAnnotation: d, booleanTypeAnnotation: h, buildMatchMemberExpression: m, genericTypeAnnotation: f, identifier: y, nullLiteralTypeAnnotation: b, numberTypeAnnotation: g, stringTypeAnnotation: x, tupleTypeAnnotation: v, unionTypeAnnotation: E, voidTypeAnnotation: T, isIdentifier: S } = n;
				function TypeCastExpression(e) {
					return e.typeAnnotation;
				}
				function TSAsExpression(e) {
					return e.typeAnnotation;
				}
				function ArrayExpression() {
					return f(y("Array"));
				}
				function RestElement() {
					return ArrayExpression();
				}
				TypeCastExpression.validParent = !0, TSAsExpression.validParent = !0, RestElement.validParent = !0;
				const P = m("Array.from"), _ = m("Object.keys"), A = m("Object.values"), C = m("Object.entries");
				function resolveCall(e) {
					if ((e = e.resolve()).isFunction()) {
						const { node: t } = e;
						if (t.async) return t.generator ? f(y("AsyncIterator")) : f(y("Promise"));
						if (t.generator) return f(y("Iterator"));
						if (e.node.returnType) return e.node.returnType;
					}
				}
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/inference/util.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.createUnionType = function(e) {
					if (e.every((e) => a(e))) return s ? s(e) : o(e);
					if (e.every((e) => l(e)) && i) return i(e);
				};
				const { createFlowUnionType: s, createTSUnionType: i, createUnionTypeAnnotation: o, isFlowType: a, isTSType: l } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/introspection.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t._guessExecutionStatusRelativeTo = function(e) {
					return _guessExecutionStatusRelativeToCached(this, e, /* @__PURE__ */ new Map());
				}, t._resolve = _resolve, t.canHaveVariableDeclarationOrExpression = function() {
					return ("init" === this.key || "left" === this.key) && this.parentPath.isFor();
				}, t.canSwapBetweenExpressionAndStatement = function(e) {
					if ("body" !== this.key || !this.parentPath.isArrowFunctionExpression()) return !1;
					if (this.isExpression()) return o(e);
					if (this.isBlockStatement()) return a(e);
					return !1;
				}, t.getSource = function() {
					const e = this.node;
					if (e.end) {
						const t = this.hub.getCode();
						if (t) return t.slice(e.start, e.end);
					}
					return "";
				}, t.isCompletionRecord = function(e) {
					let t = this, r = !0;
					do {
						const { type: n, container: s } = t;
						if (!r && (t.isFunction() || "StaticBlock" === n)) return !!e;
						if (r = !1, Array.isArray(s) && t.key !== s.length - 1) return !1;
					} while ((t = t.parentPath) && !t.isProgram() && !t.isDoExpression());
					return !0;
				}, t.isConstantExpression = function() {
					if (this.isIdentifier()) {
						const e = this.scope.getBinding(this.node.name);
						return !!e && e.constant;
					}
					if (this.isLiteral()) return !this.isRegExpLiteral() && (!this.isTemplateLiteral() || this.get("expressions").every((e) => e.isConstantExpression()));
					if (this.isUnaryExpression()) return "void" === this.node.operator && this.get("argument").isConstantExpression();
					if (this.isBinaryExpression()) {
						const { operator: e } = this.node;
						return "in" !== e && "instanceof" !== e && this.get("left").isConstantExpression() && this.get("right").isConstantExpression();
					}
					if (this.isMemberExpression()) return !this.node.computed && this.get("object").isIdentifier({ name: "Symbol" }) && !this.scope.hasBinding("Symbol", { noGlobals: !0 });
					if (this.isCallExpression()) return 1 === this.node.arguments.length && this.get("callee").matchesPattern("Symbol.for") && !this.scope.hasBinding("Symbol", { noGlobals: !0 }) && this.get("arguments")[0].isStringLiteral();
					return !1;
				}, t.isInStrictMode = function() {
					return !!(this.isProgram() ? this : this.parentPath).find((e) => {
						if (e.isProgram({ sourceType: "module" })) return !0;
						if (e.isClass()) return !0;
						if (e.isArrowFunctionExpression() && !e.get("body").isBlockStatement()) return !1;
						let t;
						if (e.isFunction()) t = e.node.body;
						else {
							if (!e.isProgram()) return !1;
							t = e.node;
						}
						for (const e of t.directives) if ("use strict" === e.value.value) return !0;
					});
				}, t.isNodeType = function(e) {
					return u(this.type, e);
				}, t.isStatementOrBlock = function() {
					return !this.parentPath.isLabeledStatement() && !o(this.container) && s.includes(this.key);
				}, t.isStatic = function() {
					return this.scope.isStatic(this.node);
				}, t.matchesPattern = function(e, t) {
					return d(this.node, e, t);
				}, t.referencesImport = function(e, t) {
					if (!this.isReferencedIdentifier()) {
						if (this.isJSXMemberExpression() && this.node.property.name === t || (this.isMemberExpression() || this.isOptionalMemberExpression()) && (this.node.computed ? c(this.node.property, { value: t }) : this.node.property.name === t)) {
							const t = this.get("object");
							return t.isReferencedIdentifier() && t.referencesImport(e, "*");
						}
						return !1;
					}
					const r = this.scope.getBinding(this.node.name);
					if (!r || "module" !== r.kind) return !1;
					const n = r.path, s = n.parentPath;
					if (!s.isImportDeclaration()) return !1;
					if (s.node.source.value !== e) return !1;
					if (!t) return !0;
					if (n.isImportDefaultSpecifier() && "default" === t) return !0;
					if (n.isImportNamespaceSpecifier() && "*" === t) return !0;
					if (n.isImportSpecifier() && l(n.node.imported, { name: t })) return !0;
					return !1;
				}, t.resolve = function(e, t) {
					return _resolve.call(this, e, t) || this;
				}, t.willIMaybeExecuteBefore = function(e) {
					return "after" !== this._guessExecutionStatusRelativeTo(e);
				};
				const { STATEMENT_OR_BLOCK_KEYS: s, VISITOR_KEYS: i, isBlockStatement: o, isExpression: a, isIdentifier: l, isLiteral: p, isStringLiteral: c, isType: u, matchesPattern: d } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
				function getOuterFunction(e) {
					return e.isProgram() ? e : (e.parentPath.scope.getFunctionParent() || e.parentPath.scope.getProgramParent()).path;
				}
				function isExecutionUncertain(e, t) {
					switch (e) {
						case "LogicalExpression":
						case "AssignmentPattern": return "right" === t;
						case "ConditionalExpression":
						case "IfStatement": return "consequent" === t || "alternate" === t;
						case "WhileStatement":
						case "DoWhileStatement":
						case "ForInStatement":
						case "ForOfStatement": return "body" === t;
						case "ForStatement": return "body" === t || "update" === t;
						case "SwitchStatement": return "cases" === t;
						case "TryStatement": return "handler" === t;
						case "OptionalMemberExpression": return "property" === t;
						case "OptionalCallExpression": return "arguments" === t;
						default: return !1;
					}
				}
				function isExecutionUncertainInList(e, t) {
					for (let r = 0; r < t; r++) {
						const t = e[r];
						if (isExecutionUncertain(t.parent.type, t.parentKey)) return !0;
					}
					return !1;
				}
				t.has = function(e) {
					var t;
					const r = null == (t = this.node) ? void 0 : t[e];
					return r && Array.isArray(r) ? !!r.length : !!r;
				}, t.is = t.has, t.isnt = function(e) {
					return !this.has(e);
				}, t.equals = function(e, t) {
					return this.node[e] === t;
				};
				const h = Symbol();
				function _guessExecutionStatusRelativeToCached(e, t, r) {
					const n = {
						this: getOuterFunction(e),
						target: getOuterFunction(t)
					};
					if (n.target.node !== n.this.node) return function(e, t, r) {
						let n, s = r.get(e.node);
						if (s) {
							if (n = s.get(t.node)) return n === h ? "unknown" : n;
						} else r.set(e.node, s = /* @__PURE__ */ new Map());
						s.set(t.node, h);
						const i = function(e, t, r) {
							if (!t.isFunctionDeclaration()) return "before" === _guessExecutionStatusRelativeToCached(e, t, r) ? "before" : "unknown";
							if (t.parentPath.isExportDeclaration()) return "unknown";
							const n = t.scope.getBinding(t.node.id.name);
							if (!n.references) return "before";
							const s = n.referencePaths;
							let i;
							for (const n of s) {
								if (!!n.find((e) => e.node === t.node)) continue;
								if ("callee" !== n.key || !n.parentPath.isCallExpression()) return "unknown";
								const s = _guessExecutionStatusRelativeToCached(e, n, r);
								if (i && i !== s) return "unknown";
								i = s;
							}
							return i;
						}(e, t, r);
						return s.set(t.node, i), i;
					}(e, n.target, r);
					const s = {
						target: t.getAncestry(),
						this: e.getAncestry()
					};
					if (s.target.includes(e)) return "after";
					if (s.this.includes(t)) return "before";
					let o;
					const a = {
						target: 0,
						this: 0
					};
					for (; !o && a.this < s.this.length;) {
						const e = s.this[a.this];
						a.target = s.target.indexOf(e), a.target >= 0 ? o = e : a.this++;
					}
					if (!o) throw new Error("Internal Babel error - The two compared nodes don't appear to belong to the same program.");
					if (isExecutionUncertainInList(s.this, a.this - 1) || isExecutionUncertainInList(s.target, a.target - 1)) return "unknown";
					const l = {
						this: s.this[a.this - 1],
						target: s.target[a.target - 1]
					};
					if (l.target.listKey && l.this.listKey && l.target.container === l.this.container) return l.target.key > l.this.key ? "before" : "after";
					const p = i[o.type], c = p.indexOf(l.this.parentKey);
					return p.indexOf(l.target.parentKey) > c ? "before" : "after";
				}
				function _resolve(e, t) {
					var r;
					if (null == (r = t) || !r.includes(this)) if ((t = t || []).push(this), this.isVariableDeclarator()) {
						if (this.get("id").isIdentifier()) return this.get("init").resolve(e, t);
					} else if (this.isReferencedIdentifier()) {
						const r = this.scope.getBinding(this.node.name);
						if (!r) return;
						if (!r.constant) return;
						if ("module" === r.kind) return;
						if (r.path !== this) {
							const n = r.path.resolve(e, t);
							if (this.find((e) => e.node === n.node)) return;
							return n;
						}
					} else {
						if (this.isTypeCastExpression()) return this.get("expression").resolve(e, t);
						if (e && this.isMemberExpression()) {
							const r = this.toComputedKey();
							if (!p(r)) return;
							const n = r.value, s = this.get("object").resolve(e, t);
							if (s.isObjectExpression()) {
								const r = s.get("properties");
								for (const s of r) {
									if (!s.isProperty()) continue;
									const r = s.get("key");
									let i = s.isnt("computed") && r.isIdentifier({ name: n });
									if (i = i || r.isLiteral({ value: n }), i) return s.get("value").resolve(e, t);
								}
							} else if (s.isArrayExpression() && !isNaN(+n)) {
								const r = s.get("elements")[n];
								if (r) return r.resolve(e, t);
							}
						}
					}
				}
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/lib/hoister.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = n;
				const { react: i } = n, { cloneNode: o, jsxExpressionContainer: a, variableDeclaration: l, variableDeclarator: p } = s, c = { ReferencedIdentifier(e, t) {
					if (e.isJSXIdentifier() && i.isCompatTag(e.node.name) && !e.parentPath.isJSXMemberExpression()) return;
					if ("this" === e.node.name) {
						let r = e.scope;
						do
							if (r.path.isFunction() && !r.path.isArrowFunctionExpression()) break;
						while (r = r.parent);
						r && t.breakOnScopePaths.push(r.path);
					}
					const r = e.scope.getBinding(e.node.name);
					if (r) {
						for (const n of r.constantViolations) if (n.scope !== r.path.scope) return t.mutableBinding = !0, void e.stop();
						r === t.scope.getBinding(e.node.name) && (t.bindings[e.node.name] = r);
					}
				} };
				t.default = class {
					constructor(e, t) {
						this.breakOnScopePaths = void 0, this.bindings = void 0, this.mutableBinding = void 0, this.scopes = void 0, this.scope = void 0, this.path = void 0, this.attachAfter = void 0, this.breakOnScopePaths = [], this.bindings = {}, this.mutableBinding = !1, this.scopes = [], this.scope = t, this.path = e, this.attachAfter = !1;
					}
					isCompatibleScope(e) {
						for (const t of Object.keys(this.bindings)) {
							const r = this.bindings[t];
							if (!e.bindingIdentifierEquals(t, r.identifier)) return !1;
						}
						return !0;
					}
					getCompatibleScopes() {
						let e = this.path.scope;
						do {
							if (!this.isCompatibleScope(e)) break;
							if (this.scopes.push(e), this.breakOnScopePaths.includes(e.path)) break;
						} while (e = e.parent);
					}
					getAttachmentPath() {
						let e = this._getAttachmentPath();
						if (!e) return;
						let t = e.scope;
						if (t.path === e && (t = e.scope.parent), t.path.isProgram() || t.path.isFunction()) for (const r of Object.keys(this.bindings)) {
							if (!t.hasOwnBinding(r)) continue;
							const n = this.bindings[r];
							if ("param" === n.kind || "params" === n.path.parentKey) continue;
							if (this.getAttachmentParentForPath(n.path).key >= e.key) {
								this.attachAfter = !0, e = n.path;
								for (const t of n.constantViolations) this.getAttachmentParentForPath(t).key > e.key && (e = t);
							}
						}
						return e;
					}
					_getAttachmentPath() {
						const e = this.scopes.pop();
						if (e) {
							if (e.path.isFunction()) {
								if (!this.hasOwnParamBindings(e)) return this.getNextScopeAttachmentParent();
								{
									if (this.scope === e) return;
									const t = e.path.get("body").get("body");
									for (let e = 0; e < t.length; e++) if (!t[e].node._blockHoist) return t[e];
								}
							} else if (e.path.isProgram()) return this.getNextScopeAttachmentParent();
						}
					}
					getNextScopeAttachmentParent() {
						const e = this.scopes.pop();
						if (e) return this.getAttachmentParentForPath(e.path);
					}
					getAttachmentParentForPath(e) {
						do
							if (!e.parentPath || Array.isArray(e.container) && e.isStatement()) return e;
						while (e = e.parentPath);
					}
					hasOwnParamBindings(e) {
						for (const t of Object.keys(this.bindings)) {
							if (!e.hasOwnBinding(t)) continue;
							const r = this.bindings[t];
							if ("param" === r.kind && r.constant) return !0;
						}
						return !1;
					}
					run() {
						if (this.path.traverse(c, this), this.mutableBinding) return;
						this.getCompatibleScopes();
						const e = this.getAttachmentPath();
						if (!e) return;
						if (e.getFunctionParent() === this.path.getFunctionParent()) return;
						let t = e.scope.generateUidIdentifier("ref");
						const r = p(t, this.path.node), [s] = e[this.attachAfter ? "insertAfter" : "insertBefore"]([e.isVariableDeclarator() ? r : l("var", [r])]), i = this.path.parentPath;
						return i.isJSXElement() && this.path.container === i.node.children && (t = a(t)), this.path.replaceWith(o(t)), s.isVariableDeclarator() ? s.get("init") : s.get("declarations.0.init");
					}
				};
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/lib/removal-hooks.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.hooks = void 0;
				t.hooks = [
					function(e, t) {
						if ("test" === e.key && (t.isWhile() || t.isSwitchCase()) || "declaration" === e.key && t.isExportDeclaration() || "body" === e.key && t.isLabeledStatement() || "declarations" === e.listKey && t.isVariableDeclaration() && 1 === t.node.declarations.length || "expression" === e.key && t.isExpressionStatement()) return t.remove(), !0;
					},
					function(e, t) {
						if (t.isSequenceExpression() && 1 === t.node.expressions.length) return t.replaceWith(t.node.expressions[0]), !0;
					},
					function(e, t) {
						if (t.isBinary()) return "left" === e.key ? t.replaceWith(t.node.right) : t.replaceWith(t.node.left), !0;
					},
					function(e, t) {
						if (t.isIfStatement() && "consequent" === e.key || "body" === e.key && (t.isLoop() || t.isArrowFunctionExpression())) return e.replaceWith({
							type: "BlockStatement",
							body: []
						}), !0;
					}
				];
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/lib/virtual-types-validator.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.isBindingIdentifier = function() {
					const { node: e, parent: t } = this, r = this.parentPath.parent;
					return u(e) && s(e, t, r);
				}, t.isBlockScoped = function() {
					return i(this.node);
				}, t.isExpression = function() {
					return this.isIdentifier() ? this.isReferencedIdentifier() : a(this.node);
				}, t.isFlow = function() {
					const { node: e } = this;
					return !!l(e) || (d(e) ? "type" === e.importKind || "typeof" === e.importKind : o(e) ? "type" === e.exportKind : !!h(e) && ("type" === e.importKind || "typeof" === e.importKind));
				}, t.isForAwaitStatement = function() {
					return P(this.node, { await: !0 });
				}, t.isGenerated = function() {
					return !this.isUser();
				}, t.isPure = function(e) {
					return this.scope.isPure(this.node, e);
				}, t.isReferenced = function() {
					return g(this.node, this.parent);
				}, t.isReferencedIdentifier = function(e) {
					const { node: t, parent: r } = this;
					if (!u(t, e) && !f(r, e)) {
						if (!m(t, e)) return !1;
						if (_(t.name)) return !1;
					}
					return g(t, r, this.parentPath.parent);
				}, t.isReferencedMemberExpression = function() {
					const { node: e, parent: t } = this;
					return y(e) && g(e, t);
				}, t.isRestProperty = function() {
					var e;
					return b(this.node) && (null == (e = this.parentPath) ? void 0 : e.isObjectPattern());
				}, t.isScope = function() {
					return x(this.node, this.parent);
				}, t.isSpreadProperty = function() {
					var e;
					return b(this.node) && (null == (e = this.parentPath) ? void 0 : e.isObjectExpression());
				}, t.isStatement = function() {
					const { node: e, parent: t } = this;
					if (v(e)) {
						if (T(e)) {
							if (c(t, { left: e })) return !1;
							if (p(t, { init: e })) return !1;
						}
						return !0;
					}
					return !1;
				}, t.isUser = function() {
					return this.node && !!this.node.loc;
				}, t.isVar = function() {
					return E(this.node);
				};
				const { isBinding: s, isBlockScoped: i, isExportDeclaration: o, isExpression: a, isFlow: l, isForStatement: p, isForXStatement: c, isIdentifier: u, isImportDeclaration: d, isImportSpecifier: h, isJSXIdentifier: m, isJSXMemberExpression: f, isMemberExpression: y, isRestElement: b, isReferenced: g, isScope: x, isStatement: v, isVar: E, isVariableDeclaration: T, react: S, isForOfStatement: P } = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), { isCompatTag: _ } = S;
				t.isExistentialTypeParam = function() {
					throw new Error("`path.isExistentialTypeParam` has been renamed to `path.isExistsTypeAnnotation()` in Babel 7.");
				}, t.isNumericLiteralTypeAnnotation = function() {
					throw new Error("`path.isNumericLiteralTypeAnnotation()` has been renamed to `path.isNumberLiteralTypeAnnotation()` in Babel 7.");
				};
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/lib/virtual-types.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.Var = t.User = t.Statement = t.SpreadProperty = t.Scope = t.RestProperty = t.ReferencedMemberExpression = t.ReferencedIdentifier = t.Referenced = t.Pure = t.NumericLiteralTypeAnnotation = t.Generated = t.ForAwaitStatement = t.Flow = t.Expression = t.ExistentialTypeParam = t.BlockScoped = t.BindingIdentifier = void 0;
				t.ReferencedIdentifier = ["Identifier", "JSXIdentifier"], t.ReferencedMemberExpression = ["MemberExpression"], t.BindingIdentifier = ["Identifier"], t.Statement = ["Statement"], t.Expression = ["Expression"], t.Scope = ["Scopable", "Pattern"], t.Referenced = null, t.BlockScoped = null, t.Var = ["VariableDeclaration"], t.User = null, t.Generated = null, t.Pure = null, t.Flow = [
					"Flow",
					"ImportDeclaration",
					"ExportDeclaration",
					"ImportSpecifier"
				], t.RestProperty = ["RestElement"], t.SpreadProperty = ["RestElement"], t.ExistentialTypeParam = ["ExistsTypeAnnotation"], t.NumericLiteralTypeAnnotation = ["NumberLiteralTypeAnnotation"], t.ForAwaitStatement = ["ForOfStatement"];
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/modification.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t._containerInsert = _containerInsert, t._containerInsertAfter = _containerInsertAfter, t._containerInsertBefore = _containerInsertBefore, t._verifyNodeList = _verifyNodeList, t.insertAfter = function(e) {
					if (o._assertUnremoved.call(this), this.isSequenceExpression()) return last(this.get("expressions")).insertAfter(e);
					const t = _verifyNodeList.call(this, e), { parentPath: r, parent: n } = this;
					if (r.isExpressionStatement() || r.isLabeledStatement() || g(n) || r.isExportDefaultDeclaration() && this.isDeclaration()) return r.insertAfter(t.map((e) => x(e) ? f(e) : e));
					if (this.isNodeType("Expression") && !this.isJSXElement() && !r.isJSXElement() || r.isForStatement() && "init" === this.key) {
						const e = this;
						if (e.node) {
							const n = e.node;
							let { scope: s } = this;
							if (s.path.isPattern()) return c(n), e.replaceWith(h(p([], n), [])), e.get("callee.body").insertAfter(t), [e];
							if (isHiddenInSequenceExpression(e)) t.unshift(n);
							else if (b(n) && T(n.callee)) t.unshift(n), t.push(S());
							else if (function(e, t) {
								if (!y(e) || !v(e.left)) return !1;
								const r = t.getBlockParent();
								return r.hasOwnBinding(e.left.name) && r.getOwnBinding(e.left.name).constantViolations.length <= 1;
							}(n, s)) t.unshift(n), t.push(m(n.left));
							else if (s.isPure(n, !0)) t.push(n);
							else {
								r.isMethod({
									computed: !0,
									key: n
								}) && (s = s.parent);
								const e = s.generateDeclaredUidIdentifier();
								t.unshift(f(u("=", m(e), n))), t.push(f(m(e)));
							}
						}
						return this.replaceExpressionWithStatements(t);
					}
					if (Array.isArray(this.container)) return _containerInsertAfter.call(this, t);
					if (this.isStatementOrBlock()) {
						const e = this.node, r = e && (!this.isExpressionStatement() || null != e.expression), [n] = this.replaceWith(d(r ? [e] : []));
						return n.pushContainer("body", t);
					}
					throw new Error("We don't know what to do with this node type. We were previously a Statement but we can't fit in here?");
				}, t.insertBefore = function(e) {
					o._assertUnremoved.call(this);
					const t = _verifyNodeList.call(this, e), { parentPath: r, parent: n } = this;
					if (r.isExpressionStatement() || r.isLabeledStatement() || g(n) || r.isExportDefaultDeclaration() && this.isDeclaration()) return r.insertBefore(t);
					if (this.isNodeType("Expression") && !this.isJSXElement() || r.isForStatement() && "init" === this.key) return this.node && t.push(this.node), this.replaceExpressionWithStatements(t);
					if (Array.isArray(this.container)) return _containerInsertBefore.call(this, t);
					if (this.isStatementOrBlock()) {
						const e = this.node, r = e && (!this.isExpressionStatement() || null != e.expression), [n] = this.replaceWith(d(r ? [e] : []));
						return n.unshiftContainer("body", t);
					}
					throw new Error("We don't know what to do with this node type. We were previously a Statement but we can't fit in here?");
				}, t.pushContainer = function(e, t) {
					o._assertUnremoved.call(this);
					const r = _verifyNodeList.call(this, t), n = this.node[e];
					return s.default.get({
						parentPath: this,
						parent: this.node,
						container: n,
						listKey: e,
						key: n.length
					}).setContext(this.context).replaceWithMultiple(r);
				}, t.unshiftContainer = function(e, t) {
					o._assertUnremoved.call(this);
					const r = _verifyNodeList.call(this, t), n = this.node[e], i = s.default.get({
						parentPath: this,
						parent: this.node,
						container: n,
						listKey: e,
						key: 0
					}).setContext(this.context);
					return _containerInsertBefore.call(i, r);
				}, t.updateSiblingKeys = updateSiblingKeys;
				var n = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/cache.js"), s = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/index.js"), i = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/context.js"), o = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/removal.js"), a = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), l = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/lib/hoister.js");
				const { arrowFunctionExpression: p, assertExpression: c, assignmentExpression: u, blockStatement: d, callExpression: h, cloneNode: m, expressionStatement: f, isAssignmentExpression: y, isCallExpression: b, isExportNamedDeclaration: g, isExpression: x, isIdentifier: v, isSequenceExpression: E, isSuper: T, thisExpression: S } = a;
				function _containerInsert(e, t) {
					updateSiblingKeys.call(this, e, t.length);
					const r = [];
					this.container.splice(e, 0, ...t);
					for (let s = 0; s < t.length; s++) {
						var n;
						const t = e + s, o = this.getSibling(t);
						r.push(o), null != (n = this.context) && n.queue && i.pushContext.call(o, this.context);
					}
					const s = i._getQueueContexts.call(this);
					for (const e of r) {
						i.setScope.call(e), e.debug("Inserted.");
						for (const t of s) t.maybeQueue(e, !0);
					}
					return r;
				}
				function _containerInsertBefore(e) {
					return _containerInsert.call(this, this.key, e);
				}
				function _containerInsertAfter(e) {
					return _containerInsert.call(this, this.key + 1, e);
				}
				const last = (e) => e[e.length - 1];
				function isHiddenInSequenceExpression(e) {
					return E(e.parent) && (last(e.parent.expressions) !== e.node || isHiddenInSequenceExpression(e.parentPath));
				}
				function updateSiblingKeys(e, t) {
					if (!this.parent) return;
					const r = (0, n.getCachedPaths)(this);
					if (r) for (const [, n] of r) "number" == typeof n.key && n.container === this.container && n.key >= e && (n.key += t);
				}
				function _verifyNodeList(e) {
					if (!e) return [];
					Array.isArray(e) || (e = [e]);
					for (let t = 0; t < e.length; t++) {
						const r = e[t];
						let n;
						if (r ? "object" != typeof r ? n = "contains a non-object node" : r.type ? r instanceof s.default && (n = "has a NodePath when it expected a raw object") : n = "without a type" : n = "has falsy node", n) throw new Error(`Node list ${n} with the index of ${t} and type of ${Array.isArray(r) ? "array" : typeof r}`);
					}
					return e;
				}
				t.hoist = function(e = this.scope) {
					return new l.default(this, e).run();
				};
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/removal.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t._assertUnremoved = _assertUnremoved, t._callRemovalHooks = _callRemovalHooks, t._markRemoved = _markRemoved, t._remove = _remove, t._removeFromScope = _removeFromScope, t.remove = function() {
					var e;
					if (_assertUnremoved.call(this), p.resync.call(this), _callRemovalHooks.call(this)) return void _markRemoved.call(this);
					null != (e = this.opts) && e.noScope || _removeFromScope.call(this);
					this.shareCommentsWithSiblings(), _remove.call(this), _markRemoved.call(this);
				};
				var n = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/lib/removal-hooks.js"), s = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/cache.js"), i = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/replacement.js"), o = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/index.js"), a = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), l = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/modification.js"), p = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/context.js");
				const { getBindingIdentifiers: c } = a;
				function _removeFromScope() {
					const e = c(this.node, !1, !1, !0);
					Object.keys(e).forEach((e) => this.scope.removeBinding(e));
				}
				function _callRemovalHooks() {
					if (this.parentPath) {
						for (const e of n.hooks) if (e(this, this.parentPath)) return !0;
					}
				}
				function _remove() {
					Array.isArray(this.container) ? (this.container.splice(this.key, 1), l.updateSiblingKeys.call(this, this.key, -1)) : i._replaceWith.call(this, null);
				}
				function _markRemoved() {
					var e;
					(this._traverseFlags |= o.SHOULD_SKIP | o.REMOVED, this.parent) && (null == (e = (0, s.getCachedPaths)(this)) || e.delete(this.node));
					this.node = null;
				}
				function _assertUnremoved() {
					if (this.removed) throw this.buildCodeFrameError("NodePath has been removed so is read-only.");
				}
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/replacement.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t._replaceWith = _replaceWith, t.replaceExpressionWithStatements = function(e) {
					c.resync.call(this);
					const t = [], r = gatherSequenceExpressions(e, t);
					if (r) {
						for (const e of t) this.scope.push({ id: e });
						return this.replaceWith(r)[0].get("expressions");
					}
					const n = this.getFunctionParent(), i = null == n ? void 0 : n.node.async, o = null == n ? void 0 : n.node.generator, a = d([], f(e));
					this.replaceWith(b(a, []));
					const l = this.get("callee");
					l.get("body").scope.hoistVariables((e) => this.scope.push({ id: e }));
					const p = l.getCompletionRecords();
					for (const e of p) {
						if (!e.isExpressionStatement()) continue;
						const t = e.findParent((e) => e.isLoop());
						if (t) {
							let r = t.getData("expressionReplacementReturnUid");
							r ? r = T(r.name) : (r = l.scope.generateDeclaredUidIdentifier("ret"), l.get("body").pushContainer("body", F(g(r))), t.setData("expressionReplacementReturnUid", r)), e.get("expression").replaceWith(h("=", g(r), e.node.expression));
						} else e.replaceWith(F(e.node.expression));
					}
					l.arrowFunctionToExpression();
					const y = l, x = i && s.default.hasType(this.get("callee.body").node, "AwaitExpression", u), v = o && s.default.hasType(this.get("callee.body").node, "YieldExpression", u);
					x && (y.set("async", !0), v || this.replaceWith(m(this.node)));
					v && (y.set("generator", !0), this.replaceWith(B(this.node, !0)));
					return y.get("body.body");
				}, t.replaceInline = function(e) {
					if (c.resync.call(this), Array.isArray(e)) {
						if (Array.isArray(this.container)) {
							e = a._verifyNodeList.call(this, e);
							const t = a._containerInsertAfter.call(this, e);
							return this.remove(), t;
						}
						return this.replaceWithMultiple(e);
					}
					return this.replaceWith(e);
				}, t.replaceWith = function(e) {
					if (c.resync.call(this), this.removed) throw new Error("You can't replace this node, we've already removed it");
					let t = e instanceof i.default ? e.node : e;
					if (!t) throw new Error("You passed `path.replaceWith()` a falsy node, use `path.remove()` instead");
					if (this.node === t) return [this];
					if (this.isProgram() && !k(t)) throw new Error("You can only replace a Program root node with another Program node");
					if (Array.isArray(t)) throw new Error("Don't use `path.replaceWith()` with an array of nodes, use `path.replaceWithMultiple()`");
					if ("string" == typeof t) throw new Error("Don't use `path.replaceWith()` with a source string, use `path.replaceWithSourceString()`");
					let r = "";
					this.isNodeType("Statement") && w(t) && (this.canHaveVariableDeclarationOrExpression() || this.canSwapBetweenExpressionAndStatement(t) || this.parentPath.isExportDefaultDeclaration() || (t = v(t), r = "expression"));
					if (this.isNodeType("Expression") && N(t) && !this.canHaveVariableDeclarationOrExpression() && !this.canSwapBetweenExpressionAndStatement(t)) return this.replaceExpressionWithStatements([t]);
					const n = this.node;
					n && (_(t, n), j(n));
					return _replaceWith.call(this, t), this.type = t.type, c.setScope.call(this), this.requeue(), [r ? this.get(r) : this];
				}, t.replaceWithMultiple = function(e) {
					var t;
					c.resync.call(this);
					const r = a._verifyNodeList.call(this, e);
					S(r[0], this.node), P(r[r.length - 1], this.node), null == (t = (0, o.getCachedPaths)(this)) || t.delete(this.node), this.node = this.container[this.key] = null;
					const n = this.insertAfter(e);
					this.node ? this.requeue() : this.remove();
					return n;
				}, t.replaceWithSourceString = function(e) {
					let t;
					c.resync.call(this);
					try {
						e = `(${e})`, t = (0, l.parse)(e);
					} catch (t) {
						const r = t.loc;
						throw r && (t.message += " - make sure this is an expression.\n" + (0, n.codeFrameColumns)(e, { start: {
							line: r.line,
							column: r.column + 1
						} }), t.code = "BABEL_REPLACE_SOURCE_ERROR"), t;
					}
					const r = t.program.body[0].expression;
					return s.default.removeProperties(r), this.replaceWith(r);
				};
				var n = r("./stubs/babel-codeframe.mjs"), s = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js"), i = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/index.js"), o = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/cache.js"), a = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/modification.js"), l = r("./node_modules/.pnpm/@babel+parser@7.28.4/node_modules/@babel/parser/lib/index.js"), p = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), c = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/context.js");
				const { FUNCTION_TYPES: u, arrowFunctionExpression: d, assignmentExpression: h, awaitExpression: m, blockStatement: f, buildUndefinedNode: y, callExpression: b, cloneNode: g, conditionalExpression: x, expressionStatement: v, getBindingIdentifiers: E, identifier: T, inheritLeadingComments: S, inheritTrailingComments: P, inheritsComments: _, isBlockStatement: A, isEmptyStatement: C, isExpression: w, isExpressionStatement: I, isIfStatement: D, isProgram: k, isStatement: N, isVariableDeclaration: O, removeComments: j, returnStatement: F, sequenceExpression: L, validate: M, yieldExpression: B } = p;
				function _replaceWith(e) {
					var t;
					if (!this.container) throw new ReferenceError("Container is falsy");
					this.inList ? M(this.parent, this.key, [e]) : M(this.parent, this.key, e), this.debug(`Replace with ${null == e ? void 0 : e.type}`), null == (t = (0, o.getCachedPaths)(this)) || t.set(e, this).delete(this.node), this.node = this.container[this.key] = e;
				}
				function gatherSequenceExpressions(e, t) {
					const r = [];
					let n = !0;
					for (const s of e) if (C(s) || (n = !1), w(s)) r.push(s);
					else if (I(s)) r.push(s.expression);
					else if (O(s)) {
						if ("var" !== s.kind) return;
						for (const e of s.declarations) {
							const n = E(e);
							for (const e of Object.keys(n)) t.push(g(n[e]));
							e.init && r.push(h("=", e.id, e.init));
						}
						n = !0;
					} else if (D(s)) {
						const e = s.consequent ? gatherSequenceExpressions([s.consequent], t) : y(), n = s.alternate ? gatherSequenceExpressions([s.alternate], t) : y();
						if (!e || !n) return;
						r.push(x(s.test, e, n));
					} else if (A(s)) {
						const e = gatherSequenceExpressions(s.body, t);
						if (!e) return;
						r.push(e);
					} else {
						if (!C(s)) return;
						0 === e.indexOf(s) && (n = !0);
					}
					return n && r.push(y()), 1 === r.length ? r[0] : L(r);
				}
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/scope/binding.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				t.default = class {
					constructor({ identifier: e, scope: t, path: r, kind: n }) {
						this.identifier = void 0, this.scope = void 0, this.path = void 0, this.kind = void 0, this.constantViolations = [], this.constant = !0, this.referencePaths = [], this.referenced = !1, this.references = 0, this.identifier = e, this.scope = t, this.path = r, this.kind = n, "var" !== n && "hoisted" !== n || !function(e) {
							const t = !e.isVariableDeclarator() || e.node.init;
							for (let { parentPath: r, key: n } = e; r; {parentPath: r, key: n} = r) {
								if (r.isFunctionParent()) return !1;
								if ("left" === n && r.isForXStatement() || t && "body" === n && r.isLoop()) return !0;
							}
							return !1;
						}(r) || this.reassign(r), this.clearValue();
					}
					deoptValue() {
						this.clearValue(), this.hasDeoptedValue = !0;
					}
					setValue(e) {
						this.hasDeoptedValue || (this.hasValue = !0, this.value = e);
					}
					clearValue() {
						this.hasDeoptedValue = !1, this.hasValue = !1, this.value = null;
					}
					reassign(e) {
						this.constant = !1, this.constantViolations.includes(e) || this.constantViolations.push(e);
					}
					reference(e) {
						this.referencePaths.includes(e) || (this.referenced = !0, this.references++, this.referencePaths.push(e));
					}
					dereference() {
						this.references--, this.referenced = !!this.references;
					}
				};
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/scope/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/scope/lib/renamer.js"), s = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/index.js"), i = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/scope/binding.js"), o = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), a = o, l = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/cache.js");
				const p = r("./node_modules/.pnpm/@babel+helper-globals@7.28.0/node_modules/@babel/helper-globals/data/builtin-lower.json"), c = r("./node_modules/.pnpm/@babel+helper-globals@7.28.0/node_modules/@babel/helper-globals/data/builtin-upper.json"), { assignmentExpression: u, callExpression: d, cloneNode: h, getBindingIdentifiers: m, identifier: f, isArrayExpression: y, isBinary: b, isCallExpression: g, isClass: x, isClassBody: v, isClassDeclaration: E, isExportAllDeclaration: T, isExportDefaultDeclaration: S, isExportNamedDeclaration: P, isFunctionDeclaration: _, isIdentifier: A, isImportDeclaration: C, isLiteral: w, isMemberExpression: I, isMethod: D, isModuleSpecifier: k, isNullLiteral: N, isObjectExpression: O, isProperty: j, isPureish: F, isRegExpLiteral: L, isSuper: M, isTaggedTemplateExpression: B, isTemplateLiteral: R, isThisExpression: U, isUnaryExpression: V, isVariableDeclaration: $, expressionStatement: K, matchesPattern: W, memberExpression: q, numericLiteral: H, toIdentifier: z, variableDeclaration: G, variableDeclarator: X, isRecordExpression: J, isTupleExpression: Y, isObjectProperty: Q, isTopicReference: Z, isMetaProperty: ee, isPrivateName: te, isExportDeclaration: re, buildUndefinedNode: ne, sequenceExpression: se } = o;
				function gatherNodeParts(e, t) {
					switch (null == e ? void 0 : e.type) {
						default:
							var r;
							if (C(e) || re(e)) if ((T(e) || P(e) || C(e)) && e.source) gatherNodeParts(e.source, t);
							else if ((P(e) || C(e)) && null != (r = e.specifiers) && r.length) for (const r of e.specifiers) gatherNodeParts(r, t);
							else (S(e) || P(e)) && e.declaration && gatherNodeParts(e.declaration, t);
							else k(e) ? gatherNodeParts(e.local, t) : !w(e) || N(e) || L(e) || R(e) || t.push(e.value);
							break;
						case "MemberExpression":
						case "OptionalMemberExpression":
						case "JSXMemberExpression":
							gatherNodeParts(e.object, t), gatherNodeParts(e.property, t);
							break;
						case "Identifier":
						case "JSXIdentifier":
							t.push(e.name);
							break;
						case "CallExpression":
						case "OptionalCallExpression":
						case "NewExpression":
							gatherNodeParts(e.callee, t);
							break;
						case "ObjectExpression":
						case "ObjectPattern":
							for (const r of e.properties) gatherNodeParts(r, t);
							break;
						case "SpreadElement":
						case "RestElement":
						case "UnaryExpression":
						case "UpdateExpression":
							gatherNodeParts(e.argument, t);
							break;
						case "ObjectProperty":
						case "ObjectMethod":
						case "ClassProperty":
						case "ClassMethod":
						case "ClassPrivateProperty":
						case "ClassPrivateMethod":
							gatherNodeParts(e.key, t);
							break;
						case "ThisExpression":
							t.push("this");
							break;
						case "Super":
							t.push("super");
							break;
						case "Import":
						case "ImportExpression":
							t.push("import");
							break;
						case "DoExpression":
							t.push("do");
							break;
						case "YieldExpression":
							t.push("yield"), gatherNodeParts(e.argument, t);
							break;
						case "AwaitExpression":
							t.push("await"), gatherNodeParts(e.argument, t);
							break;
						case "AssignmentExpression":
							gatherNodeParts(e.left, t);
							break;
						case "VariableDeclarator":
						case "FunctionExpression":
						case "FunctionDeclaration":
						case "ClassExpression":
						case "ClassDeclaration":
						case "PrivateName":
							gatherNodeParts(e.id, t);
							break;
						case "ParenthesizedExpression":
							gatherNodeParts(e.expression, t);
							break;
						case "MetaProperty":
							gatherNodeParts(e.meta, t), gatherNodeParts(e.property, t);
							break;
						case "JSXElement":
							gatherNodeParts(e.openingElement, t);
							break;
						case "JSXOpeningElement":
							gatherNodeParts(e.name, t);
							break;
						case "JSXFragment":
							gatherNodeParts(e.openingFragment, t);
							break;
						case "JSXOpeningFragment":
							t.push("Fragment");
							break;
						case "JSXNamespacedName": gatherNodeParts(e.namespace, t), gatherNodeParts(e.name, t);
					}
				}
				function resetScope(e) {
					e.references = Object.create(null), e.uids = Object.create(null), e.bindings = Object.create(null), e.globals = Object.create(null);
				}
				var ie = Symbol.for("should not be considered a local binding");
				const oe = {
					ForStatement(e) {
						const t = e.get("init");
						if (t.isVar()) {
							const { scope: r } = e;
							(r.getFunctionParent() || r.getProgramParent()).registerBinding("var", t);
						}
					},
					Declaration(e) {
						if (e.isBlockScoped()) return;
						if (e.isImportDeclaration()) return;
						if (e.isExportDeclaration()) return;
						(e.scope.getFunctionParent() || e.scope.getProgramParent()).registerDeclaration(e);
					},
					ImportDeclaration(e) {
						e.scope.getBlockParent().registerDeclaration(e);
					},
					TSImportEqualsDeclaration(e) {
						e.scope.getBlockParent().registerDeclaration(e);
					},
					ReferencedIdentifier(e, t) {
						a.isTSQualifiedName(e.parent) && e.parent.right === e.node || e.parentPath.isTSImportEqualsDeclaration() || t.references.push(e);
					},
					ForXStatement(e, t) {
						const r = e.get("left");
						if (r.isPattern() || r.isIdentifier()) t.constantViolations.push(e);
						else if (r.isVar()) {
							const { scope: t } = e;
							(t.getFunctionParent() || t.getProgramParent()).registerBinding("var", r);
						}
					},
					ExportDeclaration: { exit(e) {
						const { node: t, scope: r } = e;
						if (T(t)) return;
						const n = t.declaration;
						if (E(n) || _(n)) {
							const t = n.id;
							if (!t) return;
							r.getBinding(t.name)?.reference(e);
						} else if ($(n)) for (const t of n.declarations) for (const n of Object.keys(m(t))) r.getBinding(n)?.reference(e);
					} },
					LabeledStatement(e) {
						e.scope.getBlockParent().registerDeclaration(e);
					},
					AssignmentExpression(e, t) {
						t.assignments.push(e);
					},
					UpdateExpression(e, t) {
						t.constantViolations.push(e);
					},
					UnaryExpression(e, t) {
						"delete" === e.node.operator && t.constantViolations.push(e);
					},
					BlockScoped(e) {
						let t = e.scope;
						t.path === e && (t = t.parent);
						if (t.getBlockParent().registerDeclaration(e), e.isClassDeclaration() && e.node.id) {
							const t = e.node.id.name;
							e.scope.bindings[t] = e.scope.parent.getBinding(t);
						}
					},
					CatchClause(e) {
						e.scope.registerBinding("let", e);
					},
					Function(e) {
						const t = e.get("params");
						for (const r of t) e.scope.registerBinding("param", r);
						e.isFunctionExpression() && e.node.id && !e.node.id[ie] && e.scope.registerBinding("local", e.get("id"), e);
					},
					ClassExpression(e) {
						e.node.id && !e.node.id[ie] && e.scope.registerBinding("local", e.get("id"), e);
					},
					TSTypeAnnotation(e) {
						e.skip();
					}
				};
				let ae, le = 0;
				class Scope {
					constructor(e) {
						this.uid = void 0, this.path = void 0, this.block = void 0, this.inited = void 0, this.labels = void 0, this.bindings = void 0, this.referencesSet = void 0, this.globals = void 0, this.uidsSet = void 0, this.data = void 0, this.crawling = void 0;
						const { node: t } = e, r = l.scope.get(t);
						if ((null == r ? void 0 : r.path) === e) return r;
						l.scope.set(t, this), this.uid = le++, this.block = t, this.path = e, this.labels = /* @__PURE__ */ new Map(), this.inited = !1, Object.defineProperties(this, {
							references: {
								enumerable: !0,
								configurable: !0,
								writable: !0,
								value: Object.create(null)
							},
							uids: {
								enumerable: !0,
								configurable: !0,
								writable: !0,
								value: Object.create(null)
							}
						});
					}
					get parent() {
						var e;
						let t, r = this.path;
						do {
							var n;
							const e = "key" === r.key || "decorators" === r.listKey;
							r = r.parentPath, e && r.isMethod() && (r = r.parentPath), null != (n = r) && n.isScope() && (t = r);
						} while (r && !t);
						return null == (e = t) ? void 0 : e.scope;
					}
					get references() {
						throw new Error("Scope#references is not available in Babel 8. Use Scope#referencesSet instead.");
					}
					get uids() {
						throw new Error("Scope#uids is not available in Babel 8. Use Scope#uidsSet instead.");
					}
					generateDeclaredUidIdentifier(e) {
						const t = this.generateUidIdentifier(e);
						return this.push({ id: t }), h(t);
					}
					generateUidIdentifier(e) {
						return f(this.generateUid(e));
					}
					generateUid(e = "temp") {
						let t;
						e = z(e).replace(/^_+/, "").replace(/\d+$/g, "");
						let r = 0;
						do
							t = `_${e}`, r >= 11 ? t += r - 1 : r >= 9 ? t += r - 9 : r >= 1 && (t += r + 1), r++;
						while (this.hasLabel(t) || this.hasBinding(t) || this.hasGlobal(t) || this.hasReference(t));
						const n = this.getProgramParent();
						return n.references[t] = !0, n.uids[t] = !0, t;
					}
					generateUidBasedOnNode(e, t) {
						const r = [];
						gatherNodeParts(e, r);
						let n = r.join("$");
						return n = n.replace(/^_/, "") || t || "ref", this.generateUid(n.slice(0, 20));
					}
					generateUidIdentifierBasedOnNode(e, t) {
						return f(this.generateUidBasedOnNode(e, t));
					}
					isStatic(e) {
						if (U(e) || M(e) || Z(e)) return !0;
						if (A(e)) {
							const t = this.getBinding(e.name);
							return t ? t.constant : this.hasBinding(e.name);
						}
						return !1;
					}
					maybeGenerateMemoised(e, t) {
						if (this.isStatic(e)) return null;
						{
							const r = this.generateUidIdentifierBasedOnNode(e);
							return t ? r : (this.push({ id: r }), h(r));
						}
					}
					checkBlockScopedCollisions(e, t, r, n) {
						if ("param" === t) return;
						if ("local" === e.kind) return;
						if ("let" === t || "let" === e.kind || "const" === e.kind || "module" === e.kind || "param" === e.kind && "const" === t) throw this.path.hub.buildError(n, `Duplicate declaration "${r}"`, TypeError);
					}
					rename(e, t) {
						const r = this.getBinding(e);
						if (r) {
							t || (t = this.generateUidIdentifier(e).name);
							new n.default(r, e, t).rename(arguments[2]);
						}
					}
					dump() {
						const e = "-".repeat(60);
						console.log(e);
						let t = this;
						do {
							console.log("#", t.block.type);
							for (const e of Object.keys(t.bindings)) {
								const r = t.bindings[e];
								console.log(" -", e, {
									constant: r.constant,
									references: r.references,
									violations: r.constantViolations.length,
									kind: r.kind
								});
							}
						} while (t = t.parent);
						console.log(e);
					}
					hasLabel(e) {
						return !!this.getLabel(e);
					}
					getLabel(e) {
						return this.labels.get(e);
					}
					registerLabel(e) {
						this.labels.set(e.node.label.name, e);
					}
					registerDeclaration(e) {
						if (e.isLabeledStatement()) this.registerLabel(e);
						else if (e.isFunctionDeclaration()) this.registerBinding("hoisted", e.get("id"), e);
						else if (e.isVariableDeclaration()) {
							const t = e.get("declarations"), { kind: r } = e.node;
							for (const e of t) this.registerBinding("using" === r || "await using" === r ? "const" : r, e);
						} else if (e.isClassDeclaration()) {
							if (e.node.declare) return;
							this.registerBinding("let", e);
						} else if (e.isImportDeclaration()) {
							const t = "type" === e.node.importKind || "typeof" === e.node.importKind, r = e.get("specifiers");
							for (const e of r) {
								const r = t || e.isImportSpecifier() && ("type" === e.node.importKind || "typeof" === e.node.importKind);
								this.registerBinding(r ? "unknown" : "module", e);
							}
						} else if (e.isExportDeclaration()) {
							const t = e.get("declaration");
							(t.isClassDeclaration() || t.isFunctionDeclaration() || t.isVariableDeclaration()) && this.registerDeclaration(t);
						} else this.registerBinding("unknown", e);
					}
					buildUndefinedNode() {
						return ne();
					}
					registerConstantViolation(e) {
						const t = e.getAssignmentIdentifiers();
						for (const n of Object.keys(t)) {
							var r;
							null == (r = this.getBinding(n)) || r.reassign(e);
						}
					}
					registerBinding(e, t, r = t) {
						if (!e) throw new ReferenceError("no `kind`");
						if (t.isVariableDeclaration()) {
							const r = t.get("declarations");
							for (const t of r) this.registerBinding(e, t);
							return;
						}
						const n = this.getProgramParent(), s = t.getOuterBindingIdentifiers(!0);
						for (const t of Object.keys(s)) {
							n.references[t] = !0;
							for (const n of s[t]) {
								const s = this.getOwnBinding(t);
								if (s) {
									if (s.identifier === n) continue;
									this.checkBlockScopedCollisions(s, e, t, n);
								}
								s ? s.reassign(r) : this.bindings[t] = new i.default({
									identifier: n,
									scope: this,
									path: r,
									kind: e
								});
							}
						}
					}
					addGlobal(e) {
						this.globals[e.name] = e;
					}
					hasUid(e) {
						{
							let t = this;
							do
								if (t.uids[e]) return !0;
							while (t = t.parent);
							return !1;
						}
					}
					hasGlobal(e) {
						let t = this;
						do
							if (t.globals[e]) return !0;
						while (t = t.parent);
						return !1;
					}
					hasReference(e) {
						return !!this.getProgramParent().references[e];
					}
					isPure(e, t) {
						if (A(e)) {
							const r = this.getBinding(e.name);
							return !!r && (!t || r.constant);
						}
						if (U(e) || ee(e) || Z(e) || te(e)) return !0;
						var r, n, s;
						if (x(e)) return !(e.superClass && !this.isPure(e.superClass, t)) && !((null == (r = e.decorators) ? void 0 : r.length) > 0) && this.isPure(e.body, t);
						if (v(e)) {
							for (const r of e.body) if (!this.isPure(r, t)) return !1;
							return !0;
						}
						if (b(e)) return this.isPure(e.left, t) && this.isPure(e.right, t);
						if (y(e) || Y(e)) {
							for (const r of e.elements) if (null !== r && !this.isPure(r, t)) return !1;
							return !0;
						}
						if (O(e) || J(e)) {
							for (const r of e.properties) if (!this.isPure(r, t)) return !1;
							return !0;
						}
						if (D(e)) return !(e.computed && !this.isPure(e.key, t)) && !((null == (n = e.decorators) ? void 0 : n.length) > 0);
						if (j(e)) return !(e.computed && !this.isPure(e.key, t)) && !((null == (s = e.decorators) ? void 0 : s.length) > 0) && !((Q(e) || e.static) && null !== e.value && !this.isPure(e.value, t));
						if (V(e)) return this.isPure(e.argument, t);
						if (R(e)) {
							for (const r of e.expressions) if (!this.isPure(r, t)) return !1;
							return !0;
						}
						return B(e) ? W(e.tag, "String.raw") && !this.hasBinding("String", { noGlobals: !0 }) && this.isPure(e.quasi, t) : I(e) ? !e.computed && A(e.object) && "Symbol" === e.object.name && A(e.property) && "for" !== e.property.name && !this.hasBinding("Symbol", { noGlobals: !0 }) : g(e) ? W(e.callee, "Symbol.for") && !this.hasBinding("Symbol", { noGlobals: !0 }) && 1 === e.arguments.length && a.isStringLiteral(e.arguments[0]) : F(e);
					}
					setData(e, t) {
						return this.data[e] = t;
					}
					getData(e) {
						let t = this;
						do {
							const r = t.data[e];
							if (null != r) return r;
						} while (t = t.parent);
					}
					removeData(e) {
						let t = this;
						do
							null != t.data[e] && (t.data[e] = null);
						while (t = t.parent);
					}
					init() {
						this.inited || (this.inited = !0, this.crawl());
					}
					crawl() {
						const e = this.path;
						resetScope(this), this.data = Object.create(null);
						let t = this;
						do {
							if (t.crawling) return;
							if (t.path.isProgram()) break;
						} while (t = t.parent);
						const r = t, n = {
							references: [],
							constantViolations: [],
							assignments: []
						};
						if (this.crawling = !0, ae || (ae = s.default.visitors.merge([{ Scope(e) {
							resetScope(e.scope);
						} }, oe])), "Program" !== e.type) {
							for (const t of ae.enter) t.call(n, e, n);
							const t = ae[e.type];
							if (t) for (const r of t.enter) r.call(n, e, n);
						}
						e.traverse(ae, n), this.crawling = !1;
						for (const e of n.assignments) {
							const t = e.getAssignmentIdentifiers();
							for (const n of Object.keys(t)) e.scope.getBinding(n) || r.addGlobal(t[n]);
							e.scope.registerConstantViolation(e);
						}
						for (const e of n.references) {
							const t = e.scope.getBinding(e.node.name);
							t ? t.reference(e) : r.addGlobal(e.node);
						}
						for (const e of n.constantViolations) e.scope.registerConstantViolation(e);
					}
					push(e) {
						let t = this.path;
						t.isPattern() ? t = this.getPatternParent().path : t.isBlockStatement() || t.isProgram() || (t = this.getBlockParent().path), t.isSwitchStatement() && (t = (this.getFunctionParent() || this.getProgramParent()).path);
						const { init: r, unique: n, kind: s = "var", id: i } = e;
						if (!r && !n && ("var" === s || "let" === s) && t.isFunction() && !t.node.name && g(t.parent, { callee: t.node }) && t.parent.arguments.length <= t.node.params.length && A(i)) return t.pushContainer("params", i), void t.scope.registerBinding("param", t.get("params")[t.node.params.length - 1]);
						(t.isLoop() || t.isCatchClause() || t.isFunction()) && (t.ensureBlock(), t = t.get("body"));
						const o = null == e._blockHoist ? 2 : e._blockHoist, a = `declaration:${s}:${o}`;
						let l = !n && t.getData(a);
						if (!l) {
							const e = G(s, []);
							e._blockHoist = o, [l] = t.unshiftContainer("body", [e]), n || t.setData(a, l);
						}
						const p = X(i, r), c = l.node.declarations.push(p);
						t.scope.registerBinding(s, l.get("declarations")[c - 1]);
					}
					getProgramParent() {
						let e = this;
						do
							if (e.path.isProgram()) return e;
						while (e = e.parent);
						throw new Error("Couldn't find a Program");
					}
					getFunctionParent() {
						let e = this;
						do
							if (e.path.isFunctionParent()) return e;
						while (e = e.parent);
						return null;
					}
					getBlockParent() {
						let e = this;
						do
							if (e.path.isBlockParent()) return e;
						while (e = e.parent);
						throw new Error("We couldn't find a BlockStatement, For, Switch, Function, Loop or Program...");
					}
					getPatternParent() {
						let e = this;
						do
							if (!e.path.isPattern()) return e.getBlockParent();
						while (e = e.parent.parent);
						throw new Error("We couldn't find a BlockStatement, For, Switch, Function, Loop or Program...");
					}
					getAllBindings() {
						const e = Object.create(null);
						let t = this;
						do {
							for (const r of Object.keys(t.bindings)) r in e == !1 && (e[r] = t.bindings[r]);
							t = t.parent;
						} while (t);
						return e;
					}
					bindingIdentifierEquals(e, t) {
						return this.getBindingIdentifier(e) === t;
					}
					getBinding(e) {
						let t, r = this;
						do {
							const s = r.getOwnBinding(e);
							var n;
							if (s) {
								if (null == (n = t) || !n.isPattern() || "param" === s.kind || "local" === s.kind) return s;
							} else if (!s && "arguments" === e && r.path.isFunction() && !r.path.isArrowFunctionExpression()) break;
							t = r.path;
						} while (r = r.parent);
					}
					getOwnBinding(e) {
						return this.bindings[e];
					}
					getBindingIdentifier(e) {
						var t;
						return null == (t = this.getBinding(e)) ? void 0 : t.identifier;
					}
					getOwnBindingIdentifier(e) {
						const t = this.bindings[e];
						return null == t ? void 0 : t.identifier;
					}
					hasOwnBinding(e) {
						return !!this.getOwnBinding(e);
					}
					hasBinding(e, t) {
						if (!e) return !1;
						let r, n, s;
						"object" == typeof t ? (r = t.noGlobals, n = t.noUids, s = t.upToScope) : "boolean" == typeof t && (r = t);
						let i = this;
						do {
							if (s === i) break;
							if (i.hasOwnBinding(e)) return !0;
						} while (i = i.parent);
						return !(n || !this.hasUid(e)) || !(r || !Scope.globals.includes(e)) || !(r || !Scope.contextVariables.includes(e));
					}
					parentHasBinding(e, t) {
						var r;
						return null == (r = this.parent) ? void 0 : r.hasBinding(e, t);
					}
					moveBindingTo(e, t) {
						const r = this.getBinding(e);
						r && (r.scope.removeOwnBinding(e), r.scope = t, t.bindings[e] = r);
					}
					removeOwnBinding(e) {
						delete this.bindings[e];
					}
					removeBinding(e) {
						var t;
						null == (t = this.getBinding(e)) || t.scope.removeOwnBinding(e);
						{
							let t = this;
							do
								t.uids[e] && (t.uids[e] = !1);
							while (t = t.parent);
						}
					}
					hoistVariables(e = (e) => this.push({ id: e })) {
						this.crawl();
						const t = /* @__PURE__ */ new Set();
						for (const r of Object.keys(this.bindings)) {
							const n = this.bindings[r];
							if (!n) continue;
							const { path: s } = n;
							if (!s.isVariableDeclarator()) continue;
							const { parent: i, parentPath: o } = s;
							if ("var" !== i.kind || t.has(i)) continue;
							let a;
							t.add(s.parent);
							const l = [];
							for (const t of i.declarations) {
								a ?? (a = t.id), t.init && l.push(u("=", t.id, t.init));
								const r = Object.keys(m(t, !1, !0, !0));
								for (const n of r) e(f(n), null != t.init);
							}
							if (o.parentPath.isFor({ left: i })) o.replaceWith(a);
							else if (0 === l.length) o.remove();
							else {
								const e = 1 === l.length ? l[0] : se(l);
								o.parentPath.isForStatement({ init: i }) ? o.replaceWith(e) : o.replaceWith(K(e));
							}
						}
					}
				}
				t.default = Scope, Scope.globals = [...p, ...c], Scope.contextVariables = [
					"arguments",
					"undefined",
					"Infinity",
					"NaN"
				], Scope.prototype._renameFromMap = function(e, t, r, n) {
					e[t] && (e[r] = n, e[t] = null);
				}, Scope.prototype.traverse = function(e, t, r) {
					(0, s.default)(e, t, this, r, this.path);
				}, Scope.prototype._generateUid = function(e, t) {
					let r = e;
					return t > 1 && (r += t), `_${r}`;
				}, Scope.prototype.toArray = function(e, t, r) {
					if (A(e)) {
						const t = this.getBinding(e.name);
						if (null != t && t.constant && t.path.isGenericType("Array")) return e;
					}
					if (y(e)) return e;
					if (A(e, { name: "arguments" })) return d(q(q(q(f("Array"), f("prototype")), f("slice")), f("call")), [e]);
					let n;
					const s = [e];
					return !0 === t ? n = "toConsumableArray" : "number" == typeof t ? (s.push(H(t)), n = "slicedToArray") : n = "toArray", r && (s.unshift(this.path.hub.addHelper(n)), n = "maybeArrayLike"), d(this.path.hub.addHelper(n), s);
				}, Scope.prototype.getAllBindingsOfKind = function(...e) {
					const t = Object.create(null);
					for (const r of e) {
						let e = this;
						do {
							for (const n of Object.keys(e.bindings)) {
								const s = e.bindings[n];
								s.kind === r && (t[n] = s);
							}
							e = e.parent;
						} while (e);
					}
					return t;
				}, Object.defineProperties(Scope.prototype, {
					parentBlock: {
						configurable: !0,
						enumerable: !0,
						get() {
							return this.path.parent;
						}
					},
					hub: {
						configurable: !0,
						enumerable: !0,
						get() {
							return this.path.hub;
						}
					}
				});
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/scope/lib/renamer.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), s = n, i = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/traverse-node.js"), o = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/visitors.js"), a = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/context.js");
				const { getAssignmentIdentifiers: l } = s, p = {
					ReferencedIdentifier({ node: e }, t) {
						e.name === t.oldName && (e.name = t.newName);
					},
					Scope(e, t) {
						e.scope.bindingIdentifierEquals(t.oldName, t.binding.identifier) || (e.skip(), e.isMethod() && (e.requeueComputedKeyAndDecorators ? e.requeueComputedKeyAndDecorators() : a.requeueComputedKeyAndDecorators.call(e)));
					},
					ObjectProperty({ node: e, scope: t }, r) {
						const { name: n } = e.key;
						var s;
						!e.shorthand || n !== r.oldName && n !== r.newName || t.getBindingIdentifier(n) !== r.binding.identifier || (e.shorthand = !1, null != (s = e.extra) && s.shorthand && (e.extra.shorthand = !1));
					},
					"AssignmentExpression|Declaration|VariableDeclarator"(e, t) {
						if (e.isVariableDeclaration()) return;
						const r = e.isAssignmentExpression() ? l(e.node) : e.getOuterBindingIdentifiers();
						for (const e in r) e === t.oldName && (r[e].name = t.newName);
					}
				};
				t.default = class {
					constructor(e, t, r) {
						this.newName = r, this.oldName = t, this.binding = e;
					}
					maybeConvertFromExportDeclaration(e) {
						const t = e.parentPath;
						if (t.isExportDeclaration()) {
							if (t.isExportDefaultDeclaration()) {
								const { declaration: e } = t.node;
								if (n.isDeclaration(e) && !e.id) return;
							}
							t.isExportAllDeclaration() || t.splitExportDeclaration();
						}
					}
					maybeConvertFromClassFunctionDeclaration(e) {
						return e;
					}
					maybeConvertFromClassFunctionExpression(e) {
						return e;
					}
					rename() {
						const { binding: e, oldName: t, newName: r } = this, { scope: s, path: a } = e, l = a.find((e) => e.isDeclaration() || e.isFunctionExpression() || e.isClassExpression());
						if (l) l.getOuterBindingIdentifiers()[t] === e.identifier && this.maybeConvertFromExportDeclaration(l);
						const c = arguments[0] || s.block, u = { discriminant: !0 };
						n.isMethod(c) && (c.computed && (u.key = !0), n.isObjectMethod(c) || (u.decorators = !0)), (0, i.traverseNode)(c, (0, o.explode)(p), s, this, s.path, u), arguments[0] || (s.removeOwnBinding(t), s.bindings[r] = e, this.binding.identifier.name = r), l && (this.maybeConvertFromClassFunctionDeclaration(a), this.maybeConvertFromClassFunctionExpression(a));
					}
				};
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/traverse-node.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.traverseNode = function(e, t, r, s, o, a, l) {
					const p = i[e.type];
					if (!p) return !1;
					const c = new n.default(r, t, s, o);
					if (l) return (null == a || !a[o.parentKey]) && c.visitQueue([o]);
					for (const t of p) if ((null == a || !a[t]) && c.visit(e, t)) return !0;
					return !1;
				};
				var n = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/context.js"), s = (r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/index.js"), r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"));
				r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/context.js");
				const { VISITOR_KEYS: i } = s;
			},
			"./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/visitors.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.environmentVisitor = function(e) {
					return merge([d, e]);
				}, t.explode = explode$1, t.isExplodedVisitor = isExplodedVisitor, t.merge = merge, t.verify = verify$1;
				var n = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/lib/virtual-types.js"), s = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/lib/virtual-types-validator.js"), i = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js"), o = r("./node_modules/.pnpm/@babel+traverse@7.28.4/node_modules/@babel/traverse/lib/path/context.js");
				const { DEPRECATED_KEYS: a, DEPRECATED_ALIASES: l, FLIPPED_ALIAS_KEYS: p, TYPES: c, __internal__deprecationWarning: u } = i;
				function isVirtualType(e) {
					return e in n;
				}
				function isExplodedVisitor(e) {
					return null == e ? void 0 : e._exploded;
				}
				function explode$1(e) {
					if (isExplodedVisitor(e)) return e;
					e._exploded = !0;
					for (const t of Object.keys(e)) {
						if (shouldIgnoreKey(t)) continue;
						const r = t.split("|");
						if (1 === r.length) continue;
						const n = e[t];
						delete e[t];
						for (const t of r) e[t] = n;
					}
					verify$1(e), delete e.__esModule, function(e) {
						for (const t of Object.keys(e)) {
							if (shouldIgnoreKey(t)) continue;
							const r = e[t];
							"function" == typeof r && (e[t] = { enter: r });
						}
					}(e), ensureCallbackArrays(e);
					for (const t of Object.keys(e)) {
						if (shouldIgnoreKey(t)) continue;
						if (!isVirtualType(t)) continue;
						const r = e[t];
						for (const e of Object.keys(r)) r[e] = wrapCheck(t, r[e]);
						delete e[t];
						const s = n[t];
						if (null !== s) for (const t of s) e[t] ? mergePair(e[t], r) : e[t] = r;
						else mergePair(e, r);
					}
					for (const t of Object.keys(e)) {
						if (shouldIgnoreKey(t)) continue;
						let r = p[t];
						if (t in a) {
							const e = a[t];
							u(t, e, "Visitor "), r = [e];
						} else if (t in l) {
							const e = l[t];
							u(t, e, "Visitor "), r = p[e];
						}
						if (!r) continue;
						const n = e[t];
						delete e[t];
						for (const t of r) {
							const r = e[t];
							r ? mergePair(r, n) : e[t] = Object.assign({}, n);
						}
					}
					for (const t of Object.keys(e)) shouldIgnoreKey(t) || ensureCallbackArrays(e[t]);
					return e;
				}
				function verify$1(e) {
					if (!e._verified) {
						if ("function" == typeof e) throw new Error("You passed `traverse()` a function when it expected a visitor object, are you sure you didn't mean `{ enter: Function }`?");
						for (const t of Object.keys(e)) {
							if ("enter" !== t && "exit" !== t || validateVisitorMethods(t, e[t]), shouldIgnoreKey(t)) continue;
							if (!c.includes(t)) throw new Error(`You gave us a visitor for the node type ${t} but it's not a valid type in @babel/traverse 7.28.4`);
							const r = e[t];
							if ("object" == typeof r) for (const e of Object.keys(r)) {
								if ("enter" !== e && "exit" !== e) throw new Error(`You passed \`traverse()\` a visitor object with the property ${t} that has the invalid property ${e}`);
								validateVisitorMethods(`${t}.${e}`, r[e]);
							}
						}
						e._verified = !0;
					}
				}
				function validateVisitorMethods(e, t) {
					const r = [].concat(t);
					for (const t of r) if ("function" != typeof t) throw new TypeError(`Non-function found defined in ${e} with type ${typeof t}`);
				}
				function merge(e, t = [], r) {
					const n = {
						_verified: !0,
						_exploded: !0
					};
					Object.defineProperty(n, "_exploded", { enumerable: !1 }), Object.defineProperty(n, "_verified", { enumerable: !1 });
					for (let s = 0; s < e.length; s++) {
						const i = explode$1(e[s]), o = t[s];
						let a = i;
						(o || r) && (a = wrapWithStateOrWrapper(a, o, r)), mergePair(n, a);
						for (const e of Object.keys(i)) {
							if (shouldIgnoreKey(e)) continue;
							let t = i[e];
							(o || r) && (t = wrapWithStateOrWrapper(t, o, r));
							mergePair(n[e] || (n[e] = {}), t);
						}
					}
					return n;
				}
				function wrapWithStateOrWrapper(e, t, r) {
					const n = {};
					for (const s of ["enter", "exit"]) {
						let i = e[s];
						Array.isArray(i) && (i = i.map(function(e) {
							let n = e;
							return t && (n = function(r) {
								e.call(t, r, t);
							}), r && (n = r(null == t ? void 0 : t.key, s, n)), n !== e && (n.toString = () => e.toString()), n;
						}), n[s] = i);
					}
					return n;
				}
				function ensureCallbackArrays(e) {
					e.enter && !Array.isArray(e.enter) && (e.enter = [e.enter]), e.exit && !Array.isArray(e.exit) && (e.exit = [e.exit]);
				}
				function wrapCheck(e, t) {
					const r = s[`is${e}`], newFn = function(e) {
						if (r.call(e)) return t.apply(this, arguments);
					};
					return newFn.toString = () => t.toString(), newFn;
				}
				function shouldIgnoreKey(e) {
					return "_" === e[0] || "enter" === e || "exit" === e || "shouldSkip" === e || "denylist" === e || "noScope" === e || "skipKeys" === e || "blacklist" === e;
				}
				function mergePair(e, t) {
					for (const r of ["enter", "exit"]) t[r] && (e[r] = [].concat(e[r] || [], t[r]));
				}
				const d = {
					FunctionParent(e) {
						e.isArrowFunctionExpression() || (e.skip(), e.isMethod() && (e.requeueComputedKeyAndDecorators ? e.requeueComputedKeyAndDecorators() : o.requeueComputedKeyAndDecorators.call(e)));
					},
					Property(e) {
						e.isObjectProperty() || (e.skip(), e.requeueComputedKeyAndDecorators ? e.requeueComputedKeyAndDecorators() : o.requeueComputedKeyAndDecorators.call(e));
					}
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/asserts/assertNode.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					if (!(0, n.default)(e)) {
						var t;
						const r = null != (t = null == e ? void 0 : e.type) ? t : JSON.stringify(e);
						throw new TypeError(`Not a valid node of type "${r}"`);
					}
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isNode.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/asserts/generated/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.assertAccessor = function(e, t) {
					assert("Accessor", e, t);
				}, t.assertAnyTypeAnnotation = function(e, t) {
					assert("AnyTypeAnnotation", e, t);
				}, t.assertArgumentPlaceholder = function(e, t) {
					assert("ArgumentPlaceholder", e, t);
				}, t.assertArrayExpression = function(e, t) {
					assert("ArrayExpression", e, t);
				}, t.assertArrayPattern = function(e, t) {
					assert("ArrayPattern", e, t);
				}, t.assertArrayTypeAnnotation = function(e, t) {
					assert("ArrayTypeAnnotation", e, t);
				}, t.assertArrowFunctionExpression = function(e, t) {
					assert("ArrowFunctionExpression", e, t);
				}, t.assertAssignmentExpression = function(e, t) {
					assert("AssignmentExpression", e, t);
				}, t.assertAssignmentPattern = function(e, t) {
					assert("AssignmentPattern", e, t);
				}, t.assertAwaitExpression = function(e, t) {
					assert("AwaitExpression", e, t);
				}, t.assertBigIntLiteral = function(e, t) {
					assert("BigIntLiteral", e, t);
				}, t.assertBinary = function(e, t) {
					assert("Binary", e, t);
				}, t.assertBinaryExpression = function(e, t) {
					assert("BinaryExpression", e, t);
				}, t.assertBindExpression = function(e, t) {
					assert("BindExpression", e, t);
				}, t.assertBlock = function(e, t) {
					assert("Block", e, t);
				}, t.assertBlockParent = function(e, t) {
					assert("BlockParent", e, t);
				}, t.assertBlockStatement = function(e, t) {
					assert("BlockStatement", e, t);
				}, t.assertBooleanLiteral = function(e, t) {
					assert("BooleanLiteral", e, t);
				}, t.assertBooleanLiteralTypeAnnotation = function(e, t) {
					assert("BooleanLiteralTypeAnnotation", e, t);
				}, t.assertBooleanTypeAnnotation = function(e, t) {
					assert("BooleanTypeAnnotation", e, t);
				}, t.assertBreakStatement = function(e, t) {
					assert("BreakStatement", e, t);
				}, t.assertCallExpression = function(e, t) {
					assert("CallExpression", e, t);
				}, t.assertCatchClause = function(e, t) {
					assert("CatchClause", e, t);
				}, t.assertClass = function(e, t) {
					assert("Class", e, t);
				}, t.assertClassAccessorProperty = function(e, t) {
					assert("ClassAccessorProperty", e, t);
				}, t.assertClassBody = function(e, t) {
					assert("ClassBody", e, t);
				}, t.assertClassDeclaration = function(e, t) {
					assert("ClassDeclaration", e, t);
				}, t.assertClassExpression = function(e, t) {
					assert("ClassExpression", e, t);
				}, t.assertClassImplements = function(e, t) {
					assert("ClassImplements", e, t);
				}, t.assertClassMethod = function(e, t) {
					assert("ClassMethod", e, t);
				}, t.assertClassPrivateMethod = function(e, t) {
					assert("ClassPrivateMethod", e, t);
				}, t.assertClassPrivateProperty = function(e, t) {
					assert("ClassPrivateProperty", e, t);
				}, t.assertClassProperty = function(e, t) {
					assert("ClassProperty", e, t);
				}, t.assertCompletionStatement = function(e, t) {
					assert("CompletionStatement", e, t);
				}, t.assertConditional = function(e, t) {
					assert("Conditional", e, t);
				}, t.assertConditionalExpression = function(e, t) {
					assert("ConditionalExpression", e, t);
				}, t.assertContinueStatement = function(e, t) {
					assert("ContinueStatement", e, t);
				}, t.assertDebuggerStatement = function(e, t) {
					assert("DebuggerStatement", e, t);
				}, t.assertDecimalLiteral = function(e, t) {
					assert("DecimalLiteral", e, t);
				}, t.assertDeclaration = function(e, t) {
					assert("Declaration", e, t);
				}, t.assertDeclareClass = function(e, t) {
					assert("DeclareClass", e, t);
				}, t.assertDeclareExportAllDeclaration = function(e, t) {
					assert("DeclareExportAllDeclaration", e, t);
				}, t.assertDeclareExportDeclaration = function(e, t) {
					assert("DeclareExportDeclaration", e, t);
				}, t.assertDeclareFunction = function(e, t) {
					assert("DeclareFunction", e, t);
				}, t.assertDeclareInterface = function(e, t) {
					assert("DeclareInterface", e, t);
				}, t.assertDeclareModule = function(e, t) {
					assert("DeclareModule", e, t);
				}, t.assertDeclareModuleExports = function(e, t) {
					assert("DeclareModuleExports", e, t);
				}, t.assertDeclareOpaqueType = function(e, t) {
					assert("DeclareOpaqueType", e, t);
				}, t.assertDeclareTypeAlias = function(e, t) {
					assert("DeclareTypeAlias", e, t);
				}, t.assertDeclareVariable = function(e, t) {
					assert("DeclareVariable", e, t);
				}, t.assertDeclaredPredicate = function(e, t) {
					assert("DeclaredPredicate", e, t);
				}, t.assertDecorator = function(e, t) {
					assert("Decorator", e, t);
				}, t.assertDirective = function(e, t) {
					assert("Directive", e, t);
				}, t.assertDirectiveLiteral = function(e, t) {
					assert("DirectiveLiteral", e, t);
				}, t.assertDoExpression = function(e, t) {
					assert("DoExpression", e, t);
				}, t.assertDoWhileStatement = function(e, t) {
					assert("DoWhileStatement", e, t);
				}, t.assertEmptyStatement = function(e, t) {
					assert("EmptyStatement", e, t);
				}, t.assertEmptyTypeAnnotation = function(e, t) {
					assert("EmptyTypeAnnotation", e, t);
				}, t.assertEnumBody = function(e, t) {
					assert("EnumBody", e, t);
				}, t.assertEnumBooleanBody = function(e, t) {
					assert("EnumBooleanBody", e, t);
				}, t.assertEnumBooleanMember = function(e, t) {
					assert("EnumBooleanMember", e, t);
				}, t.assertEnumDeclaration = function(e, t) {
					assert("EnumDeclaration", e, t);
				}, t.assertEnumDefaultedMember = function(e, t) {
					assert("EnumDefaultedMember", e, t);
				}, t.assertEnumMember = function(e, t) {
					assert("EnumMember", e, t);
				}, t.assertEnumNumberBody = function(e, t) {
					assert("EnumNumberBody", e, t);
				}, t.assertEnumNumberMember = function(e, t) {
					assert("EnumNumberMember", e, t);
				}, t.assertEnumStringBody = function(e, t) {
					assert("EnumStringBody", e, t);
				}, t.assertEnumStringMember = function(e, t) {
					assert("EnumStringMember", e, t);
				}, t.assertEnumSymbolBody = function(e, t) {
					assert("EnumSymbolBody", e, t);
				}, t.assertExistsTypeAnnotation = function(e, t) {
					assert("ExistsTypeAnnotation", e, t);
				}, t.assertExportAllDeclaration = function(e, t) {
					assert("ExportAllDeclaration", e, t);
				}, t.assertExportDeclaration = function(e, t) {
					assert("ExportDeclaration", e, t);
				}, t.assertExportDefaultDeclaration = function(e, t) {
					assert("ExportDefaultDeclaration", e, t);
				}, t.assertExportDefaultSpecifier = function(e, t) {
					assert("ExportDefaultSpecifier", e, t);
				}, t.assertExportNamedDeclaration = function(e, t) {
					assert("ExportNamedDeclaration", e, t);
				}, t.assertExportNamespaceSpecifier = function(e, t) {
					assert("ExportNamespaceSpecifier", e, t);
				}, t.assertExportSpecifier = function(e, t) {
					assert("ExportSpecifier", e, t);
				}, t.assertExpression = function(e, t) {
					assert("Expression", e, t);
				}, t.assertExpressionStatement = function(e, t) {
					assert("ExpressionStatement", e, t);
				}, t.assertExpressionWrapper = function(e, t) {
					assert("ExpressionWrapper", e, t);
				}, t.assertFile = function(e, t) {
					assert("File", e, t);
				}, t.assertFlow = function(e, t) {
					assert("Flow", e, t);
				}, t.assertFlowBaseAnnotation = function(e, t) {
					assert("FlowBaseAnnotation", e, t);
				}, t.assertFlowDeclaration = function(e, t) {
					assert("FlowDeclaration", e, t);
				}, t.assertFlowPredicate = function(e, t) {
					assert("FlowPredicate", e, t);
				}, t.assertFlowType = function(e, t) {
					assert("FlowType", e, t);
				}, t.assertFor = function(e, t) {
					assert("For", e, t);
				}, t.assertForInStatement = function(e, t) {
					assert("ForInStatement", e, t);
				}, t.assertForOfStatement = function(e, t) {
					assert("ForOfStatement", e, t);
				}, t.assertForStatement = function(e, t) {
					assert("ForStatement", e, t);
				}, t.assertForXStatement = function(e, t) {
					assert("ForXStatement", e, t);
				}, t.assertFunction = function(e, t) {
					assert("Function", e, t);
				}, t.assertFunctionDeclaration = function(e, t) {
					assert("FunctionDeclaration", e, t);
				}, t.assertFunctionExpression = function(e, t) {
					assert("FunctionExpression", e, t);
				}, t.assertFunctionParameter = function(e, t) {
					assert("FunctionParameter", e, t);
				}, t.assertFunctionParent = function(e, t) {
					assert("FunctionParent", e, t);
				}, t.assertFunctionTypeAnnotation = function(e, t) {
					assert("FunctionTypeAnnotation", e, t);
				}, t.assertFunctionTypeParam = function(e, t) {
					assert("FunctionTypeParam", e, t);
				}, t.assertGenericTypeAnnotation = function(e, t) {
					assert("GenericTypeAnnotation", e, t);
				}, t.assertIdentifier = function(e, t) {
					assert("Identifier", e, t);
				}, t.assertIfStatement = function(e, t) {
					assert("IfStatement", e, t);
				}, t.assertImmutable = function(e, t) {
					assert("Immutable", e, t);
				}, t.assertImport = function(e, t) {
					assert("Import", e, t);
				}, t.assertImportAttribute = function(e, t) {
					assert("ImportAttribute", e, t);
				}, t.assertImportDeclaration = function(e, t) {
					assert("ImportDeclaration", e, t);
				}, t.assertImportDefaultSpecifier = function(e, t) {
					assert("ImportDefaultSpecifier", e, t);
				}, t.assertImportExpression = function(e, t) {
					assert("ImportExpression", e, t);
				}, t.assertImportNamespaceSpecifier = function(e, t) {
					assert("ImportNamespaceSpecifier", e, t);
				}, t.assertImportOrExportDeclaration = function(e, t) {
					assert("ImportOrExportDeclaration", e, t);
				}, t.assertImportSpecifier = function(e, t) {
					assert("ImportSpecifier", e, t);
				}, t.assertIndexedAccessType = function(e, t) {
					assert("IndexedAccessType", e, t);
				}, t.assertInferredPredicate = function(e, t) {
					assert("InferredPredicate", e, t);
				}, t.assertInterfaceDeclaration = function(e, t) {
					assert("InterfaceDeclaration", e, t);
				}, t.assertInterfaceExtends = function(e, t) {
					assert("InterfaceExtends", e, t);
				}, t.assertInterfaceTypeAnnotation = function(e, t) {
					assert("InterfaceTypeAnnotation", e, t);
				}, t.assertInterpreterDirective = function(e, t) {
					assert("InterpreterDirective", e, t);
				}, t.assertIntersectionTypeAnnotation = function(e, t) {
					assert("IntersectionTypeAnnotation", e, t);
				}, t.assertJSX = function(e, t) {
					assert("JSX", e, t);
				}, t.assertJSXAttribute = function(e, t) {
					assert("JSXAttribute", e, t);
				}, t.assertJSXClosingElement = function(e, t) {
					assert("JSXClosingElement", e, t);
				}, t.assertJSXClosingFragment = function(e, t) {
					assert("JSXClosingFragment", e, t);
				}, t.assertJSXElement = function(e, t) {
					assert("JSXElement", e, t);
				}, t.assertJSXEmptyExpression = function(e, t) {
					assert("JSXEmptyExpression", e, t);
				}, t.assertJSXExpressionContainer = function(e, t) {
					assert("JSXExpressionContainer", e, t);
				}, t.assertJSXFragment = function(e, t) {
					assert("JSXFragment", e, t);
				}, t.assertJSXIdentifier = function(e, t) {
					assert("JSXIdentifier", e, t);
				}, t.assertJSXMemberExpression = function(e, t) {
					assert("JSXMemberExpression", e, t);
				}, t.assertJSXNamespacedName = function(e, t) {
					assert("JSXNamespacedName", e, t);
				}, t.assertJSXOpeningElement = function(e, t) {
					assert("JSXOpeningElement", e, t);
				}, t.assertJSXOpeningFragment = function(e, t) {
					assert("JSXOpeningFragment", e, t);
				}, t.assertJSXSpreadAttribute = function(e, t) {
					assert("JSXSpreadAttribute", e, t);
				}, t.assertJSXSpreadChild = function(e, t) {
					assert("JSXSpreadChild", e, t);
				}, t.assertJSXText = function(e, t) {
					assert("JSXText", e, t);
				}, t.assertLVal = function(e, t) {
					assert("LVal", e, t);
				}, t.assertLabeledStatement = function(e, t) {
					assert("LabeledStatement", e, t);
				}, t.assertLiteral = function(e, t) {
					assert("Literal", e, t);
				}, t.assertLogicalExpression = function(e, t) {
					assert("LogicalExpression", e, t);
				}, t.assertLoop = function(e, t) {
					assert("Loop", e, t);
				}, t.assertMemberExpression = function(e, t) {
					assert("MemberExpression", e, t);
				}, t.assertMetaProperty = function(e, t) {
					assert("MetaProperty", e, t);
				}, t.assertMethod = function(e, t) {
					assert("Method", e, t);
				}, t.assertMiscellaneous = function(e, t) {
					assert("Miscellaneous", e, t);
				}, t.assertMixedTypeAnnotation = function(e, t) {
					assert("MixedTypeAnnotation", e, t);
				}, t.assertModuleDeclaration = function(e, t) {
					(0, s.default)("assertModuleDeclaration", "assertImportOrExportDeclaration"), assert("ModuleDeclaration", e, t);
				}, t.assertModuleExpression = function(e, t) {
					assert("ModuleExpression", e, t);
				}, t.assertModuleSpecifier = function(e, t) {
					assert("ModuleSpecifier", e, t);
				}, t.assertNewExpression = function(e, t) {
					assert("NewExpression", e, t);
				}, t.assertNoop = function(e, t) {
					assert("Noop", e, t);
				}, t.assertNullLiteral = function(e, t) {
					assert("NullLiteral", e, t);
				}, t.assertNullLiteralTypeAnnotation = function(e, t) {
					assert("NullLiteralTypeAnnotation", e, t);
				}, t.assertNullableTypeAnnotation = function(e, t) {
					assert("NullableTypeAnnotation", e, t);
				}, t.assertNumberLiteral = function(e, t) {
					(0, s.default)("assertNumberLiteral", "assertNumericLiteral"), assert("NumberLiteral", e, t);
				}, t.assertNumberLiteralTypeAnnotation = function(e, t) {
					assert("NumberLiteralTypeAnnotation", e, t);
				}, t.assertNumberTypeAnnotation = function(e, t) {
					assert("NumberTypeAnnotation", e, t);
				}, t.assertNumericLiteral = function(e, t) {
					assert("NumericLiteral", e, t);
				}, t.assertObjectExpression = function(e, t) {
					assert("ObjectExpression", e, t);
				}, t.assertObjectMember = function(e, t) {
					assert("ObjectMember", e, t);
				}, t.assertObjectMethod = function(e, t) {
					assert("ObjectMethod", e, t);
				}, t.assertObjectPattern = function(e, t) {
					assert("ObjectPattern", e, t);
				}, t.assertObjectProperty = function(e, t) {
					assert("ObjectProperty", e, t);
				}, t.assertObjectTypeAnnotation = function(e, t) {
					assert("ObjectTypeAnnotation", e, t);
				}, t.assertObjectTypeCallProperty = function(e, t) {
					assert("ObjectTypeCallProperty", e, t);
				}, t.assertObjectTypeIndexer = function(e, t) {
					assert("ObjectTypeIndexer", e, t);
				}, t.assertObjectTypeInternalSlot = function(e, t) {
					assert("ObjectTypeInternalSlot", e, t);
				}, t.assertObjectTypeProperty = function(e, t) {
					assert("ObjectTypeProperty", e, t);
				}, t.assertObjectTypeSpreadProperty = function(e, t) {
					assert("ObjectTypeSpreadProperty", e, t);
				}, t.assertOpaqueType = function(e, t) {
					assert("OpaqueType", e, t);
				}, t.assertOptionalCallExpression = function(e, t) {
					assert("OptionalCallExpression", e, t);
				}, t.assertOptionalIndexedAccessType = function(e, t) {
					assert("OptionalIndexedAccessType", e, t);
				}, t.assertOptionalMemberExpression = function(e, t) {
					assert("OptionalMemberExpression", e, t);
				}, t.assertParenthesizedExpression = function(e, t) {
					assert("ParenthesizedExpression", e, t);
				}, t.assertPattern = function(e, t) {
					assert("Pattern", e, t);
				}, t.assertPatternLike = function(e, t) {
					assert("PatternLike", e, t);
				}, t.assertPipelineBareFunction = function(e, t) {
					assert("PipelineBareFunction", e, t);
				}, t.assertPipelinePrimaryTopicReference = function(e, t) {
					assert("PipelinePrimaryTopicReference", e, t);
				}, t.assertPipelineTopicExpression = function(e, t) {
					assert("PipelineTopicExpression", e, t);
				}, t.assertPlaceholder = function(e, t) {
					assert("Placeholder", e, t);
				}, t.assertPrivate = function(e, t) {
					assert("Private", e, t);
				}, t.assertPrivateName = function(e, t) {
					assert("PrivateName", e, t);
				}, t.assertProgram = function(e, t) {
					assert("Program", e, t);
				}, t.assertProperty = function(e, t) {
					assert("Property", e, t);
				}, t.assertPureish = function(e, t) {
					assert("Pureish", e, t);
				}, t.assertQualifiedTypeIdentifier = function(e, t) {
					assert("QualifiedTypeIdentifier", e, t);
				}, t.assertRecordExpression = function(e, t) {
					assert("RecordExpression", e, t);
				}, t.assertRegExpLiteral = function(e, t) {
					assert("RegExpLiteral", e, t);
				}, t.assertRegexLiteral = function(e, t) {
					(0, s.default)("assertRegexLiteral", "assertRegExpLiteral"), assert("RegexLiteral", e, t);
				}, t.assertRestElement = function(e, t) {
					assert("RestElement", e, t);
				}, t.assertRestProperty = function(e, t) {
					(0, s.default)("assertRestProperty", "assertRestElement"), assert("RestProperty", e, t);
				}, t.assertReturnStatement = function(e, t) {
					assert("ReturnStatement", e, t);
				}, t.assertScopable = function(e, t) {
					assert("Scopable", e, t);
				}, t.assertSequenceExpression = function(e, t) {
					assert("SequenceExpression", e, t);
				}, t.assertSpreadElement = function(e, t) {
					assert("SpreadElement", e, t);
				}, t.assertSpreadProperty = function(e, t) {
					(0, s.default)("assertSpreadProperty", "assertSpreadElement"), assert("SpreadProperty", e, t);
				}, t.assertStandardized = function(e, t) {
					assert("Standardized", e, t);
				}, t.assertStatement = function(e, t) {
					assert("Statement", e, t);
				}, t.assertStaticBlock = function(e, t) {
					assert("StaticBlock", e, t);
				}, t.assertStringLiteral = function(e, t) {
					assert("StringLiteral", e, t);
				}, t.assertStringLiteralTypeAnnotation = function(e, t) {
					assert("StringLiteralTypeAnnotation", e, t);
				}, t.assertStringTypeAnnotation = function(e, t) {
					assert("StringTypeAnnotation", e, t);
				}, t.assertSuper = function(e, t) {
					assert("Super", e, t);
				}, t.assertSwitchCase = function(e, t) {
					assert("SwitchCase", e, t);
				}, t.assertSwitchStatement = function(e, t) {
					assert("SwitchStatement", e, t);
				}, t.assertSymbolTypeAnnotation = function(e, t) {
					assert("SymbolTypeAnnotation", e, t);
				}, t.assertTSAnyKeyword = function(e, t) {
					assert("TSAnyKeyword", e, t);
				}, t.assertTSArrayType = function(e, t) {
					assert("TSArrayType", e, t);
				}, t.assertTSAsExpression = function(e, t) {
					assert("TSAsExpression", e, t);
				}, t.assertTSBaseType = function(e, t) {
					assert("TSBaseType", e, t);
				}, t.assertTSBigIntKeyword = function(e, t) {
					assert("TSBigIntKeyword", e, t);
				}, t.assertTSBooleanKeyword = function(e, t) {
					assert("TSBooleanKeyword", e, t);
				}, t.assertTSCallSignatureDeclaration = function(e, t) {
					assert("TSCallSignatureDeclaration", e, t);
				}, t.assertTSConditionalType = function(e, t) {
					assert("TSConditionalType", e, t);
				}, t.assertTSConstructSignatureDeclaration = function(e, t) {
					assert("TSConstructSignatureDeclaration", e, t);
				}, t.assertTSConstructorType = function(e, t) {
					assert("TSConstructorType", e, t);
				}, t.assertTSDeclareFunction = function(e, t) {
					assert("TSDeclareFunction", e, t);
				}, t.assertTSDeclareMethod = function(e, t) {
					assert("TSDeclareMethod", e, t);
				}, t.assertTSEntityName = function(e, t) {
					assert("TSEntityName", e, t);
				}, t.assertTSEnumBody = function(e, t) {
					assert("TSEnumBody", e, t);
				}, t.assertTSEnumDeclaration = function(e, t) {
					assert("TSEnumDeclaration", e, t);
				}, t.assertTSEnumMember = function(e, t) {
					assert("TSEnumMember", e, t);
				}, t.assertTSExportAssignment = function(e, t) {
					assert("TSExportAssignment", e, t);
				}, t.assertTSExpressionWithTypeArguments = function(e, t) {
					assert("TSExpressionWithTypeArguments", e, t);
				}, t.assertTSExternalModuleReference = function(e, t) {
					assert("TSExternalModuleReference", e, t);
				}, t.assertTSFunctionType = function(e, t) {
					assert("TSFunctionType", e, t);
				}, t.assertTSImportEqualsDeclaration = function(e, t) {
					assert("TSImportEqualsDeclaration", e, t);
				}, t.assertTSImportType = function(e, t) {
					assert("TSImportType", e, t);
				}, t.assertTSIndexSignature = function(e, t) {
					assert("TSIndexSignature", e, t);
				}, t.assertTSIndexedAccessType = function(e, t) {
					assert("TSIndexedAccessType", e, t);
				}, t.assertTSInferType = function(e, t) {
					assert("TSInferType", e, t);
				}, t.assertTSInstantiationExpression = function(e, t) {
					assert("TSInstantiationExpression", e, t);
				}, t.assertTSInterfaceBody = function(e, t) {
					assert("TSInterfaceBody", e, t);
				}, t.assertTSInterfaceDeclaration = function(e, t) {
					assert("TSInterfaceDeclaration", e, t);
				}, t.assertTSIntersectionType = function(e, t) {
					assert("TSIntersectionType", e, t);
				}, t.assertTSIntrinsicKeyword = function(e, t) {
					assert("TSIntrinsicKeyword", e, t);
				}, t.assertTSLiteralType = function(e, t) {
					assert("TSLiteralType", e, t);
				}, t.assertTSMappedType = function(e, t) {
					assert("TSMappedType", e, t);
				}, t.assertTSMethodSignature = function(e, t) {
					assert("TSMethodSignature", e, t);
				}, t.assertTSModuleBlock = function(e, t) {
					assert("TSModuleBlock", e, t);
				}, t.assertTSModuleDeclaration = function(e, t) {
					assert("TSModuleDeclaration", e, t);
				}, t.assertTSNamedTupleMember = function(e, t) {
					assert("TSNamedTupleMember", e, t);
				}, t.assertTSNamespaceExportDeclaration = function(e, t) {
					assert("TSNamespaceExportDeclaration", e, t);
				}, t.assertTSNeverKeyword = function(e, t) {
					assert("TSNeverKeyword", e, t);
				}, t.assertTSNonNullExpression = function(e, t) {
					assert("TSNonNullExpression", e, t);
				}, t.assertTSNullKeyword = function(e, t) {
					assert("TSNullKeyword", e, t);
				}, t.assertTSNumberKeyword = function(e, t) {
					assert("TSNumberKeyword", e, t);
				}, t.assertTSObjectKeyword = function(e, t) {
					assert("TSObjectKeyword", e, t);
				}, t.assertTSOptionalType = function(e, t) {
					assert("TSOptionalType", e, t);
				}, t.assertTSParameterProperty = function(e, t) {
					assert("TSParameterProperty", e, t);
				}, t.assertTSParenthesizedType = function(e, t) {
					assert("TSParenthesizedType", e, t);
				}, t.assertTSPropertySignature = function(e, t) {
					assert("TSPropertySignature", e, t);
				}, t.assertTSQualifiedName = function(e, t) {
					assert("TSQualifiedName", e, t);
				}, t.assertTSRestType = function(e, t) {
					assert("TSRestType", e, t);
				}, t.assertTSSatisfiesExpression = function(e, t) {
					assert("TSSatisfiesExpression", e, t);
				}, t.assertTSStringKeyword = function(e, t) {
					assert("TSStringKeyword", e, t);
				}, t.assertTSSymbolKeyword = function(e, t) {
					assert("TSSymbolKeyword", e, t);
				}, t.assertTSTemplateLiteralType = function(e, t) {
					assert("TSTemplateLiteralType", e, t);
				}, t.assertTSThisType = function(e, t) {
					assert("TSThisType", e, t);
				}, t.assertTSTupleType = function(e, t) {
					assert("TSTupleType", e, t);
				}, t.assertTSType = function(e, t) {
					assert("TSType", e, t);
				}, t.assertTSTypeAliasDeclaration = function(e, t) {
					assert("TSTypeAliasDeclaration", e, t);
				}, t.assertTSTypeAnnotation = function(e, t) {
					assert("TSTypeAnnotation", e, t);
				}, t.assertTSTypeAssertion = function(e, t) {
					assert("TSTypeAssertion", e, t);
				}, t.assertTSTypeElement = function(e, t) {
					assert("TSTypeElement", e, t);
				}, t.assertTSTypeLiteral = function(e, t) {
					assert("TSTypeLiteral", e, t);
				}, t.assertTSTypeOperator = function(e, t) {
					assert("TSTypeOperator", e, t);
				}, t.assertTSTypeParameter = function(e, t) {
					assert("TSTypeParameter", e, t);
				}, t.assertTSTypeParameterDeclaration = function(e, t) {
					assert("TSTypeParameterDeclaration", e, t);
				}, t.assertTSTypeParameterInstantiation = function(e, t) {
					assert("TSTypeParameterInstantiation", e, t);
				}, t.assertTSTypePredicate = function(e, t) {
					assert("TSTypePredicate", e, t);
				}, t.assertTSTypeQuery = function(e, t) {
					assert("TSTypeQuery", e, t);
				}, t.assertTSTypeReference = function(e, t) {
					assert("TSTypeReference", e, t);
				}, t.assertTSUndefinedKeyword = function(e, t) {
					assert("TSUndefinedKeyword", e, t);
				}, t.assertTSUnionType = function(e, t) {
					assert("TSUnionType", e, t);
				}, t.assertTSUnknownKeyword = function(e, t) {
					assert("TSUnknownKeyword", e, t);
				}, t.assertTSVoidKeyword = function(e, t) {
					assert("TSVoidKeyword", e, t);
				}, t.assertTaggedTemplateExpression = function(e, t) {
					assert("TaggedTemplateExpression", e, t);
				}, t.assertTemplateElement = function(e, t) {
					assert("TemplateElement", e, t);
				}, t.assertTemplateLiteral = function(e, t) {
					assert("TemplateLiteral", e, t);
				}, t.assertTerminatorless = function(e, t) {
					assert("Terminatorless", e, t);
				}, t.assertThisExpression = function(e, t) {
					assert("ThisExpression", e, t);
				}, t.assertThisTypeAnnotation = function(e, t) {
					assert("ThisTypeAnnotation", e, t);
				}, t.assertThrowStatement = function(e, t) {
					assert("ThrowStatement", e, t);
				}, t.assertTopicReference = function(e, t) {
					assert("TopicReference", e, t);
				}, t.assertTryStatement = function(e, t) {
					assert("TryStatement", e, t);
				}, t.assertTupleExpression = function(e, t) {
					assert("TupleExpression", e, t);
				}, t.assertTupleTypeAnnotation = function(e, t) {
					assert("TupleTypeAnnotation", e, t);
				}, t.assertTypeAlias = function(e, t) {
					assert("TypeAlias", e, t);
				}, t.assertTypeAnnotation = function(e, t) {
					assert("TypeAnnotation", e, t);
				}, t.assertTypeCastExpression = function(e, t) {
					assert("TypeCastExpression", e, t);
				}, t.assertTypeParameter = function(e, t) {
					assert("TypeParameter", e, t);
				}, t.assertTypeParameterDeclaration = function(e, t) {
					assert("TypeParameterDeclaration", e, t);
				}, t.assertTypeParameterInstantiation = function(e, t) {
					assert("TypeParameterInstantiation", e, t);
				}, t.assertTypeScript = function(e, t) {
					assert("TypeScript", e, t);
				}, t.assertTypeofTypeAnnotation = function(e, t) {
					assert("TypeofTypeAnnotation", e, t);
				}, t.assertUnaryExpression = function(e, t) {
					assert("UnaryExpression", e, t);
				}, t.assertUnaryLike = function(e, t) {
					assert("UnaryLike", e, t);
				}, t.assertUnionTypeAnnotation = function(e, t) {
					assert("UnionTypeAnnotation", e, t);
				}, t.assertUpdateExpression = function(e, t) {
					assert("UpdateExpression", e, t);
				}, t.assertUserWhitespacable = function(e, t) {
					assert("UserWhitespacable", e, t);
				}, t.assertV8IntrinsicIdentifier = function(e, t) {
					assert("V8IntrinsicIdentifier", e, t);
				}, t.assertVariableDeclaration = function(e, t) {
					assert("VariableDeclaration", e, t);
				}, t.assertVariableDeclarator = function(e, t) {
					assert("VariableDeclarator", e, t);
				}, t.assertVariance = function(e, t) {
					assert("Variance", e, t);
				}, t.assertVoidPattern = function(e, t) {
					assert("VoidPattern", e, t);
				}, t.assertVoidTypeAnnotation = function(e, t) {
					assert("VoidTypeAnnotation", e, t);
				}, t.assertWhile = function(e, t) {
					assert("While", e, t);
				}, t.assertWhileStatement = function(e, t) {
					assert("WhileStatement", e, t);
				}, t.assertWithStatement = function(e, t) {
					assert("WithStatement", e, t);
				}, t.assertYieldExpression = function(e, t) {
					assert("YieldExpression", e, t);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/is.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/deprecationWarning.js");
				function assert(e, t, r) {
					if (!(0, n.default)(e, t, r)) throw new Error(`Expected type "${e}" with option ${JSON.stringify(r)}, but instead got "${t.type}".`);
				}
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/flow/createFlowUnionType.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					const t = (0, s.default)(e);
					return 1 === t.length ? t[0] : (0, n.unionTypeAnnotation)(t);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/flow/removeTypeDuplicates.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/flow/createTypeAnnotationBasedOnTypeof.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js");
				t.default = function(e) {
					switch (e) {
						case "string": return (0, n.stringTypeAnnotation)();
						case "number": return (0, n.numberTypeAnnotation)();
						case "undefined": return (0, n.voidTypeAnnotation)();
						case "boolean": return (0, n.booleanTypeAnnotation)();
						case "function": return (0, n.genericTypeAnnotation)((0, n.identifier)("Function"));
						case "object": return (0, n.genericTypeAnnotation)((0, n.identifier)("Object"));
						case "symbol": return (0, n.genericTypeAnnotation)((0, n.identifier)("Symbol"));
						case "bigint": return (0, n.anyTypeAnnotation)();
					}
					throw new Error("Invalid typeof value: " + e);
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 });
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/lowercase.js");
				Object.keys(n).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === n[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return n[e];
						}
					}));
				});
				var s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/uppercase.js");
				Object.keys(s).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (e in t && t[e] === s[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return s[e];
						}
					}));
				});
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/lowercase.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.anyTypeAnnotation = function() {
					return { type: "AnyTypeAnnotation" };
				}, t.argumentPlaceholder = function() {
					return { type: "ArgumentPlaceholder" };
				}, t.arrayExpression = function(e = []) {
					const t = {
						type: "ArrayExpression",
						elements: e
					}, r = a.ArrayExpression;
					return o(r.elements, t, "elements", e, 1), t;
				}, t.arrayPattern = function(e) {
					const t = {
						type: "ArrayPattern",
						elements: e
					}, r = a.ArrayPattern;
					return o(r.elements, t, "elements", e, 1), t;
				}, t.arrayTypeAnnotation = function(e) {
					const t = {
						type: "ArrayTypeAnnotation",
						elementType: e
					}, r = a.ArrayTypeAnnotation;
					return o(r.elementType, t, "elementType", e, 1), t;
				}, t.arrowFunctionExpression = function(e, t, r = !1) {
					const n = {
						type: "ArrowFunctionExpression",
						params: e,
						body: t,
						async: r,
						expression: null
					}, s = a.ArrowFunctionExpression;
					return o(s.params, n, "params", e, 1), o(s.body, n, "body", t, 1), o(s.async, n, "async", r), n;
				}, t.assignmentExpression = function(e, t, r) {
					const n = {
						type: "AssignmentExpression",
						operator: e,
						left: t,
						right: r
					}, s = a.AssignmentExpression;
					return o(s.operator, n, "operator", e), o(s.left, n, "left", t, 1), o(s.right, n, "right", r, 1), n;
				}, t.assignmentPattern = function(e, t) {
					const r = {
						type: "AssignmentPattern",
						left: e,
						right: t
					}, n = a.AssignmentPattern;
					return o(n.left, r, "left", e, 1), o(n.right, r, "right", t, 1), r;
				}, t.awaitExpression = function(e) {
					const t = {
						type: "AwaitExpression",
						argument: e
					}, r = a.AwaitExpression;
					return o(r.argument, t, "argument", e, 1), t;
				}, t.bigIntLiteral = function(e) {
					"bigint" == typeof e && (e = e.toString());
					const t = {
						type: "BigIntLiteral",
						value: e
					}, r = a.BigIntLiteral;
					return o(r.value, t, "value", e), t;
				}, t.binaryExpression = function(e, t, r) {
					const n = {
						type: "BinaryExpression",
						operator: e,
						left: t,
						right: r
					}, s = a.BinaryExpression;
					return o(s.operator, n, "operator", e), o(s.left, n, "left", t, 1), o(s.right, n, "right", r, 1), n;
				}, t.bindExpression = function(e, t) {
					const r = {
						type: "BindExpression",
						object: e,
						callee: t
					}, n = a.BindExpression;
					return o(n.object, r, "object", e, 1), o(n.callee, r, "callee", t, 1), r;
				}, t.blockStatement = function(e, t = []) {
					const r = {
						type: "BlockStatement",
						body: e,
						directives: t
					}, n = a.BlockStatement;
					return o(n.body, r, "body", e, 1), o(n.directives, r, "directives", t, 1), r;
				}, t.booleanLiteral = function(e) {
					const t = {
						type: "BooleanLiteral",
						value: e
					}, r = a.BooleanLiteral;
					return o(r.value, t, "value", e), t;
				}, t.booleanLiteralTypeAnnotation = function(e) {
					const t = {
						type: "BooleanLiteralTypeAnnotation",
						value: e
					}, r = a.BooleanLiteralTypeAnnotation;
					return o(r.value, t, "value", e), t;
				}, t.booleanTypeAnnotation = function() {
					return { type: "BooleanTypeAnnotation" };
				}, t.breakStatement = function(e = null) {
					const t = {
						type: "BreakStatement",
						label: e
					}, r = a.BreakStatement;
					return o(r.label, t, "label", e, 1), t;
				}, t.callExpression = function(e, t) {
					const r = {
						type: "CallExpression",
						callee: e,
						arguments: t
					}, n = a.CallExpression;
					return o(n.callee, r, "callee", e, 1), o(n.arguments, r, "arguments", t, 1), r;
				}, t.catchClause = function(e = null, t) {
					const r = {
						type: "CatchClause",
						param: e,
						body: t
					}, n = a.CatchClause;
					return o(n.param, r, "param", e, 1), o(n.body, r, "body", t, 1), r;
				}, t.classAccessorProperty = function(e, t = null, r = null, n = null, s = !1, i = !1) {
					const l = {
						type: "ClassAccessorProperty",
						key: e,
						value: t,
						typeAnnotation: r,
						decorators: n,
						computed: s,
						static: i
					}, p = a.ClassAccessorProperty;
					return o(p.key, l, "key", e, 1), o(p.value, l, "value", t, 1), o(p.typeAnnotation, l, "typeAnnotation", r, 1), o(p.decorators, l, "decorators", n, 1), o(p.computed, l, "computed", s), o(p.static, l, "static", i), l;
				}, t.classBody = function(e) {
					const t = {
						type: "ClassBody",
						body: e
					}, r = a.ClassBody;
					return o(r.body, t, "body", e, 1), t;
				}, t.classDeclaration = function(e = null, t = null, r, n = null) {
					const s = {
						type: "ClassDeclaration",
						id: e,
						superClass: t,
						body: r,
						decorators: n
					}, i = a.ClassDeclaration;
					return o(i.id, s, "id", e, 1), o(i.superClass, s, "superClass", t, 1), o(i.body, s, "body", r, 1), o(i.decorators, s, "decorators", n, 1), s;
				}, t.classExpression = function(e = null, t = null, r, n = null) {
					const s = {
						type: "ClassExpression",
						id: e,
						superClass: t,
						body: r,
						decorators: n
					}, i = a.ClassExpression;
					return o(i.id, s, "id", e, 1), o(i.superClass, s, "superClass", t, 1), o(i.body, s, "body", r, 1), o(i.decorators, s, "decorators", n, 1), s;
				}, t.classImplements = function(e, t = null) {
					const r = {
						type: "ClassImplements",
						id: e,
						typeParameters: t
					}, n = a.ClassImplements;
					return o(n.id, r, "id", e, 1), o(n.typeParameters, r, "typeParameters", t, 1), r;
				}, t.classMethod = function(e = "method", t, r, n, s = !1, i = !1, l = !1, p = !1) {
					const c = {
						type: "ClassMethod",
						kind: e,
						key: t,
						params: r,
						body: n,
						computed: s,
						static: i,
						generator: l,
						async: p
					}, u = a.ClassMethod;
					return o(u.kind, c, "kind", e), o(u.key, c, "key", t, 1), o(u.params, c, "params", r, 1), o(u.body, c, "body", n, 1), o(u.computed, c, "computed", s), o(u.static, c, "static", i), o(u.generator, c, "generator", l), o(u.async, c, "async", p), c;
				}, t.classPrivateMethod = function(e = "method", t, r, n, s = !1) {
					const i = {
						type: "ClassPrivateMethod",
						kind: e,
						key: t,
						params: r,
						body: n,
						static: s
					}, l = a.ClassPrivateMethod;
					return o(l.kind, i, "kind", e), o(l.key, i, "key", t, 1), o(l.params, i, "params", r, 1), o(l.body, i, "body", n, 1), o(l.static, i, "static", s), i;
				}, t.classPrivateProperty = function(e, t = null, r = null, n = !1) {
					const s = {
						type: "ClassPrivateProperty",
						key: e,
						value: t,
						decorators: r,
						static: n
					}, i = a.ClassPrivateProperty;
					return o(i.key, s, "key", e, 1), o(i.value, s, "value", t, 1), o(i.decorators, s, "decorators", r, 1), o(i.static, s, "static", n), s;
				}, t.classProperty = function(e, t = null, r = null, n = null, s = !1, i = !1) {
					const l = {
						type: "ClassProperty",
						key: e,
						value: t,
						typeAnnotation: r,
						decorators: n,
						computed: s,
						static: i
					}, p = a.ClassProperty;
					return o(p.key, l, "key", e, 1), o(p.value, l, "value", t, 1), o(p.typeAnnotation, l, "typeAnnotation", r, 1), o(p.decorators, l, "decorators", n, 1), o(p.computed, l, "computed", s), o(p.static, l, "static", i), l;
				}, t.conditionalExpression = function(e, t, r) {
					const n = {
						type: "ConditionalExpression",
						test: e,
						consequent: t,
						alternate: r
					}, s = a.ConditionalExpression;
					return o(s.test, n, "test", e, 1), o(s.consequent, n, "consequent", t, 1), o(s.alternate, n, "alternate", r, 1), n;
				}, t.continueStatement = function(e = null) {
					const t = {
						type: "ContinueStatement",
						label: e
					}, r = a.ContinueStatement;
					return o(r.label, t, "label", e, 1), t;
				}, t.debuggerStatement = function() {
					return { type: "DebuggerStatement" };
				}, t.decimalLiteral = function(e) {
					const t = {
						type: "DecimalLiteral",
						value: e
					}, r = a.DecimalLiteral;
					return o(r.value, t, "value", e), t;
				}, t.declareClass = function(e, t = null, r = null, n) {
					const s = {
						type: "DeclareClass",
						id: e,
						typeParameters: t,
						extends: r,
						body: n
					}, i = a.DeclareClass;
					return o(i.id, s, "id", e, 1), o(i.typeParameters, s, "typeParameters", t, 1), o(i.extends, s, "extends", r, 1), o(i.body, s, "body", n, 1), s;
				}, t.declareExportAllDeclaration = function(e, t = null) {
					const r = {
						type: "DeclareExportAllDeclaration",
						source: e,
						attributes: t
					}, n = a.DeclareExportAllDeclaration;
					return o(n.source, r, "source", e, 1), o(n.attributes, r, "attributes", t, 1), r;
				}, t.declareExportDeclaration = function(e = null, t = null, r = null, n = null) {
					const s = {
						type: "DeclareExportDeclaration",
						declaration: e,
						specifiers: t,
						source: r,
						attributes: n
					}, i = a.DeclareExportDeclaration;
					return o(i.declaration, s, "declaration", e, 1), o(i.specifiers, s, "specifiers", t, 1), o(i.source, s, "source", r, 1), o(i.attributes, s, "attributes", n, 1), s;
				}, t.declareFunction = function(e) {
					const t = {
						type: "DeclareFunction",
						id: e
					}, r = a.DeclareFunction;
					return o(r.id, t, "id", e, 1), t;
				}, t.declareInterface = function(e, t = null, r = null, n) {
					const s = {
						type: "DeclareInterface",
						id: e,
						typeParameters: t,
						extends: r,
						body: n
					}, i = a.DeclareInterface;
					return o(i.id, s, "id", e, 1), o(i.typeParameters, s, "typeParameters", t, 1), o(i.extends, s, "extends", r, 1), o(i.body, s, "body", n, 1), s;
				}, t.declareModule = function(e, t, r = null) {
					const n = {
						type: "DeclareModule",
						id: e,
						body: t,
						kind: r
					}, s = a.DeclareModule;
					return o(s.id, n, "id", e, 1), o(s.body, n, "body", t, 1), o(s.kind, n, "kind", r), n;
				}, t.declareModuleExports = function(e) {
					const t = {
						type: "DeclareModuleExports",
						typeAnnotation: e
					}, r = a.DeclareModuleExports;
					return o(r.typeAnnotation, t, "typeAnnotation", e, 1), t;
				}, t.declareOpaqueType = function(e, t = null, r = null) {
					const n = {
						type: "DeclareOpaqueType",
						id: e,
						typeParameters: t,
						supertype: r
					}, s = a.DeclareOpaqueType;
					return o(s.id, n, "id", e, 1), o(s.typeParameters, n, "typeParameters", t, 1), o(s.supertype, n, "supertype", r, 1), n;
				}, t.declareTypeAlias = function(e, t = null, r) {
					const n = {
						type: "DeclareTypeAlias",
						id: e,
						typeParameters: t,
						right: r
					}, s = a.DeclareTypeAlias;
					return o(s.id, n, "id", e, 1), o(s.typeParameters, n, "typeParameters", t, 1), o(s.right, n, "right", r, 1), n;
				}, t.declareVariable = function(e) {
					const t = {
						type: "DeclareVariable",
						id: e
					}, r = a.DeclareVariable;
					return o(r.id, t, "id", e, 1), t;
				}, t.declaredPredicate = function(e) {
					const t = {
						type: "DeclaredPredicate",
						value: e
					}, r = a.DeclaredPredicate;
					return o(r.value, t, "value", e, 1), t;
				}, t.decorator = function(e) {
					const t = {
						type: "Decorator",
						expression: e
					}, r = a.Decorator;
					return o(r.expression, t, "expression", e, 1), t;
				}, t.directive = function(e) {
					const t = {
						type: "Directive",
						value: e
					}, r = a.Directive;
					return o(r.value, t, "value", e, 1), t;
				}, t.directiveLiteral = function(e) {
					const t = {
						type: "DirectiveLiteral",
						value: e
					}, r = a.DirectiveLiteral;
					return o(r.value, t, "value", e), t;
				}, t.doExpression = function(e, t = !1) {
					const r = {
						type: "DoExpression",
						body: e,
						async: t
					}, n = a.DoExpression;
					return o(n.body, r, "body", e, 1), o(n.async, r, "async", t), r;
				}, t.doWhileStatement = function(e, t) {
					const r = {
						type: "DoWhileStatement",
						test: e,
						body: t
					}, n = a.DoWhileStatement;
					return o(n.test, r, "test", e, 1), o(n.body, r, "body", t, 1), r;
				}, t.emptyStatement = function() {
					return { type: "EmptyStatement" };
				}, t.emptyTypeAnnotation = function() {
					return { type: "EmptyTypeAnnotation" };
				}, t.enumBooleanBody = function(e) {
					const t = {
						type: "EnumBooleanBody",
						members: e,
						explicitType: null,
						hasUnknownMembers: null
					}, r = a.EnumBooleanBody;
					return o(r.members, t, "members", e, 1), t;
				}, t.enumBooleanMember = function(e) {
					const t = {
						type: "EnumBooleanMember",
						id: e,
						init: null
					}, r = a.EnumBooleanMember;
					return o(r.id, t, "id", e, 1), t;
				}, t.enumDeclaration = function(e, t) {
					const r = {
						type: "EnumDeclaration",
						id: e,
						body: t
					}, n = a.EnumDeclaration;
					return o(n.id, r, "id", e, 1), o(n.body, r, "body", t, 1), r;
				}, t.enumDefaultedMember = function(e) {
					const t = {
						type: "EnumDefaultedMember",
						id: e
					}, r = a.EnumDefaultedMember;
					return o(r.id, t, "id", e, 1), t;
				}, t.enumNumberBody = function(e) {
					const t = {
						type: "EnumNumberBody",
						members: e,
						explicitType: null,
						hasUnknownMembers: null
					}, r = a.EnumNumberBody;
					return o(r.members, t, "members", e, 1), t;
				}, t.enumNumberMember = function(e, t) {
					const r = {
						type: "EnumNumberMember",
						id: e,
						init: t
					}, n = a.EnumNumberMember;
					return o(n.id, r, "id", e, 1), o(n.init, r, "init", t, 1), r;
				}, t.enumStringBody = function(e) {
					const t = {
						type: "EnumStringBody",
						members: e,
						explicitType: null,
						hasUnknownMembers: null
					}, r = a.EnumStringBody;
					return o(r.members, t, "members", e, 1), t;
				}, t.enumStringMember = function(e, t) {
					const r = {
						type: "EnumStringMember",
						id: e,
						init: t
					}, n = a.EnumStringMember;
					return o(n.id, r, "id", e, 1), o(n.init, r, "init", t, 1), r;
				}, t.enumSymbolBody = function(e) {
					const t = {
						type: "EnumSymbolBody",
						members: e,
						hasUnknownMembers: null
					}, r = a.EnumSymbolBody;
					return o(r.members, t, "members", e, 1), t;
				}, t.existsTypeAnnotation = function() {
					return { type: "ExistsTypeAnnotation" };
				}, t.exportAllDeclaration = function(e) {
					const t = {
						type: "ExportAllDeclaration",
						source: e
					}, r = a.ExportAllDeclaration;
					return o(r.source, t, "source", e, 1), t;
				}, t.exportDefaultDeclaration = function(e) {
					const t = {
						type: "ExportDefaultDeclaration",
						declaration: e
					}, r = a.ExportDefaultDeclaration;
					return o(r.declaration, t, "declaration", e, 1), t;
				}, t.exportDefaultSpecifier = function(e) {
					const t = {
						type: "ExportDefaultSpecifier",
						exported: e
					}, r = a.ExportDefaultSpecifier;
					return o(r.exported, t, "exported", e, 1), t;
				}, t.exportNamedDeclaration = function(e = null, t = [], r = null) {
					const n = {
						type: "ExportNamedDeclaration",
						declaration: e,
						specifiers: t,
						source: r
					}, s = a.ExportNamedDeclaration;
					return o(s.declaration, n, "declaration", e, 1), o(s.specifiers, n, "specifiers", t, 1), o(s.source, n, "source", r, 1), n;
				}, t.exportNamespaceSpecifier = function(e) {
					const t = {
						type: "ExportNamespaceSpecifier",
						exported: e
					}, r = a.ExportNamespaceSpecifier;
					return o(r.exported, t, "exported", e, 1), t;
				}, t.exportSpecifier = function(e, t) {
					const r = {
						type: "ExportSpecifier",
						local: e,
						exported: t
					}, n = a.ExportSpecifier;
					return o(n.local, r, "local", e, 1), o(n.exported, r, "exported", t, 1), r;
				}, t.expressionStatement = function(e) {
					const t = {
						type: "ExpressionStatement",
						expression: e
					}, r = a.ExpressionStatement;
					return o(r.expression, t, "expression", e, 1), t;
				}, t.file = function(e, t = null, r = null) {
					const n = {
						type: "File",
						program: e,
						comments: t,
						tokens: r
					}, s = a.File;
					return o(s.program, n, "program", e, 1), o(s.comments, n, "comments", t, 1), o(s.tokens, n, "tokens", r), n;
				}, t.forInStatement = function(e, t, r) {
					const n = {
						type: "ForInStatement",
						left: e,
						right: t,
						body: r
					}, s = a.ForInStatement;
					return o(s.left, n, "left", e, 1), o(s.right, n, "right", t, 1), o(s.body, n, "body", r, 1), n;
				}, t.forOfStatement = function(e, t, r, n = !1) {
					const s = {
						type: "ForOfStatement",
						left: e,
						right: t,
						body: r,
						await: n
					}, i = a.ForOfStatement;
					return o(i.left, s, "left", e, 1), o(i.right, s, "right", t, 1), o(i.body, s, "body", r, 1), o(i.await, s, "await", n), s;
				}, t.forStatement = function(e = null, t = null, r = null, n) {
					const s = {
						type: "ForStatement",
						init: e,
						test: t,
						update: r,
						body: n
					}, i = a.ForStatement;
					return o(i.init, s, "init", e, 1), o(i.test, s, "test", t, 1), o(i.update, s, "update", r, 1), o(i.body, s, "body", n, 1), s;
				}, t.functionDeclaration = function(e = null, t, r, n = !1, s = !1) {
					const i = {
						type: "FunctionDeclaration",
						id: e,
						params: t,
						body: r,
						generator: n,
						async: s
					}, l = a.FunctionDeclaration;
					return o(l.id, i, "id", e, 1), o(l.params, i, "params", t, 1), o(l.body, i, "body", r, 1), o(l.generator, i, "generator", n), o(l.async, i, "async", s), i;
				}, t.functionExpression = function(e = null, t, r, n = !1, s = !1) {
					const i = {
						type: "FunctionExpression",
						id: e,
						params: t,
						body: r,
						generator: n,
						async: s
					}, l = a.FunctionExpression;
					return o(l.id, i, "id", e, 1), o(l.params, i, "params", t, 1), o(l.body, i, "body", r, 1), o(l.generator, i, "generator", n), o(l.async, i, "async", s), i;
				}, t.functionTypeAnnotation = function(e = null, t, r = null, n) {
					const s = {
						type: "FunctionTypeAnnotation",
						typeParameters: e,
						params: t,
						rest: r,
						returnType: n
					}, i = a.FunctionTypeAnnotation;
					return o(i.typeParameters, s, "typeParameters", e, 1), o(i.params, s, "params", t, 1), o(i.rest, s, "rest", r, 1), o(i.returnType, s, "returnType", n, 1), s;
				}, t.functionTypeParam = function(e = null, t) {
					const r = {
						type: "FunctionTypeParam",
						name: e,
						typeAnnotation: t
					}, n = a.FunctionTypeParam;
					return o(n.name, r, "name", e, 1), o(n.typeAnnotation, r, "typeAnnotation", t, 1), r;
				}, t.genericTypeAnnotation = function(e, t = null) {
					const r = {
						type: "GenericTypeAnnotation",
						id: e,
						typeParameters: t
					}, n = a.GenericTypeAnnotation;
					return o(n.id, r, "id", e, 1), o(n.typeParameters, r, "typeParameters", t, 1), r;
				}, t.identifier = function(e) {
					const t = {
						type: "Identifier",
						name: e
					}, r = a.Identifier;
					return o(r.name, t, "name", e), t;
				}, t.ifStatement = function(e, t, r = null) {
					const n = {
						type: "IfStatement",
						test: e,
						consequent: t,
						alternate: r
					}, s = a.IfStatement;
					return o(s.test, n, "test", e, 1), o(s.consequent, n, "consequent", t, 1), o(s.alternate, n, "alternate", r, 1), n;
				}, t.import = function() {
					return { type: "Import" };
				}, t.importAttribute = function(e, t) {
					const r = {
						type: "ImportAttribute",
						key: e,
						value: t
					}, n = a.ImportAttribute;
					return o(n.key, r, "key", e, 1), o(n.value, r, "value", t, 1), r;
				}, t.importDeclaration = function(e, t) {
					const r = {
						type: "ImportDeclaration",
						specifiers: e,
						source: t
					}, n = a.ImportDeclaration;
					return o(n.specifiers, r, "specifiers", e, 1), o(n.source, r, "source", t, 1), r;
				}, t.importDefaultSpecifier = function(e) {
					const t = {
						type: "ImportDefaultSpecifier",
						local: e
					}, r = a.ImportDefaultSpecifier;
					return o(r.local, t, "local", e, 1), t;
				}, t.importExpression = function(e, t = null) {
					const r = {
						type: "ImportExpression",
						source: e,
						options: t
					}, n = a.ImportExpression;
					return o(n.source, r, "source", e, 1), o(n.options, r, "options", t, 1), r;
				}, t.importNamespaceSpecifier = function(e) {
					const t = {
						type: "ImportNamespaceSpecifier",
						local: e
					}, r = a.ImportNamespaceSpecifier;
					return o(r.local, t, "local", e, 1), t;
				}, t.importSpecifier = function(e, t) {
					const r = {
						type: "ImportSpecifier",
						local: e,
						imported: t
					}, n = a.ImportSpecifier;
					return o(n.local, r, "local", e, 1), o(n.imported, r, "imported", t, 1), r;
				}, t.indexedAccessType = function(e, t) {
					const r = {
						type: "IndexedAccessType",
						objectType: e,
						indexType: t
					}, n = a.IndexedAccessType;
					return o(n.objectType, r, "objectType", e, 1), o(n.indexType, r, "indexType", t, 1), r;
				}, t.inferredPredicate = function() {
					return { type: "InferredPredicate" };
				}, t.interfaceDeclaration = function(e, t = null, r = null, n) {
					const s = {
						type: "InterfaceDeclaration",
						id: e,
						typeParameters: t,
						extends: r,
						body: n
					}, i = a.InterfaceDeclaration;
					return o(i.id, s, "id", e, 1), o(i.typeParameters, s, "typeParameters", t, 1), o(i.extends, s, "extends", r, 1), o(i.body, s, "body", n, 1), s;
				}, t.interfaceExtends = function(e, t = null) {
					const r = {
						type: "InterfaceExtends",
						id: e,
						typeParameters: t
					}, n = a.InterfaceExtends;
					return o(n.id, r, "id", e, 1), o(n.typeParameters, r, "typeParameters", t, 1), r;
				}, t.interfaceTypeAnnotation = function(e = null, t) {
					const r = {
						type: "InterfaceTypeAnnotation",
						extends: e,
						body: t
					}, n = a.InterfaceTypeAnnotation;
					return o(n.extends, r, "extends", e, 1), o(n.body, r, "body", t, 1), r;
				}, t.interpreterDirective = function(e) {
					const t = {
						type: "InterpreterDirective",
						value: e
					}, r = a.InterpreterDirective;
					return o(r.value, t, "value", e), t;
				}, t.intersectionTypeAnnotation = function(e) {
					const t = {
						type: "IntersectionTypeAnnotation",
						types: e
					}, r = a.IntersectionTypeAnnotation;
					return o(r.types, t, "types", e, 1), t;
				}, t.jSXAttribute = t.jsxAttribute = function(e, t = null) {
					const r = {
						type: "JSXAttribute",
						name: e,
						value: t
					}, n = a.JSXAttribute;
					return o(n.name, r, "name", e, 1), o(n.value, r, "value", t, 1), r;
				}, t.jSXClosingElement = t.jsxClosingElement = function(e) {
					const t = {
						type: "JSXClosingElement",
						name: e
					}, r = a.JSXClosingElement;
					return o(r.name, t, "name", e, 1), t;
				}, t.jSXClosingFragment = t.jsxClosingFragment = function() {
					return { type: "JSXClosingFragment" };
				}, t.jSXElement = t.jsxElement = function(e, t = null, r, n = null) {
					const s = {
						type: "JSXElement",
						openingElement: e,
						closingElement: t,
						children: r,
						selfClosing: n
					}, i = a.JSXElement;
					return o(i.openingElement, s, "openingElement", e, 1), o(i.closingElement, s, "closingElement", t, 1), o(i.children, s, "children", r, 1), o(i.selfClosing, s, "selfClosing", n), s;
				}, t.jSXEmptyExpression = t.jsxEmptyExpression = function() {
					return { type: "JSXEmptyExpression" };
				}, t.jSXExpressionContainer = t.jsxExpressionContainer = function(e) {
					const t = {
						type: "JSXExpressionContainer",
						expression: e
					}, r = a.JSXExpressionContainer;
					return o(r.expression, t, "expression", e, 1), t;
				}, t.jSXFragment = t.jsxFragment = function(e, t, r) {
					const n = {
						type: "JSXFragment",
						openingFragment: e,
						closingFragment: t,
						children: r
					}, s = a.JSXFragment;
					return o(s.openingFragment, n, "openingFragment", e, 1), o(s.closingFragment, n, "closingFragment", t, 1), o(s.children, n, "children", r, 1), n;
				}, t.jSXIdentifier = t.jsxIdentifier = function(e) {
					const t = {
						type: "JSXIdentifier",
						name: e
					}, r = a.JSXIdentifier;
					return o(r.name, t, "name", e), t;
				}, t.jSXMemberExpression = t.jsxMemberExpression = function(e, t) {
					const r = {
						type: "JSXMemberExpression",
						object: e,
						property: t
					}, n = a.JSXMemberExpression;
					return o(n.object, r, "object", e, 1), o(n.property, r, "property", t, 1), r;
				}, t.jSXNamespacedName = t.jsxNamespacedName = function(e, t) {
					const r = {
						type: "JSXNamespacedName",
						namespace: e,
						name: t
					}, n = a.JSXNamespacedName;
					return o(n.namespace, r, "namespace", e, 1), o(n.name, r, "name", t, 1), r;
				}, t.jSXOpeningElement = t.jsxOpeningElement = function(e, t, r = !1) {
					const n = {
						type: "JSXOpeningElement",
						name: e,
						attributes: t,
						selfClosing: r
					}, s = a.JSXOpeningElement;
					return o(s.name, n, "name", e, 1), o(s.attributes, n, "attributes", t, 1), o(s.selfClosing, n, "selfClosing", r), n;
				}, t.jSXOpeningFragment = t.jsxOpeningFragment = function() {
					return { type: "JSXOpeningFragment" };
				}, t.jSXSpreadAttribute = t.jsxSpreadAttribute = function(e) {
					const t = {
						type: "JSXSpreadAttribute",
						argument: e
					}, r = a.JSXSpreadAttribute;
					return o(r.argument, t, "argument", e, 1), t;
				}, t.jSXSpreadChild = t.jsxSpreadChild = function(e) {
					const t = {
						type: "JSXSpreadChild",
						expression: e
					}, r = a.JSXSpreadChild;
					return o(r.expression, t, "expression", e, 1), t;
				}, t.jSXText = t.jsxText = function(e) {
					const t = {
						type: "JSXText",
						value: e
					}, r = a.JSXText;
					return o(r.value, t, "value", e), t;
				}, t.labeledStatement = function(e, t) {
					const r = {
						type: "LabeledStatement",
						label: e,
						body: t
					}, n = a.LabeledStatement;
					return o(n.label, r, "label", e, 1), o(n.body, r, "body", t, 1), r;
				}, t.logicalExpression = function(e, t, r) {
					const n = {
						type: "LogicalExpression",
						operator: e,
						left: t,
						right: r
					}, s = a.LogicalExpression;
					return o(s.operator, n, "operator", e), o(s.left, n, "left", t, 1), o(s.right, n, "right", r, 1), n;
				}, t.memberExpression = function(e, t, r = !1, n = null) {
					const s = {
						type: "MemberExpression",
						object: e,
						property: t,
						computed: r,
						optional: n
					}, i = a.MemberExpression;
					return o(i.object, s, "object", e, 1), o(i.property, s, "property", t, 1), o(i.computed, s, "computed", r), o(i.optional, s, "optional", n), s;
				}, t.metaProperty = function(e, t) {
					const r = {
						type: "MetaProperty",
						meta: e,
						property: t
					}, n = a.MetaProperty;
					return o(n.meta, r, "meta", e, 1), o(n.property, r, "property", t, 1), r;
				}, t.mixedTypeAnnotation = function() {
					return { type: "MixedTypeAnnotation" };
				}, t.moduleExpression = function(e) {
					const t = {
						type: "ModuleExpression",
						body: e
					}, r = a.ModuleExpression;
					return o(r.body, t, "body", e, 1), t;
				}, t.newExpression = function(e, t) {
					const r = {
						type: "NewExpression",
						callee: e,
						arguments: t
					}, n = a.NewExpression;
					return o(n.callee, r, "callee", e, 1), o(n.arguments, r, "arguments", t, 1), r;
				}, t.noop = function() {
					return { type: "Noop" };
				}, t.nullLiteral = function() {
					return { type: "NullLiteral" };
				}, t.nullLiteralTypeAnnotation = function() {
					return { type: "NullLiteralTypeAnnotation" };
				}, t.nullableTypeAnnotation = function(e) {
					const t = {
						type: "NullableTypeAnnotation",
						typeAnnotation: e
					}, r = a.NullableTypeAnnotation;
					return o(r.typeAnnotation, t, "typeAnnotation", e, 1), t;
				}, t.numberLiteral = function(e) {
					return (0, s.default)("NumberLiteral", "NumericLiteral", "The node type "), numericLiteral(e);
				}, t.numberLiteralTypeAnnotation = function(e) {
					const t = {
						type: "NumberLiteralTypeAnnotation",
						value: e
					}, r = a.NumberLiteralTypeAnnotation;
					return o(r.value, t, "value", e), t;
				}, t.numberTypeAnnotation = function() {
					return { type: "NumberTypeAnnotation" };
				}, t.numericLiteral = numericLiteral, t.objectExpression = function(e) {
					const t = {
						type: "ObjectExpression",
						properties: e
					}, r = a.ObjectExpression;
					return o(r.properties, t, "properties", e, 1), t;
				}, t.objectMethod = function(e = "method", t, r, n, s = !1, i = !1, l = !1) {
					const p = {
						type: "ObjectMethod",
						kind: e,
						key: t,
						params: r,
						body: n,
						computed: s,
						generator: i,
						async: l
					}, c = a.ObjectMethod;
					return o(c.kind, p, "kind", e), o(c.key, p, "key", t, 1), o(c.params, p, "params", r, 1), o(c.body, p, "body", n, 1), o(c.computed, p, "computed", s), o(c.generator, p, "generator", i), o(c.async, p, "async", l), p;
				}, t.objectPattern = function(e) {
					const t = {
						type: "ObjectPattern",
						properties: e
					}, r = a.ObjectPattern;
					return o(r.properties, t, "properties", e, 1), t;
				}, t.objectProperty = function(e, t, r = !1, n = !1, s = null) {
					const i = {
						type: "ObjectProperty",
						key: e,
						value: t,
						computed: r,
						shorthand: n,
						decorators: s
					}, l = a.ObjectProperty;
					return o(l.key, i, "key", e, 1), o(l.value, i, "value", t, 1), o(l.computed, i, "computed", r), o(l.shorthand, i, "shorthand", n), o(l.decorators, i, "decorators", s, 1), i;
				}, t.objectTypeAnnotation = function(e, t = [], r = [], n = [], s = !1) {
					const i = {
						type: "ObjectTypeAnnotation",
						properties: e,
						indexers: t,
						callProperties: r,
						internalSlots: n,
						exact: s
					}, l = a.ObjectTypeAnnotation;
					return o(l.properties, i, "properties", e, 1), o(l.indexers, i, "indexers", t, 1), o(l.callProperties, i, "callProperties", r, 1), o(l.internalSlots, i, "internalSlots", n, 1), o(l.exact, i, "exact", s), i;
				}, t.objectTypeCallProperty = function(e) {
					const t = {
						type: "ObjectTypeCallProperty",
						value: e,
						static: null
					}, r = a.ObjectTypeCallProperty;
					return o(r.value, t, "value", e, 1), t;
				}, t.objectTypeIndexer = function(e = null, t, r, n = null) {
					const s = {
						type: "ObjectTypeIndexer",
						id: e,
						key: t,
						value: r,
						variance: n,
						static: null
					}, i = a.ObjectTypeIndexer;
					return o(i.id, s, "id", e, 1), o(i.key, s, "key", t, 1), o(i.value, s, "value", r, 1), o(i.variance, s, "variance", n, 1), s;
				}, t.objectTypeInternalSlot = function(e, t, r, n, s) {
					const i = {
						type: "ObjectTypeInternalSlot",
						id: e,
						value: t,
						optional: r,
						static: n,
						method: s
					}, l = a.ObjectTypeInternalSlot;
					return o(l.id, i, "id", e, 1), o(l.value, i, "value", t, 1), o(l.optional, i, "optional", r), o(l.static, i, "static", n), o(l.method, i, "method", s), i;
				}, t.objectTypeProperty = function(e, t, r = null) {
					const n = {
						type: "ObjectTypeProperty",
						key: e,
						value: t,
						variance: r,
						kind: null,
						method: null,
						optional: null,
						proto: null,
						static: null
					}, s = a.ObjectTypeProperty;
					return o(s.key, n, "key", e, 1), o(s.value, n, "value", t, 1), o(s.variance, n, "variance", r, 1), n;
				}, t.objectTypeSpreadProperty = function(e) {
					const t = {
						type: "ObjectTypeSpreadProperty",
						argument: e
					}, r = a.ObjectTypeSpreadProperty;
					return o(r.argument, t, "argument", e, 1), t;
				}, t.opaqueType = function(e, t = null, r = null, n) {
					const s = {
						type: "OpaqueType",
						id: e,
						typeParameters: t,
						supertype: r,
						impltype: n
					}, i = a.OpaqueType;
					return o(i.id, s, "id", e, 1), o(i.typeParameters, s, "typeParameters", t, 1), o(i.supertype, s, "supertype", r, 1), o(i.impltype, s, "impltype", n, 1), s;
				}, t.optionalCallExpression = function(e, t, r) {
					const n = {
						type: "OptionalCallExpression",
						callee: e,
						arguments: t,
						optional: r
					}, s = a.OptionalCallExpression;
					return o(s.callee, n, "callee", e, 1), o(s.arguments, n, "arguments", t, 1), o(s.optional, n, "optional", r), n;
				}, t.optionalIndexedAccessType = function(e, t) {
					const r = {
						type: "OptionalIndexedAccessType",
						objectType: e,
						indexType: t,
						optional: null
					}, n = a.OptionalIndexedAccessType;
					return o(n.objectType, r, "objectType", e, 1), o(n.indexType, r, "indexType", t, 1), r;
				}, t.optionalMemberExpression = function(e, t, r = !1, n) {
					const s = {
						type: "OptionalMemberExpression",
						object: e,
						property: t,
						computed: r,
						optional: n
					}, i = a.OptionalMemberExpression;
					return o(i.object, s, "object", e, 1), o(i.property, s, "property", t, 1), o(i.computed, s, "computed", r), o(i.optional, s, "optional", n), s;
				}, t.parenthesizedExpression = function(e) {
					const t = {
						type: "ParenthesizedExpression",
						expression: e
					}, r = a.ParenthesizedExpression;
					return o(r.expression, t, "expression", e, 1), t;
				}, t.pipelineBareFunction = function(e) {
					const t = {
						type: "PipelineBareFunction",
						callee: e
					}, r = a.PipelineBareFunction;
					return o(r.callee, t, "callee", e, 1), t;
				}, t.pipelinePrimaryTopicReference = function() {
					return { type: "PipelinePrimaryTopicReference" };
				}, t.pipelineTopicExpression = function(e) {
					const t = {
						type: "PipelineTopicExpression",
						expression: e
					}, r = a.PipelineTopicExpression;
					return o(r.expression, t, "expression", e, 1), t;
				}, t.placeholder = function(e, t) {
					const r = {
						type: "Placeholder",
						expectedNode: e,
						name: t
					}, n = a.Placeholder;
					return o(n.expectedNode, r, "expectedNode", e), o(n.name, r, "name", t, 1), r;
				}, t.privateName = function(e) {
					const t = {
						type: "PrivateName",
						id: e
					}, r = a.PrivateName;
					return o(r.id, t, "id", e, 1), t;
				}, t.program = function(e, t = [], r = "script", n = null) {
					const s = {
						type: "Program",
						body: e,
						directives: t,
						sourceType: r,
						interpreter: n
					}, i = a.Program;
					return o(i.body, s, "body", e, 1), o(i.directives, s, "directives", t, 1), o(i.sourceType, s, "sourceType", r), o(i.interpreter, s, "interpreter", n, 1), s;
				}, t.qualifiedTypeIdentifier = function(e, t) {
					const r = {
						type: "QualifiedTypeIdentifier",
						id: e,
						qualification: t
					}, n = a.QualifiedTypeIdentifier;
					return o(n.id, r, "id", e, 1), o(n.qualification, r, "qualification", t, 1), r;
				}, t.recordExpression = function(e) {
					const t = {
						type: "RecordExpression",
						properties: e
					}, r = a.RecordExpression;
					return o(r.properties, t, "properties", e, 1), t;
				}, t.regExpLiteral = regExpLiteral, t.regexLiteral = function(e, t = "") {
					return (0, s.default)("RegexLiteral", "RegExpLiteral", "The node type "), regExpLiteral(e, t);
				}, t.restElement = restElement, t.restProperty = function(e) {
					return (0, s.default)("RestProperty", "RestElement", "The node type "), restElement(e);
				}, t.returnStatement = function(e = null) {
					const t = {
						type: "ReturnStatement",
						argument: e
					}, r = a.ReturnStatement;
					return o(r.argument, t, "argument", e, 1), t;
				}, t.sequenceExpression = function(e) {
					const t = {
						type: "SequenceExpression",
						expressions: e
					}, r = a.SequenceExpression;
					return o(r.expressions, t, "expressions", e, 1), t;
				}, t.spreadElement = spreadElement, t.spreadProperty = function(e) {
					return (0, s.default)("SpreadProperty", "SpreadElement", "The node type "), spreadElement(e);
				}, t.staticBlock = function(e) {
					const t = {
						type: "StaticBlock",
						body: e
					}, r = a.StaticBlock;
					return o(r.body, t, "body", e, 1), t;
				}, t.stringLiteral = function(e) {
					const t = {
						type: "StringLiteral",
						value: e
					}, r = a.StringLiteral;
					return o(r.value, t, "value", e), t;
				}, t.stringLiteralTypeAnnotation = function(e) {
					const t = {
						type: "StringLiteralTypeAnnotation",
						value: e
					}, r = a.StringLiteralTypeAnnotation;
					return o(r.value, t, "value", e), t;
				}, t.stringTypeAnnotation = function() {
					return { type: "StringTypeAnnotation" };
				}, t.super = function() {
					return { type: "Super" };
				}, t.switchCase = function(e = null, t) {
					const r = {
						type: "SwitchCase",
						test: e,
						consequent: t
					}, n = a.SwitchCase;
					return o(n.test, r, "test", e, 1), o(n.consequent, r, "consequent", t, 1), r;
				}, t.switchStatement = function(e, t) {
					const r = {
						type: "SwitchStatement",
						discriminant: e,
						cases: t
					}, n = a.SwitchStatement;
					return o(n.discriminant, r, "discriminant", e, 1), o(n.cases, r, "cases", t, 1), r;
				}, t.symbolTypeAnnotation = function() {
					return { type: "SymbolTypeAnnotation" };
				}, t.taggedTemplateExpression = function(e, t) {
					const r = {
						type: "TaggedTemplateExpression",
						tag: e,
						quasi: t
					}, n = a.TaggedTemplateExpression;
					return o(n.tag, r, "tag", e, 1), o(n.quasi, r, "quasi", t, 1), r;
				}, t.templateElement = function(e, t = !1) {
					const r = {
						type: "TemplateElement",
						value: e,
						tail: t
					}, n = a.TemplateElement;
					return o(n.value, r, "value", e), o(n.tail, r, "tail", t), r;
				}, t.templateLiteral = function(e, t) {
					const r = {
						type: "TemplateLiteral",
						quasis: e,
						expressions: t
					}, n = a.TemplateLiteral;
					return o(n.quasis, r, "quasis", e, 1), o(n.expressions, r, "expressions", t, 1), r;
				}, t.thisExpression = function() {
					return { type: "ThisExpression" };
				}, t.thisTypeAnnotation = function() {
					return { type: "ThisTypeAnnotation" };
				}, t.throwStatement = function(e) {
					const t = {
						type: "ThrowStatement",
						argument: e
					}, r = a.ThrowStatement;
					return o(r.argument, t, "argument", e, 1), t;
				}, t.topicReference = function() {
					return { type: "TopicReference" };
				}, t.tryStatement = function(e, t = null, r = null) {
					const n = {
						type: "TryStatement",
						block: e,
						handler: t,
						finalizer: r
					}, s = a.TryStatement;
					return o(s.block, n, "block", e, 1), o(s.handler, n, "handler", t, 1), o(s.finalizer, n, "finalizer", r, 1), n;
				}, t.tSAnyKeyword = t.tsAnyKeyword = function() {
					return { type: "TSAnyKeyword" };
				}, t.tSArrayType = t.tsArrayType = function(e) {
					const t = {
						type: "TSArrayType",
						elementType: e
					}, r = a.TSArrayType;
					return o(r.elementType, t, "elementType", e, 1), t;
				}, t.tSAsExpression = t.tsAsExpression = function(e, t) {
					const r = {
						type: "TSAsExpression",
						expression: e,
						typeAnnotation: t
					}, n = a.TSAsExpression;
					return o(n.expression, r, "expression", e, 1), o(n.typeAnnotation, r, "typeAnnotation", t, 1), r;
				}, t.tSBigIntKeyword = t.tsBigIntKeyword = function() {
					return { type: "TSBigIntKeyword" };
				}, t.tSBooleanKeyword = t.tsBooleanKeyword = function() {
					return { type: "TSBooleanKeyword" };
				}, t.tSCallSignatureDeclaration = t.tsCallSignatureDeclaration = function(e = null, t, r = null) {
					const n = {
						type: "TSCallSignatureDeclaration",
						typeParameters: e,
						parameters: t,
						typeAnnotation: r
					}, s = a.TSCallSignatureDeclaration;
					return o(s.typeParameters, n, "typeParameters", e, 1), o(s.parameters, n, "parameters", t, 1), o(s.typeAnnotation, n, "typeAnnotation", r, 1), n;
				}, t.tSConditionalType = t.tsConditionalType = function(e, t, r, n) {
					const s = {
						type: "TSConditionalType",
						checkType: e,
						extendsType: t,
						trueType: r,
						falseType: n
					}, i = a.TSConditionalType;
					return o(i.checkType, s, "checkType", e, 1), o(i.extendsType, s, "extendsType", t, 1), o(i.trueType, s, "trueType", r, 1), o(i.falseType, s, "falseType", n, 1), s;
				}, t.tSConstructSignatureDeclaration = t.tsConstructSignatureDeclaration = function(e = null, t, r = null) {
					const n = {
						type: "TSConstructSignatureDeclaration",
						typeParameters: e,
						parameters: t,
						typeAnnotation: r
					}, s = a.TSConstructSignatureDeclaration;
					return o(s.typeParameters, n, "typeParameters", e, 1), o(s.parameters, n, "parameters", t, 1), o(s.typeAnnotation, n, "typeAnnotation", r, 1), n;
				}, t.tSConstructorType = t.tsConstructorType = function(e = null, t, r = null) {
					const n = {
						type: "TSConstructorType",
						typeParameters: e,
						parameters: t,
						typeAnnotation: r
					}, s = a.TSConstructorType;
					return o(s.typeParameters, n, "typeParameters", e, 1), o(s.parameters, n, "parameters", t, 1), o(s.typeAnnotation, n, "typeAnnotation", r, 1), n;
				}, t.tSDeclareFunction = t.tsDeclareFunction = function(e = null, t = null, r, n = null) {
					const s = {
						type: "TSDeclareFunction",
						id: e,
						typeParameters: t,
						params: r,
						returnType: n
					}, i = a.TSDeclareFunction;
					return o(i.id, s, "id", e, 1), o(i.typeParameters, s, "typeParameters", t, 1), o(i.params, s, "params", r, 1), o(i.returnType, s, "returnType", n, 1), s;
				}, t.tSDeclareMethod = t.tsDeclareMethod = function(e = null, t, r = null, n, s = null) {
					const i = {
						type: "TSDeclareMethod",
						decorators: e,
						key: t,
						typeParameters: r,
						params: n,
						returnType: s
					}, l = a.TSDeclareMethod;
					return o(l.decorators, i, "decorators", e, 1), o(l.key, i, "key", t, 1), o(l.typeParameters, i, "typeParameters", r, 1), o(l.params, i, "params", n, 1), o(l.returnType, i, "returnType", s, 1), i;
				}, t.tSEnumBody = t.tsEnumBody = function(e) {
					const t = {
						type: "TSEnumBody",
						members: e
					}, r = a.TSEnumBody;
					return o(r.members, t, "members", e, 1), t;
				}, t.tSEnumDeclaration = t.tsEnumDeclaration = function(e, t) {
					const r = {
						type: "TSEnumDeclaration",
						id: e,
						members: t
					}, n = a.TSEnumDeclaration;
					return o(n.id, r, "id", e, 1), o(n.members, r, "members", t, 1), r;
				}, t.tSEnumMember = t.tsEnumMember = function(e, t = null) {
					const r = {
						type: "TSEnumMember",
						id: e,
						initializer: t
					}, n = a.TSEnumMember;
					return o(n.id, r, "id", e, 1), o(n.initializer, r, "initializer", t, 1), r;
				}, t.tSExportAssignment = t.tsExportAssignment = function(e) {
					const t = {
						type: "TSExportAssignment",
						expression: e
					}, r = a.TSExportAssignment;
					return o(r.expression, t, "expression", e, 1), t;
				}, t.tSExpressionWithTypeArguments = t.tsExpressionWithTypeArguments = function(e, t = null) {
					const r = {
						type: "TSExpressionWithTypeArguments",
						expression: e,
						typeParameters: t
					}, n = a.TSExpressionWithTypeArguments;
					return o(n.expression, r, "expression", e, 1), o(n.typeParameters, r, "typeParameters", t, 1), r;
				}, t.tSExternalModuleReference = t.tsExternalModuleReference = function(e) {
					const t = {
						type: "TSExternalModuleReference",
						expression: e
					}, r = a.TSExternalModuleReference;
					return o(r.expression, t, "expression", e, 1), t;
				}, t.tSFunctionType = t.tsFunctionType = function(e = null, t, r = null) {
					const n = {
						type: "TSFunctionType",
						typeParameters: e,
						parameters: t,
						typeAnnotation: r
					}, s = a.TSFunctionType;
					return o(s.typeParameters, n, "typeParameters", e, 1), o(s.parameters, n, "parameters", t, 1), o(s.typeAnnotation, n, "typeAnnotation", r, 1), n;
				}, t.tSImportEqualsDeclaration = t.tsImportEqualsDeclaration = function(e, t) {
					const r = {
						type: "TSImportEqualsDeclaration",
						id: e,
						moduleReference: t,
						isExport: null
					}, n = a.TSImportEqualsDeclaration;
					return o(n.id, r, "id", e, 1), o(n.moduleReference, r, "moduleReference", t, 1), r;
				}, t.tSImportType = t.tsImportType = function(e, t = null, r = null) {
					const n = {
						type: "TSImportType",
						argument: e,
						qualifier: t,
						typeParameters: r
					}, s = a.TSImportType;
					return o(s.argument, n, "argument", e, 1), o(s.qualifier, n, "qualifier", t, 1), o(s.typeParameters, n, "typeParameters", r, 1), n;
				}, t.tSIndexSignature = t.tsIndexSignature = function(e, t = null) {
					const r = {
						type: "TSIndexSignature",
						parameters: e,
						typeAnnotation: t
					}, n = a.TSIndexSignature;
					return o(n.parameters, r, "parameters", e, 1), o(n.typeAnnotation, r, "typeAnnotation", t, 1), r;
				}, t.tSIndexedAccessType = t.tsIndexedAccessType = function(e, t) {
					const r = {
						type: "TSIndexedAccessType",
						objectType: e,
						indexType: t
					}, n = a.TSIndexedAccessType;
					return o(n.objectType, r, "objectType", e, 1), o(n.indexType, r, "indexType", t, 1), r;
				}, t.tSInferType = t.tsInferType = function(e) {
					const t = {
						type: "TSInferType",
						typeParameter: e
					}, r = a.TSInferType;
					return o(r.typeParameter, t, "typeParameter", e, 1), t;
				}, t.tSInstantiationExpression = t.tsInstantiationExpression = function(e, t = null) {
					const r = {
						type: "TSInstantiationExpression",
						expression: e,
						typeParameters: t
					}, n = a.TSInstantiationExpression;
					return o(n.expression, r, "expression", e, 1), o(n.typeParameters, r, "typeParameters", t, 1), r;
				}, t.tSInterfaceBody = t.tsInterfaceBody = function(e) {
					const t = {
						type: "TSInterfaceBody",
						body: e
					}, r = a.TSInterfaceBody;
					return o(r.body, t, "body", e, 1), t;
				}, t.tSInterfaceDeclaration = t.tsInterfaceDeclaration = function(e, t = null, r = null, n) {
					const s = {
						type: "TSInterfaceDeclaration",
						id: e,
						typeParameters: t,
						extends: r,
						body: n
					}, i = a.TSInterfaceDeclaration;
					return o(i.id, s, "id", e, 1), o(i.typeParameters, s, "typeParameters", t, 1), o(i.extends, s, "extends", r, 1), o(i.body, s, "body", n, 1), s;
				}, t.tSIntersectionType = t.tsIntersectionType = function(e) {
					const t = {
						type: "TSIntersectionType",
						types: e
					}, r = a.TSIntersectionType;
					return o(r.types, t, "types", e, 1), t;
				}, t.tSIntrinsicKeyword = t.tsIntrinsicKeyword = function() {
					return { type: "TSIntrinsicKeyword" };
				}, t.tSLiteralType = t.tsLiteralType = function(e) {
					const t = {
						type: "TSLiteralType",
						literal: e
					}, r = a.TSLiteralType;
					return o(r.literal, t, "literal", e, 1), t;
				}, t.tSMappedType = t.tsMappedType = function(e, t = null, r = null) {
					const n = {
						type: "TSMappedType",
						typeParameter: e,
						typeAnnotation: t,
						nameType: r
					}, s = a.TSMappedType;
					return o(s.typeParameter, n, "typeParameter", e, 1), o(s.typeAnnotation, n, "typeAnnotation", t, 1), o(s.nameType, n, "nameType", r, 1), n;
				}, t.tSMethodSignature = t.tsMethodSignature = function(e, t = null, r, n = null) {
					const s = {
						type: "TSMethodSignature",
						key: e,
						typeParameters: t,
						parameters: r,
						typeAnnotation: n,
						kind: null
					}, i = a.TSMethodSignature;
					return o(i.key, s, "key", e, 1), o(i.typeParameters, s, "typeParameters", t, 1), o(i.parameters, s, "parameters", r, 1), o(i.typeAnnotation, s, "typeAnnotation", n, 1), s;
				}, t.tSModuleBlock = t.tsModuleBlock = function(e) {
					const t = {
						type: "TSModuleBlock",
						body: e
					}, r = a.TSModuleBlock;
					return o(r.body, t, "body", e, 1), t;
				}, t.tSModuleDeclaration = t.tsModuleDeclaration = function(e, t) {
					const r = {
						type: "TSModuleDeclaration",
						id: e,
						body: t,
						kind: null
					}, n = a.TSModuleDeclaration;
					return o(n.id, r, "id", e, 1), o(n.body, r, "body", t, 1), r;
				}, t.tSNamedTupleMember = t.tsNamedTupleMember = function(e, t, r = !1) {
					const n = {
						type: "TSNamedTupleMember",
						label: e,
						elementType: t,
						optional: r
					}, s = a.TSNamedTupleMember;
					return o(s.label, n, "label", e, 1), o(s.elementType, n, "elementType", t, 1), o(s.optional, n, "optional", r), n;
				}, t.tSNamespaceExportDeclaration = t.tsNamespaceExportDeclaration = function(e) {
					const t = {
						type: "TSNamespaceExportDeclaration",
						id: e
					}, r = a.TSNamespaceExportDeclaration;
					return o(r.id, t, "id", e, 1), t;
				}, t.tSNeverKeyword = t.tsNeverKeyword = function() {
					return { type: "TSNeverKeyword" };
				}, t.tSNonNullExpression = t.tsNonNullExpression = function(e) {
					const t = {
						type: "TSNonNullExpression",
						expression: e
					}, r = a.TSNonNullExpression;
					return o(r.expression, t, "expression", e, 1), t;
				}, t.tSNullKeyword = t.tsNullKeyword = function() {
					return { type: "TSNullKeyword" };
				}, t.tSNumberKeyword = t.tsNumberKeyword = function() {
					return { type: "TSNumberKeyword" };
				}, t.tSObjectKeyword = t.tsObjectKeyword = function() {
					return { type: "TSObjectKeyword" };
				}, t.tSOptionalType = t.tsOptionalType = function(e) {
					const t = {
						type: "TSOptionalType",
						typeAnnotation: e
					}, r = a.TSOptionalType;
					return o(r.typeAnnotation, t, "typeAnnotation", e, 1), t;
				}, t.tSParameterProperty = t.tsParameterProperty = function(e) {
					const t = {
						type: "TSParameterProperty",
						parameter: e
					}, r = a.TSParameterProperty;
					return o(r.parameter, t, "parameter", e, 1), t;
				}, t.tSParenthesizedType = t.tsParenthesizedType = function(e) {
					const t = {
						type: "TSParenthesizedType",
						typeAnnotation: e
					}, r = a.TSParenthesizedType;
					return o(r.typeAnnotation, t, "typeAnnotation", e, 1), t;
				}, t.tSPropertySignature = t.tsPropertySignature = function(e, t = null) {
					const r = {
						type: "TSPropertySignature",
						key: e,
						typeAnnotation: t
					}, n = a.TSPropertySignature;
					return o(n.key, r, "key", e, 1), o(n.typeAnnotation, r, "typeAnnotation", t, 1), r;
				}, t.tSQualifiedName = t.tsQualifiedName = function(e, t) {
					const r = {
						type: "TSQualifiedName",
						left: e,
						right: t
					}, n = a.TSQualifiedName;
					return o(n.left, r, "left", e, 1), o(n.right, r, "right", t, 1), r;
				}, t.tSRestType = t.tsRestType = function(e) {
					const t = {
						type: "TSRestType",
						typeAnnotation: e
					}, r = a.TSRestType;
					return o(r.typeAnnotation, t, "typeAnnotation", e, 1), t;
				}, t.tSSatisfiesExpression = t.tsSatisfiesExpression = function(e, t) {
					const r = {
						type: "TSSatisfiesExpression",
						expression: e,
						typeAnnotation: t
					}, n = a.TSSatisfiesExpression;
					return o(n.expression, r, "expression", e, 1), o(n.typeAnnotation, r, "typeAnnotation", t, 1), r;
				}, t.tSStringKeyword = t.tsStringKeyword = function() {
					return { type: "TSStringKeyword" };
				}, t.tSSymbolKeyword = t.tsSymbolKeyword = function() {
					return { type: "TSSymbolKeyword" };
				}, t.tSTemplateLiteralType = t.tsTemplateLiteralType = function(e, t) {
					const r = {
						type: "TSTemplateLiteralType",
						quasis: e,
						types: t
					}, n = a.TSTemplateLiteralType;
					return o(n.quasis, r, "quasis", e, 1), o(n.types, r, "types", t, 1), r;
				}, t.tSThisType = t.tsThisType = function() {
					return { type: "TSThisType" };
				}, t.tSTupleType = t.tsTupleType = function(e) {
					const t = {
						type: "TSTupleType",
						elementTypes: e
					}, r = a.TSTupleType;
					return o(r.elementTypes, t, "elementTypes", e, 1), t;
				}, t.tSTypeAliasDeclaration = t.tsTypeAliasDeclaration = function(e, t = null, r) {
					const n = {
						type: "TSTypeAliasDeclaration",
						id: e,
						typeParameters: t,
						typeAnnotation: r
					}, s = a.TSTypeAliasDeclaration;
					return o(s.id, n, "id", e, 1), o(s.typeParameters, n, "typeParameters", t, 1), o(s.typeAnnotation, n, "typeAnnotation", r, 1), n;
				}, t.tSTypeAnnotation = t.tsTypeAnnotation = function(e) {
					const t = {
						type: "TSTypeAnnotation",
						typeAnnotation: e
					}, r = a.TSTypeAnnotation;
					return o(r.typeAnnotation, t, "typeAnnotation", e, 1), t;
				}, t.tSTypeAssertion = t.tsTypeAssertion = function(e, t) {
					const r = {
						type: "TSTypeAssertion",
						typeAnnotation: e,
						expression: t
					}, n = a.TSTypeAssertion;
					return o(n.typeAnnotation, r, "typeAnnotation", e, 1), o(n.expression, r, "expression", t, 1), r;
				}, t.tSTypeLiteral = t.tsTypeLiteral = function(e) {
					const t = {
						type: "TSTypeLiteral",
						members: e
					}, r = a.TSTypeLiteral;
					return o(r.members, t, "members", e, 1), t;
				}, t.tSTypeOperator = t.tsTypeOperator = function(e, t = "keyof") {
					const r = {
						type: "TSTypeOperator",
						typeAnnotation: e,
						operator: t
					}, n = a.TSTypeOperator;
					return o(n.typeAnnotation, r, "typeAnnotation", e, 1), o(n.operator, r, "operator", t), r;
				}, t.tSTypeParameter = t.tsTypeParameter = function(e = null, t = null, r) {
					const n = {
						type: "TSTypeParameter",
						constraint: e,
						default: t,
						name: r
					}, s = a.TSTypeParameter;
					return o(s.constraint, n, "constraint", e, 1), o(s.default, n, "default", t, 1), o(s.name, n, "name", r), n;
				}, t.tSTypeParameterDeclaration = t.tsTypeParameterDeclaration = function(e) {
					const t = {
						type: "TSTypeParameterDeclaration",
						params: e
					}, r = a.TSTypeParameterDeclaration;
					return o(r.params, t, "params", e, 1), t;
				}, t.tSTypeParameterInstantiation = t.tsTypeParameterInstantiation = function(e) {
					const t = {
						type: "TSTypeParameterInstantiation",
						params: e
					}, r = a.TSTypeParameterInstantiation;
					return o(r.params, t, "params", e, 1), t;
				}, t.tSTypePredicate = t.tsTypePredicate = function(e, t = null, r = null) {
					const n = {
						type: "TSTypePredicate",
						parameterName: e,
						typeAnnotation: t,
						asserts: r
					}, s = a.TSTypePredicate;
					return o(s.parameterName, n, "parameterName", e, 1), o(s.typeAnnotation, n, "typeAnnotation", t, 1), o(s.asserts, n, "asserts", r), n;
				}, t.tSTypeQuery = t.tsTypeQuery = function(e, t = null) {
					const r = {
						type: "TSTypeQuery",
						exprName: e,
						typeParameters: t
					}, n = a.TSTypeQuery;
					return o(n.exprName, r, "exprName", e, 1), o(n.typeParameters, r, "typeParameters", t, 1), r;
				}, t.tSTypeReference = t.tsTypeReference = function(e, t = null) {
					const r = {
						type: "TSTypeReference",
						typeName: e,
						typeParameters: t
					}, n = a.TSTypeReference;
					return o(n.typeName, r, "typeName", e, 1), o(n.typeParameters, r, "typeParameters", t, 1), r;
				}, t.tSUndefinedKeyword = t.tsUndefinedKeyword = function() {
					return { type: "TSUndefinedKeyword" };
				}, t.tSUnionType = t.tsUnionType = function(e) {
					const t = {
						type: "TSUnionType",
						types: e
					}, r = a.TSUnionType;
					return o(r.types, t, "types", e, 1), t;
				}, t.tSUnknownKeyword = t.tsUnknownKeyword = function() {
					return { type: "TSUnknownKeyword" };
				}, t.tSVoidKeyword = t.tsVoidKeyword = function() {
					return { type: "TSVoidKeyword" };
				}, t.tupleExpression = function(e = []) {
					const t = {
						type: "TupleExpression",
						elements: e
					}, r = a.TupleExpression;
					return o(r.elements, t, "elements", e, 1), t;
				}, t.tupleTypeAnnotation = function(e) {
					const t = {
						type: "TupleTypeAnnotation",
						types: e
					}, r = a.TupleTypeAnnotation;
					return o(r.types, t, "types", e, 1), t;
				}, t.typeAlias = function(e, t = null, r) {
					const n = {
						type: "TypeAlias",
						id: e,
						typeParameters: t,
						right: r
					}, s = a.TypeAlias;
					return o(s.id, n, "id", e, 1), o(s.typeParameters, n, "typeParameters", t, 1), o(s.right, n, "right", r, 1), n;
				}, t.typeAnnotation = function(e) {
					const t = {
						type: "TypeAnnotation",
						typeAnnotation: e
					}, r = a.TypeAnnotation;
					return o(r.typeAnnotation, t, "typeAnnotation", e, 1), t;
				}, t.typeCastExpression = function(e, t) {
					const r = {
						type: "TypeCastExpression",
						expression: e,
						typeAnnotation: t
					}, n = a.TypeCastExpression;
					return o(n.expression, r, "expression", e, 1), o(n.typeAnnotation, r, "typeAnnotation", t, 1), r;
				}, t.typeParameter = function(e = null, t = null, r = null) {
					const n = {
						type: "TypeParameter",
						bound: e,
						default: t,
						variance: r,
						name: null
					}, s = a.TypeParameter;
					return o(s.bound, n, "bound", e, 1), o(s.default, n, "default", t, 1), o(s.variance, n, "variance", r, 1), n;
				}, t.typeParameterDeclaration = function(e) {
					const t = {
						type: "TypeParameterDeclaration",
						params: e
					}, r = a.TypeParameterDeclaration;
					return o(r.params, t, "params", e, 1), t;
				}, t.typeParameterInstantiation = function(e) {
					const t = {
						type: "TypeParameterInstantiation",
						params: e
					}, r = a.TypeParameterInstantiation;
					return o(r.params, t, "params", e, 1), t;
				}, t.typeofTypeAnnotation = function(e) {
					const t = {
						type: "TypeofTypeAnnotation",
						argument: e
					}, r = a.TypeofTypeAnnotation;
					return o(r.argument, t, "argument", e, 1), t;
				}, t.unaryExpression = function(e, t, r = !0) {
					const n = {
						type: "UnaryExpression",
						operator: e,
						argument: t,
						prefix: r
					}, s = a.UnaryExpression;
					return o(s.operator, n, "operator", e), o(s.argument, n, "argument", t, 1), o(s.prefix, n, "prefix", r), n;
				}, t.unionTypeAnnotation = function(e) {
					const t = {
						type: "UnionTypeAnnotation",
						types: e
					}, r = a.UnionTypeAnnotation;
					return o(r.types, t, "types", e, 1), t;
				}, t.updateExpression = function(e, t, r = !1) {
					const n = {
						type: "UpdateExpression",
						operator: e,
						argument: t,
						prefix: r
					}, s = a.UpdateExpression;
					return o(s.operator, n, "operator", e), o(s.argument, n, "argument", t, 1), o(s.prefix, n, "prefix", r), n;
				}, t.v8IntrinsicIdentifier = function(e) {
					const t = {
						type: "V8IntrinsicIdentifier",
						name: e
					}, r = a.V8IntrinsicIdentifier;
					return o(r.name, t, "name", e), t;
				}, t.variableDeclaration = function(e, t) {
					const r = {
						type: "VariableDeclaration",
						kind: e,
						declarations: t
					}, n = a.VariableDeclaration;
					return o(n.kind, r, "kind", e), o(n.declarations, r, "declarations", t, 1), r;
				}, t.variableDeclarator = function(e, t = null) {
					const r = {
						type: "VariableDeclarator",
						id: e,
						init: t
					}, n = a.VariableDeclarator;
					return o(n.id, r, "id", e, 1), o(n.init, r, "init", t, 1), r;
				}, t.variance = function(e) {
					const t = {
						type: "Variance",
						kind: e
					}, r = a.Variance;
					return o(r.kind, t, "kind", e), t;
				}, t.voidPattern = function() {
					return { type: "VoidPattern" };
				}, t.voidTypeAnnotation = function() {
					return { type: "VoidTypeAnnotation" };
				}, t.whileStatement = function(e, t) {
					const r = {
						type: "WhileStatement",
						test: e,
						body: t
					}, n = a.WhileStatement;
					return o(n.test, r, "test", e, 1), o(n.body, r, "body", t, 1), r;
				}, t.withStatement = function(e, t) {
					const r = {
						type: "WithStatement",
						object: e,
						body: t
					}, n = a.WithStatement;
					return o(n.object, r, "object", e, 1), o(n.body, r, "body", t, 1), r;
				}, t.yieldExpression = function(e = null, t = !1) {
					const r = {
						type: "YieldExpression",
						argument: e,
						delegate: t
					}, n = a.YieldExpression;
					return o(n.argument, r, "argument", e, 1), o(n.delegate, r, "delegate", t), r;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/validate.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/deprecationWarning.js"), i = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/utils.js");
				const { validateInternal: o } = n, { NODE_FIELDS: a } = i;
				function numericLiteral(e) {
					const t = {
						type: "NumericLiteral",
						value: e
					}, r = a.NumericLiteral;
					return o(r.value, t, "value", e), t;
				}
				function regExpLiteral(e, t = "") {
					const r = {
						type: "RegExpLiteral",
						pattern: e,
						flags: t
					}, n = a.RegExpLiteral;
					return o(n.pattern, r, "pattern", e), o(n.flags, r, "flags", t), r;
				}
				function restElement(e) {
					const t = {
						type: "RestElement",
						argument: e
					}, r = a.RestElement;
					return o(r.argument, t, "argument", e, 1), t;
				}
				function spreadElement(e) {
					const t = {
						type: "SpreadElement",
						argument: e
					}, r = a.SpreadElement;
					return o(r.argument, t, "argument", e, 1), t;
				}
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/uppercase.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.JSXIdentifier = t.JSXFragment = t.JSXExpressionContainer = t.JSXEmptyExpression = t.JSXElement = t.JSXClosingFragment = t.JSXClosingElement = t.JSXAttribute = t.IntersectionTypeAnnotation = t.InterpreterDirective = t.InterfaceTypeAnnotation = t.InterfaceExtends = t.InterfaceDeclaration = t.InferredPredicate = t.IndexedAccessType = t.ImportSpecifier = t.ImportNamespaceSpecifier = t.ImportExpression = t.ImportDefaultSpecifier = t.ImportDeclaration = t.ImportAttribute = t.Import = t.IfStatement = t.Identifier = t.GenericTypeAnnotation = t.FunctionTypeParam = t.FunctionTypeAnnotation = t.FunctionExpression = t.FunctionDeclaration = t.ForStatement = t.ForOfStatement = t.ForInStatement = t.File = t.ExpressionStatement = t.ExportSpecifier = t.ExportNamespaceSpecifier = t.ExportNamedDeclaration = t.ExportDefaultSpecifier = t.ExportDefaultDeclaration = t.ExportAllDeclaration = t.ExistsTypeAnnotation = t.EnumSymbolBody = t.EnumStringMember = t.EnumStringBody = t.EnumNumberMember = t.EnumNumberBody = t.EnumDefaultedMember = t.EnumDeclaration = t.EnumBooleanMember = t.EnumBooleanBody = t.EmptyTypeAnnotation = t.EmptyStatement = t.DoWhileStatement = t.DoExpression = t.DirectiveLiteral = t.Directive = t.Decorator = t.DeclaredPredicate = t.DeclareVariable = t.DeclareTypeAlias = t.DeclareOpaqueType = t.DeclareModuleExports = t.DeclareModule = t.DeclareInterface = t.DeclareFunction = t.DeclareExportDeclaration = t.DeclareExportAllDeclaration = t.DeclareClass = t.DecimalLiteral = t.DebuggerStatement = t.ContinueStatement = t.ConditionalExpression = t.ClassProperty = t.ClassPrivateProperty = t.ClassPrivateMethod = t.ClassMethod = t.ClassImplements = t.ClassExpression = t.ClassDeclaration = t.ClassBody = t.ClassAccessorProperty = t.CatchClause = t.CallExpression = t.BreakStatement = t.BooleanTypeAnnotation = t.BooleanLiteralTypeAnnotation = t.BooleanLiteral = t.BlockStatement = t.BindExpression = t.BinaryExpression = t.BigIntLiteral = t.AwaitExpression = t.AssignmentPattern = t.AssignmentExpression = t.ArrowFunctionExpression = t.ArrayTypeAnnotation = t.ArrayPattern = t.ArrayExpression = t.ArgumentPlaceholder = t.AnyTypeAnnotation = void 0, t.TSNumberKeyword = t.TSNullKeyword = t.TSNonNullExpression = t.TSNeverKeyword = t.TSNamespaceExportDeclaration = t.TSNamedTupleMember = t.TSModuleDeclaration = t.TSModuleBlock = t.TSMethodSignature = t.TSMappedType = t.TSLiteralType = t.TSIntrinsicKeyword = t.TSIntersectionType = t.TSInterfaceDeclaration = t.TSInterfaceBody = t.TSInstantiationExpression = t.TSInferType = t.TSIndexedAccessType = t.TSIndexSignature = t.TSImportType = t.TSImportEqualsDeclaration = t.TSFunctionType = t.TSExternalModuleReference = t.TSExpressionWithTypeArguments = t.TSExportAssignment = t.TSEnumMember = t.TSEnumDeclaration = t.TSEnumBody = t.TSDeclareMethod = t.TSDeclareFunction = t.TSConstructorType = t.TSConstructSignatureDeclaration = t.TSConditionalType = t.TSCallSignatureDeclaration = t.TSBooleanKeyword = t.TSBigIntKeyword = t.TSAsExpression = t.TSArrayType = t.TSAnyKeyword = t.SymbolTypeAnnotation = t.SwitchStatement = t.SwitchCase = t.Super = t.StringTypeAnnotation = t.StringLiteralTypeAnnotation = t.StringLiteral = t.StaticBlock = t.SpreadProperty = t.SpreadElement = t.SequenceExpression = t.ReturnStatement = t.RestProperty = t.RestElement = t.RegexLiteral = t.RegExpLiteral = t.RecordExpression = t.QualifiedTypeIdentifier = t.Program = t.PrivateName = t.Placeholder = t.PipelineTopicExpression = t.PipelinePrimaryTopicReference = t.PipelineBareFunction = t.ParenthesizedExpression = t.OptionalMemberExpression = t.OptionalIndexedAccessType = t.OptionalCallExpression = t.OpaqueType = t.ObjectTypeSpreadProperty = t.ObjectTypeProperty = t.ObjectTypeInternalSlot = t.ObjectTypeIndexer = t.ObjectTypeCallProperty = t.ObjectTypeAnnotation = t.ObjectProperty = t.ObjectPattern = t.ObjectMethod = t.ObjectExpression = t.NumericLiteral = t.NumberTypeAnnotation = t.NumberLiteralTypeAnnotation = t.NumberLiteral = t.NullableTypeAnnotation = t.NullLiteralTypeAnnotation = t.NullLiteral = t.Noop = t.NewExpression = t.ModuleExpression = t.MixedTypeAnnotation = t.MetaProperty = t.MemberExpression = t.LogicalExpression = t.LabeledStatement = t.JSXText = t.JSXSpreadChild = t.JSXSpreadAttribute = t.JSXOpeningFragment = t.JSXOpeningElement = t.JSXNamespacedName = t.JSXMemberExpression = void 0, t.YieldExpression = t.WithStatement = t.WhileStatement = t.VoidTypeAnnotation = t.VoidPattern = t.Variance = t.VariableDeclarator = t.VariableDeclaration = t.V8IntrinsicIdentifier = t.UpdateExpression = t.UnionTypeAnnotation = t.UnaryExpression = t.TypeofTypeAnnotation = t.TypeParameterInstantiation = t.TypeParameterDeclaration = t.TypeParameter = t.TypeCastExpression = t.TypeAnnotation = t.TypeAlias = t.TupleTypeAnnotation = t.TupleExpression = t.TryStatement = t.TopicReference = t.ThrowStatement = t.ThisTypeAnnotation = t.ThisExpression = t.TemplateLiteral = t.TemplateElement = t.TaggedTemplateExpression = t.TSVoidKeyword = t.TSUnknownKeyword = t.TSUnionType = t.TSUndefinedKeyword = t.TSTypeReference = t.TSTypeQuery = t.TSTypePredicate = t.TSTypeParameterInstantiation = t.TSTypeParameterDeclaration = t.TSTypeParameter = t.TSTypeOperator = t.TSTypeLiteral = t.TSTypeAssertion = t.TSTypeAnnotation = t.TSTypeAliasDeclaration = t.TSTupleType = t.TSThisType = t.TSTemplateLiteralType = t.TSSymbolKeyword = t.TSStringKeyword = t.TSSatisfiesExpression = t.TSRestType = t.TSQualifiedName = t.TSPropertySignature = t.TSParenthesizedType = t.TSParameterProperty = t.TSOptionalType = t.TSObjectKeyword = void 0;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/lowercase.js");
				r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/deprecationWarning.js");
				function alias(e) {
					return n[e];
				}
				t.ArrayExpression = alias("arrayExpression"), t.AssignmentExpression = alias("assignmentExpression"), t.BinaryExpression = alias("binaryExpression"), t.InterpreterDirective = alias("interpreterDirective"), t.Directive = alias("directive"), t.DirectiveLiteral = alias("directiveLiteral"), t.BlockStatement = alias("blockStatement"), t.BreakStatement = alias("breakStatement"), t.CallExpression = alias("callExpression"), t.CatchClause = alias("catchClause"), t.ConditionalExpression = alias("conditionalExpression"), t.ContinueStatement = alias("continueStatement"), t.DebuggerStatement = alias("debuggerStatement"), t.DoWhileStatement = alias("doWhileStatement"), t.EmptyStatement = alias("emptyStatement"), t.ExpressionStatement = alias("expressionStatement"), t.File = alias("file"), t.ForInStatement = alias("forInStatement"), t.ForStatement = alias("forStatement"), t.FunctionDeclaration = alias("functionDeclaration"), t.FunctionExpression = alias("functionExpression"), t.Identifier = alias("identifier"), t.IfStatement = alias("ifStatement"), t.LabeledStatement = alias("labeledStatement"), t.StringLiteral = alias("stringLiteral"), t.NumericLiteral = alias("numericLiteral"), t.NullLiteral = alias("nullLiteral"), t.BooleanLiteral = alias("booleanLiteral"), t.RegExpLiteral = alias("regExpLiteral"), t.LogicalExpression = alias("logicalExpression"), t.MemberExpression = alias("memberExpression"), t.NewExpression = alias("newExpression"), t.Program = alias("program"), t.ObjectExpression = alias("objectExpression"), t.ObjectMethod = alias("objectMethod"), t.ObjectProperty = alias("objectProperty"), t.RestElement = alias("restElement"), t.ReturnStatement = alias("returnStatement"), t.SequenceExpression = alias("sequenceExpression"), t.ParenthesizedExpression = alias("parenthesizedExpression"), t.SwitchCase = alias("switchCase"), t.SwitchStatement = alias("switchStatement"), t.ThisExpression = alias("thisExpression"), t.ThrowStatement = alias("throwStatement"), t.TryStatement = alias("tryStatement"), t.UnaryExpression = alias("unaryExpression"), t.UpdateExpression = alias("updateExpression"), t.VariableDeclaration = alias("variableDeclaration"), t.VariableDeclarator = alias("variableDeclarator"), t.WhileStatement = alias("whileStatement"), t.WithStatement = alias("withStatement"), t.AssignmentPattern = alias("assignmentPattern"), t.ArrayPattern = alias("arrayPattern"), t.ArrowFunctionExpression = alias("arrowFunctionExpression"), t.ClassBody = alias("classBody"), t.ClassExpression = alias("classExpression"), t.ClassDeclaration = alias("classDeclaration"), t.ExportAllDeclaration = alias("exportAllDeclaration"), t.ExportDefaultDeclaration = alias("exportDefaultDeclaration"), t.ExportNamedDeclaration = alias("exportNamedDeclaration"), t.ExportSpecifier = alias("exportSpecifier"), t.ForOfStatement = alias("forOfStatement"), t.ImportDeclaration = alias("importDeclaration"), t.ImportDefaultSpecifier = alias("importDefaultSpecifier"), t.ImportNamespaceSpecifier = alias("importNamespaceSpecifier"), t.ImportSpecifier = alias("importSpecifier"), t.ImportExpression = alias("importExpression"), t.MetaProperty = alias("metaProperty"), t.ClassMethod = alias("classMethod"), t.ObjectPattern = alias("objectPattern"), t.SpreadElement = alias("spreadElement"), t.Super = alias("super"), t.TaggedTemplateExpression = alias("taggedTemplateExpression"), t.TemplateElement = alias("templateElement"), t.TemplateLiteral = alias("templateLiteral"), t.YieldExpression = alias("yieldExpression"), t.AwaitExpression = alias("awaitExpression"), t.Import = alias("import"), t.BigIntLiteral = alias("bigIntLiteral"), t.ExportNamespaceSpecifier = alias("exportNamespaceSpecifier"), t.OptionalMemberExpression = alias("optionalMemberExpression"), t.OptionalCallExpression = alias("optionalCallExpression"), t.ClassProperty = alias("classProperty"), t.ClassAccessorProperty = alias("classAccessorProperty"), t.ClassPrivateProperty = alias("classPrivateProperty"), t.ClassPrivateMethod = alias("classPrivateMethod"), t.PrivateName = alias("privateName"), t.StaticBlock = alias("staticBlock"), t.ImportAttribute = alias("importAttribute"), t.AnyTypeAnnotation = alias("anyTypeAnnotation"), t.ArrayTypeAnnotation = alias("arrayTypeAnnotation"), t.BooleanTypeAnnotation = alias("booleanTypeAnnotation"), t.BooleanLiteralTypeAnnotation = alias("booleanLiteralTypeAnnotation"), t.NullLiteralTypeAnnotation = alias("nullLiteralTypeAnnotation"), t.ClassImplements = alias("classImplements"), t.DeclareClass = alias("declareClass"), t.DeclareFunction = alias("declareFunction"), t.DeclareInterface = alias("declareInterface"), t.DeclareModule = alias("declareModule"), t.DeclareModuleExports = alias("declareModuleExports"), t.DeclareTypeAlias = alias("declareTypeAlias"), t.DeclareOpaqueType = alias("declareOpaqueType"), t.DeclareVariable = alias("declareVariable"), t.DeclareExportDeclaration = alias("declareExportDeclaration"), t.DeclareExportAllDeclaration = alias("declareExportAllDeclaration"), t.DeclaredPredicate = alias("declaredPredicate"), t.ExistsTypeAnnotation = alias("existsTypeAnnotation"), t.FunctionTypeAnnotation = alias("functionTypeAnnotation"), t.FunctionTypeParam = alias("functionTypeParam"), t.GenericTypeAnnotation = alias("genericTypeAnnotation"), t.InferredPredicate = alias("inferredPredicate"), t.InterfaceExtends = alias("interfaceExtends"), t.InterfaceDeclaration = alias("interfaceDeclaration"), t.InterfaceTypeAnnotation = alias("interfaceTypeAnnotation"), t.IntersectionTypeAnnotation = alias("intersectionTypeAnnotation"), t.MixedTypeAnnotation = alias("mixedTypeAnnotation"), t.EmptyTypeAnnotation = alias("emptyTypeAnnotation"), t.NullableTypeAnnotation = alias("nullableTypeAnnotation"), t.NumberLiteralTypeAnnotation = alias("numberLiteralTypeAnnotation"), t.NumberTypeAnnotation = alias("numberTypeAnnotation"), t.ObjectTypeAnnotation = alias("objectTypeAnnotation"), t.ObjectTypeInternalSlot = alias("objectTypeInternalSlot"), t.ObjectTypeCallProperty = alias("objectTypeCallProperty"), t.ObjectTypeIndexer = alias("objectTypeIndexer"), t.ObjectTypeProperty = alias("objectTypeProperty"), t.ObjectTypeSpreadProperty = alias("objectTypeSpreadProperty"), t.OpaqueType = alias("opaqueType"), t.QualifiedTypeIdentifier = alias("qualifiedTypeIdentifier"), t.StringLiteralTypeAnnotation = alias("stringLiteralTypeAnnotation"), t.StringTypeAnnotation = alias("stringTypeAnnotation"), t.SymbolTypeAnnotation = alias("symbolTypeAnnotation"), t.ThisTypeAnnotation = alias("thisTypeAnnotation"), t.TupleTypeAnnotation = alias("tupleTypeAnnotation"), t.TypeofTypeAnnotation = alias("typeofTypeAnnotation"), t.TypeAlias = alias("typeAlias"), t.TypeAnnotation = alias("typeAnnotation"), t.TypeCastExpression = alias("typeCastExpression"), t.TypeParameter = alias("typeParameter"), t.TypeParameterDeclaration = alias("typeParameterDeclaration"), t.TypeParameterInstantiation = alias("typeParameterInstantiation"), t.UnionTypeAnnotation = alias("unionTypeAnnotation"), t.Variance = alias("variance"), t.VoidTypeAnnotation = alias("voidTypeAnnotation"), t.EnumDeclaration = alias("enumDeclaration"), t.EnumBooleanBody = alias("enumBooleanBody"), t.EnumNumberBody = alias("enumNumberBody"), t.EnumStringBody = alias("enumStringBody"), t.EnumSymbolBody = alias("enumSymbolBody"), t.EnumBooleanMember = alias("enumBooleanMember"), t.EnumNumberMember = alias("enumNumberMember"), t.EnumStringMember = alias("enumStringMember"), t.EnumDefaultedMember = alias("enumDefaultedMember"), t.IndexedAccessType = alias("indexedAccessType"), t.OptionalIndexedAccessType = alias("optionalIndexedAccessType"), t.JSXAttribute = alias("jsxAttribute"), t.JSXClosingElement = alias("jsxClosingElement"), t.JSXElement = alias("jsxElement"), t.JSXEmptyExpression = alias("jsxEmptyExpression"), t.JSXExpressionContainer = alias("jsxExpressionContainer"), t.JSXSpreadChild = alias("jsxSpreadChild"), t.JSXIdentifier = alias("jsxIdentifier"), t.JSXMemberExpression = alias("jsxMemberExpression"), t.JSXNamespacedName = alias("jsxNamespacedName"), t.JSXOpeningElement = alias("jsxOpeningElement"), t.JSXSpreadAttribute = alias("jsxSpreadAttribute"), t.JSXText = alias("jsxText"), t.JSXFragment = alias("jsxFragment"), t.JSXOpeningFragment = alias("jsxOpeningFragment"), t.JSXClosingFragment = alias("jsxClosingFragment"), t.Noop = alias("noop"), t.Placeholder = alias("placeholder"), t.V8IntrinsicIdentifier = alias("v8IntrinsicIdentifier"), t.ArgumentPlaceholder = alias("argumentPlaceholder"), t.BindExpression = alias("bindExpression"), t.Decorator = alias("decorator"), t.DoExpression = alias("doExpression"), t.ExportDefaultSpecifier = alias("exportDefaultSpecifier"), t.RecordExpression = alias("recordExpression"), t.TupleExpression = alias("tupleExpression"), t.DecimalLiteral = alias("decimalLiteral"), t.ModuleExpression = alias("moduleExpression"), t.TopicReference = alias("topicReference"), t.PipelineTopicExpression = alias("pipelineTopicExpression"), t.PipelineBareFunction = alias("pipelineBareFunction"), t.PipelinePrimaryTopicReference = alias("pipelinePrimaryTopicReference"), t.VoidPattern = alias("voidPattern"), t.TSParameterProperty = alias("tsParameterProperty"), t.TSDeclareFunction = alias("tsDeclareFunction"), t.TSDeclareMethod = alias("tsDeclareMethod"), t.TSQualifiedName = alias("tsQualifiedName"), t.TSCallSignatureDeclaration = alias("tsCallSignatureDeclaration"), t.TSConstructSignatureDeclaration = alias("tsConstructSignatureDeclaration"), t.TSPropertySignature = alias("tsPropertySignature"), t.TSMethodSignature = alias("tsMethodSignature"), t.TSIndexSignature = alias("tsIndexSignature"), t.TSAnyKeyword = alias("tsAnyKeyword"), t.TSBooleanKeyword = alias("tsBooleanKeyword"), t.TSBigIntKeyword = alias("tsBigIntKeyword"), t.TSIntrinsicKeyword = alias("tsIntrinsicKeyword"), t.TSNeverKeyword = alias("tsNeverKeyword"), t.TSNullKeyword = alias("tsNullKeyword"), t.TSNumberKeyword = alias("tsNumberKeyword"), t.TSObjectKeyword = alias("tsObjectKeyword"), t.TSStringKeyword = alias("tsStringKeyword"), t.TSSymbolKeyword = alias("tsSymbolKeyword"), t.TSUndefinedKeyword = alias("tsUndefinedKeyword"), t.TSUnknownKeyword = alias("tsUnknownKeyword"), t.TSVoidKeyword = alias("tsVoidKeyword"), t.TSThisType = alias("tsThisType"), t.TSFunctionType = alias("tsFunctionType"), t.TSConstructorType = alias("tsConstructorType"), t.TSTypeReference = alias("tsTypeReference"), t.TSTypePredicate = alias("tsTypePredicate"), t.TSTypeQuery = alias("tsTypeQuery"), t.TSTypeLiteral = alias("tsTypeLiteral"), t.TSArrayType = alias("tsArrayType"), t.TSTupleType = alias("tsTupleType"), t.TSOptionalType = alias("tsOptionalType"), t.TSRestType = alias("tsRestType"), t.TSNamedTupleMember = alias("tsNamedTupleMember"), t.TSUnionType = alias("tsUnionType"), t.TSIntersectionType = alias("tsIntersectionType"), t.TSConditionalType = alias("tsConditionalType"), t.TSInferType = alias("tsInferType"), t.TSParenthesizedType = alias("tsParenthesizedType"), t.TSTypeOperator = alias("tsTypeOperator"), t.TSIndexedAccessType = alias("tsIndexedAccessType"), t.TSMappedType = alias("tsMappedType"), t.TSTemplateLiteralType = alias("tsTemplateLiteralType"), t.TSLiteralType = alias("tsLiteralType"), t.TSExpressionWithTypeArguments = alias("tsExpressionWithTypeArguments"), t.TSInterfaceDeclaration = alias("tsInterfaceDeclaration"), t.TSInterfaceBody = alias("tsInterfaceBody"), t.TSTypeAliasDeclaration = alias("tsTypeAliasDeclaration"), t.TSInstantiationExpression = alias("tsInstantiationExpression"), t.TSAsExpression = alias("tsAsExpression"), t.TSSatisfiesExpression = alias("tsSatisfiesExpression"), t.TSTypeAssertion = alias("tsTypeAssertion"), t.TSEnumBody = alias("tsEnumBody"), t.TSEnumDeclaration = alias("tsEnumDeclaration"), t.TSEnumMember = alias("tsEnumMember"), t.TSModuleDeclaration = alias("tsModuleDeclaration"), t.TSModuleBlock = alias("tsModuleBlock"), t.TSImportType = alias("tsImportType"), t.TSImportEqualsDeclaration = alias("tsImportEqualsDeclaration"), t.TSExternalModuleReference = alias("tsExternalModuleReference"), t.TSNonNullExpression = alias("tsNonNullExpression"), t.TSExportAssignment = alias("tsExportAssignment"), t.TSNamespaceExportDeclaration = alias("tsNamespaceExportDeclaration"), t.TSTypeAnnotation = alias("tsTypeAnnotation"), t.TSTypeParameterInstantiation = alias("tsTypeParameterInstantiation"), t.TSTypeParameterDeclaration = alias("tsTypeParameterDeclaration"), t.TSTypeParameter = alias("tsTypeParameter"), t.NumberLiteral = n.numberLiteral, t.RegexLiteral = n.regexLiteral, t.RestProperty = n.restProperty, t.SpreadProperty = n.spreadProperty;
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/productions.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.buildUndefinedNode = function() {
					return (0, n.unaryExpression)("void", (0, n.numericLiteral)(0), !0);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/react/buildChildren.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					const t = [];
					for (let r = 0; r < e.children.length; r++) {
						let i = e.children[r];
						(0, n.isJSXText)(i) ? (0, s.default)(i, t) : ((0, n.isJSXExpressionContainer)(i) && (i = i.expression), (0, n.isJSXEmptyExpression)(i) || t.push(i));
					}
					return t;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/react/cleanJSXElementLiteralChild.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/typescript/createTSUnionType.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					const t = e.map((e) => (0, i.isTSTypeAnnotation)(e) ? e.typeAnnotation : e), r = (0, s.default)(t);
					return 1 === r.length ? r[0] : (0, n.tsUnionType)(r);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/typescript/removeTypeDuplicates.js"), i = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/clone.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return (0, n.default)(e, !1);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneNode.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneDeep.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return (0, n.default)(e);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneNode.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneDeepWithoutLoc.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return (0, n.default)(e, !0, !0);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneNode.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneNode.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t = !0, r = !1) {
					return cloneNodeInternal(e, t, r, /* @__PURE__ */ new Map());
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
				const { hasOwn: i } = { hasOwn: Function.call.bind(Object.prototype.hasOwnProperty) };
				function cloneIfNode(e, t, r, n) {
					return e && "string" == typeof e.type ? cloneNodeInternal(e, t, r, n) : e;
				}
				function cloneIfNodeOrArray(e, t, r, n) {
					return Array.isArray(e) ? e.map((e) => cloneIfNode(e, t, r, n)) : cloneIfNode(e, t, r, n);
				}
				function cloneNodeInternal(e, t = !0, r = !1, o) {
					if (!e) return e;
					const { type: a } = e, l = { type: e.type };
					if ((0, s.isIdentifier)(e)) l.name = e.name, i(e, "optional") && "boolean" == typeof e.optional && (l.optional = e.optional), i(e, "typeAnnotation") && (l.typeAnnotation = t ? cloneIfNodeOrArray(e.typeAnnotation, !0, r, o) : e.typeAnnotation), i(e, "decorators") && (l.decorators = t ? cloneIfNodeOrArray(e.decorators, !0, r, o) : e.decorators);
					else {
						if (!i(n.NODE_FIELDS, a)) throw new Error(`Unknown node type: "${a}"`);
						for (const p of Object.keys(n.NODE_FIELDS[a])) i(e, p) && (l[p] = t ? (0, s.isFile)(e) && "comments" === p ? maybeCloneComments(e.comments, t, r, o) : cloneIfNodeOrArray(e[p], !0, r, o) : e[p]);
					}
					return i(e, "loc") && (l.loc = r ? null : e.loc), i(e, "leadingComments") && (l.leadingComments = maybeCloneComments(e.leadingComments, t, r, o)), i(e, "innerComments") && (l.innerComments = maybeCloneComments(e.innerComments, t, r, o)), i(e, "trailingComments") && (l.trailingComments = maybeCloneComments(e.trailingComments, t, r, o)), i(e, "extra") && (l.extra = Object.assign({}, e.extra)), l;
				}
				function maybeCloneComments(e, t, r, n) {
					return e && t ? e.map((e) => {
						const t = n.get(e);
						if (t) return t;
						const { type: s, value: i, loc: o } = e, a = {
							type: s,
							value: i,
							loc: o
						};
						return r && (a.loc = null), n.set(e, a), a;
					}) : e;
				}
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneWithoutLoc.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return (0, n.default)(e, !1, !0);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneNode.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/addComment.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r, s) {
					return (0, n.default)(e, t, [{
						type: s ? "CommentLine" : "CommentBlock",
						value: r
					}]);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/addComments.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/addComments.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					if (!r || !e) return e;
					const n = `${t}Comments`;
					e[n] ? "leading" === t ? e[n] = r.concat(e[n]) : e[n].push(...r) : e[n] = r;
					return e;
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritInnerComments.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					(0, n.default)("innerComments", e, t);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/inherit.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritLeadingComments.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					(0, n.default)("leadingComments", e, t);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/inherit.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritTrailingComments.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					(0, n.default)("trailingComments", e, t);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/inherit.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritsComments.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					return (0, n.default)(e, t), (0, s.default)(e, t), (0, i.default)(e, t), e;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritTrailingComments.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritLeadingComments.js"), i = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritInnerComments.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/removeComments.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return n.COMMENT_KEYS.forEach((t) => {
						e[t] = null;
					}), e;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/constants/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/constants/generated/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.WHILE_TYPES = t.USERWHITESPACABLE_TYPES = t.UNARYLIKE_TYPES = t.TYPESCRIPT_TYPES = t.TSTYPE_TYPES = t.TSTYPEELEMENT_TYPES = t.TSENTITYNAME_TYPES = t.TSBASETYPE_TYPES = t.TERMINATORLESS_TYPES = t.STATEMENT_TYPES = t.STANDARDIZED_TYPES = t.SCOPABLE_TYPES = t.PUREISH_TYPES = t.PROPERTY_TYPES = t.PRIVATE_TYPES = t.PATTERN_TYPES = t.PATTERNLIKE_TYPES = t.OBJECTMEMBER_TYPES = t.MODULESPECIFIER_TYPES = t.MODULEDECLARATION_TYPES = t.MISCELLANEOUS_TYPES = t.METHOD_TYPES = t.LVAL_TYPES = t.LOOP_TYPES = t.LITERAL_TYPES = t.JSX_TYPES = t.IMPORTOREXPORTDECLARATION_TYPES = t.IMMUTABLE_TYPES = t.FUNCTION_TYPES = t.FUNCTIONPARENT_TYPES = t.FUNCTIONPARAMETER_TYPES = t.FOR_TYPES = t.FORXSTATEMENT_TYPES = t.FLOW_TYPES = t.FLOWTYPE_TYPES = t.FLOWPREDICATE_TYPES = t.FLOWDECLARATION_TYPES = t.FLOWBASEANNOTATION_TYPES = t.EXPRESSION_TYPES = t.EXPRESSIONWRAPPER_TYPES = t.EXPORTDECLARATION_TYPES = t.ENUMMEMBER_TYPES = t.ENUMBODY_TYPES = t.DECLARATION_TYPES = t.CONDITIONAL_TYPES = t.COMPLETIONSTATEMENT_TYPES = t.CLASS_TYPES = t.BLOCK_TYPES = t.BLOCKPARENT_TYPES = t.BINARY_TYPES = t.ACCESSOR_TYPES = void 0;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js");
				t.STANDARDIZED_TYPES = n.FLIPPED_ALIAS_KEYS.Standardized, t.EXPRESSION_TYPES = n.FLIPPED_ALIAS_KEYS.Expression, t.BINARY_TYPES = n.FLIPPED_ALIAS_KEYS.Binary, t.SCOPABLE_TYPES = n.FLIPPED_ALIAS_KEYS.Scopable, t.BLOCKPARENT_TYPES = n.FLIPPED_ALIAS_KEYS.BlockParent, t.BLOCK_TYPES = n.FLIPPED_ALIAS_KEYS.Block, t.STATEMENT_TYPES = n.FLIPPED_ALIAS_KEYS.Statement, t.TERMINATORLESS_TYPES = n.FLIPPED_ALIAS_KEYS.Terminatorless, t.COMPLETIONSTATEMENT_TYPES = n.FLIPPED_ALIAS_KEYS.CompletionStatement, t.CONDITIONAL_TYPES = n.FLIPPED_ALIAS_KEYS.Conditional, t.LOOP_TYPES = n.FLIPPED_ALIAS_KEYS.Loop, t.WHILE_TYPES = n.FLIPPED_ALIAS_KEYS.While, t.EXPRESSIONWRAPPER_TYPES = n.FLIPPED_ALIAS_KEYS.ExpressionWrapper, t.FOR_TYPES = n.FLIPPED_ALIAS_KEYS.For, t.FORXSTATEMENT_TYPES = n.FLIPPED_ALIAS_KEYS.ForXStatement, t.FUNCTION_TYPES = n.FLIPPED_ALIAS_KEYS.Function, t.FUNCTIONPARENT_TYPES = n.FLIPPED_ALIAS_KEYS.FunctionParent, t.PUREISH_TYPES = n.FLIPPED_ALIAS_KEYS.Pureish, t.DECLARATION_TYPES = n.FLIPPED_ALIAS_KEYS.Declaration, t.FUNCTIONPARAMETER_TYPES = n.FLIPPED_ALIAS_KEYS.FunctionParameter, t.PATTERNLIKE_TYPES = n.FLIPPED_ALIAS_KEYS.PatternLike, t.LVAL_TYPES = n.FLIPPED_ALIAS_KEYS.LVal, t.TSENTITYNAME_TYPES = n.FLIPPED_ALIAS_KEYS.TSEntityName, t.LITERAL_TYPES = n.FLIPPED_ALIAS_KEYS.Literal, t.IMMUTABLE_TYPES = n.FLIPPED_ALIAS_KEYS.Immutable, t.USERWHITESPACABLE_TYPES = n.FLIPPED_ALIAS_KEYS.UserWhitespacable, t.METHOD_TYPES = n.FLIPPED_ALIAS_KEYS.Method, t.OBJECTMEMBER_TYPES = n.FLIPPED_ALIAS_KEYS.ObjectMember, t.PROPERTY_TYPES = n.FLIPPED_ALIAS_KEYS.Property, t.UNARYLIKE_TYPES = n.FLIPPED_ALIAS_KEYS.UnaryLike, t.PATTERN_TYPES = n.FLIPPED_ALIAS_KEYS.Pattern, t.CLASS_TYPES = n.FLIPPED_ALIAS_KEYS.Class;
				const s = t.IMPORTOREXPORTDECLARATION_TYPES = n.FLIPPED_ALIAS_KEYS.ImportOrExportDeclaration;
				t.EXPORTDECLARATION_TYPES = n.FLIPPED_ALIAS_KEYS.ExportDeclaration, t.MODULESPECIFIER_TYPES = n.FLIPPED_ALIAS_KEYS.ModuleSpecifier, t.ACCESSOR_TYPES = n.FLIPPED_ALIAS_KEYS.Accessor, t.PRIVATE_TYPES = n.FLIPPED_ALIAS_KEYS.Private, t.FLOW_TYPES = n.FLIPPED_ALIAS_KEYS.Flow, t.FLOWTYPE_TYPES = n.FLIPPED_ALIAS_KEYS.FlowType, t.FLOWBASEANNOTATION_TYPES = n.FLIPPED_ALIAS_KEYS.FlowBaseAnnotation, t.FLOWDECLARATION_TYPES = n.FLIPPED_ALIAS_KEYS.FlowDeclaration, t.FLOWPREDICATE_TYPES = n.FLIPPED_ALIAS_KEYS.FlowPredicate, t.ENUMBODY_TYPES = n.FLIPPED_ALIAS_KEYS.EnumBody, t.ENUMMEMBER_TYPES = n.FLIPPED_ALIAS_KEYS.EnumMember, t.JSX_TYPES = n.FLIPPED_ALIAS_KEYS.JSX, t.MISCELLANEOUS_TYPES = n.FLIPPED_ALIAS_KEYS.Miscellaneous, t.TYPESCRIPT_TYPES = n.FLIPPED_ALIAS_KEYS.TypeScript, t.TSTYPEELEMENT_TYPES = n.FLIPPED_ALIAS_KEYS.TSTypeElement, t.TSTYPE_TYPES = n.FLIPPED_ALIAS_KEYS.TSType, t.TSBASETYPE_TYPES = n.FLIPPED_ALIAS_KEYS.TSBaseType, t.MODULEDECLARATION_TYPES = s;
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/constants/index.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.UPDATE_OPERATORS = t.UNARY_OPERATORS = t.STRING_UNARY_OPERATORS = t.STATEMENT_OR_BLOCK_KEYS = t.NUMBER_UNARY_OPERATORS = t.NUMBER_BINARY_OPERATORS = t.LOGICAL_OPERATORS = t.INHERIT_KEYS = t.FOR_INIT_KEYS = t.FLATTENABLE_KEYS = t.EQUALITY_BINARY_OPERATORS = t.COMPARISON_BINARY_OPERATORS = t.COMMENT_KEYS = t.BOOLEAN_UNARY_OPERATORS = t.BOOLEAN_NUMBER_BINARY_OPERATORS = t.BOOLEAN_BINARY_OPERATORS = t.BINARY_OPERATORS = t.ASSIGNMENT_OPERATORS = void 0;
				t.STATEMENT_OR_BLOCK_KEYS = [
					"consequent",
					"body",
					"alternate"
				], t.FLATTENABLE_KEYS = ["body", "expressions"], t.FOR_INIT_KEYS = ["left", "init"], t.COMMENT_KEYS = [
					"leadingComments",
					"trailingComments",
					"innerComments"
				];
				const r = t.LOGICAL_OPERATORS = [
					"||",
					"&&",
					"??"
				], n = (t.UPDATE_OPERATORS = ["++", "--"], t.BOOLEAN_NUMBER_BINARY_OPERATORS = [
					">",
					"<",
					">=",
					"<="
				]), o = t.BOOLEAN_BINARY_OPERATORS = [...t.COMPARISON_BINARY_OPERATORS = [
					...t.EQUALITY_BINARY_OPERATORS = [
						"==",
						"===",
						"!=",
						"!=="
					],
					"in",
					"instanceof"
				], ...n], a = t.NUMBER_BINARY_OPERATORS = [
					"-",
					"/",
					"%",
					"*",
					"**",
					"&",
					"|",
					">>",
					">>>",
					"<<",
					"^"
				], l = (t.BINARY_OPERATORS = [
					"+",
					...a,
					...o,
					"|>"
				], t.ASSIGNMENT_OPERATORS = [
					"=",
					"+=",
					...a.map((e) => e + "="),
					...r.map((e) => e + "=")
				], t.BOOLEAN_UNARY_OPERATORS = ["delete", "!"]), p = t.NUMBER_UNARY_OPERATORS = [
					"+",
					"-",
					"~"
				], c = t.STRING_UNARY_OPERATORS = ["typeof"];
				t.UNARY_OPERATORS = [
					"void",
					"throw",
					...l,
					...p,
					...c
				], t.INHERIT_KEYS = {
					optional: [
						"typeAnnotation",
						"typeParameters",
						"returnType"
					],
					force: [
						"start",
						"loc",
						"end"
					]
				};
				t.BLOCK_SCOPED_SYMBOL = Symbol.for("var used to be block scoped"), t.NOT_LOCAL_BINDING = Symbol.for("should not be considered a local binding");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/ensureBlock.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t = "body") {
					const r = (0, n.default)(e[t], e);
					return e[t] = r, r;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toBlock.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/gatherSequenceExpressions.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function gatherSequenceExpressions(e, t) {
					const r = [];
					let l = !0;
					for (const p of e) if ((0, s.isEmptyStatement)(p) || (l = !1), (0, s.isExpression)(p)) r.push(p);
					else if ((0, s.isExpressionStatement)(p)) r.push(p.expression);
					else if ((0, s.isVariableDeclaration)(p)) {
						if ("var" !== p.kind) return;
						for (const e of p.declarations) {
							const s = (0, n.default)(e);
							for (const e of Object.keys(s)) t.push({
								kind: p.kind,
								id: (0, a.default)(s[e])
							});
							e.init && r.push((0, i.assignmentExpression)("=", e.id, e.init));
						}
						l = !0;
					} else if ((0, s.isIfStatement)(p)) {
						const e = p.consequent ? gatherSequenceExpressions([p.consequent], t) : (0, o.buildUndefinedNode)(), n = p.alternate ? gatherSequenceExpressions([p.alternate], t) : (0, o.buildUndefinedNode)();
						if (!e || !n) return;
						r.push((0, i.conditionalExpression)(p.test, e, n));
					} else if ((0, s.isBlockStatement)(p)) {
						const e = gatherSequenceExpressions(p.body, t);
						if (!e) return;
						r.push(e);
					} else {
						if (!(0, s.isEmptyStatement)(p)) return;
						0 === e.indexOf(p) && (l = !0);
					}
					l && r.push((0, o.buildUndefinedNode)());
					return 1 === r.length ? r[0] : (0, i.sequenceExpression)(r);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/retrievers/getBindingIdentifiers.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js"), i = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js"), o = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/productions.js"), a = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneNode.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toBindingIdentifierName.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					"eval" !== (e = (0, n.default)(e)) && "arguments" !== e || (e = "_" + e);
					return e;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toIdentifier.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toBlock.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					if ((0, n.isBlockStatement)(e)) return e;
					let r = [];
					(0, n.isEmptyStatement)(e) ? r = [] : ((0, n.isStatement)(e) || (e = (0, n.isFunction)(t) ? (0, s.returnStatement)(e) : (0, s.expressionStatement)(e)), r = [e]);
					return (0, s.blockStatement)(r);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toComputedKey.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t = e.key || e.property) {
					!e.computed && (0, n.isIdentifier)(t) && (t = (0, s.stringLiteral)(t.name));
					return t;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toExpression.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
				t.default = function(e) {
					(0, n.isExpressionStatement)(e) && (e = e.expression);
					if ((0, n.isExpression)(e)) return e;
					(0, n.isClass)(e) ? (e.type = "ClassExpression", e.abstract = !1) : (0, n.isFunction)(e) && (e.type = "FunctionExpression");
					if (!(0, n.isExpression)(e)) throw new Error(`cannot turn ${e.type} to an expression`);
					return e;
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toIdentifier.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					e += "";
					let t = "";
					for (const r of e) t += (0, s.isIdentifierChar)(r.codePointAt(0)) ? r : "-";
					t = t.replace(/^[-0-9]+/, ""), t = t.replace(/[-\s]+(.)?/g, function(e, t) {
						return t ? t.toUpperCase() : "";
					}), (0, n.default)(t) || (t = `_${t}`);
					return t || "_";
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isValidIdentifier.js"), s = r("./node_modules/.pnpm/@babel+helper-validator-identifier@7.27.1/node_modules/@babel/helper-validator-identifier/lib/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toKeyAlias.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = toKeyAlias;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneNode.js"), i = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/removePropertiesDeep.js");
				function toKeyAlias(e, t = e.key) {
					let r;
					return "method" === e.kind ? toKeyAlias.increment() + "" : (r = (0, n.isIdentifier)(t) ? t.name : (0, n.isStringLiteral)(t) ? JSON.stringify(t.value) : JSON.stringify((0, i.default)((0, s.default)(t))), e.computed && (r = `[${r}]`), e.static && (r = `static:${r}`), r);
				}
				toKeyAlias.uid = 0, toKeyAlias.increment = function() {
					return toKeyAlias.uid >= Number.MAX_SAFE_INTEGER ? toKeyAlias.uid = 0 : toKeyAlias.uid++;
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toSequenceExpression.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					if (null == e || !e.length) return;
					const r = [], s = (0, n.default)(e, r);
					if (!s) return;
					for (const e of r) t.push(e);
					return s;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/gatherSequenceExpressions.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toStatement.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js");
				t.default = function(e, t) {
					if ((0, n.isStatement)(e)) return e;
					let r, i = !1;
					if ((0, n.isClass)(e)) i = !0, r = "ClassDeclaration";
					else if ((0, n.isFunction)(e)) i = !0, r = "FunctionDeclaration";
					else if ((0, n.isAssignmentExpression)(e)) return (0, s.expressionStatement)(e);
					i && !e.id && (r = !1);
					if (!r) {
						if (t) return !1;
						throw new Error(`cannot turn ${e.type} to a statement`);
					}
					return e.type = r, e;
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/valueToNode.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isValidIdentifier.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js");
				t.default = function valueToNode(e) {
					if (void 0 === e) return (0, s.identifier)("undefined");
					if (!0 === e || !1 === e) return (0, s.booleanLiteral)(e);
					if (null === e) return (0, s.nullLiteral)();
					if ("string" == typeof e) return (0, s.stringLiteral)(e);
					if ("number" == typeof e) {
						let t;
						if (Number.isFinite(e)) t = (0, s.numericLiteral)(Math.abs(e));
						else {
							let r;
							r = Number.isNaN(e) ? (0, s.numericLiteral)(0) : (0, s.numericLiteral)(1), t = (0, s.binaryExpression)("/", r, (0, s.numericLiteral)(0));
						}
						return (e < 0 || Object.is(e, -0)) && (t = (0, s.unaryExpression)("-", t)), t;
					}
					if ("bigint" == typeof e) return e < 0 ? (0, s.unaryExpression)("-", (0, s.bigIntLiteral)(-e)) : (0, s.bigIntLiteral)(e);
					if (function(e) {
						return "[object RegExp]" === i(e);
					}(e)) {
						const t = e.source, r = /\/([a-z]*)$/.exec(e.toString())[1];
						return (0, s.regExpLiteral)(t, r);
					}
					if (Array.isArray(e)) return (0, s.arrayExpression)(e.map(valueToNode));
					if (function(e) {
						if ("object" != typeof e || null === e || "[object Object]" !== Object.prototype.toString.call(e)) return !1;
						const t = Object.getPrototypeOf(e);
						return null === t || null === Object.getPrototypeOf(t);
					}(e)) {
						const t = [];
						for (const r of Object.keys(e)) {
							let i, o = !1;
							(0, n.default)(r) ? "__proto__" === r ? (o = !0, i = (0, s.stringLiteral)(r)) : i = (0, s.identifier)(r) : i = (0, s.stringLiteral)(r), t.push((0, s.objectProperty)(i, valueToNode(e[r]), o));
						}
						return (0, s.objectExpression)(t);
					}
					throw new Error("don't know how to turn this value into a node");
				};
				const i = Function.call.bind(Object.prototype.toString);
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/core.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.patternLikeCommon = t.importAttributes = t.functionTypeAnnotationCommon = t.functionDeclarationCommon = t.functionCommon = t.classMethodOrPropertyCommon = t.classMethodOrDeclareMethodCommon = void 0;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/is.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isValidIdentifier.js"), i = r("./node_modules/.pnpm/@babel+helper-validator-identifier@7.27.1/node_modules/@babel/helper-validator-identifier/lib/index.js"), o = r("./node_modules/.pnpm/@babel+helper-string-parser@7.27.1/node_modules/@babel/helper-string-parser/lib/index.js"), a = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/constants/index.js"), l = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/utils.js");
				const p = (0, l.defineAliasedType)("Standardized");
				p("ArrayExpression", {
					fields: { elements: {
						validate: (0, l.arrayOf)((0, l.assertNodeOrValueType)("null", "Expression", "SpreadElement")),
						default: process.env.BABEL_TYPES_8_BREAKING ? void 0 : []
					} },
					visitor: ["elements"],
					aliases: ["Expression"]
				}), p("AssignmentExpression", {
					fields: {
						operator: { validate: process.env.BABEL_TYPES_8_BREAKING ? Object.assign(function() {
							const e = (0, l.assertOneOf)(...a.ASSIGNMENT_OPERATORS), t = (0, l.assertOneOf)("=");
							return function(r, s, i) {
								((0, n.default)("Pattern", r.left) ? t : e)(r, s, i);
							};
						}(), { oneOf: a.ASSIGNMENT_OPERATORS }) : (0, l.assertValueType)("string") },
						left: { validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.assertNodeType)("Identifier", "MemberExpression", "OptionalMemberExpression", "ArrayPattern", "ObjectPattern", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression") : (0, l.assertNodeType)("LVal", "OptionalMemberExpression") },
						right: { validate: (0, l.assertNodeType)("Expression") }
					},
					builder: [
						"operator",
						"left",
						"right"
					],
					visitor: ["left", "right"],
					aliases: ["Expression"]
				}), p("BinaryExpression", {
					builder: [
						"operator",
						"left",
						"right"
					],
					fields: {
						operator: { validate: (0, l.assertOneOf)(...a.BINARY_OPERATORS) },
						left: { validate: function() {
							const e = (0, l.assertNodeType)("Expression"), t = (0, l.assertNodeType)("Expression", "PrivateName");
							return Object.assign(function(r, n, s) {
								("in" === r.operator ? t : e)(r, n, s);
							}, { oneOfNodeTypes: ["Expression", "PrivateName"] });
						}() },
						right: { validate: (0, l.assertNodeType)("Expression") }
					},
					visitor: ["left", "right"],
					aliases: ["Binary", "Expression"]
				}), p("InterpreterDirective", {
					builder: ["value"],
					fields: { value: { validate: (0, l.assertValueType)("string") } }
				}), p("Directive", {
					visitor: ["value"],
					fields: { value: { validate: (0, l.assertNodeType)("DirectiveLiteral") } }
				}), p("DirectiveLiteral", {
					builder: ["value"],
					fields: { value: { validate: (0, l.assertValueType)("string") } }
				}), p("BlockStatement", {
					builder: ["body", "directives"],
					visitor: ["directives", "body"],
					fields: {
						directives: {
							validate: (0, l.arrayOfType)("Directive"),
							default: []
						},
						body: (0, l.validateArrayOfType)("Statement")
					},
					aliases: [
						"Scopable",
						"BlockParent",
						"Block",
						"Statement"
					]
				}), p("BreakStatement", {
					visitor: ["label"],
					fields: { label: {
						validate: (0, l.assertNodeType)("Identifier"),
						optional: !0
					} },
					aliases: [
						"Statement",
						"Terminatorless",
						"CompletionStatement"
					]
				}), p("CallExpression", {
					visitor: [
						"callee",
						"typeParameters",
						"typeArguments",
						"arguments"
					],
					builder: ["callee", "arguments"],
					aliases: ["Expression"],
					fields: Object.assign({
						callee: { validate: (0, l.assertNodeType)("Expression", "Super", "V8IntrinsicIdentifier") },
						arguments: (0, l.validateArrayOfType)("Expression", "SpreadElement", "ArgumentPlaceholder"),
						typeArguments: {
							validate: (0, l.assertNodeType)("TypeParameterInstantiation"),
							optional: !0
						}
					}, process.env.BABEL_TYPES_8_BREAKING ? {} : {
						optional: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						typeParameters: {
							validate: (0, l.assertNodeType)("TSTypeParameterInstantiation"),
							optional: !0
						}
					})
				}), p("CatchClause", {
					visitor: ["param", "body"],
					fields: {
						param: {
							validate: (0, l.assertNodeType)("Identifier", "ArrayPattern", "ObjectPattern"),
							optional: !0
						},
						body: { validate: (0, l.assertNodeType)("BlockStatement") }
					},
					aliases: ["Scopable", "BlockParent"]
				}), p("ConditionalExpression", {
					visitor: [
						"test",
						"consequent",
						"alternate"
					],
					fields: {
						test: { validate: (0, l.assertNodeType)("Expression") },
						consequent: { validate: (0, l.assertNodeType)("Expression") },
						alternate: { validate: (0, l.assertNodeType)("Expression") }
					},
					aliases: ["Expression", "Conditional"]
				}), p("ContinueStatement", {
					visitor: ["label"],
					fields: { label: {
						validate: (0, l.assertNodeType)("Identifier"),
						optional: !0
					} },
					aliases: [
						"Statement",
						"Terminatorless",
						"CompletionStatement"
					]
				}), p("DebuggerStatement", { aliases: ["Statement"] }), p("DoWhileStatement", {
					builder: ["test", "body"],
					visitor: ["body", "test"],
					fields: {
						test: { validate: (0, l.assertNodeType)("Expression") },
						body: { validate: (0, l.assertNodeType)("Statement") }
					},
					aliases: [
						"Statement",
						"BlockParent",
						"Loop",
						"While",
						"Scopable"
					]
				}), p("EmptyStatement", { aliases: ["Statement"] }), p("ExpressionStatement", {
					visitor: ["expression"],
					fields: { expression: { validate: (0, l.assertNodeType)("Expression") } },
					aliases: ["Statement", "ExpressionWrapper"]
				}), p("File", {
					builder: [
						"program",
						"comments",
						"tokens"
					],
					visitor: ["program"],
					fields: {
						program: { validate: (0, l.assertNodeType)("Program") },
						comments: {
							validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.assertEach)((0, l.assertNodeType)("CommentBlock", "CommentLine")) : Object.assign(() => {}, { each: { oneOfNodeTypes: ["CommentBlock", "CommentLine"] } }),
							optional: !0
						},
						tokens: {
							validate: (0, l.assertEach)(Object.assign(() => {}, { type: "any" })),
							optional: !0
						}
					}
				}), p("ForInStatement", {
					visitor: [
						"left",
						"right",
						"body"
					],
					aliases: [
						"Scopable",
						"Statement",
						"For",
						"BlockParent",
						"Loop",
						"ForXStatement"
					],
					fields: {
						left: { validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.assertNodeType)("VariableDeclaration", "Identifier", "MemberExpression", "ArrayPattern", "ObjectPattern", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression") : (0, l.assertNodeType)("VariableDeclaration", "LVal") },
						right: { validate: (0, l.assertNodeType)("Expression") },
						body: { validate: (0, l.assertNodeType)("Statement") }
					}
				}), p("ForStatement", {
					visitor: [
						"init",
						"test",
						"update",
						"body"
					],
					aliases: [
						"Scopable",
						"Statement",
						"For",
						"BlockParent",
						"Loop"
					],
					fields: {
						init: {
							validate: (0, l.assertNodeType)("VariableDeclaration", "Expression"),
							optional: !0
						},
						test: {
							validate: (0, l.assertNodeType)("Expression"),
							optional: !0
						},
						update: {
							validate: (0, l.assertNodeType)("Expression"),
							optional: !0
						},
						body: { validate: (0, l.assertNodeType)("Statement") }
					}
				});
				const functionCommon = () => ({
					params: (0, l.validateArrayOfType)("FunctionParameter"),
					generator: { default: !1 },
					async: { default: !1 }
				});
				t.functionCommon = functionCommon;
				const functionTypeAnnotationCommon = () => ({
					returnType: {
						validate: (0, l.assertNodeType)("TypeAnnotation", "TSTypeAnnotation", "Noop"),
						optional: !0
					},
					typeParameters: {
						validate: (0, l.assertNodeType)("TypeParameterDeclaration", "TSTypeParameterDeclaration", "Noop"),
						optional: !0
					}
				});
				t.functionTypeAnnotationCommon = functionTypeAnnotationCommon;
				const functionDeclarationCommon = () => Object.assign({}, functionCommon(), {
					declare: {
						validate: (0, l.assertValueType)("boolean"),
						optional: !0
					},
					id: {
						validate: (0, l.assertNodeType)("Identifier"),
						optional: !0
					}
				});
				t.functionDeclarationCommon = functionDeclarationCommon, p("FunctionDeclaration", {
					builder: [
						"id",
						"params",
						"body",
						"generator",
						"async"
					],
					visitor: [
						"id",
						"typeParameters",
						"params",
						"predicate",
						"returnType",
						"body"
					],
					fields: Object.assign({}, functionDeclarationCommon(), functionTypeAnnotationCommon(), {
						body: { validate: (0, l.assertNodeType)("BlockStatement") },
						predicate: {
							validate: (0, l.assertNodeType)("DeclaredPredicate", "InferredPredicate"),
							optional: !0
						}
					}),
					aliases: [
						"Scopable",
						"Function",
						"BlockParent",
						"FunctionParent",
						"Statement",
						"Pureish",
						"Declaration"
					],
					validate: process.env.BABEL_TYPES_8_BREAKING ? function() {
						const e = (0, l.assertNodeType)("Identifier");
						return function(t, r, s) {
							(0, n.default)("ExportDefaultDeclaration", t) || e(s, "id", s.id);
						};
					}() : void 0
				}), p("FunctionExpression", {
					inherits: "FunctionDeclaration",
					aliases: [
						"Scopable",
						"Function",
						"BlockParent",
						"FunctionParent",
						"Expression",
						"Pureish"
					],
					fields: Object.assign({}, functionCommon(), functionTypeAnnotationCommon(), {
						id: {
							validate: (0, l.assertNodeType)("Identifier"),
							optional: !0
						},
						body: { validate: (0, l.assertNodeType)("BlockStatement") },
						predicate: {
							validate: (0, l.assertNodeType)("DeclaredPredicate", "InferredPredicate"),
							optional: !0
						}
					})
				});
				const patternLikeCommon = () => ({
					typeAnnotation: {
						validate: (0, l.assertNodeType)("TypeAnnotation", "TSTypeAnnotation", "Noop"),
						optional: !0
					},
					optional: {
						validate: (0, l.assertValueType)("boolean"),
						optional: !0
					},
					decorators: {
						validate: (0, l.arrayOfType)("Decorator"),
						optional: !0
					}
				});
				t.patternLikeCommon = patternLikeCommon, p("Identifier", {
					builder: ["name"],
					visitor: ["typeAnnotation", "decorators"],
					aliases: [
						"Expression",
						"FunctionParameter",
						"PatternLike",
						"LVal",
						"TSEntityName"
					],
					fields: Object.assign({}, patternLikeCommon(), { name: { validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.chain)((0, l.assertValueType)("string"), Object.assign(function(e, t, r) {
						if (!(0, s.default)(r, !1)) throw new TypeError(`"${r}" is not a valid identifier name`);
					}, { type: "string" })) : (0, l.assertValueType)("string") } }),
					validate: process.env.BABEL_TYPES_8_BREAKING ? function(e, t, r) {
						const s = /\.(\w+)$/.exec(t.toString());
						if (!s) return;
						const [, o] = s, a = { computed: !1 };
						if ("property" === o) {
							if ((0, n.default)("MemberExpression", e, a)) return;
							if ((0, n.default)("OptionalMemberExpression", e, a)) return;
						} else if ("key" === o) {
							if ((0, n.default)("Property", e, a)) return;
							if ((0, n.default)("Method", e, a)) return;
						} else if ("exported" === o) {
							if ((0, n.default)("ExportSpecifier", e)) return;
						} else if ("imported" === o) {
							if ((0, n.default)("ImportSpecifier", e, { imported: r })) return;
						} else if ("meta" === o && (0, n.default)("MetaProperty", e, { meta: r })) return;
						if (((0, i.isKeyword)(r.name) || (0, i.isReservedWord)(r.name, !1)) && "this" !== r.name) throw new TypeError(`"${r.name}" is not a valid identifier`);
					} : void 0
				}), p("IfStatement", {
					visitor: [
						"test",
						"consequent",
						"alternate"
					],
					aliases: ["Statement", "Conditional"],
					fields: {
						test: { validate: (0, l.assertNodeType)("Expression") },
						consequent: { validate: (0, l.assertNodeType)("Statement") },
						alternate: {
							optional: !0,
							validate: (0, l.assertNodeType)("Statement")
						}
					}
				}), p("LabeledStatement", {
					visitor: ["label", "body"],
					aliases: ["Statement"],
					fields: {
						label: { validate: (0, l.assertNodeType)("Identifier") },
						body: { validate: (0, l.assertNodeType)("Statement") }
					}
				}), p("StringLiteral", {
					builder: ["value"],
					fields: { value: { validate: (0, l.assertValueType)("string") } },
					aliases: [
						"Expression",
						"Pureish",
						"Literal",
						"Immutable"
					]
				}), p("NumericLiteral", {
					builder: ["value"],
					deprecatedAlias: "NumberLiteral",
					fields: { value: { validate: (0, l.chain)((0, l.assertValueType)("number"), Object.assign(function(e, t, r) {
						if (1 / r < 0 || !Number.isFinite(r)) `${r}`;
					}, { type: "number" })) } },
					aliases: [
						"Expression",
						"Pureish",
						"Literal",
						"Immutable"
					]
				}), p("NullLiteral", { aliases: [
					"Expression",
					"Pureish",
					"Literal",
					"Immutable"
				] }), p("BooleanLiteral", {
					builder: ["value"],
					fields: { value: { validate: (0, l.assertValueType)("boolean") } },
					aliases: [
						"Expression",
						"Pureish",
						"Literal",
						"Immutable"
					]
				}), p("RegExpLiteral", {
					builder: ["pattern", "flags"],
					deprecatedAlias: "RegexLiteral",
					aliases: [
						"Expression",
						"Pureish",
						"Literal"
					],
					fields: {
						pattern: { validate: (0, l.assertValueType)("string") },
						flags: {
							validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.chain)((0, l.assertValueType)("string"), Object.assign(function(e, t, r) {
								const n = /[^dgimsuvy]/.exec(r);
								if (n) throw new TypeError(`"${n[0]}" is not a valid RegExp flag`);
							}, { type: "string" })) : (0, l.assertValueType)("string"),
							default: ""
						}
					}
				}), p("LogicalExpression", {
					builder: [
						"operator",
						"left",
						"right"
					],
					visitor: ["left", "right"],
					aliases: ["Binary", "Expression"],
					fields: {
						operator: { validate: (0, l.assertOneOf)(...a.LOGICAL_OPERATORS) },
						left: { validate: (0, l.assertNodeType)("Expression") },
						right: { validate: (0, l.assertNodeType)("Expression") }
					}
				}), p("MemberExpression", {
					builder: [
						"object",
						"property",
						"computed",
						...process.env.BABEL_TYPES_8_BREAKING ? [] : ["optional"]
					],
					visitor: ["object", "property"],
					aliases: [
						"Expression",
						"LVal",
						"PatternLike"
					],
					fields: Object.assign({
						object: { validate: (0, l.assertNodeType)("Expression", "Super") },
						property: { validate: function() {
							const e = (0, l.assertNodeType)("Identifier", "PrivateName"), t = (0, l.assertNodeType)("Expression"), validator = function(r, n, s) {
								(r.computed ? t : e)(r, n, s);
							};
							return validator.oneOfNodeTypes = [
								"Expression",
								"Identifier",
								"PrivateName"
							], validator;
						}() },
						computed: { default: !1 }
					}, process.env.BABEL_TYPES_8_BREAKING ? {} : { optional: {
						validate: (0, l.assertValueType)("boolean"),
						optional: !0
					} })
				}), p("NewExpression", { inherits: "CallExpression" }), p("Program", {
					visitor: ["directives", "body"],
					builder: [
						"body",
						"directives",
						"sourceType",
						"interpreter"
					],
					fields: {
						sourceType: {
							validate: (0, l.assertOneOf)("script", "module"),
							default: "script"
						},
						interpreter: {
							validate: (0, l.assertNodeType)("InterpreterDirective"),
							default: null,
							optional: !0
						},
						directives: {
							validate: (0, l.arrayOfType)("Directive"),
							default: []
						},
						body: (0, l.validateArrayOfType)("Statement")
					},
					aliases: [
						"Scopable",
						"BlockParent",
						"Block"
					]
				}), p("ObjectExpression", {
					visitor: ["properties"],
					aliases: ["Expression"],
					fields: { properties: (0, l.validateArrayOfType)("ObjectMethod", "ObjectProperty", "SpreadElement") }
				}), p("ObjectMethod", {
					builder: [
						"kind",
						"key",
						"params",
						"body",
						"computed",
						"generator",
						"async"
					],
					visitor: [
						"decorators",
						"key",
						"typeParameters",
						"params",
						"returnType",
						"body"
					],
					fields: Object.assign({}, functionCommon(), functionTypeAnnotationCommon(), {
						kind: Object.assign({ validate: (0, l.assertOneOf)("method", "get", "set") }, process.env.BABEL_TYPES_8_BREAKING ? {} : { default: "method" }),
						computed: { default: !1 },
						key: { validate: function() {
							const e = (0, l.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral"), t = (0, l.assertNodeType)("Expression"), validator = function(r, n, s) {
								(r.computed ? t : e)(r, n, s);
							};
							return validator.oneOfNodeTypes = [
								"Expression",
								"Identifier",
								"StringLiteral",
								"NumericLiteral",
								"BigIntLiteral"
							], validator;
						}() },
						decorators: {
							validate: (0, l.arrayOfType)("Decorator"),
							optional: !0
						},
						body: { validate: (0, l.assertNodeType)("BlockStatement") }
					}),
					aliases: [
						"UserWhitespacable",
						"Function",
						"Scopable",
						"BlockParent",
						"FunctionParent",
						"Method",
						"ObjectMember"
					]
				}), p("ObjectProperty", {
					builder: [
						"key",
						"value",
						"computed",
						"shorthand",
						...process.env.BABEL_TYPES_8_BREAKING ? [] : ["decorators"]
					],
					fields: {
						computed: { default: !1 },
						key: { validate: function() {
							const e = (0, l.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "DecimalLiteral", "PrivateName"), t = (0, l.assertNodeType)("Expression");
							return Object.assign(function(r, n, s) {
								(r.computed ? t : e)(r, n, s);
							}, { oneOfNodeTypes: [
								"Expression",
								"Identifier",
								"StringLiteral",
								"NumericLiteral",
								"BigIntLiteral",
								"DecimalLiteral",
								"PrivateName"
							] });
						}() },
						value: { validate: (0, l.assertNodeType)("Expression", "PatternLike") },
						shorthand: {
							validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.chain)((0, l.assertValueType)("boolean"), Object.assign(function(e, t, r) {
								if (r) {
									if (e.computed) throw new TypeError("Property shorthand of ObjectProperty cannot be true if computed is true");
									if (!(0, n.default)("Identifier", e.key)) throw new TypeError("Property shorthand of ObjectProperty cannot be true if key is not an Identifier");
								}
							}, { type: "boolean" })) : (0, l.assertValueType)("boolean"),
							default: !1
						},
						decorators: {
							validate: (0, l.arrayOfType)("Decorator"),
							optional: !0
						}
					},
					visitor: [
						"decorators",
						"key",
						"value"
					],
					aliases: [
						"UserWhitespacable",
						"Property",
						"ObjectMember"
					],
					validate: process.env.BABEL_TYPES_8_BREAKING ? function() {
						const e = (0, l.assertNodeType)("Identifier", "Pattern", "TSAsExpression", "TSSatisfiesExpression", "TSNonNullExpression", "TSTypeAssertion"), t = (0, l.assertNodeType)("Expression");
						return function(r, s, i) {
							((0, n.default)("ObjectPattern", r) ? e : t)(i, "value", i.value);
						};
					}() : void 0
				}), p("RestElement", {
					visitor: ["argument", "typeAnnotation"],
					builder: ["argument"],
					aliases: [
						"FunctionParameter",
						"PatternLike",
						"LVal"
					],
					deprecatedAlias: "RestProperty",
					fields: Object.assign({}, patternLikeCommon(), { argument: { validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.assertNodeType)("Identifier", "ArrayPattern", "ObjectPattern", "MemberExpression", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression") : (0, l.assertNodeType)("Identifier", "ArrayPattern", "ObjectPattern", "MemberExpression", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression", "RestElement", "AssignmentPattern") } }),
					validate: process.env.BABEL_TYPES_8_BREAKING ? function(e, t) {
						const r = /(\w+)\[(\d+)\]/.exec(t.toString());
						if (!r) throw new Error("Internal Babel error: malformed key.");
						const [, n, s] = r;
						if (e[n].length > +s + 1) throw new TypeError(`RestElement must be last element of ${n}`);
					} : void 0
				}), p("ReturnStatement", {
					visitor: ["argument"],
					aliases: [
						"Statement",
						"Terminatorless",
						"CompletionStatement"
					],
					fields: { argument: {
						validate: (0, l.assertNodeType)("Expression"),
						optional: !0
					} }
				}), p("SequenceExpression", {
					visitor: ["expressions"],
					fields: { expressions: (0, l.validateArrayOfType)("Expression") },
					aliases: ["Expression"]
				}), p("ParenthesizedExpression", {
					visitor: ["expression"],
					aliases: ["Expression", "ExpressionWrapper"],
					fields: { expression: { validate: (0, l.assertNodeType)("Expression") } }
				}), p("SwitchCase", {
					visitor: ["test", "consequent"],
					fields: {
						test: {
							validate: (0, l.assertNodeType)("Expression"),
							optional: !0
						},
						consequent: (0, l.validateArrayOfType)("Statement")
					}
				}), p("SwitchStatement", {
					visitor: ["discriminant", "cases"],
					aliases: [
						"Statement",
						"BlockParent",
						"Scopable"
					],
					fields: {
						discriminant: { validate: (0, l.assertNodeType)("Expression") },
						cases: (0, l.validateArrayOfType)("SwitchCase")
					}
				}), p("ThisExpression", { aliases: ["Expression"] }), p("ThrowStatement", {
					visitor: ["argument"],
					aliases: [
						"Statement",
						"Terminatorless",
						"CompletionStatement"
					],
					fields: { argument: { validate: (0, l.assertNodeType)("Expression") } }
				}), p("TryStatement", {
					visitor: [
						"block",
						"handler",
						"finalizer"
					],
					aliases: ["Statement"],
					fields: {
						block: { validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.chain)((0, l.assertNodeType)("BlockStatement"), Object.assign(function(e) {
							if (!e.handler && !e.finalizer) throw new TypeError("TryStatement expects either a handler or finalizer, or both");
						}, { oneOfNodeTypes: ["BlockStatement"] })) : (0, l.assertNodeType)("BlockStatement") },
						handler: {
							optional: !0,
							validate: (0, l.assertNodeType)("CatchClause")
						},
						finalizer: {
							optional: !0,
							validate: (0, l.assertNodeType)("BlockStatement")
						}
					}
				}), p("UnaryExpression", {
					builder: [
						"operator",
						"argument",
						"prefix"
					],
					fields: {
						prefix: { default: !0 },
						argument: { validate: (0, l.assertNodeType)("Expression") },
						operator: { validate: (0, l.assertOneOf)(...a.UNARY_OPERATORS) }
					},
					visitor: ["argument"],
					aliases: ["UnaryLike", "Expression"]
				}), p("UpdateExpression", {
					builder: [
						"operator",
						"argument",
						"prefix"
					],
					fields: {
						prefix: { default: !1 },
						argument: { validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.assertNodeType)("Identifier", "MemberExpression") : (0, l.assertNodeType)("Expression") },
						operator: { validate: (0, l.assertOneOf)(...a.UPDATE_OPERATORS) }
					},
					visitor: ["argument"],
					aliases: ["Expression"]
				}), p("VariableDeclaration", {
					builder: ["kind", "declarations"],
					visitor: ["declarations"],
					aliases: ["Statement", "Declaration"],
					fields: {
						declare: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						kind: { validate: (0, l.assertOneOf)("var", "let", "const", "using", "await using") },
						declarations: (0, l.validateArrayOfType)("VariableDeclarator")
					},
					validate: process.env.BABEL_TYPES_8_BREAKING ? (() => {
						const e = (0, l.assertNodeType)("Identifier", "Placeholder"), t = (0, l.assertNodeType)("Identifier", "ArrayPattern", "ObjectPattern", "Placeholder"), r = (0, l.assertNodeType)("Identifier", "VoidPattern", "Placeholder");
						return function(s, i, o) {
							const { kind: a, declarations: l } = o, p = (0, n.default)("ForXStatement", s, { left: o });
							if (p && 1 !== l.length) throw new TypeError(`Exactly one VariableDeclarator is required in the VariableDeclaration of a ${s.type}`);
							for (const n of l) "const" === a || "let" === a || "var" === a ? p || n.init ? t(n, "id", n.id) : e(n, "id", n.id) : r(n, "id", n.id);
						};
					})() : void 0
				}), p("VariableDeclarator", {
					visitor: ["id", "init"],
					fields: {
						id: { validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.assertNodeType)("Identifier", "ArrayPattern", "ObjectPattern", "VoidPattern") : (0, l.assertNodeType)("LVal", "VoidPattern") },
						definite: {
							optional: !0,
							validate: (0, l.assertValueType)("boolean")
						},
						init: {
							optional: !0,
							validate: (0, l.assertNodeType)("Expression")
						}
					}
				}), p("WhileStatement", {
					visitor: ["test", "body"],
					aliases: [
						"Statement",
						"BlockParent",
						"Loop",
						"While",
						"Scopable"
					],
					fields: {
						test: { validate: (0, l.assertNodeType)("Expression") },
						body: { validate: (0, l.assertNodeType)("Statement") }
					}
				}), p("WithStatement", {
					visitor: ["object", "body"],
					aliases: ["Statement"],
					fields: {
						object: { validate: (0, l.assertNodeType)("Expression") },
						body: { validate: (0, l.assertNodeType)("Statement") }
					}
				}), p("AssignmentPattern", {
					visitor: [
						"left",
						"right",
						"decorators"
					],
					builder: ["left", "right"],
					aliases: [
						"FunctionParameter",
						"Pattern",
						"PatternLike",
						"LVal"
					],
					fields: Object.assign({}, patternLikeCommon(), {
						left: { validate: (0, l.assertNodeType)("Identifier", "ObjectPattern", "ArrayPattern", "MemberExpression", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression") },
						right: { validate: (0, l.assertNodeType)("Expression") },
						decorators: {
							validate: (0, l.arrayOfType)("Decorator"),
							optional: !0
						}
					})
				}), p("ArrayPattern", {
					visitor: ["elements", "typeAnnotation"],
					builder: ["elements"],
					aliases: [
						"FunctionParameter",
						"Pattern",
						"PatternLike",
						"LVal"
					],
					fields: Object.assign({}, patternLikeCommon(), { elements: { validate: (0, l.chain)((0, l.assertValueType)("array"), (0, l.assertEach)((0, l.assertNodeOrValueType)("null", "PatternLike"))) } })
				}), p("ArrowFunctionExpression", {
					builder: [
						"params",
						"body",
						"async"
					],
					visitor: [
						"typeParameters",
						"params",
						"predicate",
						"returnType",
						"body"
					],
					aliases: [
						"Scopable",
						"Function",
						"BlockParent",
						"FunctionParent",
						"Expression",
						"Pureish"
					],
					fields: Object.assign({}, functionCommon(), functionTypeAnnotationCommon(), {
						expression: { validate: (0, l.assertValueType)("boolean") },
						body: { validate: (0, l.assertNodeType)("BlockStatement", "Expression") },
						predicate: {
							validate: (0, l.assertNodeType)("DeclaredPredicate", "InferredPredicate"),
							optional: !0
						}
					})
				}), p("ClassBody", {
					visitor: ["body"],
					fields: { body: (0, l.validateArrayOfType)("ClassMethod", "ClassPrivateMethod", "ClassProperty", "ClassPrivateProperty", "ClassAccessorProperty", "TSDeclareMethod", "TSIndexSignature", "StaticBlock") }
				}), p("ClassExpression", {
					builder: [
						"id",
						"superClass",
						"body",
						"decorators"
					],
					visitor: [
						"decorators",
						"id",
						"typeParameters",
						"superClass",
						"superTypeParameters",
						"mixins",
						"implements",
						"body"
					],
					aliases: [
						"Scopable",
						"Class",
						"Expression"
					],
					fields: {
						id: {
							validate: (0, l.assertNodeType)("Identifier"),
							optional: !0
						},
						typeParameters: {
							validate: (0, l.assertNodeType)("TypeParameterDeclaration", "TSTypeParameterDeclaration", "Noop"),
							optional: !0
						},
						body: { validate: (0, l.assertNodeType)("ClassBody") },
						superClass: {
							optional: !0,
							validate: (0, l.assertNodeType)("Expression")
						},
						superTypeParameters: {
							validate: (0, l.assertNodeType)("TypeParameterInstantiation", "TSTypeParameterInstantiation"),
							optional: !0
						},
						implements: {
							validate: (0, l.arrayOfType)("TSExpressionWithTypeArguments", "ClassImplements"),
							optional: !0
						},
						decorators: {
							validate: (0, l.arrayOfType)("Decorator"),
							optional: !0
						},
						mixins: {
							validate: (0, l.assertNodeType)("InterfaceExtends"),
							optional: !0
						}
					}
				}), p("ClassDeclaration", {
					inherits: "ClassExpression",
					aliases: [
						"Scopable",
						"Class",
						"Statement",
						"Declaration"
					],
					fields: {
						id: {
							validate: (0, l.assertNodeType)("Identifier"),
							optional: !0
						},
						typeParameters: {
							validate: (0, l.assertNodeType)("TypeParameterDeclaration", "TSTypeParameterDeclaration", "Noop"),
							optional: !0
						},
						body: { validate: (0, l.assertNodeType)("ClassBody") },
						superClass: {
							optional: !0,
							validate: (0, l.assertNodeType)("Expression")
						},
						superTypeParameters: {
							validate: (0, l.assertNodeType)("TypeParameterInstantiation", "TSTypeParameterInstantiation"),
							optional: !0
						},
						implements: {
							validate: (0, l.arrayOfType)("TSExpressionWithTypeArguments", "ClassImplements"),
							optional: !0
						},
						decorators: {
							validate: (0, l.arrayOfType)("Decorator"),
							optional: !0
						},
						mixins: {
							validate: (0, l.assertNodeType)("InterfaceExtends"),
							optional: !0
						},
						declare: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						abstract: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						}
					},
					validate: process.env.BABEL_TYPES_8_BREAKING ? function() {
						const e = (0, l.assertNodeType)("Identifier");
						return function(t, r, s) {
							(0, n.default)("ExportDefaultDeclaration", t) || e(s, "id", s.id);
						};
					}() : void 0
				});
				const c = t.importAttributes = {
					attributes: {
						optional: !0,
						validate: (0, l.arrayOfType)("ImportAttribute")
					},
					assertions: {
						deprecated: !0,
						optional: !0,
						validate: (0, l.arrayOfType)("ImportAttribute")
					}
				};
				p("ExportAllDeclaration", {
					builder: ["source"],
					visitor: [
						"source",
						"attributes",
						"assertions"
					],
					aliases: [
						"Statement",
						"Declaration",
						"ImportOrExportDeclaration",
						"ExportDeclaration"
					],
					fields: Object.assign({
						source: { validate: (0, l.assertNodeType)("StringLiteral") },
						exportKind: (0, l.validateOptional)((0, l.assertOneOf)("type", "value"))
					}, c)
				}), p("ExportDefaultDeclaration", {
					visitor: ["declaration"],
					aliases: [
						"Statement",
						"Declaration",
						"ImportOrExportDeclaration",
						"ExportDeclaration"
					],
					fields: {
						declaration: (0, l.validateType)("TSDeclareFunction", "FunctionDeclaration", "ClassDeclaration", "Expression"),
						exportKind: (0, l.validateOptional)((0, l.assertOneOf)("value"))
					}
				}), p("ExportNamedDeclaration", {
					builder: [
						"declaration",
						"specifiers",
						"source"
					],
					visitor: [
						"declaration",
						"specifiers",
						"source",
						"attributes",
						"assertions"
					],
					aliases: [
						"Statement",
						"Declaration",
						"ImportOrExportDeclaration",
						"ExportDeclaration"
					],
					fields: Object.assign({ declaration: {
						optional: !0,
						validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.chain)((0, l.assertNodeType)("Declaration"), Object.assign(function(e, t, r) {
							if (r && e.specifiers.length) throw new TypeError("Only declaration or specifiers is allowed on ExportNamedDeclaration");
							if (r && e.source) throw new TypeError("Cannot export a declaration from a source");
						}, { oneOfNodeTypes: ["Declaration"] })) : (0, l.assertNodeType)("Declaration")
					} }, c, {
						specifiers: {
							default: [],
							validate: (0, l.arrayOf)(function() {
								const e = (0, l.assertNodeType)("ExportSpecifier", "ExportDefaultSpecifier", "ExportNamespaceSpecifier"), t = (0, l.assertNodeType)("ExportSpecifier");
								return process.env.BABEL_TYPES_8_BREAKING ? Object.assign(function(r, n, s) {
									(r.source ? e : t)(r, n, s);
								}, { oneOfNodeTypes: [
									"ExportSpecifier",
									"ExportDefaultSpecifier",
									"ExportNamespaceSpecifier"
								] }) : e;
							}())
						},
						source: {
							validate: (0, l.assertNodeType)("StringLiteral"),
							optional: !0
						},
						exportKind: (0, l.validateOptional)((0, l.assertOneOf)("type", "value"))
					})
				}), p("ExportSpecifier", {
					visitor: ["local", "exported"],
					aliases: ["ModuleSpecifier"],
					fields: {
						local: { validate: (0, l.assertNodeType)("Identifier") },
						exported: { validate: (0, l.assertNodeType)("Identifier", "StringLiteral") },
						exportKind: {
							validate: (0, l.assertOneOf)("type", "value"),
							optional: !0
						}
					}
				}), p("ForOfStatement", {
					visitor: [
						"left",
						"right",
						"body"
					],
					builder: [
						"left",
						"right",
						"body",
						"await"
					],
					aliases: [
						"Scopable",
						"Statement",
						"For",
						"BlockParent",
						"Loop",
						"ForXStatement"
					],
					fields: {
						left: { validate: function() {
							if (!process.env.BABEL_TYPES_8_BREAKING) return (0, l.assertNodeType)("VariableDeclaration", "LVal");
							const e = (0, l.assertNodeType)("VariableDeclaration"), t = (0, l.assertNodeType)("Identifier", "MemberExpression", "ArrayPattern", "ObjectPattern", "TSAsExpression", "TSSatisfiesExpression", "TSTypeAssertion", "TSNonNullExpression");
							return Object.assign(function(r, s, i) {
								(0, n.default)("VariableDeclaration", i) ? e(r, s, i) : t(r, s, i);
							}, { oneOfNodeTypes: [
								"VariableDeclaration",
								"Identifier",
								"MemberExpression",
								"ArrayPattern",
								"ObjectPattern",
								"TSAsExpression",
								"TSSatisfiesExpression",
								"TSTypeAssertion",
								"TSNonNullExpression"
							] });
						}() },
						right: { validate: (0, l.assertNodeType)("Expression") },
						body: { validate: (0, l.assertNodeType)("Statement") },
						await: { default: !1 }
					}
				}), p("ImportDeclaration", {
					builder: ["specifiers", "source"],
					visitor: [
						"specifiers",
						"source",
						"attributes",
						"assertions"
					],
					aliases: [
						"Statement",
						"Declaration",
						"ImportOrExportDeclaration"
					],
					fields: Object.assign({}, c, {
						module: {
							optional: !0,
							validate: (0, l.assertValueType)("boolean")
						},
						phase: {
							default: null,
							validate: (0, l.assertOneOf)("source", "defer")
						},
						specifiers: (0, l.validateArrayOfType)("ImportSpecifier", "ImportDefaultSpecifier", "ImportNamespaceSpecifier"),
						source: { validate: (0, l.assertNodeType)("StringLiteral") },
						importKind: {
							validate: (0, l.assertOneOf)("type", "typeof", "value"),
							optional: !0
						}
					})
				}), p("ImportDefaultSpecifier", {
					visitor: ["local"],
					aliases: ["ModuleSpecifier"],
					fields: { local: { validate: (0, l.assertNodeType)("Identifier") } }
				}), p("ImportNamespaceSpecifier", {
					visitor: ["local"],
					aliases: ["ModuleSpecifier"],
					fields: { local: { validate: (0, l.assertNodeType)("Identifier") } }
				}), p("ImportSpecifier", {
					visitor: ["imported", "local"],
					builder: ["local", "imported"],
					aliases: ["ModuleSpecifier"],
					fields: {
						local: { validate: (0, l.assertNodeType)("Identifier") },
						imported: { validate: (0, l.assertNodeType)("Identifier", "StringLiteral") },
						importKind: {
							validate: (0, l.assertOneOf)("type", "typeof", "value"),
							optional: !0
						}
					}
				}), p("ImportExpression", {
					visitor: ["source", "options"],
					aliases: ["Expression"],
					fields: {
						phase: {
							default: null,
							validate: (0, l.assertOneOf)("source", "defer")
						},
						source: { validate: (0, l.assertNodeType)("Expression") },
						options: {
							validate: (0, l.assertNodeType)("Expression"),
							optional: !0
						}
					}
				}), p("MetaProperty", {
					visitor: ["meta", "property"],
					aliases: ["Expression"],
					fields: {
						meta: { validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.chain)((0, l.assertNodeType)("Identifier"), Object.assign(function(e, t, r) {
							let s;
							switch (r.name) {
								case "function":
									s = "sent";
									break;
								case "new":
									s = "target";
									break;
								case "import": s = "meta";
							}
							if (!(0, n.default)("Identifier", e.property, { name: s })) throw new TypeError("Unrecognised MetaProperty");
						}, { oneOfNodeTypes: ["Identifier"] })) : (0, l.assertNodeType)("Identifier") },
						property: { validate: (0, l.assertNodeType)("Identifier") }
					}
				});
				const classMethodOrPropertyCommon = () => ({
					abstract: {
						validate: (0, l.assertValueType)("boolean"),
						optional: !0
					},
					accessibility: {
						validate: (0, l.assertOneOf)("public", "private", "protected"),
						optional: !0
					},
					static: { default: !1 },
					override: { default: !1 },
					computed: { default: !1 },
					optional: {
						validate: (0, l.assertValueType)("boolean"),
						optional: !0
					},
					key: { validate: (0, l.chain)(function() {
						const e = (0, l.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral"), t = (0, l.assertNodeType)("Expression");
						return function(r, n, s) {
							(r.computed ? t : e)(r, n, s);
						};
					}(), (0, l.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "Expression")) }
				});
				t.classMethodOrPropertyCommon = classMethodOrPropertyCommon;
				const classMethodOrDeclareMethodCommon = () => Object.assign({}, functionCommon(), classMethodOrPropertyCommon(), {
					params: (0, l.validateArrayOfType)("FunctionParameter", "TSParameterProperty"),
					kind: {
						validate: (0, l.assertOneOf)("get", "set", "method", "constructor"),
						default: "method"
					},
					access: {
						validate: (0, l.chain)((0, l.assertValueType)("string"), (0, l.assertOneOf)("public", "private", "protected")),
						optional: !0
					},
					decorators: {
						validate: (0, l.arrayOfType)("Decorator"),
						optional: !0
					}
				});
				t.classMethodOrDeclareMethodCommon = classMethodOrDeclareMethodCommon, p("ClassMethod", {
					aliases: [
						"Function",
						"Scopable",
						"BlockParent",
						"FunctionParent",
						"Method"
					],
					builder: [
						"kind",
						"key",
						"params",
						"body",
						"computed",
						"static",
						"generator",
						"async"
					],
					visitor: [
						"decorators",
						"key",
						"typeParameters",
						"params",
						"returnType",
						"body"
					],
					fields: Object.assign({}, classMethodOrDeclareMethodCommon(), functionTypeAnnotationCommon(), { body: { validate: (0, l.assertNodeType)("BlockStatement") } })
				}), p("ObjectPattern", {
					visitor: [
						"decorators",
						"properties",
						"typeAnnotation"
					],
					builder: ["properties"],
					aliases: [
						"FunctionParameter",
						"Pattern",
						"PatternLike",
						"LVal"
					],
					fields: Object.assign({}, patternLikeCommon(), { properties: (0, l.validateArrayOfType)("RestElement", "ObjectProperty") })
				}), p("SpreadElement", {
					visitor: ["argument"],
					aliases: ["UnaryLike"],
					deprecatedAlias: "SpreadProperty",
					fields: { argument: { validate: (0, l.assertNodeType)("Expression") } }
				}), p("Super", { aliases: ["Expression"] }), p("TaggedTemplateExpression", {
					visitor: [
						"tag",
						"typeParameters",
						"quasi"
					],
					builder: ["tag", "quasi"],
					aliases: ["Expression"],
					fields: {
						tag: { validate: (0, l.assertNodeType)("Expression") },
						quasi: { validate: (0, l.assertNodeType)("TemplateLiteral") },
						typeParameters: {
							validate: (0, l.assertNodeType)("TypeParameterInstantiation", "TSTypeParameterInstantiation"),
							optional: !0
						}
					}
				}), p("TemplateElement", {
					builder: ["value", "tail"],
					fields: {
						value: { validate: (0, l.chain)((0, l.assertShape)({
							raw: { validate: (0, l.assertValueType)("string") },
							cooked: {
								validate: (0, l.assertValueType)("string"),
								optional: !0
							}
						}), function(e) {
							const t = e.value.raw;
							let r = !1;
							const error = () => {
								throw new Error("Internal @babel/types error.");
							}, { str: n, firstInvalidLoc: s } = (0, o.readStringContents)("template", t, 0, 0, 0, {
								unterminated() {
									r = !0;
								},
								strictNumericEscape: error,
								invalidEscapeSequence: error,
								numericSeparatorInEscapeSequence: error,
								unexpectedNumericSeparator: error,
								invalidDigit: error,
								invalidCodePoint: error
							});
							if (!r) throw new Error("Invalid raw");
							e.value.cooked = s ? null : n;
						}) },
						tail: { default: !1 }
					}
				}), p("TemplateLiteral", {
					visitor: ["quasis", "expressions"],
					aliases: ["Expression", "Literal"],
					fields: {
						quasis: (0, l.validateArrayOfType)("TemplateElement"),
						expressions: { validate: (0, l.chain)((0, l.assertValueType)("array"), (0, l.assertEach)((0, l.assertNodeType)("Expression", "TSType")), function(e, t, r) {
							if (e.quasis.length !== r.length + 1) throw new TypeError(`Number of ${e.type} quasis should be exactly one more than the number of expressions.\nExpected ${r.length + 1} quasis but got ${e.quasis.length}`);
						}) }
					}
				}), p("YieldExpression", {
					builder: ["argument", "delegate"],
					visitor: ["argument"],
					aliases: ["Expression", "Terminatorless"],
					fields: {
						delegate: {
							validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.chain)((0, l.assertValueType)("boolean"), Object.assign(function(e, t, r) {
								if (r && !e.argument) throw new TypeError("Property delegate of YieldExpression cannot be true if there is no argument");
							}, { type: "boolean" })) : (0, l.assertValueType)("boolean"),
							default: !1
						},
						argument: {
							optional: !0,
							validate: (0, l.assertNodeType)("Expression")
						}
					}
				}), p("AwaitExpression", {
					builder: ["argument"],
					visitor: ["argument"],
					aliases: ["Expression", "Terminatorless"],
					fields: { argument: { validate: (0, l.assertNodeType)("Expression") } }
				}), p("Import", { aliases: ["Expression"] }), p("BigIntLiteral", {
					builder: ["value"],
					fields: { value: { validate: (0, l.assertValueType)("string") } },
					aliases: [
						"Expression",
						"Pureish",
						"Literal",
						"Immutable"
					]
				}), p("ExportNamespaceSpecifier", {
					visitor: ["exported"],
					aliases: ["ModuleSpecifier"],
					fields: { exported: { validate: (0, l.assertNodeType)("Identifier") } }
				}), p("OptionalMemberExpression", {
					builder: [
						"object",
						"property",
						"computed",
						"optional"
					],
					visitor: ["object", "property"],
					aliases: ["Expression"],
					fields: {
						object: { validate: (0, l.assertNodeType)("Expression") },
						property: { validate: function() {
							const e = (0, l.assertNodeType)("Identifier"), t = (0, l.assertNodeType)("Expression");
							return Object.assign(function(r, n, s) {
								(r.computed ? t : e)(r, n, s);
							}, { oneOfNodeTypes: ["Expression", "Identifier"] });
						}() },
						computed: { default: !1 },
						optional: { validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.chain)((0, l.assertValueType)("boolean"), (0, l.assertOptionalChainStart)()) : (0, l.assertValueType)("boolean") }
					}
				}), p("OptionalCallExpression", {
					visitor: [
						"callee",
						"typeParameters",
						"typeArguments",
						"arguments"
					],
					builder: [
						"callee",
						"arguments",
						"optional"
					],
					aliases: ["Expression"],
					fields: Object.assign({
						callee: { validate: (0, l.assertNodeType)("Expression") },
						arguments: (0, l.validateArrayOfType)("Expression", "SpreadElement", "ArgumentPlaceholder"),
						optional: { validate: process.env.BABEL_TYPES_8_BREAKING ? (0, l.chain)((0, l.assertValueType)("boolean"), (0, l.assertOptionalChainStart)()) : (0, l.assertValueType)("boolean") },
						typeArguments: {
							validate: (0, l.assertNodeType)("TypeParameterInstantiation"),
							optional: !0
						}
					}, { typeParameters: {
						validate: (0, l.assertNodeType)("TSTypeParameterInstantiation"),
						optional: !0
					} })
				}), p("ClassProperty", {
					visitor: [
						"decorators",
						"variance",
						"key",
						"typeAnnotation",
						"value"
					],
					builder: [
						"key",
						"value",
						"typeAnnotation",
						"decorators",
						"computed",
						"static"
					],
					aliases: ["Property"],
					fields: Object.assign({}, classMethodOrPropertyCommon(), {
						value: {
							validate: (0, l.assertNodeType)("Expression"),
							optional: !0
						},
						definite: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						typeAnnotation: {
							validate: (0, l.assertNodeType)("TypeAnnotation", "TSTypeAnnotation", "Noop"),
							optional: !0
						},
						decorators: {
							validate: (0, l.arrayOfType)("Decorator"),
							optional: !0
						},
						readonly: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						declare: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						variance: {
							validate: (0, l.assertNodeType)("Variance"),
							optional: !0
						}
					})
				}), p("ClassAccessorProperty", {
					visitor: [
						"decorators",
						"key",
						"typeAnnotation",
						"value"
					],
					builder: [
						"key",
						"value",
						"typeAnnotation",
						"decorators",
						"computed",
						"static"
					],
					aliases: ["Property", "Accessor"],
					fields: Object.assign({}, classMethodOrPropertyCommon(), {
						key: { validate: (0, l.chain)(function() {
							const e = (0, l.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "PrivateName"), t = (0, l.assertNodeType)("Expression");
							return function(r, n, s) {
								(r.computed ? t : e)(r, n, s);
							};
						}(), (0, l.assertNodeType)("Identifier", "StringLiteral", "NumericLiteral", "BigIntLiteral", "Expression", "PrivateName")) },
						value: {
							validate: (0, l.assertNodeType)("Expression"),
							optional: !0
						},
						definite: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						typeAnnotation: {
							validate: (0, l.assertNodeType)("TypeAnnotation", "TSTypeAnnotation", "Noop"),
							optional: !0
						},
						decorators: {
							validate: (0, l.arrayOfType)("Decorator"),
							optional: !0
						},
						readonly: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						declare: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						variance: {
							validate: (0, l.assertNodeType)("Variance"),
							optional: !0
						}
					})
				}), p("ClassPrivateProperty", {
					visitor: [
						"decorators",
						"variance",
						"key",
						"typeAnnotation",
						"value"
					],
					builder: [
						"key",
						"value",
						"decorators",
						"static"
					],
					aliases: ["Property", "Private"],
					fields: {
						key: { validate: (0, l.assertNodeType)("PrivateName") },
						value: {
							validate: (0, l.assertNodeType)("Expression"),
							optional: !0
						},
						typeAnnotation: {
							validate: (0, l.assertNodeType)("TypeAnnotation", "TSTypeAnnotation", "Noop"),
							optional: !0
						},
						decorators: {
							validate: (0, l.arrayOfType)("Decorator"),
							optional: !0
						},
						static: {
							validate: (0, l.assertValueType)("boolean"),
							default: !1
						},
						readonly: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						optional: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						definite: {
							validate: (0, l.assertValueType)("boolean"),
							optional: !0
						},
						variance: {
							validate: (0, l.assertNodeType)("Variance"),
							optional: !0
						}
					}
				}), p("ClassPrivateMethod", {
					builder: [
						"kind",
						"key",
						"params",
						"body",
						"static"
					],
					visitor: [
						"decorators",
						"key",
						"typeParameters",
						"params",
						"returnType",
						"body"
					],
					aliases: [
						"Function",
						"Scopable",
						"BlockParent",
						"FunctionParent",
						"Method",
						"Private"
					],
					fields: Object.assign({}, classMethodOrDeclareMethodCommon(), functionTypeAnnotationCommon(), {
						kind: {
							validate: (0, l.assertOneOf)("get", "set", "method"),
							default: "method"
						},
						key: { validate: (0, l.assertNodeType)("PrivateName") },
						body: { validate: (0, l.assertNodeType)("BlockStatement") }
					})
				}), p("PrivateName", {
					visitor: ["id"],
					aliases: ["Private"],
					fields: { id: { validate: (0, l.assertNodeType)("Identifier") } }
				}), p("StaticBlock", {
					visitor: ["body"],
					fields: { body: (0, l.validateArrayOfType)("Statement") },
					aliases: [
						"Scopable",
						"BlockParent",
						"FunctionParent"
					]
				}), p("ImportAttribute", {
					visitor: ["key", "value"],
					fields: {
						key: { validate: (0, l.assertNodeType)("Identifier", "StringLiteral") },
						value: { validate: (0, l.assertNodeType)("StringLiteral") }
					}
				});
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/deprecated-aliases.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.DEPRECATED_ALIASES = void 0;
				t.DEPRECATED_ALIASES = { ModuleDeclaration: "ImportOrExportDeclaration" };
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/experimental.js": function(e, t, r) {
				"use strict";
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/utils.js");
				(0, n.default)("ArgumentPlaceholder", {}), (0, n.default)("BindExpression", {
					visitor: ["object", "callee"],
					aliases: ["Expression"],
					fields: process.env.BABEL_TYPES_8_BREAKING ? {
						object: { validate: (0, n.assertNodeType)("Expression") },
						callee: { validate: (0, n.assertNodeType)("Expression") }
					} : {
						object: { validate: Object.assign(() => {}, { oneOfNodeTypes: ["Expression"] }) },
						callee: { validate: Object.assign(() => {}, { oneOfNodeTypes: ["Expression"] }) }
					}
				}), (0, n.default)("Decorator", {
					visitor: ["expression"],
					fields: { expression: { validate: (0, n.assertNodeType)("Expression") } }
				}), (0, n.default)("DoExpression", {
					visitor: ["body"],
					builder: ["body", "async"],
					aliases: ["Expression"],
					fields: {
						body: { validate: (0, n.assertNodeType)("BlockStatement") },
						async: {
							validate: (0, n.assertValueType)("boolean"),
							default: !1
						}
					}
				}), (0, n.default)("ExportDefaultSpecifier", {
					visitor: ["exported"],
					aliases: ["ModuleSpecifier"],
					fields: { exported: { validate: (0, n.assertNodeType)("Identifier") } }
				}), (0, n.default)("RecordExpression", {
					visitor: ["properties"],
					aliases: ["Expression"],
					fields: { properties: (0, n.validateArrayOfType)("ObjectProperty", "SpreadElement") }
				}), (0, n.default)("TupleExpression", {
					fields: { elements: {
						validate: (0, n.arrayOfType)("Expression", "SpreadElement"),
						default: []
					} },
					visitor: ["elements"],
					aliases: ["Expression"]
				}), (0, n.default)("DecimalLiteral", {
					builder: ["value"],
					fields: { value: { validate: (0, n.assertValueType)("string") } },
					aliases: [
						"Expression",
						"Pureish",
						"Literal",
						"Immutable"
					]
				}), (0, n.default)("ModuleExpression", {
					visitor: ["body"],
					fields: { body: { validate: (0, n.assertNodeType)("Program") } },
					aliases: ["Expression"]
				}), (0, n.default)("TopicReference", { aliases: ["Expression"] }), (0, n.default)("PipelineTopicExpression", {
					builder: ["expression"],
					visitor: ["expression"],
					fields: { expression: { validate: (0, n.assertNodeType)("Expression") } },
					aliases: ["Expression"]
				}), (0, n.default)("PipelineBareFunction", {
					builder: ["callee"],
					visitor: ["callee"],
					fields: { callee: { validate: (0, n.assertNodeType)("Expression") } },
					aliases: ["Expression"]
				}), (0, n.default)("PipelinePrimaryTopicReference", { aliases: ["Expression"] }), (0, n.default)("VoidPattern", { aliases: [
					"Pattern",
					"PatternLike",
					"FunctionParameter"
				] });
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/flow.js": function(e, t, r) {
				"use strict";
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/core.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/utils.js");
				const i = (0, s.defineAliasedType)("Flow"), defineInterfaceishType = (e) => {
					const t = "DeclareClass" === e;
					i(e, {
						builder: [
							"id",
							"typeParameters",
							"extends",
							"body"
						],
						visitor: [
							"id",
							"typeParameters",
							"extends",
							...t ? ["mixins", "implements"] : [],
							"body"
						],
						aliases: [
							"FlowDeclaration",
							"Statement",
							"Declaration"
						],
						fields: Object.assign({
							id: (0, s.validateType)("Identifier"),
							typeParameters: (0, s.validateOptionalType)("TypeParameterDeclaration"),
							extends: (0, s.validateOptional)((0, s.arrayOfType)("InterfaceExtends"))
						}, t ? {
							mixins: (0, s.validateOptional)((0, s.arrayOfType)("InterfaceExtends")),
							implements: (0, s.validateOptional)((0, s.arrayOfType)("ClassImplements"))
						} : {}, { body: (0, s.validateType)("ObjectTypeAnnotation") })
					});
				};
				i("AnyTypeAnnotation", { aliases: ["FlowType", "FlowBaseAnnotation"] }), i("ArrayTypeAnnotation", {
					visitor: ["elementType"],
					aliases: ["FlowType"],
					fields: { elementType: (0, s.validateType)("FlowType") }
				}), i("BooleanTypeAnnotation", { aliases: ["FlowType", "FlowBaseAnnotation"] }), i("BooleanLiteralTypeAnnotation", {
					builder: ["value"],
					aliases: ["FlowType"],
					fields: { value: (0, s.validate)((0, s.assertValueType)("boolean")) }
				}), i("NullLiteralTypeAnnotation", { aliases: ["FlowType", "FlowBaseAnnotation"] }), i("ClassImplements", {
					visitor: ["id", "typeParameters"],
					fields: {
						id: (0, s.validateType)("Identifier"),
						typeParameters: (0, s.validateOptionalType)("TypeParameterInstantiation")
					}
				}), defineInterfaceishType("DeclareClass"), i("DeclareFunction", {
					builder: ["id"],
					visitor: ["id", "predicate"],
					aliases: [
						"FlowDeclaration",
						"Statement",
						"Declaration"
					],
					fields: {
						id: (0, s.validateType)("Identifier"),
						predicate: (0, s.validateOptionalType)("DeclaredPredicate")
					}
				}), defineInterfaceishType("DeclareInterface"), i("DeclareModule", {
					builder: [
						"id",
						"body",
						"kind"
					],
					visitor: ["id", "body"],
					aliases: [
						"FlowDeclaration",
						"Statement",
						"Declaration"
					],
					fields: {
						id: (0, s.validateType)("Identifier", "StringLiteral"),
						body: (0, s.validateType)("BlockStatement"),
						kind: (0, s.validateOptional)((0, s.assertOneOf)("CommonJS", "ES"))
					}
				}), i("DeclareModuleExports", {
					visitor: ["typeAnnotation"],
					aliases: [
						"FlowDeclaration",
						"Statement",
						"Declaration"
					],
					fields: { typeAnnotation: (0, s.validateType)("TypeAnnotation") }
				}), i("DeclareTypeAlias", {
					visitor: [
						"id",
						"typeParameters",
						"right"
					],
					aliases: [
						"FlowDeclaration",
						"Statement",
						"Declaration"
					],
					fields: {
						id: (0, s.validateType)("Identifier"),
						typeParameters: (0, s.validateOptionalType)("TypeParameterDeclaration"),
						right: (0, s.validateType)("FlowType")
					}
				}), i("DeclareOpaqueType", {
					visitor: [
						"id",
						"typeParameters",
						"supertype"
					],
					aliases: [
						"FlowDeclaration",
						"Statement",
						"Declaration"
					],
					fields: {
						id: (0, s.validateType)("Identifier"),
						typeParameters: (0, s.validateOptionalType)("TypeParameterDeclaration"),
						supertype: (0, s.validateOptionalType)("FlowType"),
						impltype: (0, s.validateOptionalType)("FlowType")
					}
				}), i("DeclareVariable", {
					visitor: ["id"],
					aliases: [
						"FlowDeclaration",
						"Statement",
						"Declaration"
					],
					fields: { id: (0, s.validateType)("Identifier") }
				}), i("DeclareExportDeclaration", {
					visitor: [
						"declaration",
						"specifiers",
						"source",
						"attributes"
					],
					aliases: [
						"FlowDeclaration",
						"Statement",
						"Declaration"
					],
					fields: Object.assign({
						declaration: (0, s.validateOptionalType)("Flow"),
						specifiers: (0, s.validateOptional)((0, s.arrayOfType)("ExportSpecifier", "ExportNamespaceSpecifier")),
						source: (0, s.validateOptionalType)("StringLiteral"),
						default: (0, s.validateOptional)((0, s.assertValueType)("boolean"))
					}, n.importAttributes)
				}), i("DeclareExportAllDeclaration", {
					visitor: ["source", "attributes"],
					aliases: [
						"FlowDeclaration",
						"Statement",
						"Declaration"
					],
					fields: Object.assign({
						source: (0, s.validateType)("StringLiteral"),
						exportKind: (0, s.validateOptional)((0, s.assertOneOf)("type", "value"))
					}, n.importAttributes)
				}), i("DeclaredPredicate", {
					visitor: ["value"],
					aliases: ["FlowPredicate"],
					fields: { value: (0, s.validateType)("Flow") }
				}), i("ExistsTypeAnnotation", { aliases: ["FlowType"] }), i("FunctionTypeAnnotation", {
					builder: [
						"typeParameters",
						"params",
						"rest",
						"returnType"
					],
					visitor: [
						"typeParameters",
						"this",
						"params",
						"rest",
						"returnType"
					],
					aliases: ["FlowType"],
					fields: {
						typeParameters: (0, s.validateOptionalType)("TypeParameterDeclaration"),
						params: (0, s.validateArrayOfType)("FunctionTypeParam"),
						rest: (0, s.validateOptionalType)("FunctionTypeParam"),
						this: (0, s.validateOptionalType)("FunctionTypeParam"),
						returnType: (0, s.validateType)("FlowType")
					}
				}), i("FunctionTypeParam", {
					visitor: ["name", "typeAnnotation"],
					fields: {
						name: (0, s.validateOptionalType)("Identifier"),
						typeAnnotation: (0, s.validateType)("FlowType"),
						optional: (0, s.validateOptional)((0, s.assertValueType)("boolean"))
					}
				}), i("GenericTypeAnnotation", {
					visitor: ["id", "typeParameters"],
					aliases: ["FlowType"],
					fields: {
						id: (0, s.validateType)("Identifier", "QualifiedTypeIdentifier"),
						typeParameters: (0, s.validateOptionalType)("TypeParameterInstantiation")
					}
				}), i("InferredPredicate", { aliases: ["FlowPredicate"] }), i("InterfaceExtends", {
					visitor: ["id", "typeParameters"],
					fields: {
						id: (0, s.validateType)("Identifier", "QualifiedTypeIdentifier"),
						typeParameters: (0, s.validateOptionalType)("TypeParameterInstantiation")
					}
				}), defineInterfaceishType("InterfaceDeclaration"), i("InterfaceTypeAnnotation", {
					visitor: ["extends", "body"],
					aliases: ["FlowType"],
					fields: {
						extends: (0, s.validateOptional)((0, s.arrayOfType)("InterfaceExtends")),
						body: (0, s.validateType)("ObjectTypeAnnotation")
					}
				}), i("IntersectionTypeAnnotation", {
					visitor: ["types"],
					aliases: ["FlowType"],
					fields: { types: (0, s.validate)((0, s.arrayOfType)("FlowType")) }
				}), i("MixedTypeAnnotation", { aliases: ["FlowType", "FlowBaseAnnotation"] }), i("EmptyTypeAnnotation", { aliases: ["FlowType", "FlowBaseAnnotation"] }), i("NullableTypeAnnotation", {
					visitor: ["typeAnnotation"],
					aliases: ["FlowType"],
					fields: { typeAnnotation: (0, s.validateType)("FlowType") }
				}), i("NumberLiteralTypeAnnotation", {
					builder: ["value"],
					aliases: ["FlowType"],
					fields: { value: (0, s.validate)((0, s.assertValueType)("number")) }
				}), i("NumberTypeAnnotation", { aliases: ["FlowType", "FlowBaseAnnotation"] }), i("ObjectTypeAnnotation", {
					visitor: [
						"properties",
						"indexers",
						"callProperties",
						"internalSlots"
					],
					aliases: ["FlowType"],
					builder: [
						"properties",
						"indexers",
						"callProperties",
						"internalSlots",
						"exact"
					],
					fields: {
						properties: (0, s.validate)((0, s.arrayOfType)("ObjectTypeProperty", "ObjectTypeSpreadProperty")),
						indexers: {
							validate: (0, s.arrayOfType)("ObjectTypeIndexer"),
							optional: !0,
							default: []
						},
						callProperties: {
							validate: (0, s.arrayOfType)("ObjectTypeCallProperty"),
							optional: !0,
							default: []
						},
						internalSlots: {
							validate: (0, s.arrayOfType)("ObjectTypeInternalSlot"),
							optional: !0,
							default: []
						},
						exact: {
							validate: (0, s.assertValueType)("boolean"),
							default: !1
						},
						inexact: (0, s.validateOptional)((0, s.assertValueType)("boolean"))
					}
				}), i("ObjectTypeInternalSlot", {
					visitor: ["id", "value"],
					builder: [
						"id",
						"value",
						"optional",
						"static",
						"method"
					],
					aliases: ["UserWhitespacable"],
					fields: {
						id: (0, s.validateType)("Identifier"),
						value: (0, s.validateType)("FlowType"),
						optional: (0, s.validate)((0, s.assertValueType)("boolean")),
						static: (0, s.validate)((0, s.assertValueType)("boolean")),
						method: (0, s.validate)((0, s.assertValueType)("boolean"))
					}
				}), i("ObjectTypeCallProperty", {
					visitor: ["value"],
					aliases: ["UserWhitespacable"],
					fields: {
						value: (0, s.validateType)("FlowType"),
						static: (0, s.validate)((0, s.assertValueType)("boolean"))
					}
				}), i("ObjectTypeIndexer", {
					visitor: [
						"variance",
						"id",
						"key",
						"value"
					],
					builder: [
						"id",
						"key",
						"value",
						"variance"
					],
					aliases: ["UserWhitespacable"],
					fields: {
						id: (0, s.validateOptionalType)("Identifier"),
						key: (0, s.validateType)("FlowType"),
						value: (0, s.validateType)("FlowType"),
						static: (0, s.validate)((0, s.assertValueType)("boolean")),
						variance: (0, s.validateOptionalType)("Variance")
					}
				}), i("ObjectTypeProperty", {
					visitor: [
						"key",
						"value",
						"variance"
					],
					aliases: ["UserWhitespacable"],
					fields: {
						key: (0, s.validateType)("Identifier", "StringLiteral"),
						value: (0, s.validateType)("FlowType"),
						kind: (0, s.validate)((0, s.assertOneOf)("init", "get", "set")),
						static: (0, s.validate)((0, s.assertValueType)("boolean")),
						proto: (0, s.validate)((0, s.assertValueType)("boolean")),
						optional: (0, s.validate)((0, s.assertValueType)("boolean")),
						variance: (0, s.validateOptionalType)("Variance"),
						method: (0, s.validate)((0, s.assertValueType)("boolean"))
					}
				}), i("ObjectTypeSpreadProperty", {
					visitor: ["argument"],
					aliases: ["UserWhitespacable"],
					fields: { argument: (0, s.validateType)("FlowType") }
				}), i("OpaqueType", {
					visitor: [
						"id",
						"typeParameters",
						"supertype",
						"impltype"
					],
					aliases: [
						"FlowDeclaration",
						"Statement",
						"Declaration"
					],
					fields: {
						id: (0, s.validateType)("Identifier"),
						typeParameters: (0, s.validateOptionalType)("TypeParameterDeclaration"),
						supertype: (0, s.validateOptionalType)("FlowType"),
						impltype: (0, s.validateType)("FlowType")
					}
				}), i("QualifiedTypeIdentifier", {
					visitor: ["qualification", "id"],
					builder: ["id", "qualification"],
					fields: {
						id: (0, s.validateType)("Identifier"),
						qualification: (0, s.validateType)("Identifier", "QualifiedTypeIdentifier")
					}
				}), i("StringLiteralTypeAnnotation", {
					builder: ["value"],
					aliases: ["FlowType"],
					fields: { value: (0, s.validate)((0, s.assertValueType)("string")) }
				}), i("StringTypeAnnotation", { aliases: ["FlowType", "FlowBaseAnnotation"] }), i("SymbolTypeAnnotation", { aliases: ["FlowType", "FlowBaseAnnotation"] }), i("ThisTypeAnnotation", { aliases: ["FlowType", "FlowBaseAnnotation"] }), i("TupleTypeAnnotation", {
					visitor: ["types"],
					aliases: ["FlowType"],
					fields: { types: (0, s.validate)((0, s.arrayOfType)("FlowType")) }
				}), i("TypeofTypeAnnotation", {
					visitor: ["argument"],
					aliases: ["FlowType"],
					fields: { argument: (0, s.validateType)("FlowType") }
				}), i("TypeAlias", {
					visitor: [
						"id",
						"typeParameters",
						"right"
					],
					aliases: [
						"FlowDeclaration",
						"Statement",
						"Declaration"
					],
					fields: {
						id: (0, s.validateType)("Identifier"),
						typeParameters: (0, s.validateOptionalType)("TypeParameterDeclaration"),
						right: (0, s.validateType)("FlowType")
					}
				}), i("TypeAnnotation", {
					visitor: ["typeAnnotation"],
					fields: { typeAnnotation: (0, s.validateType)("FlowType") }
				}), i("TypeCastExpression", {
					visitor: ["expression", "typeAnnotation"],
					aliases: ["ExpressionWrapper", "Expression"],
					fields: {
						expression: (0, s.validateType)("Expression"),
						typeAnnotation: (0, s.validateType)("TypeAnnotation")
					}
				}), i("TypeParameter", {
					visitor: [
						"bound",
						"default",
						"variance"
					],
					fields: {
						name: (0, s.validate)((0, s.assertValueType)("string")),
						bound: (0, s.validateOptionalType)("TypeAnnotation"),
						default: (0, s.validateOptionalType)("FlowType"),
						variance: (0, s.validateOptionalType)("Variance")
					}
				}), i("TypeParameterDeclaration", {
					visitor: ["params"],
					fields: { params: (0, s.validate)((0, s.arrayOfType)("TypeParameter")) }
				}), i("TypeParameterInstantiation", {
					visitor: ["params"],
					fields: { params: (0, s.validate)((0, s.arrayOfType)("FlowType")) }
				}), i("UnionTypeAnnotation", {
					visitor: ["types"],
					aliases: ["FlowType"],
					fields: { types: (0, s.validate)((0, s.arrayOfType)("FlowType")) }
				}), i("Variance", {
					builder: ["kind"],
					fields: { kind: (0, s.validate)((0, s.assertOneOf)("minus", "plus")) }
				}), i("VoidTypeAnnotation", { aliases: ["FlowType", "FlowBaseAnnotation"] }), i("EnumDeclaration", {
					aliases: ["Statement", "Declaration"],
					visitor: ["id", "body"],
					fields: {
						id: (0, s.validateType)("Identifier"),
						body: (0, s.validateType)("EnumBooleanBody", "EnumNumberBody", "EnumStringBody", "EnumSymbolBody")
					}
				}), i("EnumBooleanBody", {
					aliases: ["EnumBody"],
					visitor: ["members"],
					fields: {
						explicitType: (0, s.validate)((0, s.assertValueType)("boolean")),
						members: (0, s.validateArrayOfType)("EnumBooleanMember"),
						hasUnknownMembers: (0, s.validate)((0, s.assertValueType)("boolean"))
					}
				}), i("EnumNumberBody", {
					aliases: ["EnumBody"],
					visitor: ["members"],
					fields: {
						explicitType: (0, s.validate)((0, s.assertValueType)("boolean")),
						members: (0, s.validateArrayOfType)("EnumNumberMember"),
						hasUnknownMembers: (0, s.validate)((0, s.assertValueType)("boolean"))
					}
				}), i("EnumStringBody", {
					aliases: ["EnumBody"],
					visitor: ["members"],
					fields: {
						explicitType: (0, s.validate)((0, s.assertValueType)("boolean")),
						members: (0, s.validateArrayOfType)("EnumStringMember", "EnumDefaultedMember"),
						hasUnknownMembers: (0, s.validate)((0, s.assertValueType)("boolean"))
					}
				}), i("EnumSymbolBody", {
					aliases: ["EnumBody"],
					visitor: ["members"],
					fields: {
						members: (0, s.validateArrayOfType)("EnumDefaultedMember"),
						hasUnknownMembers: (0, s.validate)((0, s.assertValueType)("boolean"))
					}
				}), i("EnumBooleanMember", {
					aliases: ["EnumMember"],
					builder: ["id"],
					visitor: ["id", "init"],
					fields: {
						id: (0, s.validateType)("Identifier"),
						init: (0, s.validateType)("BooleanLiteral")
					}
				}), i("EnumNumberMember", {
					aliases: ["EnumMember"],
					visitor: ["id", "init"],
					fields: {
						id: (0, s.validateType)("Identifier"),
						init: (0, s.validateType)("NumericLiteral")
					}
				}), i("EnumStringMember", {
					aliases: ["EnumMember"],
					visitor: ["id", "init"],
					fields: {
						id: (0, s.validateType)("Identifier"),
						init: (0, s.validateType)("StringLiteral")
					}
				}), i("EnumDefaultedMember", {
					aliases: ["EnumMember"],
					visitor: ["id"],
					fields: { id: (0, s.validateType)("Identifier") }
				}), i("IndexedAccessType", {
					visitor: ["objectType", "indexType"],
					aliases: ["FlowType"],
					fields: {
						objectType: (0, s.validateType)("FlowType"),
						indexType: (0, s.validateType)("FlowType")
					}
				}), i("OptionalIndexedAccessType", {
					visitor: ["objectType", "indexType"],
					aliases: ["FlowType"],
					fields: {
						objectType: (0, s.validateType)("FlowType"),
						indexType: (0, s.validateType)("FlowType"),
						optional: (0, s.validate)((0, s.assertValueType)("boolean"))
					}
				});
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), Object.defineProperty(t, "ALIAS_KEYS", {
					enumerable: !0,
					get: function() {
						return n.ALIAS_KEYS;
					}
				}), Object.defineProperty(t, "BUILDER_KEYS", {
					enumerable: !0,
					get: function() {
						return n.BUILDER_KEYS;
					}
				}), Object.defineProperty(t, "DEPRECATED_ALIASES", {
					enumerable: !0,
					get: function() {
						return i.DEPRECATED_ALIASES;
					}
				}), Object.defineProperty(t, "DEPRECATED_KEYS", {
					enumerable: !0,
					get: function() {
						return n.DEPRECATED_KEYS;
					}
				}), Object.defineProperty(t, "FLIPPED_ALIAS_KEYS", {
					enumerable: !0,
					get: function() {
						return n.FLIPPED_ALIAS_KEYS;
					}
				}), Object.defineProperty(t, "NODE_FIELDS", {
					enumerable: !0,
					get: function() {
						return n.NODE_FIELDS;
					}
				}), Object.defineProperty(t, "NODE_PARENT_VALIDATIONS", {
					enumerable: !0,
					get: function() {
						return n.NODE_PARENT_VALIDATIONS;
					}
				}), Object.defineProperty(t, "PLACEHOLDERS", {
					enumerable: !0,
					get: function() {
						return s.PLACEHOLDERS;
					}
				}), Object.defineProperty(t, "PLACEHOLDERS_ALIAS", {
					enumerable: !0,
					get: function() {
						return s.PLACEHOLDERS_ALIAS;
					}
				}), Object.defineProperty(t, "PLACEHOLDERS_FLIPPED_ALIAS", {
					enumerable: !0,
					get: function() {
						return s.PLACEHOLDERS_FLIPPED_ALIAS;
					}
				}), t.TYPES = void 0, Object.defineProperty(t, "VISITOR_KEYS", {
					enumerable: !0,
					get: function() {
						return n.VISITOR_KEYS;
					}
				}), r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/core.js"), r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/flow.js"), r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/jsx.js"), r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/misc.js"), r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/experimental.js"), r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/typescript.js");
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/utils.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/placeholders.js"), i = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/deprecated-aliases.js");
				Object.keys(i.DEPRECATED_ALIASES).forEach((e) => {
					n.FLIPPED_ALIAS_KEYS[e] = n.FLIPPED_ALIAS_KEYS[i.DEPRECATED_ALIASES[e]];
				});
				for (const { types: e, set: t } of n.allExpandedTypes) for (const r of e) {
					const e = n.FLIPPED_ALIAS_KEYS[r];
					e ? e.forEach(t.add, t) : t.add(r);
				}
				t.TYPES = [].concat(Object.keys(n.VISITOR_KEYS), Object.keys(n.FLIPPED_ALIAS_KEYS), Object.keys(n.DEPRECATED_KEYS));
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/jsx.js": function(e, t, r) {
				"use strict";
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/utils.js");
				const s = (0, n.defineAliasedType)("JSX");
				s("JSXAttribute", {
					visitor: ["name", "value"],
					aliases: ["Immutable"],
					fields: {
						name: { validate: (0, n.assertNodeType)("JSXIdentifier", "JSXNamespacedName") },
						value: {
							optional: !0,
							validate: (0, n.assertNodeType)("JSXElement", "JSXFragment", "StringLiteral", "JSXExpressionContainer")
						}
					}
				}), s("JSXClosingElement", {
					visitor: ["name"],
					aliases: ["Immutable"],
					fields: { name: { validate: (0, n.assertNodeType)("JSXIdentifier", "JSXMemberExpression", "JSXNamespacedName") } }
				}), s("JSXElement", {
					builder: [
						"openingElement",
						"closingElement",
						"children",
						"selfClosing"
					],
					visitor: [
						"openingElement",
						"children",
						"closingElement"
					],
					aliases: ["Immutable", "Expression"],
					fields: Object.assign({
						openingElement: { validate: (0, n.assertNodeType)("JSXOpeningElement") },
						closingElement: {
							optional: !0,
							validate: (0, n.assertNodeType)("JSXClosingElement")
						},
						children: (0, n.validateArrayOfType)("JSXText", "JSXExpressionContainer", "JSXSpreadChild", "JSXElement", "JSXFragment")
					}, { selfClosing: {
						validate: (0, n.assertValueType)("boolean"),
						optional: !0
					} })
				}), s("JSXEmptyExpression", {}), s("JSXExpressionContainer", {
					visitor: ["expression"],
					aliases: ["Immutable"],
					fields: { expression: { validate: (0, n.assertNodeType)("Expression", "JSXEmptyExpression") } }
				}), s("JSXSpreadChild", {
					visitor: ["expression"],
					aliases: ["Immutable"],
					fields: { expression: { validate: (0, n.assertNodeType)("Expression") } }
				}), s("JSXIdentifier", {
					builder: ["name"],
					fields: { name: { validate: (0, n.assertValueType)("string") } }
				}), s("JSXMemberExpression", {
					visitor: ["object", "property"],
					fields: {
						object: { validate: (0, n.assertNodeType)("JSXMemberExpression", "JSXIdentifier") },
						property: { validate: (0, n.assertNodeType)("JSXIdentifier") }
					}
				}), s("JSXNamespacedName", {
					visitor: ["namespace", "name"],
					fields: {
						namespace: { validate: (0, n.assertNodeType)("JSXIdentifier") },
						name: { validate: (0, n.assertNodeType)("JSXIdentifier") }
					}
				}), s("JSXOpeningElement", {
					builder: [
						"name",
						"attributes",
						"selfClosing"
					],
					visitor: [
						"name",
						"typeParameters",
						"typeArguments",
						"attributes"
					],
					aliases: ["Immutable"],
					fields: Object.assign({
						name: { validate: (0, n.assertNodeType)("JSXIdentifier", "JSXMemberExpression", "JSXNamespacedName") },
						selfClosing: { default: !1 },
						attributes: (0, n.validateArrayOfType)("JSXAttribute", "JSXSpreadAttribute"),
						typeArguments: {
							validate: (0, n.assertNodeType)("TypeParameterInstantiation"),
							optional: !0
						}
					}, { typeParameters: {
						validate: (0, n.assertNodeType)("TSTypeParameterInstantiation"),
						optional: !0
					} })
				}), s("JSXSpreadAttribute", {
					visitor: ["argument"],
					fields: { argument: { validate: (0, n.assertNodeType)("Expression") } }
				}), s("JSXText", {
					aliases: ["Immutable"],
					builder: ["value"],
					fields: { value: { validate: (0, n.assertValueType)("string") } }
				}), s("JSXFragment", {
					builder: [
						"openingFragment",
						"closingFragment",
						"children"
					],
					visitor: [
						"openingFragment",
						"children",
						"closingFragment"
					],
					aliases: ["Immutable", "Expression"],
					fields: {
						openingFragment: { validate: (0, n.assertNodeType)("JSXOpeningFragment") },
						closingFragment: { validate: (0, n.assertNodeType)("JSXClosingFragment") },
						children: (0, n.validateArrayOfType)("JSXText", "JSXExpressionContainer", "JSXSpreadChild", "JSXElement", "JSXFragment")
					}
				}), s("JSXOpeningFragment", { aliases: ["Immutable"] }), s("JSXClosingFragment", { aliases: ["Immutable"] });
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/misc.js": function(e, t, r) {
				"use strict";
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/utils.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/placeholders.js"), i = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/core.js");
				const o = (0, n.defineAliasedType)("Miscellaneous");
				o("Noop", { visitor: [] }), o("Placeholder", {
					visitor: [],
					builder: ["expectedNode", "name"],
					fields: Object.assign({
						name: { validate: (0, n.assertNodeType)("Identifier") },
						expectedNode: { validate: (0, n.assertOneOf)(...s.PLACEHOLDERS) }
					}, (0, i.patternLikeCommon)())
				}), o("V8IntrinsicIdentifier", {
					builder: ["name"],
					fields: { name: { validate: (0, n.assertValueType)("string") } }
				});
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/placeholders.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.PLACEHOLDERS_FLIPPED_ALIAS = t.PLACEHOLDERS_ALIAS = t.PLACEHOLDERS = void 0;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/utils.js");
				const s = t.PLACEHOLDERS = [
					"Identifier",
					"StringLiteral",
					"Expression",
					"Statement",
					"Declaration",
					"BlockStatement",
					"ClassBody",
					"Pattern"
				], i = t.PLACEHOLDERS_ALIAS = {
					Declaration: ["Statement"],
					Pattern: ["PatternLike", "LVal"]
				};
				for (const e of s) {
					const t = n.ALIAS_KEYS[e];
					null != t && t.length && (i[e] = t);
				}
				const o = t.PLACEHOLDERS_FLIPPED_ALIAS = {};
				Object.keys(i).forEach((e) => {
					i[e].forEach((t) => {
						hasOwnProperty.call(o, t) || (o[t] = []), o[t].push(e);
					});
				});
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/typescript.js": function(e, t, r) {
				"use strict";
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/utils.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/core.js"), i = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/is.js");
				const o = (0, n.defineAliasedType)("TypeScript"), a = (0, n.assertValueType)("boolean"), tSFunctionTypeAnnotationCommon = () => ({
					returnType: {
						validate: (0, n.assertNodeType)("TSTypeAnnotation", "Noop"),
						optional: !0
					},
					typeParameters: {
						validate: (0, n.assertNodeType)("TSTypeParameterDeclaration", "Noop"),
						optional: !0
					}
				});
				o("TSParameterProperty", {
					aliases: ["LVal"],
					visitor: ["parameter"],
					fields: {
						accessibility: {
							validate: (0, n.assertOneOf)("public", "private", "protected"),
							optional: !0
						},
						readonly: {
							validate: (0, n.assertValueType)("boolean"),
							optional: !0
						},
						parameter: { validate: (0, n.assertNodeType)("Identifier", "AssignmentPattern") },
						override: {
							validate: (0, n.assertValueType)("boolean"),
							optional: !0
						},
						decorators: {
							validate: (0, n.arrayOfType)("Decorator"),
							optional: !0
						}
					}
				}), o("TSDeclareFunction", {
					aliases: ["Statement", "Declaration"],
					visitor: [
						"id",
						"typeParameters",
						"params",
						"returnType"
					],
					fields: Object.assign({}, (0, s.functionDeclarationCommon)(), tSFunctionTypeAnnotationCommon())
				}), o("TSDeclareMethod", {
					visitor: [
						"decorators",
						"key",
						"typeParameters",
						"params",
						"returnType"
					],
					fields: Object.assign({}, (0, s.classMethodOrDeclareMethodCommon)(), tSFunctionTypeAnnotationCommon())
				}), o("TSQualifiedName", {
					aliases: ["TSEntityName"],
					visitor: ["left", "right"],
					fields: {
						left: (0, n.validateType)("TSEntityName"),
						right: (0, n.validateType)("Identifier")
					}
				});
				const signatureDeclarationCommon = () => ({
					typeParameters: (0, n.validateOptionalType)("TSTypeParameterDeclaration"),
					parameters: (0, n.validateArrayOfType)("ArrayPattern", "Identifier", "ObjectPattern", "RestElement"),
					typeAnnotation: (0, n.validateOptionalType)("TSTypeAnnotation")
				}), l = {
					aliases: ["TSTypeElement"],
					visitor: [
						"typeParameters",
						"parameters",
						"typeAnnotation"
					],
					fields: signatureDeclarationCommon()
				};
				o("TSCallSignatureDeclaration", l), o("TSConstructSignatureDeclaration", l);
				const namedTypeElementCommon = () => ({
					key: (0, n.validateType)("Expression"),
					computed: { default: !1 },
					optional: (0, n.validateOptional)(a)
				});
				o("TSPropertySignature", {
					aliases: ["TSTypeElement"],
					visitor: ["key", "typeAnnotation"],
					fields: Object.assign({}, namedTypeElementCommon(), {
						readonly: (0, n.validateOptional)(a),
						typeAnnotation: (0, n.validateOptionalType)("TSTypeAnnotation"),
						kind: {
							optional: !0,
							validate: (0, n.assertOneOf)("get", "set")
						}
					})
				}), o("TSMethodSignature", {
					aliases: ["TSTypeElement"],
					visitor: [
						"key",
						"typeParameters",
						"parameters",
						"typeAnnotation"
					],
					fields: Object.assign({}, signatureDeclarationCommon(), namedTypeElementCommon(), { kind: { validate: (0, n.assertOneOf)("method", "get", "set") } })
				}), o("TSIndexSignature", {
					aliases: ["TSTypeElement"],
					visitor: ["parameters", "typeAnnotation"],
					fields: {
						readonly: (0, n.validateOptional)(a),
						static: (0, n.validateOptional)(a),
						parameters: (0, n.validateArrayOfType)("Identifier"),
						typeAnnotation: (0, n.validateOptionalType)("TSTypeAnnotation")
					}
				});
				for (const e of [
					"TSAnyKeyword",
					"TSBooleanKeyword",
					"TSBigIntKeyword",
					"TSIntrinsicKeyword",
					"TSNeverKeyword",
					"TSNullKeyword",
					"TSNumberKeyword",
					"TSObjectKeyword",
					"TSStringKeyword",
					"TSSymbolKeyword",
					"TSUndefinedKeyword",
					"TSUnknownKeyword",
					"TSVoidKeyword"
				]) o(e, {
					aliases: ["TSType", "TSBaseType"],
					visitor: [],
					fields: {}
				});
				o("TSThisType", {
					aliases: ["TSType", "TSBaseType"],
					visitor: [],
					fields: {}
				});
				const c = {
					aliases: ["TSType"],
					visitor: [
						"typeParameters",
						"parameters",
						"typeAnnotation"
					]
				};
				o("TSFunctionType", Object.assign({}, c, { fields: signatureDeclarationCommon() })), o("TSConstructorType", Object.assign({}, c, { fields: Object.assign({}, signatureDeclarationCommon(), { abstract: (0, n.validateOptional)(a) }) })), o("TSTypeReference", {
					aliases: ["TSType"],
					visitor: ["typeName", "typeParameters"],
					fields: {
						typeName: (0, n.validateType)("TSEntityName"),
						typeParameters: (0, n.validateOptionalType)("TSTypeParameterInstantiation")
					}
				}), o("TSTypePredicate", {
					aliases: ["TSType"],
					visitor: ["parameterName", "typeAnnotation"],
					builder: [
						"parameterName",
						"typeAnnotation",
						"asserts"
					],
					fields: {
						parameterName: (0, n.validateType)("Identifier", "TSThisType"),
						typeAnnotation: (0, n.validateOptionalType)("TSTypeAnnotation"),
						asserts: (0, n.validateOptional)(a)
					}
				}), o("TSTypeQuery", {
					aliases: ["TSType"],
					visitor: ["exprName", "typeParameters"],
					fields: {
						exprName: (0, n.validateType)("TSEntityName", "TSImportType"),
						typeParameters: (0, n.validateOptionalType)("TSTypeParameterInstantiation")
					}
				}), o("TSTypeLiteral", {
					aliases: ["TSType"],
					visitor: ["members"],
					fields: { members: (0, n.validateArrayOfType)("TSTypeElement") }
				}), o("TSArrayType", {
					aliases: ["TSType"],
					visitor: ["elementType"],
					fields: { elementType: (0, n.validateType)("TSType") }
				}), o("TSTupleType", {
					aliases: ["TSType"],
					visitor: ["elementTypes"],
					fields: { elementTypes: (0, n.validateArrayOfType)("TSType", "TSNamedTupleMember") }
				}), o("TSOptionalType", {
					aliases: ["TSType"],
					visitor: ["typeAnnotation"],
					fields: { typeAnnotation: (0, n.validateType)("TSType") }
				}), o("TSRestType", {
					aliases: ["TSType"],
					visitor: ["typeAnnotation"],
					fields: { typeAnnotation: (0, n.validateType)("TSType") }
				}), o("TSNamedTupleMember", {
					visitor: ["label", "elementType"],
					builder: [
						"label",
						"elementType",
						"optional"
					],
					fields: {
						label: (0, n.validateType)("Identifier"),
						optional: {
							validate: a,
							default: !1
						},
						elementType: (0, n.validateType)("TSType")
					}
				});
				const u = {
					aliases: ["TSType"],
					visitor: ["types"],
					fields: { types: (0, n.validateArrayOfType)("TSType") }
				};
				o("TSUnionType", u), o("TSIntersectionType", u), o("TSConditionalType", {
					aliases: ["TSType"],
					visitor: [
						"checkType",
						"extendsType",
						"trueType",
						"falseType"
					],
					fields: {
						checkType: (0, n.validateType)("TSType"),
						extendsType: (0, n.validateType)("TSType"),
						trueType: (0, n.validateType)("TSType"),
						falseType: (0, n.validateType)("TSType")
					}
				}), o("TSInferType", {
					aliases: ["TSType"],
					visitor: ["typeParameter"],
					fields: { typeParameter: (0, n.validateType)("TSTypeParameter") }
				}), o("TSParenthesizedType", {
					aliases: ["TSType"],
					visitor: ["typeAnnotation"],
					fields: { typeAnnotation: (0, n.validateType)("TSType") }
				}), o("TSTypeOperator", {
					aliases: ["TSType"],
					visitor: ["typeAnnotation"],
					builder: ["typeAnnotation", "operator"],
					fields: {
						operator: {
							validate: (0, n.assertValueType)("string"),
							default: "keyof"
						},
						typeAnnotation: (0, n.validateType)("TSType")
					}
				}), o("TSIndexedAccessType", {
					aliases: ["TSType"],
					visitor: ["objectType", "indexType"],
					fields: {
						objectType: (0, n.validateType)("TSType"),
						indexType: (0, n.validateType)("TSType")
					}
				}), o("TSMappedType", {
					aliases: ["TSType"],
					visitor: [
						"typeParameter",
						"nameType",
						"typeAnnotation"
					],
					builder: [
						"typeParameter",
						"typeAnnotation",
						"nameType"
					],
					fields: Object.assign({}, { typeParameter: (0, n.validateType)("TSTypeParameter") }, {
						readonly: (0, n.validateOptional)((0, n.assertOneOf)(!0, !1, "+", "-")),
						optional: (0, n.validateOptional)((0, n.assertOneOf)(!0, !1, "+", "-")),
						typeAnnotation: (0, n.validateOptionalType)("TSType"),
						nameType: (0, n.validateOptionalType)("TSType")
					})
				}), o("TSTemplateLiteralType", {
					aliases: ["TSType", "TSBaseType"],
					visitor: ["quasis", "types"],
					fields: {
						quasis: (0, n.validateArrayOfType)("TemplateElement"),
						types: { validate: (0, n.chain)((0, n.assertValueType)("array"), (0, n.assertEach)((0, n.assertNodeType)("TSType")), function(e, t, r) {
							if (e.quasis.length !== r.length + 1) throw new TypeError(`Number of ${e.type} quasis should be exactly one more than the number of types.\nExpected ${r.length + 1} quasis but got ${e.quasis.length}`);
						}) }
					}
				}), o("TSLiteralType", {
					aliases: ["TSType", "TSBaseType"],
					visitor: ["literal"],
					fields: { literal: { validate: function() {
						const e = (0, n.assertNodeType)("NumericLiteral", "BigIntLiteral"), t = (0, n.assertOneOf)("-"), r = (0, n.assertNodeType)("NumericLiteral", "StringLiteral", "BooleanLiteral", "BigIntLiteral", "TemplateLiteral");
						function validator(n, s, o) {
							(0, i.default)("UnaryExpression", o) ? (t(o, "operator", o.operator), e(o, "argument", o.argument)) : r(n, s, o);
						}
						return validator.oneOfNodeTypes = [
							"NumericLiteral",
							"StringLiteral",
							"BooleanLiteral",
							"BigIntLiteral",
							"TemplateLiteral",
							"UnaryExpression"
						], validator;
					}() } }
				}), o("TSExpressionWithTypeArguments", {
					aliases: ["TSType"],
					visitor: ["expression", "typeParameters"],
					fields: {
						expression: (0, n.validateType)("TSEntityName"),
						typeParameters: (0, n.validateOptionalType)("TSTypeParameterInstantiation")
					}
				}), o("TSInterfaceDeclaration", {
					aliases: ["Statement", "Declaration"],
					visitor: [
						"id",
						"typeParameters",
						"extends",
						"body"
					],
					fields: {
						declare: (0, n.validateOptional)(a),
						id: (0, n.validateType)("Identifier"),
						typeParameters: (0, n.validateOptionalType)("TSTypeParameterDeclaration"),
						extends: (0, n.validateOptional)((0, n.arrayOfType)("TSExpressionWithTypeArguments")),
						body: (0, n.validateType)("TSInterfaceBody")
					}
				}), o("TSInterfaceBody", {
					visitor: ["body"],
					fields: { body: (0, n.validateArrayOfType)("TSTypeElement") }
				}), o("TSTypeAliasDeclaration", {
					aliases: ["Statement", "Declaration"],
					visitor: [
						"id",
						"typeParameters",
						"typeAnnotation"
					],
					fields: {
						declare: (0, n.validateOptional)(a),
						id: (0, n.validateType)("Identifier"),
						typeParameters: (0, n.validateOptionalType)("TSTypeParameterDeclaration"),
						typeAnnotation: (0, n.validateType)("TSType")
					}
				}), o("TSInstantiationExpression", {
					aliases: ["Expression"],
					visitor: ["expression", "typeParameters"],
					fields: {
						expression: (0, n.validateType)("Expression"),
						typeParameters: (0, n.validateOptionalType)("TSTypeParameterInstantiation")
					}
				});
				const d = {
					aliases: [
						"Expression",
						"LVal",
						"PatternLike"
					],
					visitor: ["expression", "typeAnnotation"],
					fields: {
						expression: (0, n.validateType)("Expression"),
						typeAnnotation: (0, n.validateType)("TSType")
					}
				};
				o("TSAsExpression", d), o("TSSatisfiesExpression", d), o("TSTypeAssertion", {
					aliases: [
						"Expression",
						"LVal",
						"PatternLike"
					],
					visitor: ["typeAnnotation", "expression"],
					fields: {
						typeAnnotation: (0, n.validateType)("TSType"),
						expression: (0, n.validateType)("Expression")
					}
				}), o("TSEnumBody", {
					visitor: ["members"],
					fields: { members: (0, n.validateArrayOfType)("TSEnumMember") }
				}), o("TSEnumDeclaration", {
					aliases: ["Statement", "Declaration"],
					visitor: ["id", "members"],
					fields: {
						declare: (0, n.validateOptional)(a),
						const: (0, n.validateOptional)(a),
						id: (0, n.validateType)("Identifier"),
						members: (0, n.validateArrayOfType)("TSEnumMember"),
						initializer: (0, n.validateOptionalType)("Expression"),
						body: (0, n.validateOptionalType)("TSEnumBody")
					}
				}), o("TSEnumMember", {
					visitor: ["id", "initializer"],
					fields: {
						id: (0, n.validateType)("Identifier", "StringLiteral"),
						initializer: (0, n.validateOptionalType)("Expression")
					}
				}), o("TSModuleDeclaration", {
					aliases: ["Statement", "Declaration"],
					visitor: ["id", "body"],
					fields: Object.assign({
						kind: { validate: (0, n.assertOneOf)("global", "module", "namespace") },
						declare: (0, n.validateOptional)(a)
					}, { global: (0, n.validateOptional)(a) }, {
						id: (0, n.validateType)("Identifier", "StringLiteral"),
						body: (0, n.validateType)("TSModuleBlock", "TSModuleDeclaration")
					})
				}), o("TSModuleBlock", {
					aliases: [
						"Scopable",
						"Block",
						"BlockParent",
						"FunctionParent"
					],
					visitor: ["body"],
					fields: { body: (0, n.validateArrayOfType)("Statement") }
				}), o("TSImportType", {
					aliases: ["TSType"],
					builder: [
						"argument",
						"qualifier",
						"typeParameters"
					],
					visitor: [
						"argument",
						"options",
						"qualifier",
						"typeParameters"
					],
					fields: {
						argument: (0, n.validateType)("StringLiteral"),
						qualifier: (0, n.validateOptionalType)("TSEntityName"),
						typeParameters: (0, n.validateOptionalType)("TSTypeParameterInstantiation"),
						options: {
							validate: (0, n.assertNodeType)("ObjectExpression"),
							optional: !0
						}
					}
				}), o("TSImportEqualsDeclaration", {
					aliases: ["Statement", "Declaration"],
					visitor: ["id", "moduleReference"],
					fields: Object.assign({}, { isExport: (0, n.validate)(a) }, {
						id: (0, n.validateType)("Identifier"),
						moduleReference: (0, n.validateType)("TSEntityName", "TSExternalModuleReference"),
						importKind: {
							validate: (0, n.assertOneOf)("type", "value"),
							optional: !0
						}
					})
				}), o("TSExternalModuleReference", {
					visitor: ["expression"],
					fields: { expression: (0, n.validateType)("StringLiteral") }
				}), o("TSNonNullExpression", {
					aliases: [
						"Expression",
						"LVal",
						"PatternLike"
					],
					visitor: ["expression"],
					fields: { expression: (0, n.validateType)("Expression") }
				}), o("TSExportAssignment", {
					aliases: ["Statement"],
					visitor: ["expression"],
					fields: { expression: (0, n.validateType)("Expression") }
				}), o("TSNamespaceExportDeclaration", {
					aliases: ["Statement"],
					visitor: ["id"],
					fields: { id: (0, n.validateType)("Identifier") }
				}), o("TSTypeAnnotation", {
					visitor: ["typeAnnotation"],
					fields: { typeAnnotation: { validate: (0, n.assertNodeType)("TSType") } }
				}), o("TSTypeParameterInstantiation", {
					visitor: ["params"],
					fields: { params: (0, n.validateArrayOfType)("TSType") }
				}), o("TSTypeParameterDeclaration", {
					visitor: ["params"],
					fields: { params: (0, n.validateArrayOfType)("TSTypeParameter") }
				}), o("TSTypeParameter", {
					builder: [
						"constraint",
						"default",
						"name"
					],
					visitor: ["constraint", "default"],
					fields: {
						name: { validate: (0, n.assertValueType)("string") },
						in: {
							validate: (0, n.assertValueType)("boolean"),
							optional: !0
						},
						out: {
							validate: (0, n.assertValueType)("boolean"),
							optional: !0
						},
						const: {
							validate: (0, n.assertValueType)("boolean"),
							optional: !0
						},
						constraint: {
							validate: (0, n.assertNodeType)("TSType"),
							optional: !0
						},
						default: {
							validate: (0, n.assertNodeType)("TSType"),
							optional: !0
						}
					}
				});
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/utils.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.allExpandedTypes = t.VISITOR_KEYS = t.NODE_PARENT_VALIDATIONS = t.NODE_FIELDS = t.FLIPPED_ALIAS_KEYS = t.DEPRECATED_KEYS = t.BUILDER_KEYS = t.ALIAS_KEYS = void 0, t.arrayOf = arrayOf, t.arrayOfType = arrayOfType, t.assertEach = assertEach, t.assertNodeOrValueType = function(...e) {
					function validate(t, r, i) {
						const o = getType(i);
						for (const a of e) if (o === a || (0, n.default)(a, i)) return void (0, s.validateChild)(t, r, i);
						throw new TypeError(`Property ${r} of ${t.type} expected node to be of a type ${JSON.stringify(e)} but instead got ${JSON.stringify(null == i ? void 0 : i.type)}`);
					}
					return validate.oneOfNodeOrValueTypes = e, validate;
				}, t.assertNodeType = assertNodeType, t.assertOneOf = function(...e) {
					function validate(t, r, n) {
						if (!e.includes(n)) throw new TypeError(`Property ${r} expected value to be one of ${JSON.stringify(e)} but got ${JSON.stringify(n)}`);
					}
					return validate.oneOf = e, validate;
				}, t.assertOptionalChainStart = function() {
					return function(e) {
						var t;
						let r = e;
						for (; e;) {
							const { type: e } = r;
							if ("OptionalCallExpression" !== e) {
								if ("OptionalMemberExpression" !== e) break;
								if (r.optional) return;
								r = r.object;
							} else {
								if (r.optional) return;
								r = r.callee;
							}
						}
						throw new TypeError(`Non-optional ${e.type} must chain from an optional OptionalMemberExpression or OptionalCallExpression. Found chain from ${null == (t = r) ? void 0 : t.type}`);
					};
				}, t.assertShape = function(e) {
					const t = Object.keys(e);
					function validate(r, n, i) {
						const o = [];
						for (const n of t) try {
							(0, s.validateField)(r, n, i[n], e[n]);
						} catch (e) {
							if (e instanceof TypeError) {
								o.push(e.message);
								continue;
							}
							throw e;
						}
						if (o.length) throw new TypeError(`Property ${n} of ${r.type} expected to have the following:\n${o.join("\n")}`);
					}
					return validate.shapeOf = e, validate;
				}, t.assertValueType = assertValueType, t.chain = chain, t.default = defineType, t.defineAliasedType = function(...e) {
					return (t, r = {}) => {
						let n = r.aliases;
						var s;
						n || (r.inherits && (n = null == (s = f[r.inherits].aliases) ? void 0 : s.slice()), n ?? (n = []), r.aliases = n);
						const i = e.filter((e) => !n.includes(e));
						n.unshift(...i), defineType(t, r);
					};
				}, t.validate = validate, t.validateArrayOfType = function(...e) {
					return validate(arrayOfType(...e));
				}, t.validateOptional = function(e) {
					return {
						validate: e,
						optional: !0
					};
				}, t.validateOptionalType = function(...e) {
					return {
						validate: assertNodeType(...e),
						optional: !0
					};
				}, t.validateType = function(...e) {
					return validate(assertNodeType(...e));
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/is.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/validate.js");
				const i = t.VISITOR_KEYS = {}, o = t.ALIAS_KEYS = {}, a = t.FLIPPED_ALIAS_KEYS = {}, l = t.NODE_FIELDS = {}, p = t.BUILDER_KEYS = {}, c = t.DEPRECATED_KEYS = {}, u = t.NODE_PARENT_VALIDATIONS = {};
				function getType(e) {
					return Array.isArray(e) ? "array" : null === e ? "null" : typeof e;
				}
				function validate(e) {
					return { validate: e };
				}
				function arrayOf(e) {
					return chain(assertValueType("array"), assertEach(e));
				}
				function arrayOfType(...e) {
					return arrayOf(assertNodeType(...e));
				}
				function assertEach(e) {
					const t = process.env.BABEL_TYPES_8_BREAKING ? s.validateChild : () => {};
					function validator(r, n, s) {
						if (!Array.isArray(s)) return;
						let i = 0;
						const o = { toString: () => `${n}[${i}]` };
						for (; i < s.length; i++) {
							const n = s[i];
							e(r, o, n), t(r, o, n);
						}
					}
					return validator.each = e, validator;
				}
				const d = t.allExpandedTypes = [];
				function assertNodeType(...e) {
					const t = /* @__PURE__ */ new Set();
					function validate(r, i, o) {
						const a = null == o ? void 0 : o.type;
						if (null != a) {
							if (t.has(a)) return void (0, s.validateChild)(r, i, o);
							if ("Placeholder" === a) {
								for (const t of e) if ((0, n.default)(t, o)) return void (0, s.validateChild)(r, i, o);
							}
						}
						throw new TypeError(`Property ${i} of ${r.type} expected node to be of a type ${JSON.stringify(e)} but instead got ${JSON.stringify(a)}`);
					}
					return d.push({
						types: e,
						set: t
					}), validate.oneOfNodeTypes = e, validate;
				}
				function assertValueType(e) {
					function validate(t, r, n) {
						if (getType(n) !== e) throw new TypeError(`Property ${r} expected type of ${e} but got ${getType(n)}`);
					}
					return validate.type = e, validate;
				}
				function chain(...e) {
					function validate(...t) {
						for (const r of e) r(...t);
					}
					if (validate.chainOf = e, e.length >= 2 && "type" in e[0] && "array" === e[0].type && !("each" in e[1])) throw new Error("An assertValueType(\"array\") validator can only be followed by an assertEach(...) validator.");
					return validate;
				}
				const h = new Set([
					"aliases",
					"builder",
					"deprecatedAlias",
					"fields",
					"inherits",
					"visitor",
					"validate"
				]), m = new Set([
					"default",
					"optional",
					"deprecated",
					"validate"
				]), f = {};
				function defineType(e, t = {}) {
					const r = t.inherits && f[t.inherits] || {};
					let n = t.fields;
					if (!n && (n = {}, r.fields)) {
						const e = Object.getOwnPropertyNames(r.fields);
						for (const t of e) {
							const e = r.fields[t], s = e.default;
							if (Array.isArray(s) ? s.length > 0 : s && "object" == typeof s) throw new Error("field defaults can only be primitives or empty arrays currently");
							n[t] = {
								default: Array.isArray(s) ? [] : s,
								optional: e.optional,
								deprecated: e.deprecated,
								validate: e.validate
							};
						}
					}
					const s = t.visitor || r.visitor || [], d = t.aliases || r.aliases || [], y = t.builder || r.builder || t.visitor || [];
					for (const r of Object.keys(t)) if (!h.has(r)) throw new Error(`Unknown type option "${r}" on ${e}`);
					t.deprecatedAlias && (c[t.deprecatedAlias] = e);
					for (const e of s.concat(y)) n[e] = n[e] || {};
					for (const t of Object.keys(n)) {
						const r = n[t];
						void 0 === r.default || y.includes(t) || (r.optional = !0), void 0 === r.default ? r.default = null : r.validate || null == r.default || (r.validate = assertValueType(getType(r.default)));
						for (const n of Object.keys(r)) if (!m.has(n)) throw new Error(`Unknown field key "${n}" on ${e}.${t}`);
					}
					i[e] = t.visitor = s, p[e] = t.builder = y, l[e] = t.fields = n, o[e] = t.aliases = d, d.forEach((t) => {
						a[t] = a[t] || [], a[t].push(e);
					}), t.validate && (u[e] = t.validate), f[e] = t;
				}
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 });
				var n = {
					react: !0,
					assertNode: !0,
					createTypeAnnotationBasedOnTypeof: !0,
					createUnionTypeAnnotation: !0,
					createFlowUnionType: !0,
					createTSUnionType: !0,
					cloneNode: !0,
					clone: !0,
					cloneDeep: !0,
					cloneDeepWithoutLoc: !0,
					cloneWithoutLoc: !0,
					addComment: !0,
					addComments: !0,
					inheritInnerComments: !0,
					inheritLeadingComments: !0,
					inheritsComments: !0,
					inheritTrailingComments: !0,
					removeComments: !0,
					ensureBlock: !0,
					toBindingIdentifierName: !0,
					toBlock: !0,
					toComputedKey: !0,
					toExpression: !0,
					toIdentifier: !0,
					toKeyAlias: !0,
					toStatement: !0,
					valueToNode: !0,
					appendToMemberExpression: !0,
					inherits: !0,
					prependToMemberExpression: !0,
					removeProperties: !0,
					removePropertiesDeep: !0,
					removeTypeDuplicates: !0,
					getAssignmentIdentifiers: !0,
					getBindingIdentifiers: !0,
					getOuterBindingIdentifiers: !0,
					getFunctionName: !0,
					traverse: !0,
					traverseFast: !0,
					shallowEqual: !0,
					is: !0,
					isBinding: !0,
					isBlockScoped: !0,
					isImmutable: !0,
					isLet: !0,
					isNode: !0,
					isNodesEquivalent: !0,
					isPlaceholderType: !0,
					isReferenced: !0,
					isScope: !0,
					isSpecifierDefault: !0,
					isType: !0,
					isValidES3Identifier: !0,
					isValidIdentifier: !0,
					isVar: !0,
					matchesPattern: !0,
					validate: !0,
					buildMatchMemberExpression: !0,
					__internal__deprecationWarning: !0
				};
				Object.defineProperty(t, "__internal__deprecationWarning", {
					enumerable: !0,
					get: function() {
						return ye.default;
					}
				}), Object.defineProperty(t, "addComment", {
					enumerable: !0,
					get: function() {
						return x.default;
					}
				}), Object.defineProperty(t, "addComments", {
					enumerable: !0,
					get: function() {
						return v.default;
					}
				}), Object.defineProperty(t, "appendToMemberExpression", {
					enumerable: !0,
					get: function() {
						return B.default;
					}
				}), Object.defineProperty(t, "assertNode", {
					enumerable: !0,
					get: function() {
						return a.default;
					}
				}), Object.defineProperty(t, "buildMatchMemberExpression", {
					enumerable: !0,
					get: function() {
						return me.default;
					}
				}), Object.defineProperty(t, "clone", {
					enumerable: !0,
					get: function() {
						return f.default;
					}
				}), Object.defineProperty(t, "cloneDeep", {
					enumerable: !0,
					get: function() {
						return y.default;
					}
				}), Object.defineProperty(t, "cloneDeepWithoutLoc", {
					enumerable: !0,
					get: function() {
						return b.default;
					}
				}), Object.defineProperty(t, "cloneNode", {
					enumerable: !0,
					get: function() {
						return m.default;
					}
				}), Object.defineProperty(t, "cloneWithoutLoc", {
					enumerable: !0,
					get: function() {
						return g.default;
					}
				}), Object.defineProperty(t, "createFlowUnionType", {
					enumerable: !0,
					get: function() {
						return c.default;
					}
				}), Object.defineProperty(t, "createTSUnionType", {
					enumerable: !0,
					get: function() {
						return u.default;
					}
				}), Object.defineProperty(t, "createTypeAnnotationBasedOnTypeof", {
					enumerable: !0,
					get: function() {
						return p.default;
					}
				}), Object.defineProperty(t, "createUnionTypeAnnotation", {
					enumerable: !0,
					get: function() {
						return c.default;
					}
				}), Object.defineProperty(t, "ensureBlock", {
					enumerable: !0,
					get: function() {
						return w.default;
					}
				}), Object.defineProperty(t, "getAssignmentIdentifiers", {
					enumerable: !0,
					get: function() {
						return W.default;
					}
				}), Object.defineProperty(t, "getBindingIdentifiers", {
					enumerable: !0,
					get: function() {
						return q.default;
					}
				}), Object.defineProperty(t, "getFunctionName", {
					enumerable: !0,
					get: function() {
						return z.default;
					}
				}), Object.defineProperty(t, "getOuterBindingIdentifiers", {
					enumerable: !0,
					get: function() {
						return H.default;
					}
				}), Object.defineProperty(t, "inheritInnerComments", {
					enumerable: !0,
					get: function() {
						return E.default;
					}
				}), Object.defineProperty(t, "inheritLeadingComments", {
					enumerable: !0,
					get: function() {
						return T.default;
					}
				}), Object.defineProperty(t, "inheritTrailingComments", {
					enumerable: !0,
					get: function() {
						return P.default;
					}
				}), Object.defineProperty(t, "inherits", {
					enumerable: !0,
					get: function() {
						return R.default;
					}
				}), Object.defineProperty(t, "inheritsComments", {
					enumerable: !0,
					get: function() {
						return S.default;
					}
				}), Object.defineProperty(t, "is", {
					enumerable: !0,
					get: function() {
						return Y.default;
					}
				}), Object.defineProperty(t, "isBinding", {
					enumerable: !0,
					get: function() {
						return Q.default;
					}
				}), Object.defineProperty(t, "isBlockScoped", {
					enumerable: !0,
					get: function() {
						return Z.default;
					}
				}), Object.defineProperty(t, "isImmutable", {
					enumerable: !0,
					get: function() {
						return ee.default;
					}
				}), Object.defineProperty(t, "isLet", {
					enumerable: !0,
					get: function() {
						return te.default;
					}
				}), Object.defineProperty(t, "isNode", {
					enumerable: !0,
					get: function() {
						return re.default;
					}
				}), Object.defineProperty(t, "isNodesEquivalent", {
					enumerable: !0,
					get: function() {
						return ne.default;
					}
				}), Object.defineProperty(t, "isPlaceholderType", {
					enumerable: !0,
					get: function() {
						return se.default;
					}
				}), Object.defineProperty(t, "isReferenced", {
					enumerable: !0,
					get: function() {
						return ie.default;
					}
				}), Object.defineProperty(t, "isScope", {
					enumerable: !0,
					get: function() {
						return oe.default;
					}
				}), Object.defineProperty(t, "isSpecifierDefault", {
					enumerable: !0,
					get: function() {
						return ae.default;
					}
				}), Object.defineProperty(t, "isType", {
					enumerable: !0,
					get: function() {
						return le.default;
					}
				}), Object.defineProperty(t, "isValidES3Identifier", {
					enumerable: !0,
					get: function() {
						return pe.default;
					}
				}), Object.defineProperty(t, "isValidIdentifier", {
					enumerable: !0,
					get: function() {
						return ce.default;
					}
				}), Object.defineProperty(t, "isVar", {
					enumerable: !0,
					get: function() {
						return ue.default;
					}
				}), Object.defineProperty(t, "matchesPattern", {
					enumerable: !0,
					get: function() {
						return de.default;
					}
				}), Object.defineProperty(t, "prependToMemberExpression", {
					enumerable: !0,
					get: function() {
						return U.default;
					}
				}), t.react = void 0, Object.defineProperty(t, "removeComments", {
					enumerable: !0,
					get: function() {
						return _.default;
					}
				}), Object.defineProperty(t, "removeProperties", {
					enumerable: !0,
					get: function() {
						return V.default;
					}
				}), Object.defineProperty(t, "removePropertiesDeep", {
					enumerable: !0,
					get: function() {
						return $.default;
					}
				}), Object.defineProperty(t, "removeTypeDuplicates", {
					enumerable: !0,
					get: function() {
						return K.default;
					}
				}), Object.defineProperty(t, "shallowEqual", {
					enumerable: !0,
					get: function() {
						return J.default;
					}
				}), Object.defineProperty(t, "toBindingIdentifierName", {
					enumerable: !0,
					get: function() {
						return I.default;
					}
				}), Object.defineProperty(t, "toBlock", {
					enumerable: !0,
					get: function() {
						return D.default;
					}
				}), Object.defineProperty(t, "toComputedKey", {
					enumerable: !0,
					get: function() {
						return k.default;
					}
				}), Object.defineProperty(t, "toExpression", {
					enumerable: !0,
					get: function() {
						return N.default;
					}
				}), Object.defineProperty(t, "toIdentifier", {
					enumerable: !0,
					get: function() {
						return O.default;
					}
				}), Object.defineProperty(t, "toKeyAlias", {
					enumerable: !0,
					get: function() {
						return j.default;
					}
				}), Object.defineProperty(t, "toStatement", {
					enumerable: !0,
					get: function() {
						return F.default;
					}
				}), Object.defineProperty(t, "traverse", {
					enumerable: !0,
					get: function() {
						return G.default;
					}
				}), Object.defineProperty(t, "traverseFast", {
					enumerable: !0,
					get: function() {
						return X.default;
					}
				}), Object.defineProperty(t, "validate", {
					enumerable: !0,
					get: function() {
						return he.default;
					}
				}), Object.defineProperty(t, "valueToNode", {
					enumerable: !0,
					get: function() {
						return L.default;
					}
				});
				var s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/react/isReactComponent.js"), i = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/react/isCompatTag.js"), o = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/react/buildChildren.js"), a = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/asserts/assertNode.js"), l = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/asserts/generated/index.js");
				Object.keys(l).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (Object.prototype.hasOwnProperty.call(n, e) || e in t && t[e] === l[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return l[e];
						}
					}));
				});
				var p = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/flow/createTypeAnnotationBasedOnTypeof.js"), c = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/flow/createFlowUnionType.js"), u = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/typescript/createTSUnionType.js"), d = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/productions.js");
				Object.keys(d).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (Object.prototype.hasOwnProperty.call(n, e) || e in t && t[e] === d[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return d[e];
						}
					}));
				});
				var h = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js");
				Object.keys(h).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (Object.prototype.hasOwnProperty.call(n, e) || e in t && t[e] === h[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return h[e];
						}
					}));
				});
				var m = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneNode.js"), f = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/clone.js"), y = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneDeep.js"), b = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneDeepWithoutLoc.js"), g = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/clone/cloneWithoutLoc.js"), x = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/addComment.js"), v = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/addComments.js"), E = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritInnerComments.js"), T = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritLeadingComments.js"), S = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritsComments.js"), P = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritTrailingComments.js"), _ = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/removeComments.js"), A = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/constants/generated/index.js");
				Object.keys(A).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (Object.prototype.hasOwnProperty.call(n, e) || e in t && t[e] === A[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return A[e];
						}
					}));
				});
				var C = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/constants/index.js");
				Object.keys(C).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (Object.prototype.hasOwnProperty.call(n, e) || e in t && t[e] === C[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return C[e];
						}
					}));
				});
				var w = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/ensureBlock.js"), I = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toBindingIdentifierName.js"), D = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toBlock.js"), k = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toComputedKey.js"), N = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toExpression.js"), O = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toIdentifier.js"), j = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toKeyAlias.js"), F = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toStatement.js"), L = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/valueToNode.js"), M = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js");
				Object.keys(M).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (Object.prototype.hasOwnProperty.call(n, e) || e in t && t[e] === M[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return M[e];
						}
					}));
				});
				var B = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/appendToMemberExpression.js"), R = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/inherits.js"), U = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/prependToMemberExpression.js"), V = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/removeProperties.js"), $ = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/removePropertiesDeep.js"), K = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/flow/removeTypeDuplicates.js"), W = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/retrievers/getAssignmentIdentifiers.js"), q = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/retrievers/getBindingIdentifiers.js"), H = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/retrievers/getOuterBindingIdentifiers.js"), z = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/retrievers/getFunctionName.js"), G = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/traverse/traverse.js");
				Object.keys(G).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (Object.prototype.hasOwnProperty.call(n, e) || e in t && t[e] === G[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return G[e];
						}
					}));
				});
				var X = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/traverse/traverseFast.js"), J = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/shallowEqual.js"), Y = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/is.js"), Q = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isBinding.js"), Z = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isBlockScoped.js"), ee = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isImmutable.js"), te = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isLet.js"), re = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isNode.js"), ne = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isNodesEquivalent.js"), se = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isPlaceholderType.js"), ie = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isReferenced.js"), oe = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isScope.js"), ae = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isSpecifierDefault.js"), le = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isType.js"), pe = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isValidES3Identifier.js"), ce = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isValidIdentifier.js"), ue = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isVar.js"), de = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/matchesPattern.js"), he = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/validate.js"), me = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/buildMatchMemberExpression.js"), fe = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
				Object.keys(fe).forEach(function(e) {
					"default" !== e && "__esModule" !== e && (Object.prototype.hasOwnProperty.call(n, e) || e in t && t[e] === fe[e] || Object.defineProperty(t, e, {
						enumerable: !0,
						get: function() {
							return fe[e];
						}
					}));
				});
				var ye = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/deprecationWarning.js"), be = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/converters/toSequenceExpression.js");
				t.react = {
					isReactComponent: s.default,
					isCompatTag: i.default,
					buildChildren: o.default
				};
				t.toSequenceExpression = be.default, process.env.BABEL_TYPES_8_BREAKING && console.warn("BABEL_TYPES_8_BREAKING is not supported anymore. Use the latest Babel 8.0.0 pre-release instead!");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/appendToMemberExpression.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r = !1) {
					return e.object = (0, n.memberExpression)(e.object, e.property, e.computed), e.property = t, e.computed = !!r, e;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/flow/removeTypeDuplicates.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function removeTypeDuplicates(e) {
					const t = Array.from(e), r = /* @__PURE__ */ new Map(), s = /* @__PURE__ */ new Map(), i = /* @__PURE__ */ new Set(), o = [];
					for (let e = 0; e < t.length; e++) {
						const a = t[e];
						if (a && !o.includes(a)) {
							if ((0, n.isAnyTypeAnnotation)(a)) return [a];
							if ((0, n.isFlowBaseAnnotation)(a)) s.set(a.type, a);
							else if ((0, n.isUnionTypeAnnotation)(a)) i.has(a.types) || (t.push(...a.types), i.add(a.types));
							else {
								if ((0, n.isGenericTypeAnnotation)(a)) {
									const e = getQualifiedName(a.id);
									if (r.has(e)) {
										let t = r.get(e);
										t.typeParameters ? a.typeParameters && (t.typeParameters.params.push(...a.typeParameters.params), t.typeParameters.params = removeTypeDuplicates(t.typeParameters.params)) : t = a.typeParameters;
									} else r.set(e, a);
									continue;
								}
								o.push(a);
							}
						}
					}
					for (const [, e] of s) o.push(e);
					for (const [, e] of r) o.push(e);
					return o;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
				function getQualifiedName(e) {
					return (0, n.isIdentifier)(e) ? e.name : `${e.id.name}.${getQualifiedName(e.qualification)}`;
				}
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/inherits.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					if (!e || !t) return e;
					for (const r of n.INHERIT_KEYS.optional) e[r] ?? (e[r] = t[r]);
					for (const r of Object.keys(t)) "_" === r[0] && "__clone" !== r && (e[r] = t[r]);
					for (const r of n.INHERIT_KEYS.force) e[r] = t[r];
					return (0, s.default)(e, t), e;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/constants/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/comments/inheritsComments.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/prependToMemberExpression.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					if ((0, s.isSuper)(e.object)) throw new Error("Cannot prepend node to super property access (`super.foo`).");
					return e.object = (0, n.memberExpression)(t, e.object), e;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/removeProperties.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t = {}) {
					const r = t.preserveComments ? s : i;
					for (const t of r) null != e[t] && (e[t] = void 0);
					for (const t of Object.keys(e)) "_" === t[0] && null != e[t] && (e[t] = void 0);
					const n = Object.getOwnPropertySymbols(e);
					for (const t of n) e[t] = null;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/constants/index.js");
				const s = [
					"tokens",
					"start",
					"end",
					"loc",
					"raw",
					"rawValue"
				], i = [
					...n.COMMENT_KEYS,
					"comments",
					...s
				];
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/removePropertiesDeep.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					return (0, n.default)(e, s.default, t), e;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/traverse/traverseFast.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/removeProperties.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/modifications/typescript/removeTypeDuplicates.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function removeTypeDuplicates(e) {
					const t = Array.from(e), r = /* @__PURE__ */ new Map(), s = /* @__PURE__ */ new Map(), i = /* @__PURE__ */ new Set(), o = [];
					for (let e = 0; e < t.length; e++) {
						const a = t[e];
						if (!a) continue;
						if (o.includes(a)) continue;
						if ((0, n.isTSAnyKeyword)(a)) return [a];
						if ((0, n.isTSBaseType)(a)) {
							s.set(a.type, a);
							continue;
						}
						if ((0, n.isTSUnionType)(a)) {
							i.has(a.types) || (t.push(...a.types), i.add(a.types));
							continue;
						}
						const l = "typeParameters";
						if ((0, n.isTSTypeReference)(a) && a[l]) {
							const e = a[l], t = getQualifiedName(a.typeName);
							if (r.has(t)) {
								let n = r.get(t);
								const s = n[l];
								s ? (s.params.push(...e.params), s.params = removeTypeDuplicates(s.params)) : n = e;
							} else r.set(t, a);
							continue;
						}
						o.push(a);
					}
					for (const [, e] of s) o.push(e);
					for (const [, e] of r) o.push(e);
					return o;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
				function getQualifiedName(e) {
					return (0, n.isIdentifier)(e) ? e.name : (0, n.isThisExpression)(e) ? "this" : `${e.right.name}.${getQualifiedName(e.left)}`;
				}
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/retrievers/getAssignmentIdentifiers.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					const t = [].concat(e), r = Object.create(null);
					for (; t.length;) {
						const e = t.pop();
						if (e) switch (e.type) {
							case "ArrayPattern":
								t.push(...e.elements);
								break;
							case "AssignmentExpression":
							case "AssignmentPattern":
							case "ForInStatement":
							case "ForOfStatement":
								t.push(e.left);
								break;
							case "ObjectPattern":
								t.push(...e.properties);
								break;
							case "ObjectProperty":
								t.push(e.value);
								break;
							case "RestElement":
							case "UpdateExpression":
								t.push(e.argument);
								break;
							case "UnaryExpression":
								"delete" === e.operator && t.push(e.argument);
								break;
							case "Identifier": r[e.name] = e;
						}
					}
					return r;
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/retrievers/getBindingIdentifiers.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = getBindingIdentifiers;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
				function getBindingIdentifiers(e, t, r, s) {
					const i = [].concat(e), o = Object.create(null);
					for (; i.length;) {
						const e = i.shift();
						if (!e) continue;
						if (s && ((0, n.isAssignmentExpression)(e) || (0, n.isUnaryExpression)(e) || (0, n.isUpdateExpression)(e))) continue;
						if ((0, n.isIdentifier)(e)) {
							if (t) (o[e.name] = o[e.name] || []).push(e);
							else o[e.name] = e;
							continue;
						}
						if ((0, n.isExportDeclaration)(e) && !(0, n.isExportAllDeclaration)(e)) {
							(0, n.isDeclaration)(e.declaration) && i.push(e.declaration);
							continue;
						}
						if (r) {
							if ((0, n.isFunctionDeclaration)(e)) {
								i.push(e.id);
								continue;
							}
							if ((0, n.isFunctionExpression)(e)) continue;
						}
						const a = getBindingIdentifiers.keys[e.type];
						if (a) for (let t = 0; t < a.length; t++) {
							const r = e[a[t]];
							r && (Array.isArray(r) ? i.push(...r) : i.push(r));
						}
					}
					return o;
				}
				getBindingIdentifiers.keys = {
					DeclareClass: ["id"],
					DeclareFunction: ["id"],
					DeclareModule: ["id"],
					DeclareVariable: ["id"],
					DeclareInterface: ["id"],
					DeclareTypeAlias: ["id"],
					DeclareOpaqueType: ["id"],
					InterfaceDeclaration: ["id"],
					TypeAlias: ["id"],
					OpaqueType: ["id"],
					CatchClause: ["param"],
					LabeledStatement: ["label"],
					UnaryExpression: ["argument"],
					AssignmentExpression: ["left"],
					ImportSpecifier: ["local"],
					ImportNamespaceSpecifier: ["local"],
					ImportDefaultSpecifier: ["local"],
					ImportDeclaration: ["specifiers"],
					TSImportEqualsDeclaration: ["id"],
					ExportSpecifier: ["exported"],
					ExportNamespaceSpecifier: ["exported"],
					ExportDefaultSpecifier: ["exported"],
					FunctionDeclaration: ["id", "params"],
					FunctionExpression: ["id", "params"],
					ArrowFunctionExpression: ["params"],
					ObjectMethod: ["params"],
					ClassMethod: ["params"],
					ClassPrivateMethod: ["params"],
					ForInStatement: ["left"],
					ForOfStatement: ["left"],
					ClassDeclaration: ["id"],
					ClassExpression: ["id"],
					RestElement: ["argument"],
					UpdateExpression: ["argument"],
					ObjectProperty: ["value"],
					AssignmentPattern: ["left"],
					ArrayPattern: ["elements"],
					ObjectPattern: ["properties"],
					VariableDeclaration: ["declarations"],
					VariableDeclarator: ["id"]
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/retrievers/getFunctionName.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					if ("id" in e && e.id) return {
						name: e.id.name,
						originalNode: e.id
					};
					let r, s = "";
					(0, n.isObjectProperty)(t, { value: e }) ? r = getObjectMemberKey(t) : (0, n.isObjectMethod)(e) || (0, n.isClassMethod)(e) ? (r = getObjectMemberKey(e), "get" === e.kind ? s = "get " : "set" === e.kind && (s = "set ")) : (0, n.isVariableDeclarator)(t, { init: e }) ? r = t.id : (0, n.isAssignmentExpression)(t, {
						operator: "=",
						right: e
					}) && (r = t.left);
					if (!r) return null;
					const i = (0, n.isLiteral)(r) ? function(e) {
						if ((0, n.isNullLiteral)(e)) return "null";
						if ((0, n.isRegExpLiteral)(e)) return `/${e.pattern}/${e.flags}`;
						if ((0, n.isTemplateLiteral)(e)) return e.quasis.map((e) => e.value.raw).join("");
						if (void 0 !== e.value) return String(e.value);
						return null;
					}(r) : (0, n.isIdentifier)(r) ? r.name : (0, n.isPrivateName)(r) ? r.id.name : null;
					return null == i ? null : {
						name: s + i,
						originalNode: r
					};
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
				function getObjectMemberKey(e) {
					if (!e.computed || (0, n.isLiteral)(e.key)) return e.key;
				}
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/retrievers/getOuterBindingIdentifiers.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/retrievers/getBindingIdentifiers.js");
				t.default = function(e, t) {
					return (0, n.default)(e, t, !0);
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/traverse/traverse.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					"function" == typeof t && (t = { enter: t });
					const { enter: n, exit: s } = t;
					traverseSimpleImpl(e, n, s, r, []);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js");
				function traverseSimpleImpl(e, t, r, s, i) {
					const o = n.VISITOR_KEYS[e.type];
					if (o) {
						t && t(e, i, s);
						for (const n of o) {
							const o = e[n];
							if (Array.isArray(o)) for (let a = 0; a < o.length; a++) {
								const l = o[a];
								l && (i.push({
									node: e,
									key: n,
									index: a
								}), traverseSimpleImpl(l, t, r, s, i), i.pop());
							}
							else o && (i.push({
								node: e,
								key: n
							}), traverseSimpleImpl(o, t, r, s, i), i.pop());
						}
						r && r(e, i, s);
					}
				}
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/traverse/traverseFast.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = traverseFast;
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js");
				const s = Symbol(), i = Symbol();
				function traverseFast(e, t, r) {
					if (!e) return !1;
					const o = n.VISITOR_KEYS[e.type];
					if (!o) return !1;
					const a = t(e, r = r || {});
					if (void 0 !== a) switch (a) {
						case s: return !1;
						case i: return !0;
					}
					for (const n of o) {
						const s = e[n];
						if (s) {
							if (Array.isArray(s)) {
								for (const e of s) if (traverseFast(e, t, r)) return !0;
							} else if (traverseFast(s, t, r)) return !0;
						}
					}
					return !1;
				}
				traverseFast.skip = s, traverseFast.stop = i;
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/deprecationWarning.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, n = "", s = e) {
					if (r.has(s)) return;
					r.add(s);
					const { internal: i, trace: o } = function(e, t) {
						const { stackTraceLimit: r, prepareStackTrace: n } = Error;
						let s;
						if (Error.stackTraceLimit = 1 + e + t, Error.prepareStackTrace = function(e, t) {
							s = t;
						}, (/* @__PURE__ */ new Error()).stack, Error.stackTraceLimit = r, Error.prepareStackTrace = n, !s) return {
							internal: !1,
							trace: ""
						};
						const i = s.slice(1 + e, 1 + e + t);
						return {
							internal: /[\\/]@babel[\\/]/.test(i[1].getFileName()),
							trace: i.map((e) => `    at ${e}`).join("\n")
						};
					}(1, 2);
					if (i) return;
					console.warn(`${n}\`${e}\` has been deprecated, please migrate to \`${t}\`\n${o}`);
				};
				const r = /* @__PURE__ */ new Set();
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/inherit.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					t && r && (t[e] = Array.from(new Set([].concat(t[e], r[e]).filter(Boolean))));
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/react/cleanJSXElementLiteralChild.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					const r = e.value.split(/\r\n|\n|\r/);
					let i = 0;
					for (let e = 0; e < r.length; e++) /[^ \t]/.exec(r[e]) && (i = e);
					let o = "";
					for (let e = 0; e < r.length; e++) {
						const t = r[e], n = 0 === e, s = e === r.length - 1, a = e === i;
						let l = t.replace(/\t/g, " ");
						n || (l = l.replace(/^ +/, "")), s || (l = l.replace(/ +$/, "")), l && (a || (l += " "), o += l);
					}
					o && t.push((0, s.inherits)((0, n.stringLiteral)(o), e));
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/builders/generated/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/shallowEqual.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					const r = Object.keys(t);
					for (const n of r) if (e[n] !== t[n]) return !1;
					return !0;
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/buildMatchMemberExpression.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					const r = e.split(".");
					return (e) => (0, n.default)(e, r, t);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/matchesPattern.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.isAccessor = function(e, t) {
					if (!e) return !1;
					if ("ClassAccessorProperty" !== e.type) return !1;
					return null == t || (0, n.default)(e, t);
				}, t.isAnyTypeAnnotation = function(e, t) {
					return !!e && "AnyTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isArgumentPlaceholder = function(e, t) {
					return !!e && "ArgumentPlaceholder" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isArrayExpression = function(e, t) {
					return !!e && "ArrayExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isArrayPattern = function(e, t) {
					return !!e && "ArrayPattern" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isArrayTypeAnnotation = function(e, t) {
					return !!e && "ArrayTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isArrowFunctionExpression = function(e, t) {
					return !!e && "ArrowFunctionExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isAssignmentExpression = function(e, t) {
					return !!e && "AssignmentExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isAssignmentPattern = function(e, t) {
					return !!e && "AssignmentPattern" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isAwaitExpression = function(e, t) {
					return !!e && "AwaitExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isBigIntLiteral = function(e, t) {
					return !!e && "BigIntLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isBinary = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "BinaryExpression":
						case "LogicalExpression": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isBinaryExpression = function(e, t) {
					return !!e && "BinaryExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isBindExpression = function(e, t) {
					return !!e && "BindExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isBlock = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "BlockStatement":
						case "Program":
						case "TSModuleBlock": break;
						case "Placeholder": if ("BlockStatement" === e.expectedNode) break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isBlockParent = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "BlockStatement":
						case "CatchClause":
						case "DoWhileStatement":
						case "ForInStatement":
						case "ForStatement":
						case "FunctionDeclaration":
						case "FunctionExpression":
						case "Program":
						case "ObjectMethod":
						case "SwitchStatement":
						case "WhileStatement":
						case "ArrowFunctionExpression":
						case "ForOfStatement":
						case "ClassMethod":
						case "ClassPrivateMethod":
						case "StaticBlock":
						case "TSModuleBlock": break;
						case "Placeholder": if ("BlockStatement" === e.expectedNode) break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isBlockStatement = function(e, t) {
					return !!e && "BlockStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isBooleanLiteral = function(e, t) {
					return !!e && "BooleanLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isBooleanLiteralTypeAnnotation = function(e, t) {
					return !!e && "BooleanLiteralTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isBooleanTypeAnnotation = function(e, t) {
					return !!e && "BooleanTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isBreakStatement = function(e, t) {
					return !!e && "BreakStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isCallExpression = function(e, t) {
					return !!e && "CallExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isCatchClause = function(e, t) {
					return !!e && "CatchClause" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isClass = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ClassExpression":
						case "ClassDeclaration": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isClassAccessorProperty = function(e, t) {
					return !!e && "ClassAccessorProperty" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isClassBody = function(e, t) {
					return !!e && "ClassBody" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isClassDeclaration = function(e, t) {
					return !!e && "ClassDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isClassExpression = function(e, t) {
					return !!e && "ClassExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isClassImplements = function(e, t) {
					return !!e && "ClassImplements" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isClassMethod = function(e, t) {
					return !!e && "ClassMethod" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isClassPrivateMethod = function(e, t) {
					return !!e && "ClassPrivateMethod" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isClassPrivateProperty = function(e, t) {
					return !!e && "ClassPrivateProperty" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isClassProperty = function(e, t) {
					return !!e && "ClassProperty" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isCompletionStatement = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "BreakStatement":
						case "ContinueStatement":
						case "ReturnStatement":
						case "ThrowStatement": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isConditional = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ConditionalExpression":
						case "IfStatement": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isConditionalExpression = function(e, t) {
					return !!e && "ConditionalExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isContinueStatement = function(e, t) {
					return !!e && "ContinueStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDebuggerStatement = function(e, t) {
					return !!e && "DebuggerStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDecimalLiteral = function(e, t) {
					return !!e && "DecimalLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDeclaration = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "FunctionDeclaration":
						case "VariableDeclaration":
						case "ClassDeclaration":
						case "ExportAllDeclaration":
						case "ExportDefaultDeclaration":
						case "ExportNamedDeclaration":
						case "ImportDeclaration":
						case "DeclareClass":
						case "DeclareFunction":
						case "DeclareInterface":
						case "DeclareModule":
						case "DeclareModuleExports":
						case "DeclareTypeAlias":
						case "DeclareOpaqueType":
						case "DeclareVariable":
						case "DeclareExportDeclaration":
						case "DeclareExportAllDeclaration":
						case "InterfaceDeclaration":
						case "OpaqueType":
						case "TypeAlias":
						case "EnumDeclaration":
						case "TSDeclareFunction":
						case "TSInterfaceDeclaration":
						case "TSTypeAliasDeclaration":
						case "TSEnumDeclaration":
						case "TSModuleDeclaration":
						case "TSImportEqualsDeclaration": break;
						case "Placeholder": if ("Declaration" === e.expectedNode) break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isDeclareClass = function(e, t) {
					return !!e && "DeclareClass" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDeclareExportAllDeclaration = function(e, t) {
					return !!e && "DeclareExportAllDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDeclareExportDeclaration = function(e, t) {
					return !!e && "DeclareExportDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDeclareFunction = function(e, t) {
					return !!e && "DeclareFunction" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDeclareInterface = function(e, t) {
					return !!e && "DeclareInterface" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDeclareModule = function(e, t) {
					return !!e && "DeclareModule" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDeclareModuleExports = function(e, t) {
					return !!e && "DeclareModuleExports" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDeclareOpaqueType = function(e, t) {
					return !!e && "DeclareOpaqueType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDeclareTypeAlias = function(e, t) {
					return !!e && "DeclareTypeAlias" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDeclareVariable = function(e, t) {
					return !!e && "DeclareVariable" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDeclaredPredicate = function(e, t) {
					return !!e && "DeclaredPredicate" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDecorator = function(e, t) {
					return !!e && "Decorator" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDirective = function(e, t) {
					return !!e && "Directive" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDirectiveLiteral = function(e, t) {
					return !!e && "DirectiveLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDoExpression = function(e, t) {
					return !!e && "DoExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isDoWhileStatement = function(e, t) {
					return !!e && "DoWhileStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isEmptyStatement = function(e, t) {
					return !!e && "EmptyStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isEmptyTypeAnnotation = function(e, t) {
					return !!e && "EmptyTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isEnumBody = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "EnumBooleanBody":
						case "EnumNumberBody":
						case "EnumStringBody":
						case "EnumSymbolBody": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isEnumBooleanBody = function(e, t) {
					return !!e && "EnumBooleanBody" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isEnumBooleanMember = function(e, t) {
					return !!e && "EnumBooleanMember" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isEnumDeclaration = function(e, t) {
					return !!e && "EnumDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isEnumDefaultedMember = function(e, t) {
					return !!e && "EnumDefaultedMember" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isEnumMember = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "EnumBooleanMember":
						case "EnumNumberMember":
						case "EnumStringMember":
						case "EnumDefaultedMember": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isEnumNumberBody = function(e, t) {
					return !!e && "EnumNumberBody" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isEnumNumberMember = function(e, t) {
					return !!e && "EnumNumberMember" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isEnumStringBody = function(e, t) {
					return !!e && "EnumStringBody" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isEnumStringMember = function(e, t) {
					return !!e && "EnumStringMember" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isEnumSymbolBody = function(e, t) {
					return !!e && "EnumSymbolBody" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isExistsTypeAnnotation = function(e, t) {
					return !!e && "ExistsTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isExportAllDeclaration = function(e, t) {
					return !!e && "ExportAllDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isExportDeclaration = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ExportAllDeclaration":
						case "ExportDefaultDeclaration":
						case "ExportNamedDeclaration": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isExportDefaultDeclaration = function(e, t) {
					return !!e && "ExportDefaultDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isExportDefaultSpecifier = function(e, t) {
					return !!e && "ExportDefaultSpecifier" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isExportNamedDeclaration = function(e, t) {
					return !!e && "ExportNamedDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isExportNamespaceSpecifier = function(e, t) {
					return !!e && "ExportNamespaceSpecifier" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isExportSpecifier = function(e, t) {
					return !!e && "ExportSpecifier" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isExpression = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ArrayExpression":
						case "AssignmentExpression":
						case "BinaryExpression":
						case "CallExpression":
						case "ConditionalExpression":
						case "FunctionExpression":
						case "Identifier":
						case "StringLiteral":
						case "NumericLiteral":
						case "NullLiteral":
						case "BooleanLiteral":
						case "RegExpLiteral":
						case "LogicalExpression":
						case "MemberExpression":
						case "NewExpression":
						case "ObjectExpression":
						case "SequenceExpression":
						case "ParenthesizedExpression":
						case "ThisExpression":
						case "UnaryExpression":
						case "UpdateExpression":
						case "ArrowFunctionExpression":
						case "ClassExpression":
						case "ImportExpression":
						case "MetaProperty":
						case "Super":
						case "TaggedTemplateExpression":
						case "TemplateLiteral":
						case "YieldExpression":
						case "AwaitExpression":
						case "Import":
						case "BigIntLiteral":
						case "OptionalMemberExpression":
						case "OptionalCallExpression":
						case "TypeCastExpression":
						case "JSXElement":
						case "JSXFragment":
						case "BindExpression":
						case "DoExpression":
						case "RecordExpression":
						case "TupleExpression":
						case "DecimalLiteral":
						case "ModuleExpression":
						case "TopicReference":
						case "PipelineTopicExpression":
						case "PipelineBareFunction":
						case "PipelinePrimaryTopicReference":
						case "TSInstantiationExpression":
						case "TSAsExpression":
						case "TSSatisfiesExpression":
						case "TSTypeAssertion":
						case "TSNonNullExpression": break;
						case "Placeholder":
							switch (e.expectedNode) {
								case "Expression":
								case "Identifier":
								case "StringLiteral": break;
								default: return !1;
							}
							break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isExpressionStatement = function(e, t) {
					return !!e && "ExpressionStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isExpressionWrapper = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ExpressionStatement":
						case "ParenthesizedExpression":
						case "TypeCastExpression": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isFile = function(e, t) {
					return !!e && "File" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isFlow = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "AnyTypeAnnotation":
						case "ArrayTypeAnnotation":
						case "BooleanTypeAnnotation":
						case "BooleanLiteralTypeAnnotation":
						case "NullLiteralTypeAnnotation":
						case "ClassImplements":
						case "DeclareClass":
						case "DeclareFunction":
						case "DeclareInterface":
						case "DeclareModule":
						case "DeclareModuleExports":
						case "DeclareTypeAlias":
						case "DeclareOpaqueType":
						case "DeclareVariable":
						case "DeclareExportDeclaration":
						case "DeclareExportAllDeclaration":
						case "DeclaredPredicate":
						case "ExistsTypeAnnotation":
						case "FunctionTypeAnnotation":
						case "FunctionTypeParam":
						case "GenericTypeAnnotation":
						case "InferredPredicate":
						case "InterfaceExtends":
						case "InterfaceDeclaration":
						case "InterfaceTypeAnnotation":
						case "IntersectionTypeAnnotation":
						case "MixedTypeAnnotation":
						case "EmptyTypeAnnotation":
						case "NullableTypeAnnotation":
						case "NumberLiteralTypeAnnotation":
						case "NumberTypeAnnotation":
						case "ObjectTypeAnnotation":
						case "ObjectTypeInternalSlot":
						case "ObjectTypeCallProperty":
						case "ObjectTypeIndexer":
						case "ObjectTypeProperty":
						case "ObjectTypeSpreadProperty":
						case "OpaqueType":
						case "QualifiedTypeIdentifier":
						case "StringLiteralTypeAnnotation":
						case "StringTypeAnnotation":
						case "SymbolTypeAnnotation":
						case "ThisTypeAnnotation":
						case "TupleTypeAnnotation":
						case "TypeofTypeAnnotation":
						case "TypeAlias":
						case "TypeAnnotation":
						case "TypeCastExpression":
						case "TypeParameter":
						case "TypeParameterDeclaration":
						case "TypeParameterInstantiation":
						case "UnionTypeAnnotation":
						case "Variance":
						case "VoidTypeAnnotation":
						case "EnumDeclaration":
						case "EnumBooleanBody":
						case "EnumNumberBody":
						case "EnumStringBody":
						case "EnumSymbolBody":
						case "EnumBooleanMember":
						case "EnumNumberMember":
						case "EnumStringMember":
						case "EnumDefaultedMember":
						case "IndexedAccessType":
						case "OptionalIndexedAccessType": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isFlowBaseAnnotation = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "AnyTypeAnnotation":
						case "BooleanTypeAnnotation":
						case "NullLiteralTypeAnnotation":
						case "MixedTypeAnnotation":
						case "EmptyTypeAnnotation":
						case "NumberTypeAnnotation":
						case "StringTypeAnnotation":
						case "SymbolTypeAnnotation":
						case "ThisTypeAnnotation":
						case "VoidTypeAnnotation": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isFlowDeclaration = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "DeclareClass":
						case "DeclareFunction":
						case "DeclareInterface":
						case "DeclareModule":
						case "DeclareModuleExports":
						case "DeclareTypeAlias":
						case "DeclareOpaqueType":
						case "DeclareVariable":
						case "DeclareExportDeclaration":
						case "DeclareExportAllDeclaration":
						case "InterfaceDeclaration":
						case "OpaqueType":
						case "TypeAlias": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isFlowPredicate = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "DeclaredPredicate":
						case "InferredPredicate": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isFlowType = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "AnyTypeAnnotation":
						case "ArrayTypeAnnotation":
						case "BooleanTypeAnnotation":
						case "BooleanLiteralTypeAnnotation":
						case "NullLiteralTypeAnnotation":
						case "ExistsTypeAnnotation":
						case "FunctionTypeAnnotation":
						case "GenericTypeAnnotation":
						case "InterfaceTypeAnnotation":
						case "IntersectionTypeAnnotation":
						case "MixedTypeAnnotation":
						case "EmptyTypeAnnotation":
						case "NullableTypeAnnotation":
						case "NumberLiteralTypeAnnotation":
						case "NumberTypeAnnotation":
						case "ObjectTypeAnnotation":
						case "StringLiteralTypeAnnotation":
						case "StringTypeAnnotation":
						case "SymbolTypeAnnotation":
						case "ThisTypeAnnotation":
						case "TupleTypeAnnotation":
						case "TypeofTypeAnnotation":
						case "UnionTypeAnnotation":
						case "VoidTypeAnnotation":
						case "IndexedAccessType":
						case "OptionalIndexedAccessType": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isFor = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ForInStatement":
						case "ForStatement":
						case "ForOfStatement": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isForInStatement = function(e, t) {
					return !!e && "ForInStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isForOfStatement = function(e, t) {
					return !!e && "ForOfStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isForStatement = function(e, t) {
					return !!e && "ForStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isForXStatement = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ForInStatement":
						case "ForOfStatement": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isFunction = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "FunctionDeclaration":
						case "FunctionExpression":
						case "ObjectMethod":
						case "ArrowFunctionExpression":
						case "ClassMethod":
						case "ClassPrivateMethod": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isFunctionDeclaration = function(e, t) {
					return !!e && "FunctionDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isFunctionExpression = function(e, t) {
					return !!e && "FunctionExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isFunctionParameter = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "Identifier":
						case "RestElement":
						case "AssignmentPattern":
						case "ArrayPattern":
						case "ObjectPattern":
						case "VoidPattern": break;
						case "Placeholder": if ("Identifier" === e.expectedNode) break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isFunctionParent = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "FunctionDeclaration":
						case "FunctionExpression":
						case "ObjectMethod":
						case "ArrowFunctionExpression":
						case "ClassMethod":
						case "ClassPrivateMethod":
						case "StaticBlock":
						case "TSModuleBlock": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isFunctionTypeAnnotation = function(e, t) {
					return !!e && "FunctionTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isFunctionTypeParam = function(e, t) {
					return !!e && "FunctionTypeParam" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isGenericTypeAnnotation = function(e, t) {
					return !!e && "GenericTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isIdentifier = function(e, t) {
					return !!e && "Identifier" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isIfStatement = function(e, t) {
					return !!e && "IfStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isImmutable = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "StringLiteral":
						case "NumericLiteral":
						case "NullLiteral":
						case "BooleanLiteral":
						case "BigIntLiteral":
						case "JSXAttribute":
						case "JSXClosingElement":
						case "JSXElement":
						case "JSXExpressionContainer":
						case "JSXSpreadChild":
						case "JSXOpeningElement":
						case "JSXText":
						case "JSXFragment":
						case "JSXOpeningFragment":
						case "JSXClosingFragment":
						case "DecimalLiteral": break;
						case "Placeholder": if ("StringLiteral" === e.expectedNode) break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isImport = function(e, t) {
					return !!e && "Import" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isImportAttribute = function(e, t) {
					return !!e && "ImportAttribute" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isImportDeclaration = function(e, t) {
					return !!e && "ImportDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isImportDefaultSpecifier = function(e, t) {
					return !!e && "ImportDefaultSpecifier" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isImportExpression = function(e, t) {
					return !!e && "ImportExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isImportNamespaceSpecifier = function(e, t) {
					return !!e && "ImportNamespaceSpecifier" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isImportOrExportDeclaration = isImportOrExportDeclaration, t.isImportSpecifier = function(e, t) {
					return !!e && "ImportSpecifier" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isIndexedAccessType = function(e, t) {
					return !!e && "IndexedAccessType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isInferredPredicate = function(e, t) {
					return !!e && "InferredPredicate" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isInterfaceDeclaration = function(e, t) {
					return !!e && "InterfaceDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isInterfaceExtends = function(e, t) {
					return !!e && "InterfaceExtends" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isInterfaceTypeAnnotation = function(e, t) {
					return !!e && "InterfaceTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isInterpreterDirective = function(e, t) {
					return !!e && "InterpreterDirective" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isIntersectionTypeAnnotation = function(e, t) {
					return !!e && "IntersectionTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSX = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "JSXAttribute":
						case "JSXClosingElement":
						case "JSXElement":
						case "JSXEmptyExpression":
						case "JSXExpressionContainer":
						case "JSXSpreadChild":
						case "JSXIdentifier":
						case "JSXMemberExpression":
						case "JSXNamespacedName":
						case "JSXOpeningElement":
						case "JSXSpreadAttribute":
						case "JSXText":
						case "JSXFragment":
						case "JSXOpeningFragment":
						case "JSXClosingFragment": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isJSXAttribute = function(e, t) {
					return !!e && "JSXAttribute" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXClosingElement = function(e, t) {
					return !!e && "JSXClosingElement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXClosingFragment = function(e, t) {
					return !!e && "JSXClosingFragment" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXElement = function(e, t) {
					return !!e && "JSXElement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXEmptyExpression = function(e, t) {
					return !!e && "JSXEmptyExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXExpressionContainer = function(e, t) {
					return !!e && "JSXExpressionContainer" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXFragment = function(e, t) {
					return !!e && "JSXFragment" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXIdentifier = function(e, t) {
					return !!e && "JSXIdentifier" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXMemberExpression = function(e, t) {
					return !!e && "JSXMemberExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXNamespacedName = function(e, t) {
					return !!e && "JSXNamespacedName" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXOpeningElement = function(e, t) {
					return !!e && "JSXOpeningElement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXOpeningFragment = function(e, t) {
					return !!e && "JSXOpeningFragment" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXSpreadAttribute = function(e, t) {
					return !!e && "JSXSpreadAttribute" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXSpreadChild = function(e, t) {
					return !!e && "JSXSpreadChild" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isJSXText = function(e, t) {
					return !!e && "JSXText" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isLVal = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "Identifier":
						case "MemberExpression":
						case "RestElement":
						case "AssignmentPattern":
						case "ArrayPattern":
						case "ObjectPattern":
						case "TSParameterProperty":
						case "TSAsExpression":
						case "TSSatisfiesExpression":
						case "TSTypeAssertion":
						case "TSNonNullExpression": break;
						case "Placeholder":
							switch (e.expectedNode) {
								case "Pattern":
								case "Identifier": break;
								default: return !1;
							}
							break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isLabeledStatement = function(e, t) {
					return !!e && "LabeledStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isLiteral = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "StringLiteral":
						case "NumericLiteral":
						case "NullLiteral":
						case "BooleanLiteral":
						case "RegExpLiteral":
						case "TemplateLiteral":
						case "BigIntLiteral":
						case "DecimalLiteral": break;
						case "Placeholder": if ("StringLiteral" === e.expectedNode) break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isLogicalExpression = function(e, t) {
					return !!e && "LogicalExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isLoop = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "DoWhileStatement":
						case "ForInStatement":
						case "ForStatement":
						case "WhileStatement":
						case "ForOfStatement": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isMemberExpression = function(e, t) {
					return !!e && "MemberExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isMetaProperty = function(e, t) {
					return !!e && "MetaProperty" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isMethod = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ObjectMethod":
						case "ClassMethod":
						case "ClassPrivateMethod": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isMiscellaneous = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "Noop":
						case "Placeholder":
						case "V8IntrinsicIdentifier": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isMixedTypeAnnotation = function(e, t) {
					return !!e && "MixedTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isModuleDeclaration = function(e, t) {
					return (0, s.default)("isModuleDeclaration", "isImportOrExportDeclaration"), isImportOrExportDeclaration(e, t);
				}, t.isModuleExpression = function(e, t) {
					return !!e && "ModuleExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isModuleSpecifier = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ExportSpecifier":
						case "ImportDefaultSpecifier":
						case "ImportNamespaceSpecifier":
						case "ImportSpecifier":
						case "ExportNamespaceSpecifier":
						case "ExportDefaultSpecifier": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isNewExpression = function(e, t) {
					return !!e && "NewExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isNoop = function(e, t) {
					return !!e && "Noop" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isNullLiteral = function(e, t) {
					return !!e && "NullLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isNullLiteralTypeAnnotation = function(e, t) {
					return !!e && "NullLiteralTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isNullableTypeAnnotation = function(e, t) {
					return !!e && "NullableTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isNumberLiteral = function(e, t) {
					return (0, s.default)("isNumberLiteral", "isNumericLiteral"), !!e && "NumberLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isNumberLiteralTypeAnnotation = function(e, t) {
					return !!e && "NumberLiteralTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isNumberTypeAnnotation = function(e, t) {
					return !!e && "NumberTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isNumericLiteral = function(e, t) {
					return !!e && "NumericLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isObjectExpression = function(e, t) {
					return !!e && "ObjectExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isObjectMember = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ObjectMethod":
						case "ObjectProperty": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isObjectMethod = function(e, t) {
					return !!e && "ObjectMethod" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isObjectPattern = function(e, t) {
					return !!e && "ObjectPattern" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isObjectProperty = function(e, t) {
					return !!e && "ObjectProperty" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isObjectTypeAnnotation = function(e, t) {
					return !!e && "ObjectTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isObjectTypeCallProperty = function(e, t) {
					return !!e && "ObjectTypeCallProperty" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isObjectTypeIndexer = function(e, t) {
					return !!e && "ObjectTypeIndexer" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isObjectTypeInternalSlot = function(e, t) {
					return !!e && "ObjectTypeInternalSlot" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isObjectTypeProperty = function(e, t) {
					return !!e && "ObjectTypeProperty" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isObjectTypeSpreadProperty = function(e, t) {
					return !!e && "ObjectTypeSpreadProperty" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isOpaqueType = function(e, t) {
					return !!e && "OpaqueType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isOptionalCallExpression = function(e, t) {
					return !!e && "OptionalCallExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isOptionalIndexedAccessType = function(e, t) {
					return !!e && "OptionalIndexedAccessType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isOptionalMemberExpression = function(e, t) {
					return !!e && "OptionalMemberExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isParenthesizedExpression = function(e, t) {
					return !!e && "ParenthesizedExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isPattern = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "AssignmentPattern":
						case "ArrayPattern":
						case "ObjectPattern":
						case "VoidPattern": break;
						case "Placeholder": if ("Pattern" === e.expectedNode) break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isPatternLike = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "Identifier":
						case "MemberExpression":
						case "RestElement":
						case "AssignmentPattern":
						case "ArrayPattern":
						case "ObjectPattern":
						case "VoidPattern":
						case "TSAsExpression":
						case "TSSatisfiesExpression":
						case "TSTypeAssertion":
						case "TSNonNullExpression": break;
						case "Placeholder":
							switch (e.expectedNode) {
								case "Pattern":
								case "Identifier": break;
								default: return !1;
							}
							break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isPipelineBareFunction = function(e, t) {
					return !!e && "PipelineBareFunction" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isPipelinePrimaryTopicReference = function(e, t) {
					return !!e && "PipelinePrimaryTopicReference" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isPipelineTopicExpression = function(e, t) {
					return !!e && "PipelineTopicExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isPlaceholder = function(e, t) {
					return !!e && "Placeholder" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isPrivate = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ClassPrivateProperty":
						case "ClassPrivateMethod":
						case "PrivateName": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isPrivateName = function(e, t) {
					return !!e && "PrivateName" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isProgram = function(e, t) {
					return !!e && "Program" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isProperty = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ObjectProperty":
						case "ClassProperty":
						case "ClassAccessorProperty":
						case "ClassPrivateProperty": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isPureish = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "FunctionDeclaration":
						case "FunctionExpression":
						case "StringLiteral":
						case "NumericLiteral":
						case "NullLiteral":
						case "BooleanLiteral":
						case "RegExpLiteral":
						case "ArrowFunctionExpression":
						case "BigIntLiteral":
						case "DecimalLiteral": break;
						case "Placeholder": if ("StringLiteral" === e.expectedNode) break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isQualifiedTypeIdentifier = function(e, t) {
					return !!e && "QualifiedTypeIdentifier" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isRecordExpression = function(e, t) {
					return !!e && "RecordExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isRegExpLiteral = function(e, t) {
					return !!e && "RegExpLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isRegexLiteral = function(e, t) {
					return (0, s.default)("isRegexLiteral", "isRegExpLiteral"), !!e && "RegexLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isRestElement = function(e, t) {
					return !!e && "RestElement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isRestProperty = function(e, t) {
					return (0, s.default)("isRestProperty", "isRestElement"), !!e && "RestProperty" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isReturnStatement = function(e, t) {
					return !!e && "ReturnStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isScopable = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "BlockStatement":
						case "CatchClause":
						case "DoWhileStatement":
						case "ForInStatement":
						case "ForStatement":
						case "FunctionDeclaration":
						case "FunctionExpression":
						case "Program":
						case "ObjectMethod":
						case "SwitchStatement":
						case "WhileStatement":
						case "ArrowFunctionExpression":
						case "ClassExpression":
						case "ClassDeclaration":
						case "ForOfStatement":
						case "ClassMethod":
						case "ClassPrivateMethod":
						case "StaticBlock":
						case "TSModuleBlock": break;
						case "Placeholder": if ("BlockStatement" === e.expectedNode) break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isSequenceExpression = function(e, t) {
					return !!e && "SequenceExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isSpreadElement = function(e, t) {
					return !!e && "SpreadElement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isSpreadProperty = function(e, t) {
					return (0, s.default)("isSpreadProperty", "isSpreadElement"), !!e && "SpreadProperty" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isStandardized = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ArrayExpression":
						case "AssignmentExpression":
						case "BinaryExpression":
						case "InterpreterDirective":
						case "Directive":
						case "DirectiveLiteral":
						case "BlockStatement":
						case "BreakStatement":
						case "CallExpression":
						case "CatchClause":
						case "ConditionalExpression":
						case "ContinueStatement":
						case "DebuggerStatement":
						case "DoWhileStatement":
						case "EmptyStatement":
						case "ExpressionStatement":
						case "File":
						case "ForInStatement":
						case "ForStatement":
						case "FunctionDeclaration":
						case "FunctionExpression":
						case "Identifier":
						case "IfStatement":
						case "LabeledStatement":
						case "StringLiteral":
						case "NumericLiteral":
						case "NullLiteral":
						case "BooleanLiteral":
						case "RegExpLiteral":
						case "LogicalExpression":
						case "MemberExpression":
						case "NewExpression":
						case "Program":
						case "ObjectExpression":
						case "ObjectMethod":
						case "ObjectProperty":
						case "RestElement":
						case "ReturnStatement":
						case "SequenceExpression":
						case "ParenthesizedExpression":
						case "SwitchCase":
						case "SwitchStatement":
						case "ThisExpression":
						case "ThrowStatement":
						case "TryStatement":
						case "UnaryExpression":
						case "UpdateExpression":
						case "VariableDeclaration":
						case "VariableDeclarator":
						case "WhileStatement":
						case "WithStatement":
						case "AssignmentPattern":
						case "ArrayPattern":
						case "ArrowFunctionExpression":
						case "ClassBody":
						case "ClassExpression":
						case "ClassDeclaration":
						case "ExportAllDeclaration":
						case "ExportDefaultDeclaration":
						case "ExportNamedDeclaration":
						case "ExportSpecifier":
						case "ForOfStatement":
						case "ImportDeclaration":
						case "ImportDefaultSpecifier":
						case "ImportNamespaceSpecifier":
						case "ImportSpecifier":
						case "ImportExpression":
						case "MetaProperty":
						case "ClassMethod":
						case "ObjectPattern":
						case "SpreadElement":
						case "Super":
						case "TaggedTemplateExpression":
						case "TemplateElement":
						case "TemplateLiteral":
						case "YieldExpression":
						case "AwaitExpression":
						case "Import":
						case "BigIntLiteral":
						case "ExportNamespaceSpecifier":
						case "OptionalMemberExpression":
						case "OptionalCallExpression":
						case "ClassProperty":
						case "ClassAccessorProperty":
						case "ClassPrivateProperty":
						case "ClassPrivateMethod":
						case "PrivateName":
						case "StaticBlock":
						case "ImportAttribute": break;
						case "Placeholder":
							switch (e.expectedNode) {
								case "Identifier":
								case "StringLiteral":
								case "BlockStatement":
								case "ClassBody": break;
								default: return !1;
							}
							break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isStatement = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "BlockStatement":
						case "BreakStatement":
						case "ContinueStatement":
						case "DebuggerStatement":
						case "DoWhileStatement":
						case "EmptyStatement":
						case "ExpressionStatement":
						case "ForInStatement":
						case "ForStatement":
						case "FunctionDeclaration":
						case "IfStatement":
						case "LabeledStatement":
						case "ReturnStatement":
						case "SwitchStatement":
						case "ThrowStatement":
						case "TryStatement":
						case "VariableDeclaration":
						case "WhileStatement":
						case "WithStatement":
						case "ClassDeclaration":
						case "ExportAllDeclaration":
						case "ExportDefaultDeclaration":
						case "ExportNamedDeclaration":
						case "ForOfStatement":
						case "ImportDeclaration":
						case "DeclareClass":
						case "DeclareFunction":
						case "DeclareInterface":
						case "DeclareModule":
						case "DeclareModuleExports":
						case "DeclareTypeAlias":
						case "DeclareOpaqueType":
						case "DeclareVariable":
						case "DeclareExportDeclaration":
						case "DeclareExportAllDeclaration":
						case "InterfaceDeclaration":
						case "OpaqueType":
						case "TypeAlias":
						case "EnumDeclaration":
						case "TSDeclareFunction":
						case "TSInterfaceDeclaration":
						case "TSTypeAliasDeclaration":
						case "TSEnumDeclaration":
						case "TSModuleDeclaration":
						case "TSImportEqualsDeclaration":
						case "TSExportAssignment":
						case "TSNamespaceExportDeclaration": break;
						case "Placeholder":
							switch (e.expectedNode) {
								case "Statement":
								case "Declaration":
								case "BlockStatement": break;
								default: return !1;
							}
							break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isStaticBlock = function(e, t) {
					return !!e && "StaticBlock" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isStringLiteral = function(e, t) {
					return !!e && "StringLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isStringLiteralTypeAnnotation = function(e, t) {
					return !!e && "StringLiteralTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isStringTypeAnnotation = function(e, t) {
					return !!e && "StringTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isSuper = function(e, t) {
					return !!e && "Super" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isSwitchCase = function(e, t) {
					return !!e && "SwitchCase" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isSwitchStatement = function(e, t) {
					return !!e && "SwitchStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isSymbolTypeAnnotation = function(e, t) {
					return !!e && "SymbolTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSAnyKeyword = function(e, t) {
					return !!e && "TSAnyKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSArrayType = function(e, t) {
					return !!e && "TSArrayType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSAsExpression = function(e, t) {
					return !!e && "TSAsExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSBaseType = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "TSAnyKeyword":
						case "TSBooleanKeyword":
						case "TSBigIntKeyword":
						case "TSIntrinsicKeyword":
						case "TSNeverKeyword":
						case "TSNullKeyword":
						case "TSNumberKeyword":
						case "TSObjectKeyword":
						case "TSStringKeyword":
						case "TSSymbolKeyword":
						case "TSUndefinedKeyword":
						case "TSUnknownKeyword":
						case "TSVoidKeyword":
						case "TSThisType":
						case "TSTemplateLiteralType":
						case "TSLiteralType": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isTSBigIntKeyword = function(e, t) {
					return !!e && "TSBigIntKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSBooleanKeyword = function(e, t) {
					return !!e && "TSBooleanKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSCallSignatureDeclaration = function(e, t) {
					return !!e && "TSCallSignatureDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSConditionalType = function(e, t) {
					return !!e && "TSConditionalType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSConstructSignatureDeclaration = function(e, t) {
					return !!e && "TSConstructSignatureDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSConstructorType = function(e, t) {
					return !!e && "TSConstructorType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSDeclareFunction = function(e, t) {
					return !!e && "TSDeclareFunction" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSDeclareMethod = function(e, t) {
					return !!e && "TSDeclareMethod" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSEntityName = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "Identifier":
						case "TSQualifiedName": break;
						case "Placeholder": if ("Identifier" === e.expectedNode) break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isTSEnumBody = function(e, t) {
					return !!e && "TSEnumBody" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSEnumDeclaration = function(e, t) {
					return !!e && "TSEnumDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSEnumMember = function(e, t) {
					return !!e && "TSEnumMember" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSExportAssignment = function(e, t) {
					return !!e && "TSExportAssignment" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSExpressionWithTypeArguments = function(e, t) {
					return !!e && "TSExpressionWithTypeArguments" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSExternalModuleReference = function(e, t) {
					return !!e && "TSExternalModuleReference" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSFunctionType = function(e, t) {
					return !!e && "TSFunctionType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSImportEqualsDeclaration = function(e, t) {
					return !!e && "TSImportEqualsDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSImportType = function(e, t) {
					return !!e && "TSImportType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSIndexSignature = function(e, t) {
					return !!e && "TSIndexSignature" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSIndexedAccessType = function(e, t) {
					return !!e && "TSIndexedAccessType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSInferType = function(e, t) {
					return !!e && "TSInferType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSInstantiationExpression = function(e, t) {
					return !!e && "TSInstantiationExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSInterfaceBody = function(e, t) {
					return !!e && "TSInterfaceBody" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSInterfaceDeclaration = function(e, t) {
					return !!e && "TSInterfaceDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSIntersectionType = function(e, t) {
					return !!e && "TSIntersectionType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSIntrinsicKeyword = function(e, t) {
					return !!e && "TSIntrinsicKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSLiteralType = function(e, t) {
					return !!e && "TSLiteralType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSMappedType = function(e, t) {
					return !!e && "TSMappedType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSMethodSignature = function(e, t) {
					return !!e && "TSMethodSignature" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSModuleBlock = function(e, t) {
					return !!e && "TSModuleBlock" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSModuleDeclaration = function(e, t) {
					return !!e && "TSModuleDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSNamedTupleMember = function(e, t) {
					return !!e && "TSNamedTupleMember" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSNamespaceExportDeclaration = function(e, t) {
					return !!e && "TSNamespaceExportDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSNeverKeyword = function(e, t) {
					return !!e && "TSNeverKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSNonNullExpression = function(e, t) {
					return !!e && "TSNonNullExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSNullKeyword = function(e, t) {
					return !!e && "TSNullKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSNumberKeyword = function(e, t) {
					return !!e && "TSNumberKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSObjectKeyword = function(e, t) {
					return !!e && "TSObjectKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSOptionalType = function(e, t) {
					return !!e && "TSOptionalType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSParameterProperty = function(e, t) {
					return !!e && "TSParameterProperty" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSParenthesizedType = function(e, t) {
					return !!e && "TSParenthesizedType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSPropertySignature = function(e, t) {
					return !!e && "TSPropertySignature" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSQualifiedName = function(e, t) {
					return !!e && "TSQualifiedName" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSRestType = function(e, t) {
					return !!e && "TSRestType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSSatisfiesExpression = function(e, t) {
					return !!e && "TSSatisfiesExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSStringKeyword = function(e, t) {
					return !!e && "TSStringKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSSymbolKeyword = function(e, t) {
					return !!e && "TSSymbolKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTemplateLiteralType = function(e, t) {
					return !!e && "TSTemplateLiteralType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSThisType = function(e, t) {
					return !!e && "TSThisType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTupleType = function(e, t) {
					return !!e && "TSTupleType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSType = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "TSAnyKeyword":
						case "TSBooleanKeyword":
						case "TSBigIntKeyword":
						case "TSIntrinsicKeyword":
						case "TSNeverKeyword":
						case "TSNullKeyword":
						case "TSNumberKeyword":
						case "TSObjectKeyword":
						case "TSStringKeyword":
						case "TSSymbolKeyword":
						case "TSUndefinedKeyword":
						case "TSUnknownKeyword":
						case "TSVoidKeyword":
						case "TSThisType":
						case "TSFunctionType":
						case "TSConstructorType":
						case "TSTypeReference":
						case "TSTypePredicate":
						case "TSTypeQuery":
						case "TSTypeLiteral":
						case "TSArrayType":
						case "TSTupleType":
						case "TSOptionalType":
						case "TSRestType":
						case "TSUnionType":
						case "TSIntersectionType":
						case "TSConditionalType":
						case "TSInferType":
						case "TSParenthesizedType":
						case "TSTypeOperator":
						case "TSIndexedAccessType":
						case "TSMappedType":
						case "TSTemplateLiteralType":
						case "TSLiteralType":
						case "TSExpressionWithTypeArguments":
						case "TSImportType": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isTSTypeAliasDeclaration = function(e, t) {
					return !!e && "TSTypeAliasDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTypeAnnotation = function(e, t) {
					return !!e && "TSTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTypeAssertion = function(e, t) {
					return !!e && "TSTypeAssertion" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTypeElement = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "TSCallSignatureDeclaration":
						case "TSConstructSignatureDeclaration":
						case "TSPropertySignature":
						case "TSMethodSignature":
						case "TSIndexSignature": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isTSTypeLiteral = function(e, t) {
					return !!e && "TSTypeLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTypeOperator = function(e, t) {
					return !!e && "TSTypeOperator" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTypeParameter = function(e, t) {
					return !!e && "TSTypeParameter" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTypeParameterDeclaration = function(e, t) {
					return !!e && "TSTypeParameterDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTypeParameterInstantiation = function(e, t) {
					return !!e && "TSTypeParameterInstantiation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTypePredicate = function(e, t) {
					return !!e && "TSTypePredicate" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTypeQuery = function(e, t) {
					return !!e && "TSTypeQuery" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSTypeReference = function(e, t) {
					return !!e && "TSTypeReference" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSUndefinedKeyword = function(e, t) {
					return !!e && "TSUndefinedKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSUnionType = function(e, t) {
					return !!e && "TSUnionType" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSUnknownKeyword = function(e, t) {
					return !!e && "TSUnknownKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTSVoidKeyword = function(e, t) {
					return !!e && "TSVoidKeyword" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTaggedTemplateExpression = function(e, t) {
					return !!e && "TaggedTemplateExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTemplateElement = function(e, t) {
					return !!e && "TemplateElement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTemplateLiteral = function(e, t) {
					return !!e && "TemplateLiteral" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTerminatorless = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "BreakStatement":
						case "ContinueStatement":
						case "ReturnStatement":
						case "ThrowStatement":
						case "YieldExpression":
						case "AwaitExpression": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isThisExpression = function(e, t) {
					return !!e && "ThisExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isThisTypeAnnotation = function(e, t) {
					return !!e && "ThisTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isThrowStatement = function(e, t) {
					return !!e && "ThrowStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTopicReference = function(e, t) {
					return !!e && "TopicReference" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTryStatement = function(e, t) {
					return !!e && "TryStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTupleExpression = function(e, t) {
					return !!e && "TupleExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTupleTypeAnnotation = function(e, t) {
					return !!e && "TupleTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTypeAlias = function(e, t) {
					return !!e && "TypeAlias" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTypeAnnotation = function(e, t) {
					return !!e && "TypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTypeCastExpression = function(e, t) {
					return !!e && "TypeCastExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTypeParameter = function(e, t) {
					return !!e && "TypeParameter" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTypeParameterDeclaration = function(e, t) {
					return !!e && "TypeParameterDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTypeParameterInstantiation = function(e, t) {
					return !!e && "TypeParameterInstantiation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isTypeScript = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "TSParameterProperty":
						case "TSDeclareFunction":
						case "TSDeclareMethod":
						case "TSQualifiedName":
						case "TSCallSignatureDeclaration":
						case "TSConstructSignatureDeclaration":
						case "TSPropertySignature":
						case "TSMethodSignature":
						case "TSIndexSignature":
						case "TSAnyKeyword":
						case "TSBooleanKeyword":
						case "TSBigIntKeyword":
						case "TSIntrinsicKeyword":
						case "TSNeverKeyword":
						case "TSNullKeyword":
						case "TSNumberKeyword":
						case "TSObjectKeyword":
						case "TSStringKeyword":
						case "TSSymbolKeyword":
						case "TSUndefinedKeyword":
						case "TSUnknownKeyword":
						case "TSVoidKeyword":
						case "TSThisType":
						case "TSFunctionType":
						case "TSConstructorType":
						case "TSTypeReference":
						case "TSTypePredicate":
						case "TSTypeQuery":
						case "TSTypeLiteral":
						case "TSArrayType":
						case "TSTupleType":
						case "TSOptionalType":
						case "TSRestType":
						case "TSNamedTupleMember":
						case "TSUnionType":
						case "TSIntersectionType":
						case "TSConditionalType":
						case "TSInferType":
						case "TSParenthesizedType":
						case "TSTypeOperator":
						case "TSIndexedAccessType":
						case "TSMappedType":
						case "TSTemplateLiteralType":
						case "TSLiteralType":
						case "TSExpressionWithTypeArguments":
						case "TSInterfaceDeclaration":
						case "TSInterfaceBody":
						case "TSTypeAliasDeclaration":
						case "TSInstantiationExpression":
						case "TSAsExpression":
						case "TSSatisfiesExpression":
						case "TSTypeAssertion":
						case "TSEnumBody":
						case "TSEnumDeclaration":
						case "TSEnumMember":
						case "TSModuleDeclaration":
						case "TSModuleBlock":
						case "TSImportType":
						case "TSImportEqualsDeclaration":
						case "TSExternalModuleReference":
						case "TSNonNullExpression":
						case "TSExportAssignment":
						case "TSNamespaceExportDeclaration":
						case "TSTypeAnnotation":
						case "TSTypeParameterInstantiation":
						case "TSTypeParameterDeclaration":
						case "TSTypeParameter": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isTypeofTypeAnnotation = function(e, t) {
					return !!e && "TypeofTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isUnaryExpression = function(e, t) {
					return !!e && "UnaryExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isUnaryLike = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "UnaryExpression":
						case "SpreadElement": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isUnionTypeAnnotation = function(e, t) {
					return !!e && "UnionTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isUpdateExpression = function(e, t) {
					return !!e && "UpdateExpression" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isUserWhitespacable = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ObjectMethod":
						case "ObjectProperty":
						case "ObjectTypeInternalSlot":
						case "ObjectTypeCallProperty":
						case "ObjectTypeIndexer":
						case "ObjectTypeProperty":
						case "ObjectTypeSpreadProperty": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isV8IntrinsicIdentifier = function(e, t) {
					return !!e && "V8IntrinsicIdentifier" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isVariableDeclaration = function(e, t) {
					return !!e && "VariableDeclaration" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isVariableDeclarator = function(e, t) {
					return !!e && "VariableDeclarator" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isVariance = function(e, t) {
					return !!e && "Variance" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isVoidPattern = function(e, t) {
					return !!e && "VoidPattern" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isVoidTypeAnnotation = function(e, t) {
					return !!e && "VoidTypeAnnotation" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isWhile = function(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "DoWhileStatement":
						case "WhileStatement": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}, t.isWhileStatement = function(e, t) {
					return !!e && "WhileStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isWithStatement = function(e, t) {
					return !!e && "WithStatement" === e.type && (null == t || (0, n.default)(e, t));
				}, t.isYieldExpression = function(e, t) {
					return !!e && "YieldExpression" === e.type && (null == t || (0, n.default)(e, t));
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/shallowEqual.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/deprecationWarning.js");
				function isImportOrExportDeclaration(e, t) {
					if (!e) return !1;
					switch (e.type) {
						case "ExportAllDeclaration":
						case "ExportDefaultDeclaration":
						case "ExportNamedDeclaration":
						case "ImportDeclaration": break;
						default: return !1;
					}
					return null == t || (0, n.default)(e, t);
				}
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/is.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					if (!t) return !1;
					if (!(0, s.default)(t.type, e)) return !r && "Placeholder" === t.type && e in o.FLIPPED_ALIAS_KEYS && (0, i.default)(t.expectedNode, e);
					return void 0 === r || (0, n.default)(t, r);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/utils/shallowEqual.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isType.js"), i = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isPlaceholderType.js"), o = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isBinding.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					if (r && "Identifier" === e.type && "ObjectProperty" === t.type && "ObjectExpression" === r.type) return !1;
					const s = n.default.keys[t.type];
					if (s) for (let r = 0; r < s.length; r++) {
						const n = t[s[r]];
						if (Array.isArray(n)) {
							if (n.includes(e)) return !0;
						} else if (n === e) return !0;
					}
					return !1;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/retrievers/getBindingIdentifiers.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isBlockScoped.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return (0, n.isFunctionDeclaration)(e) || (0, n.isClassDeclaration)(e) || (0, s.default)(e);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isLet.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isImmutable.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					if ((0, n.default)(e.type, "Immutable")) return !0;
					if ((0, s.isIdentifier)(e)) return "undefined" === e.name;
					return !1;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isType.js"), s = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isLet.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return (0, n.isVariableDeclaration)(e) && ("var" !== e.kind || e[s]);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js"), s = Symbol.for("var used to be block scoped");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isNode.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return !(!e || !n.VISITOR_KEYS[e.type]);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isNodesEquivalent.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function isNodesEquivalent(e, t) {
					if ("object" != typeof e || "object" != typeof t || null == e || null == t) return e === t;
					if (e.type !== t.type) return !1;
					const r = Object.keys(n.NODE_FIELDS[e.type] || e.type), s = n.VISITOR_KEYS[e.type];
					for (const n of r) {
						const r = e[n], i = t[n];
						if (typeof r != typeof i) return !1;
						if (null != r || null != i) {
							if (null == r || null == i) return !1;
							if (Array.isArray(r)) {
								if (!Array.isArray(i)) return !1;
								if (r.length !== i.length) return !1;
								for (let e = 0; e < r.length; e++) if (!isNodesEquivalent(r[e], i[e])) return !1;
							} else if ("object" != typeof r || null != s && s.includes(n)) {
								if (!isNodesEquivalent(r, i)) return !1;
							} else for (const e of Object.keys(r)) if (r[e] !== i[e]) return !1;
						}
					}
					return !0;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isPlaceholderType.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					if (e === t) return !0;
					const r = n.PLACEHOLDERS_ALIAS[e];
					return !(null == r || !r.includes(t));
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isReferenced.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					switch (t.type) {
						case "MemberExpression":
						case "OptionalMemberExpression": return t.property === e ? !!t.computed : t.object === e;
						case "JSXMemberExpression": return t.object === e;
						case "VariableDeclarator": return t.init === e;
						case "ArrowFunctionExpression": return t.body === e;
						case "PrivateName":
						case "LabeledStatement":
						case "CatchClause":
						case "RestElement":
						case "BreakStatement":
						case "ContinueStatement":
						case "FunctionDeclaration":
						case "FunctionExpression":
						case "ExportNamespaceSpecifier":
						case "ExportDefaultSpecifier":
						case "ImportDefaultSpecifier":
						case "ImportNamespaceSpecifier":
						case "ImportSpecifier":
						case "ImportAttribute":
						case "JSXAttribute":
						case "ObjectPattern":
						case "ArrayPattern":
						case "MetaProperty": return !1;
						case "ClassMethod":
						case "ClassPrivateMethod":
						case "ObjectMethod": return t.key === e && !!t.computed;
						case "ObjectProperty": return t.key === e ? !!t.computed : !r || "ObjectPattern" !== r.type;
						case "ClassProperty":
						case "ClassAccessorProperty":
						case "TSPropertySignature": return t.key !== e || !!t.computed;
						case "ClassPrivateProperty":
						case "ObjectTypeProperty": return t.key !== e;
						case "ClassDeclaration":
						case "ClassExpression": return t.superClass === e;
						case "AssignmentExpression":
						case "AssignmentPattern": return t.right === e;
						case "ExportSpecifier": return (null == r || !r.source) && t.local === e;
						case "TSEnumMember": return t.id !== e;
					}
					return !0;
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isScope.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					if ((0, n.isBlockStatement)(e) && ((0, n.isFunction)(t) || (0, n.isCatchClause)(t))) return !1;
					if ((0, n.isPattern)(e) && ((0, n.isFunction)(t) || (0, n.isCatchClause)(t))) return !0;
					return (0, n.isScopable)(e);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isSpecifierDefault.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return (0, n.isImportDefaultSpecifier)(e) || (0, n.isIdentifier)(e.imported || e.exported, { name: "default" });
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isType.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t) {
					if (e === t) return !0;
					if (null == e) return !1;
					if (n.ALIAS_KEYS[t]) return !1;
					const r = n.FLIPPED_ALIAS_KEYS[t];
					return !(null == r || !r.includes(e));
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isValidES3Identifier.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return (0, n.default)(e) && !s.has(e);
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isValidIdentifier.js");
				const s = new Set([
					"abstract",
					"boolean",
					"byte",
					"char",
					"double",
					"enum",
					"final",
					"float",
					"goto",
					"implements",
					"int",
					"interface",
					"long",
					"native",
					"package",
					"private",
					"protected",
					"public",
					"short",
					"static",
					"synchronized",
					"throws",
					"transient",
					"volatile"
				]);
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isValidIdentifier.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t = !0) {
					if ("string" != typeof e) return !1;
					if (t && ((0, n.isKeyword)(e) || (0, n.isStrictReservedWord)(e, !0))) return !1;
					return (0, n.isIdentifierName)(e);
				};
				var n = r("./node_modules/.pnpm/@babel+helper-validator-identifier@7.27.1/node_modules/@babel/helper-validator-identifier/lib/index.js");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/isVar.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return (0, n.isVariableDeclaration)(e, { kind: "var" }) && !e[s];
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js"), s = Symbol.for("var used to be block scoped");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/matchesPattern.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					if (!isMemberExpressionLike(e)) return !1;
					const s = Array.isArray(t) ? t : t.split("."), i = [];
					let o;
					for (o = e; isMemberExpressionLike(o); o = null != (a = o.object) ? a : o.meta) {
						var a;
						i.push(o.property);
					}
					if (i.push(o), i.length < s.length) return !1;
					if (!r && i.length > s.length) return !1;
					for (let e = 0, t = i.length - 1; e < s.length; e++, t--) {
						const r = i[t];
						let o;
						if ((0, n.isIdentifier)(r)) o = r.name;
						else if ((0, n.isStringLiteral)(r)) o = r.value;
						else if ((0, n.isThisExpression)(r)) o = "this";
						else if ((0, n.isSuper)(r)) o = "super";
						else {
							if (!(0, n.isPrivateName)(r)) return !1;
							o = "#" + r.id.name;
						}
						if (s[e] !== o) return !1;
					}
					return !0;
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/generated/index.js");
				function isMemberExpressionLike(e) {
					return (0, n.isMemberExpression)(e) || (0, n.isMetaProperty)(e);
				}
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/react/isCompatTag.js": function(e, t) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e) {
					return !!e && /^[a-z]/.test(e);
				};
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/react/isReactComponent.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = void 0;
				t.default = (0, r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/buildMatchMemberExpression.js").default)("React.Component");
			},
			"./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/validators/validate.js": function(e, t, r) {
				"use strict";
				Object.defineProperty(t, "__esModule", { value: !0 }), t.default = function(e, t, r) {
					if (!e) return;
					const s = n.NODE_FIELDS[e.type];
					if (!s) return;
					const i = s[t];
					validateField(e, t, r, i), validateChild(e, t, r);
				}, t.validateChild = validateChild, t.validateField = validateField, t.validateInternal = function(e, t, r, s, i) {
					if (null == e || !e.validate) return;
					if (e.optional && null == s) return;
					if (e.validate(t, r, s), i) {
						var o;
						const e = s.type;
						if (null == e) return;
						null == (o = n.NODE_PARENT_VALIDATIONS[e]) || o.call(n.NODE_PARENT_VALIDATIONS, t, r, s);
					}
				};
				var n = r("./node_modules/.pnpm/@babel+types@7.28.4/node_modules/@babel/types/lib/definitions/index.js");
				function validateField(e, t, r, n) {
					null != n && n.validate && (n.optional && null == r || n.validate(e, t, r));
				}
				function validateChild(e, t, r) {
					var s;
					const i = null == r ? void 0 : r.type;
					null != i && (null == (s = n.NODE_PARENT_VALIDATIONS[i]) || s.call(n.NODE_PARENT_VALIDATIONS, e, t, r));
				}
			},
			"./node_modules/.pnpm/json5@2.2.3/node_modules/json5/dist/index.mjs": function(e, t, r) {
				"use strict";
				r.r(t), r.d(t, { default: () => T });
				var n = {
					Space_Separator: /[\u1680\u2000-\u200A\u202F\u205F\u3000]/,
					ID_Start: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312E\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FEA\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF2D-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDE00\uDE0B-\uDE32\uDE3A\uDE50\uDE5C-\uDE83\uDE86-\uDE89\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC72-\uDC8F\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD30\uDD46]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F\uDFE0\uDFE1]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00-\uDD1E\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4\uDD00-\uDD43]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D]/,
					ID_Continue: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u0860-\u086A\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u09FC\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9-\u0AFF\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D00-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19D9\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF9\u1D00-\u1DF9\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u2E2F\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099\u309A\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312E\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FEA\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF2D-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDCA-\uDDCC\uDDD0-\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE37\uDE3E\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF00-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF50\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC00-\uDC4A\uDC50-\uDC59\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDDD8-\uDDDD\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9\uDF00-\uDF19\uDF1D-\uDF2B\uDF30-\uDF39]|\uD806[\uDCA0-\uDCE9\uDCFF\uDE00-\uDE3E\uDE47\uDE50-\uDE83\uDE86-\uDE99\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC36\uDC38-\uDC40\uDC50-\uDC59\uDC72-\uDC8F\uDC92-\uDCA7\uDCA9-\uDCB6\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD36\uDD3A\uDD3C\uDD3D\uDD3F-\uDD47\uDD50-\uDD59]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F\uDFE0\uDFE1]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00-\uDD1E\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD836[\uDE00-\uDE36\uDE3B-\uDE6C\uDE75\uDE84\uDE9B-\uDE9F\uDEA1-\uDEAF]|\uD838[\uDC00-\uDC06\uDC08-\uDC18\uDC1B-\uDC21\uDC23\uDC24\uDC26-\uDC2A]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6\uDD00-\uDD4A\uDD50-\uDD59]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF]/
				}, s = {
					isSpaceSeparator: (e) => "string" == typeof e && n.Space_Separator.test(e),
					isIdStartChar: (e) => "string" == typeof e && (e >= "a" && e <= "z" || e >= "A" && e <= "Z" || "$" === e || "_" === e || n.ID_Start.test(e)),
					isIdContinueChar: (e) => "string" == typeof e && (e >= "a" && e <= "z" || e >= "A" && e <= "Z" || e >= "0" && e <= "9" || "$" === e || "_" === e || "‌" === e || "‍" === e || n.ID_Continue.test(e)),
					isDigit: (e) => "string" == typeof e && /[0-9]/.test(e),
					isHexDigit: (e) => "string" == typeof e && /[0-9A-Fa-f]/.test(e)
				};
				let i, o, a, l, p, c, u, d, h;
				function internalize(e, t, r) {
					const n = e[t];
					if (null != n && "object" == typeof n) if (Array.isArray(n)) for (let e = 0; e < n.length; e++) {
						const t = String(e), s = internalize(n, t, r);
						void 0 === s ? delete n[t] : Object.defineProperty(n, t, {
							value: s,
							writable: !0,
							enumerable: !0,
							configurable: !0
						});
					}
					else for (const e in n) {
						const t = internalize(n, e, r);
						void 0 === t ? delete n[e] : Object.defineProperty(n, e, {
							value: t,
							writable: !0,
							enumerable: !0,
							configurable: !0
						});
					}
					return r.call(e, t, n);
				}
				let m, f, y, b, g;
				function lex() {
					for (m = "default", f = "", y = !1, b = 1;;) {
						g = peek();
						const e = x[m]();
						if (e) return e;
					}
				}
				function peek() {
					if (i[l]) return String.fromCodePoint(i.codePointAt(l));
				}
				function read() {
					const e = peek();
					return "\n" === e ? (p++, c = 0) : e ? c += e.length : c++, e && (l += e.length), e;
				}
				const x = {
					default() {
						switch (g) {
							case "	":
							case "\v":
							case "\f":
							case " ":
							case "\xA0":
							case "﻿":
							case "\n":
							case "\r":
							case "\u2028":
							case "\u2029":
								read();
								return;
							case "/":
								read(), m = "comment";
								return;
							case void 0: return read(), newToken("eof");
						}
						if (!s.isSpaceSeparator(g)) return x[o]();
						read();
					},
					comment() {
						switch (g) {
							case "*":
								read(), m = "multiLineComment";
								return;
							case "/":
								read(), m = "singleLineComment";
								return;
						}
						throw invalidChar(read());
					},
					multiLineComment() {
						switch (g) {
							case "*":
								read(), m = "multiLineCommentAsterisk";
								return;
							case void 0: throw invalidChar(read());
						}
						read();
					},
					multiLineCommentAsterisk() {
						switch (g) {
							case "*":
								read();
								return;
							case "/":
								read(), m = "default";
								return;
							case void 0: throw invalidChar(read());
						}
						read(), m = "multiLineComment";
					},
					singleLineComment() {
						switch (g) {
							case "\n":
							case "\r":
							case "\u2028":
							case "\u2029":
								read(), m = "default";
								return;
							case void 0: return read(), newToken("eof");
						}
						read();
					},
					value() {
						switch (g) {
							case "{":
							case "[": return newToken("punctuator", read());
							case "n": return read(), literal("ull"), newToken("null", null);
							case "t": return read(), literal("rue"), newToken("boolean", !0);
							case "f": return read(), literal("alse"), newToken("boolean", !1);
							case "-":
							case "+":
								"-" === read() && (b = -1), m = "sign";
								return;
							case ".":
								f = read(), m = "decimalPointLeading";
								return;
							case "0":
								f = read(), m = "zero";
								return;
							case "1":
							case "2":
							case "3":
							case "4":
							case "5":
							case "6":
							case "7":
							case "8":
							case "9":
								f = read(), m = "decimalInteger";
								return;
							case "I": return read(), literal("nfinity"), newToken("numeric", Infinity);
							case "N": return read(), literal("aN"), newToken("numeric", NaN);
							case "\"":
							case "'":
								y = "\"" === read(), f = "", m = "string";
								return;
						}
						throw invalidChar(read());
					},
					identifierNameStartEscape() {
						if ("u" !== g) throw invalidChar(read());
						read();
						const e = unicodeEscape();
						switch (e) {
							case "$":
							case "_": break;
							default: if (!s.isIdStartChar(e)) throw invalidIdentifier();
						}
						f += e, m = "identifierName";
					},
					identifierName() {
						switch (g) {
							case "$":
							case "_":
							case "‌":
							case "‍":
								f += read();
								return;
							case "\\":
								read(), m = "identifierNameEscape";
								return;
						}
						if (!s.isIdContinueChar(g)) return newToken("identifier", f);
						f += read();
					},
					identifierNameEscape() {
						if ("u" !== g) throw invalidChar(read());
						read();
						const e = unicodeEscape();
						switch (e) {
							case "$":
							case "_":
							case "‌":
							case "‍": break;
							default: if (!s.isIdContinueChar(e)) throw invalidIdentifier();
						}
						f += e, m = "identifierName";
					},
					sign() {
						switch (g) {
							case ".":
								f = read(), m = "decimalPointLeading";
								return;
							case "0":
								f = read(), m = "zero";
								return;
							case "1":
							case "2":
							case "3":
							case "4":
							case "5":
							case "6":
							case "7":
							case "8":
							case "9":
								f = read(), m = "decimalInteger";
								return;
							case "I": return read(), literal("nfinity"), newToken("numeric", b * Infinity);
							case "N": return read(), literal("aN"), newToken("numeric", NaN);
						}
						throw invalidChar(read());
					},
					zero() {
						switch (g) {
							case ".":
								f += read(), m = "decimalPoint";
								return;
							case "e":
							case "E":
								f += read(), m = "decimalExponent";
								return;
							case "x":
							case "X":
								f += read(), m = "hexadecimal";
								return;
						}
						return newToken("numeric", 0 * b);
					},
					decimalInteger() {
						switch (g) {
							case ".":
								f += read(), m = "decimalPoint";
								return;
							case "e":
							case "E":
								f += read(), m = "decimalExponent";
								return;
						}
						if (!s.isDigit(g)) return newToken("numeric", b * Number(f));
						f += read();
					},
					decimalPointLeading() {
						if (s.isDigit(g)) return f += read(), void (m = "decimalFraction");
						throw invalidChar(read());
					},
					decimalPoint() {
						switch (g) {
							case "e":
							case "E":
								f += read(), m = "decimalExponent";
								return;
						}
						return s.isDigit(g) ? (f += read(), void (m = "decimalFraction")) : newToken("numeric", b * Number(f));
					},
					decimalFraction() {
						switch (g) {
							case "e":
							case "E":
								f += read(), m = "decimalExponent";
								return;
						}
						if (!s.isDigit(g)) return newToken("numeric", b * Number(f));
						f += read();
					},
					decimalExponent() {
						switch (g) {
							case "+":
							case "-":
								f += read(), m = "decimalExponentSign";
								return;
						}
						if (s.isDigit(g)) return f += read(), void (m = "decimalExponentInteger");
						throw invalidChar(read());
					},
					decimalExponentSign() {
						if (s.isDigit(g)) return f += read(), void (m = "decimalExponentInteger");
						throw invalidChar(read());
					},
					decimalExponentInteger() {
						if (!s.isDigit(g)) return newToken("numeric", b * Number(f));
						f += read();
					},
					hexadecimal() {
						if (s.isHexDigit(g)) return f += read(), void (m = "hexadecimalInteger");
						throw invalidChar(read());
					},
					hexadecimalInteger() {
						if (!s.isHexDigit(g)) return newToken("numeric", b * Number(f));
						f += read();
					},
					string() {
						switch (g) {
							case "\\":
								read(), f += function() {
									switch (peek()) {
										case "b": return read(), "\b";
										case "f": return read(), "\f";
										case "n": return read(), "\n";
										case "r": return read(), "\r";
										case "t": return read(), "	";
										case "v": return read(), "\v";
										case "0":
											if (read(), s.isDigit(peek())) throw invalidChar(read());
											return "\0";
										case "x": return read(), function() {
											let e = "", t = peek();
											if (!s.isHexDigit(t)) throw invalidChar(read());
											if (e += read(), t = peek(), !s.isHexDigit(t)) throw invalidChar(read());
											return e += read(), String.fromCodePoint(parseInt(e, 16));
										}();
										case "u": return read(), unicodeEscape();
										case "\n":
										case "\u2028":
										case "\u2029": return read(), "";
										case "\r": return read(), "\n" === peek() && read(), "";
										case "1":
										case "2":
										case "3":
										case "4":
										case "5":
										case "6":
										case "7":
										case "8":
										case "9":
										case void 0: throw invalidChar(read());
									}
									return read();
								}();
								return;
							case "\"": return y ? (read(), newToken("string", f)) : void (f += read());
							case "'": return y ? void (f += read()) : (read(), newToken("string", f));
							case "\n":
							case "\r": throw invalidChar(read());
							case "\u2028":
							case "\u2029":
								(function(e) {
									console.warn(`JSON5: '${formatChar(e)}' in strings is not valid ECMAScript; consider escaping`);
								})(g);
								break;
							case void 0: throw invalidChar(read());
						}
						f += read();
					},
					start() {
						switch (g) {
							case "{":
							case "[": return newToken("punctuator", read());
						}
						m = "value";
					},
					beforePropertyName() {
						switch (g) {
							case "$":
							case "_":
								f = read(), m = "identifierName";
								return;
							case "\\":
								read(), m = "identifierNameStartEscape";
								return;
							case "}": return newToken("punctuator", read());
							case "\"":
							case "'":
								y = "\"" === read(), m = "string";
								return;
						}
						if (s.isIdStartChar(g)) return f += read(), void (m = "identifierName");
						throw invalidChar(read());
					},
					afterPropertyName() {
						if (":" === g) return newToken("punctuator", read());
						throw invalidChar(read());
					},
					beforePropertyValue() {
						m = "value";
					},
					afterPropertyValue() {
						switch (g) {
							case ",":
							case "}": return newToken("punctuator", read());
						}
						throw invalidChar(read());
					},
					beforeArrayValue() {
						if ("]" === g) return newToken("punctuator", read());
						m = "value";
					},
					afterArrayValue() {
						switch (g) {
							case ",":
							case "]": return newToken("punctuator", read());
						}
						throw invalidChar(read());
					},
					end() {
						throw invalidChar(read());
					}
				};
				function newToken(e, t) {
					return {
						type: e,
						value: t,
						line: p,
						column: c
					};
				}
				function literal(e) {
					for (const t of e) {
						if (peek() !== t) throw invalidChar(read());
						read();
					}
				}
				function unicodeEscape() {
					let e = "", t = 4;
					for (; t-- > 0;) {
						const t = peek();
						if (!s.isHexDigit(t)) throw invalidChar(read());
						e += read();
					}
					return String.fromCodePoint(parseInt(e, 16));
				}
				const v = {
					start() {
						if ("eof" === u.type) throw invalidEOF();
						push();
					},
					beforePropertyName() {
						switch (u.type) {
							case "identifier":
							case "string":
								d = u.value, o = "afterPropertyName";
								return;
							case "punctuator":
								pop();
								return;
							case "eof": throw invalidEOF();
						}
					},
					afterPropertyName() {
						if ("eof" === u.type) throw invalidEOF();
						o = "beforePropertyValue";
					},
					beforePropertyValue() {
						if ("eof" === u.type) throw invalidEOF();
						push();
					},
					beforeArrayValue() {
						if ("eof" === u.type) throw invalidEOF();
						"punctuator" !== u.type || "]" !== u.value ? push() : pop();
					},
					afterPropertyValue() {
						if ("eof" === u.type) throw invalidEOF();
						switch (u.value) {
							case ",":
								o = "beforePropertyName";
								return;
							case "}": pop();
						}
					},
					afterArrayValue() {
						if ("eof" === u.type) throw invalidEOF();
						switch (u.value) {
							case ",":
								o = "beforeArrayValue";
								return;
							case "]": pop();
						}
					},
					end() {}
				};
				function push() {
					let e;
					switch (u.type) {
						case "punctuator":
							switch (u.value) {
								case "{":
									e = {};
									break;
								case "[": e = [];
							}
							break;
						case "null":
						case "boolean":
						case "numeric":
						case "string": e = u.value;
					}
					if (void 0 === h) h = e;
					else {
						const t = a[a.length - 1];
						Array.isArray(t) ? t.push(e) : Object.defineProperty(t, d, {
							value: e,
							writable: !0,
							enumerable: !0,
							configurable: !0
						});
					}
					if (null !== e && "object" == typeof e) a.push(e), o = Array.isArray(e) ? "beforeArrayValue" : "beforePropertyName";
					else {
						const e = a[a.length - 1];
						o = null == e ? "end" : Array.isArray(e) ? "afterArrayValue" : "afterPropertyValue";
					}
				}
				function pop() {
					a.pop();
					const e = a[a.length - 1];
					o = null == e ? "end" : Array.isArray(e) ? "afterArrayValue" : "afterPropertyValue";
				}
				function invalidChar(e) {
					return syntaxError(void 0 === e ? `JSON5: invalid end of input at ${p}:${c}` : `JSON5: invalid character '${formatChar(e)}' at ${p}:${c}`);
				}
				function invalidEOF() {
					return syntaxError(`JSON5: invalid end of input at ${p}:${c}`);
				}
				function invalidIdentifier() {
					return c -= 5, syntaxError(`JSON5: invalid identifier character at ${p}:${c}`);
				}
				function formatChar(e) {
					const t = {
						"'": "\\'",
						"\"": "\\\"",
						"\\": "\\\\",
						"\b": "\\b",
						"\f": "\\f",
						"\n": "\\n",
						"\r": "\\r",
						"	": "\\t",
						"\v": "\\v",
						"\0": "\\0",
						"\u2028": "\\u2028",
						"\u2029": "\\u2029"
					};
					if (t[e]) return t[e];
					if (e < " ") {
						const t = e.charCodeAt(0).toString(16);
						return "\\x" + ("00" + t).substring(t.length);
					}
					return e;
				}
				function syntaxError(e) {
					const t = new SyntaxError(e);
					return t.lineNumber = p, t.columnNumber = c, t;
				}
				const T = {
					parse: function(e, t) {
						i = String(e), o = "start", a = [], l = 0, p = 1, c = 0, u = void 0, d = void 0, h = void 0;
						do
							u = lex(), v[o]();
						while ("eof" !== u.type);
						return "function" == typeof t ? internalize({ "": h }, "", t) : h;
					},
					stringify: function(e, t, r) {
						const n = [];
						let i, o, a, l = "", p = "";
						if (null == t || "object" != typeof t || Array.isArray(t) || (r = t.space, a = t.quote, t = t.replacer), "function" == typeof t) o = t;
						else if (Array.isArray(t)) {
							i = [];
							for (const e of t) {
								let t;
								"string" == typeof e ? t = e : ("number" == typeof e || e instanceof String || e instanceof Number) && (t = String(e)), void 0 !== t && i.indexOf(t) < 0 && i.push(t);
							}
						}
						return r instanceof Number ? r = Number(r) : r instanceof String && (r = String(r)), "number" == typeof r ? r > 0 && (r = Math.min(10, Math.floor(r)), p = "          ".substr(0, r)) : "string" == typeof r && (p = r.substr(0, 10)), serializeProperty("", { "": e });
						function serializeProperty(e, t) {
							let r = t[e];
							switch (null != r && ("function" == typeof r.toJSON5 ? r = r.toJSON5(e) : "function" == typeof r.toJSON && (r = r.toJSON(e))), o && (r = o.call(t, e, r)), r instanceof Number ? r = Number(r) : r instanceof String ? r = String(r) : r instanceof Boolean && (r = r.valueOf()), r) {
								case null: return "null";
								case !0: return "true";
								case !1: return "false";
							}
							return "string" == typeof r ? quoteString(r) : "number" == typeof r ? String(r) : "object" == typeof r ? Array.isArray(r) ? function(e) {
								if (n.indexOf(e) >= 0) throw TypeError("Converting circular structure to JSON5");
								n.push(e);
								let t = l;
								l += p;
								let r, s = [];
								for (let t = 0; t < e.length; t++) {
									const r = serializeProperty(String(t), e);
									s.push(void 0 !== r ? r : "null");
								}
								if (0 === s.length) r = "[]";
								else if ("" === p) r = "[" + s.join(",") + "]";
								else {
									let e = ",\n" + l, n = s.join(e);
									r = "[\n" + l + n + ",\n" + t + "]";
								}
								return n.pop(), l = t, r;
							}(r) : function(e) {
								if (n.indexOf(e) >= 0) throw TypeError("Converting circular structure to JSON5");
								n.push(e);
								let t = l;
								l += p;
								let r, s = i || Object.keys(e), o = [];
								for (const t of s) {
									const r = serializeProperty(t, e);
									if (void 0 !== r) {
										let e = serializeKey(t) + ":";
										"" !== p && (e += " "), e += r, o.push(e);
									}
								}
								if (0 === o.length) r = "{}";
								else {
									let e;
									if ("" === p) e = o.join(","), r = "{" + e + "}";
									else {
										let n = ",\n" + l;
										e = o.join(n), r = "{\n" + l + e + ",\n" + t + "}";
									}
								}
								return n.pop(), l = t, r;
							}(r) : void 0;
						}
						function quoteString(e) {
							const t = {
								"'": .1,
								"\"": .2
							}, r = {
								"'": "\\'",
								"\"": "\\\"",
								"\\": "\\\\",
								"\b": "\\b",
								"\f": "\\f",
								"\n": "\\n",
								"\r": "\\r",
								"	": "\\t",
								"\v": "\\v",
								"\0": "\\0",
								"\u2028": "\\u2028",
								"\u2029": "\\u2029"
							};
							let n = "";
							for (let i = 0; i < e.length; i++) {
								const o = e[i];
								switch (o) {
									case "'":
									case "\"":
										t[o]++, n += o;
										continue;
									case "\0": if (s.isDigit(e[i + 1])) {
										n += "\\x00";
										continue;
									}
								}
								if (r[o]) n += r[o];
								else {
									if (o < " ") {
										let e = o.charCodeAt(0).toString(16);
										n += "\\x" + ("00" + e).substring(e.length);
										continue;
									}
									n += o;
								}
							}
							const i = a || Object.keys(t).reduce((e, r) => t[e] < t[r] ? e : r);
							return n = n.replace(new RegExp(i, "g"), r[i]), i + n + i;
						}
						function serializeKey(e) {
							if (0 === e.length) return quoteString(e);
							const t = String.fromCodePoint(e.codePointAt(0));
							if (!s.isIdStartChar(t)) return quoteString(e);
							for (let r = t.length; r < e.length; r++) if (!s.isIdContinueChar(String.fromCodePoint(e.codePointAt(r)))) return quoteString(e);
							return e;
						}
					}
				};
			},
			"./stubs/babel-codeframe.mjs": function(e, t, r) {
				"use strict";
				function codeFrameColumns() {
					return "";
				}
				r.r(t), r.d(t, { codeFrameColumns: () => codeFrameColumns });
			},
			"./stubs/helper-compilation-targets.mjs": function(e, t, r) {
				"use strict";
				function getTargets() {
					return {};
				}
				r.r(t), r.d(t, { default: () => getTargets });
			},
			"./node_modules/.pnpm/@babel+helper-globals@7.28.0/node_modules/@babel/helper-globals/data/builtin-lower.json": function(e) {
				"use strict";
				e.exports = JSON.parse("[\"decodeURI\",\"decodeURIComponent\",\"encodeURI\",\"encodeURIComponent\",\"escape\",\"eval\",\"globalThis\",\"isFinite\",\"isNaN\",\"parseFloat\",\"parseInt\",\"undefined\",\"unescape\"]");
			},
			"./node_modules/.pnpm/@babel+helper-globals@7.28.0/node_modules/@babel/helper-globals/data/builtin-upper.json": function(e) {
				"use strict";
				e.exports = JSON.parse("[\"AggregateError\",\"Array\",\"ArrayBuffer\",\"Atomics\",\"BigInt\",\"BigInt64Array\",\"BigUint64Array\",\"Boolean\",\"DataView\",\"Date\",\"Error\",\"EvalError\",\"FinalizationRegistry\",\"Float16Array\",\"Float32Array\",\"Float64Array\",\"Function\",\"Infinity\",\"Int16Array\",\"Int32Array\",\"Int8Array\",\"Intl\",\"Iterator\",\"JSON\",\"Map\",\"Math\",\"NaN\",\"Number\",\"Object\",\"Promise\",\"Proxy\",\"RangeError\",\"ReferenceError\",\"Reflect\",\"RegExp\",\"Set\",\"SharedArrayBuffer\",\"String\",\"Symbol\",\"SyntaxError\",\"TypeError\",\"Uint16Array\",\"Uint32Array\",\"Uint8Array\",\"Uint8ClampedArray\",\"URIError\",\"WeakMap\",\"WeakRef\",\"WeakSet\"]");
			},
			"./node_modules/.pnpm/@babel+preset-typescript@7.27.1_@babel+core@7.28.4/node_modules/@babel/preset-typescript/package.json": function(e) {
				"use strict";
				e.exports = JSON.parse("{\"name\":\"@babel/preset-typescript\",\"version\":\"7.27.1\",\"description\":\"Babel preset for TypeScript.\",\"repository\":{\"type\":\"git\",\"url\":\"https://github.com/babel/babel.git\",\"directory\":\"packages/babel-preset-typescript\"},\"license\":\"MIT\",\"publishConfig\":{\"access\":\"public\"},\"main\":\"./lib/index.js\",\"keywords\":[\"babel-preset\",\"typescript\"],\"dependencies\":{\"@babel/helper-plugin-utils\":\"^7.27.1\",\"@babel/helper-validator-option\":\"^7.27.1\",\"@babel/plugin-syntax-jsx\":\"^7.27.1\",\"@babel/plugin-transform-modules-commonjs\":\"^7.27.1\",\"@babel/plugin-transform-typescript\":\"^7.27.1\"},\"peerDependencies\":{\"@babel/core\":\"^7.0.0-0\"},\"devDependencies\":{\"@babel/core\":\"^7.27.1\",\"@babel/helper-plugin-test-runner\":\"^7.27.1\"},\"homepage\":\"https://babel.dev/docs/en/next/babel-preset-typescript\",\"bugs\":\"https://github.com/babel/babel/issues?utf8=%E2%9C%93&q=is%3Aissue+label%3A%22area%3A%20typescript%22+is%3Aopen\",\"engines\":{\"node\":\">=6.9.0\"},\"author\":\"The Babel Team (https://babel.dev/team)\",\"type\":\"commonjs\"}");
			}
		}, t = {};
		function __webpack_require__(r) {
			var n = t[r];
			if (void 0 !== n) return n.exports;
			var s = t[r] = {
				id: r,
				loaded: !1,
				exports: {}
			};
			return e[r].call(s.exports, s, s.exports, __webpack_require__), s.loaded = !0, s.exports;
		}
		__webpack_require__.n = (e) => {
			var t = e && e.__esModule ? () => e.default : () => e;
			return __webpack_require__.d(t, { a: t }), t;
		}, __webpack_require__.d = (e, t) => {
			for (var r in t) __webpack_require__.o(t, r) && !__webpack_require__.o(e, r) && Object.defineProperty(e, r, {
				enumerable: !0,
				get: t[r]
			});
		}, __webpack_require__.o = (e, t) => Object.prototype.hasOwnProperty.call(e, t), __webpack_require__.r = (e) => {
			"undefined" != typeof Symbol && Symbol.toStringTag && Object.defineProperty(e, Symbol.toStringTag, { value: "Module" }), Object.defineProperty(e, "__esModule", { value: !0 });
		}, __webpack_require__.nmd = (e) => (e.paths = [], e.children || (e.children = []), e);
		var r = {};
		(() => {
			"use strict";
			__webpack_require__.d(r, { default: () => transform });
			var e = __webpack_require__("./node_modules/.pnpm/@babel+core@7.28.4/node_modules/@babel/core/lib/index.js"), t = __webpack_require__("./node_modules/.pnpm/@babel+plugin-proposal-decorators@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-proposal-decorators/lib/index.js"), n = __webpack_require__("./node_modules/.pnpm/@babel+plugin-syntax-class-properties@7.12.13_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-class-properties/lib/index.js"), s = __webpack_require__("./node_modules/.pnpm/@babel+plugin-syntax-import-assertions@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-import-assertions/lib/index.js"), i = __webpack_require__("./node_modules/.pnpm/@babel+plugin-syntax-jsx@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-syntax-jsx/lib/index.js"), o = __webpack_require__("./node_modules/.pnpm/@babel+plugin-transform-export-namespace-from@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-export-namespace-from/lib/index.js"), a = __webpack_require__("./node_modules/.pnpm/@babel+plugin-transform-react-jsx@7.27.1_@babel+core@7.28.4/node_modules/@babel/plugin-transform-react-jsx/lib/index.js"), l = __webpack_require__("./node_modules/.pnpm/@babel+plugin-transform-typescript@7.28.0_@babel+core@7.28.4/node_modules/@babel/plugin-transform-typescript/lib/index.js"), p = __webpack_require__("./node_modules/.pnpm/babel-plugin-parameter-decorator@1.0.16/node_modules/babel-plugin-parameter-decorator/lib/index.js"), c = __webpack_require__.n(p), u = __webpack_require__("./node_modules/.pnpm/@babel+helper-plugin-utils@7.27.1/node_modules/@babel/helper-plugin-utils/lib/index.js");
			function createParamDecorator(t, r, n = !1) {
				return e.types.decorator(e.types.functionExpression(null, [e.types.identifier("target"), e.types.identifier("key")], e.types.blockStatement([e.types.returnStatement(e.types.callExpression(r, [
					e.types.identifier("target"),
					e.types.identifier(n ? "undefined" : "key"),
					e.types.numericLiteral(t)
				]))])));
			}
			function parameterVisitor(e, t) {
				if ("ClassMethod" !== t.type) return;
				if ("ClassMethod" !== t.node.type) return;
				if ("Identifier" !== t.node.key.type) return;
				const r = t, n = r.get("params") || [];
				for (const t of n) {
					if (null == ("Identifier" === t.node.type || "ObjectPattern" === t.node.type ? t.node : "TSParameterProperty" === t.node.type && "Identifier" === t.node.parameter.type ? t.node.parameter : null)) continue;
					let n;
					for (const s of t.node.decorators || []) "constructor" === r.node.kind ? (n = createParamDecorator(t.key, s.expression, !0), e.node.decorators || (e.node.decorators = []), e.node.decorators.push(n)) : (n = createParamDecorator(t.key, s.expression, !1), r.node.decorators || (r.node.decorators = []), r.node.decorators.push(n));
					n && (t.node.decorators = null);
				}
			}
			function createVoidZero() {
				return e.types.unaryExpression("void", e.types.numericLiteral(0));
			}
			function getTypedNode(e) {
				return null == e ? null : "ClassProperty" === e.type || "Identifier" === e.type || "ObjectPattern" === e.type ? e : "AssignmentPattern" === e.type && "Identifier" === e.left.type ? e.left : "TSParameterProperty" === e.type ? getTypedNode(e.parameter) : null;
			}
			function serializeType(e, t) {
				const r = getTypedNode(t);
				if (null == r) return createVoidZero();
				if (!r.typeAnnotation || "TSTypeAnnotation" !== r.typeAnnotation.type) return createVoidZero();
				const n = r.typeAnnotation.typeAnnotation;
				return serializeTypeNode(e.node.id ? e.node.id.name : "", n);
			}
			function serializeTypeReferenceNode(t, r) {
				const n = serializeReference(r.typeName);
				return isClassType(t, n) ? e.types.identifier("Object") : e.types.conditionalExpression(e.types.binaryExpression("===", e.types.unaryExpression("typeof", n), e.types.stringLiteral("undefined")), e.types.identifier("Object"), e.types.cloneDeep(n));
			}
			function isClassType(e, t) {
				switch (t.type) {
					case "Identifier": return t.name === e;
					case "MemberExpression": return isClassType(e, t.object);
					default: throw new Error(`The property expression at ${t.start} is not valid as a Type to be used in Reflect.metadata`);
				}
			}
			function serializeReference(t) {
				return "Identifier" === t.type ? e.types.identifier(t.name) : e.types.memberExpression(serializeReference(t.left), t.right);
			}
			function serializeTypeNode(t, r) {
				if (void 0 === r) return e.types.identifier("Object");
				switch (r.type) {
					case "TSVoidKeyword":
					case "TSUndefinedKeyword":
					case "TSNullKeyword":
					case "TSNeverKeyword": return createVoidZero();
					case "TSParenthesizedType": return serializeTypeNode(t, r.typeAnnotation);
					case "TSFunctionType":
					case "TSConstructorType": return e.types.identifier("Function");
					case "TSArrayType":
					case "TSTupleType": return e.types.identifier("Array");
					case "TSTypePredicate":
					case "TSBooleanKeyword": return e.types.identifier("Boolean");
					case "TSStringKeyword": return e.types.identifier("String");
					case "TSObjectKeyword": return e.types.identifier("Object");
					case "TSLiteralType": switch (r.literal.type) {
						case "StringLiteral": return e.types.identifier("String");
						case "NumericLiteral": return e.types.identifier("Number");
						case "BooleanLiteral": return e.types.identifier("Boolean");
						default: throw new Error("Bad type for decorator" + r.literal);
					}
					case "TSNumberKeyword":
					case "TSBigIntKeyword": return e.types.identifier("Number");
					case "TSSymbolKeyword": return e.types.identifier("Symbol");
					case "TSTypeReference": return serializeTypeReferenceNode(t, r);
					case "TSIntersectionType":
					case "TSUnionType": return serializeTypeList(t, r.types);
					case "TSConditionalType": return serializeTypeList(t, [r.trueType, r.falseType]);
					case "TSTypeQuery":
					case "TSTypeOperator":
					case "TSIndexedAccessType":
					case "TSMappedType":
					case "TSTypeLiteral":
					case "TSAnyKeyword":
					case "TSUnknownKeyword":
					case "TSThisType": break;
					default: throw new Error("Bad type for decorator");
				}
				return e.types.identifier("Object");
			}
			function serializeTypeList(t, r) {
				let n;
				for (let s of r) {
					for (; "TSParenthesizedType" === s.type;) s = s.typeAnnotation;
					if ("TSNeverKeyword" === s.type) continue;
					if ("TSNullKeyword" === s.type || "TSUndefinedKeyword" === s.type) continue;
					const r = serializeTypeNode(t, s);
					if (e.types.isIdentifier(r) && "Object" === r.name) return r;
					if (n) {
						if (!e.types.isIdentifier(n) || !e.types.isIdentifier(r) || n.name !== r.name) return e.types.identifier("Object");
					} else n = r;
				}
				return n || createVoidZero();
			}
			function createMetadataDesignDecorator(t, r) {
				return e.types.decorator(e.types.logicalExpression("||", e.types.optionalCallExpression(e.types.memberExpression(e.types.identifier("Reflect"), e.types.identifier("metadata")), [e.types.stringLiteral(t), r], !0), e.types.arrowFunctionExpression([e.types.identifier("t")], e.types.identifier("t"))));
			}
			function metadataVisitor(t, r) {
				const n = r.node, s = t.node;
				switch (n.type) {
					case "ClassMethod": {
						const r = "constructor" === n.kind ? s.decorators : n.decorators;
						if (!r || 0 === r.length) return;
						r.push(createMetadataDesignDecorator("design:type", e.types.identifier("Function"))), r.push(createMetadataDesignDecorator("design:paramtypes", e.types.arrayExpression(n.params.map((e) => serializeType(t, e)))));
						break;
					}
					case "ClassProperty":
						if (!n.decorators || 0 === n.decorators.length) return;
						if (!n.typeAnnotation || "TSTypeAnnotation" !== n.typeAnnotation.type) return;
						n.decorators.push(createMetadataDesignDecorator("design:type", serializeType(t, n)));
				}
			}
			const d = (0, u.declare)((e) => (e.assertVersion(7), { visitor: { Program(e) {
				e.traverse({ ClassDeclaration(e) {
					for (const t of e.get("body").get("body")) "ClassMethod" !== t.type && "ClassProperty" !== t.type || (parameterVisitor(e, t), metadataVisitor(e, t));
					e.parentPath.scope.crawl();
				} });
			} } }));
			function importMetaEnvPlugin({ template: e, types: t }) {
				return {
					name: "@import-meta-env/babel",
					visitor: { Identifier(r) {
						if (!t.isIdentifier(r)) return;
						if (!t.isMemberExpression(r.parentPath) && !t.isOptionalMemberExpression(r.parentPath)) return;
						if (!t.isMemberExpression(r.parentPath.node)) return;
						const n = r.parentPath.node;
						if (!t.isMetaProperty(n.object)) return;
						const s = n.object;
						"import" === s.meta.name && "meta" === s.property.name && "env" === n.property.name && r.parentPath.replaceWith(e.expression.ast("process.env"));
					} }
				};
			}
			function importMetaResolvePlugin(e) {
				return {
					name: "import-meta-resolve",
					visitor: { Program(e) {
						const t = [];
						if (e.traverse({ MemberExpression(e) {
							const { node: r } = e;
							"MetaProperty" === r.object.type && "import" === r.object.meta.name && "meta" === r.object.property.name && "Identifier" === r.property.type && "resolve" === r.property.name && t.push(e);
						} }), 0 !== t.length) for (const e of t) e.replaceWith({
							type: "ExpressionStatement",
							expression: {
								type: "Identifier",
								name: "jitiESMResolve"
							}
						});
					} }
				};
			}
			var h = __webpack_require__("./node_modules/.pnpm/@babel+template@7.27.2/node_modules/@babel/template/lib/index.js");
			const m = /^[A-Za-z]:\//;
			function normalizeWindowsPath(e = "") {
				return e ? e.replace(/\\/g, "/").replace(m, (e) => e.toUpperCase()) : e;
			}
			const f = /^[/\\](?![/\\])|^[/\\]{2}(?!\.)|^[A-Za-z]:[/\\]/, y = /^[A-Za-z]:$/;
			const pathe_M_eThtNZ_isAbsolute = function(e) {
				return f.test(e);
			}, pathe_M_eThtNZ_dirname = function(e) {
				const t = normalizeWindowsPath(e).replace(/\/$/, "").split("/").slice(0, -1);
				return 1 === t.length && y.test(t[0]) && (t[0] += "/"), t.join("/") || (pathe_M_eThtNZ_isAbsolute(e) ? "/" : ".");
			};
			var b = [
				509,
				0,
				227,
				0,
				150,
				4,
				294,
				9,
				1368,
				2,
				2,
				1,
				6,
				3,
				41,
				2,
				5,
				0,
				166,
				1,
				574,
				3,
				9,
				9,
				7,
				9,
				32,
				4,
				318,
				1,
				80,
				3,
				71,
				10,
				50,
				3,
				123,
				2,
				54,
				14,
				32,
				10,
				3,
				1,
				11,
				3,
				46,
				10,
				8,
				0,
				46,
				9,
				7,
				2,
				37,
				13,
				2,
				9,
				6,
				1,
				45,
				0,
				13,
				2,
				49,
				13,
				9,
				3,
				2,
				11,
				83,
				11,
				7,
				0,
				3,
				0,
				158,
				11,
				6,
				9,
				7,
				3,
				56,
				1,
				2,
				6,
				3,
				1,
				3,
				2,
				10,
				0,
				11,
				1,
				3,
				6,
				4,
				4,
				68,
				8,
				2,
				0,
				3,
				0,
				2,
				3,
				2,
				4,
				2,
				0,
				15,
				1,
				83,
				17,
				10,
				9,
				5,
				0,
				82,
				19,
				13,
				9,
				214,
				6,
				3,
				8,
				28,
				1,
				83,
				16,
				16,
				9,
				82,
				12,
				9,
				9,
				7,
				19,
				58,
				14,
				5,
				9,
				243,
				14,
				166,
				9,
				71,
				5,
				2,
				1,
				3,
				3,
				2,
				0,
				2,
				1,
				13,
				9,
				120,
				6,
				3,
				6,
				4,
				0,
				29,
				9,
				41,
				6,
				2,
				3,
				9,
				0,
				10,
				10,
				47,
				15,
				343,
				9,
				54,
				7,
				2,
				7,
				17,
				9,
				57,
				21,
				2,
				13,
				123,
				5,
				4,
				0,
				2,
				1,
				2,
				6,
				2,
				0,
				9,
				9,
				49,
				4,
				2,
				1,
				2,
				4,
				9,
				9,
				330,
				3,
				10,
				1,
				2,
				0,
				49,
				6,
				4,
				4,
				14,
				10,
				5350,
				0,
				7,
				14,
				11465,
				27,
				2343,
				9,
				87,
				9,
				39,
				4,
				60,
				6,
				26,
				9,
				535,
				9,
				470,
				0,
				2,
				54,
				8,
				3,
				82,
				0,
				12,
				1,
				19628,
				1,
				4178,
				9,
				519,
				45,
				3,
				22,
				543,
				4,
				4,
				5,
				9,
				7,
				3,
				6,
				31,
				3,
				149,
				2,
				1418,
				49,
				513,
				54,
				5,
				49,
				9,
				0,
				15,
				0,
				23,
				4,
				2,
				14,
				1361,
				6,
				2,
				16,
				3,
				6,
				2,
				1,
				2,
				4,
				101,
				0,
				161,
				6,
				10,
				9,
				357,
				0,
				62,
				13,
				499,
				13,
				245,
				1,
				2,
				9,
				726,
				6,
				110,
				6,
				6,
				9,
				4759,
				9,
				787719,
				239
			], g = [
				0,
				11,
				2,
				25,
				2,
				18,
				2,
				1,
				2,
				14,
				3,
				13,
				35,
				122,
				70,
				52,
				268,
				28,
				4,
				48,
				48,
				31,
				14,
				29,
				6,
				37,
				11,
				29,
				3,
				35,
				5,
				7,
				2,
				4,
				43,
				157,
				19,
				35,
				5,
				35,
				5,
				39,
				9,
				51,
				13,
				10,
				2,
				14,
				2,
				6,
				2,
				1,
				2,
				10,
				2,
				14,
				2,
				6,
				2,
				1,
				4,
				51,
				13,
				310,
				10,
				21,
				11,
				7,
				25,
				5,
				2,
				41,
				2,
				8,
				70,
				5,
				3,
				0,
				2,
				43,
				2,
				1,
				4,
				0,
				3,
				22,
				11,
				22,
				10,
				30,
				66,
				18,
				2,
				1,
				11,
				21,
				11,
				25,
				71,
				55,
				7,
				1,
				65,
				0,
				16,
				3,
				2,
				2,
				2,
				28,
				43,
				28,
				4,
				28,
				36,
				7,
				2,
				27,
				28,
				53,
				11,
				21,
				11,
				18,
				14,
				17,
				111,
				72,
				56,
				50,
				14,
				50,
				14,
				35,
				39,
				27,
				10,
				22,
				251,
				41,
				7,
				1,
				17,
				2,
				60,
				28,
				11,
				0,
				9,
				21,
				43,
				17,
				47,
				20,
				28,
				22,
				13,
				52,
				58,
				1,
				3,
				0,
				14,
				44,
				33,
				24,
				27,
				35,
				30,
				0,
				3,
				0,
				9,
				34,
				4,
				0,
				13,
				47,
				15,
				3,
				22,
				0,
				2,
				0,
				36,
				17,
				2,
				24,
				20,
				1,
				64,
				6,
				2,
				0,
				2,
				3,
				2,
				14,
				2,
				9,
				8,
				46,
				39,
				7,
				3,
				1,
				3,
				21,
				2,
				6,
				2,
				1,
				2,
				4,
				4,
				0,
				19,
				0,
				13,
				4,
				31,
				9,
				2,
				0,
				3,
				0,
				2,
				37,
				2,
				0,
				26,
				0,
				2,
				0,
				45,
				52,
				19,
				3,
				21,
				2,
				31,
				47,
				21,
				1,
				2,
				0,
				185,
				46,
				42,
				3,
				37,
				47,
				21,
				0,
				60,
				42,
				14,
				0,
				72,
				26,
				38,
				6,
				186,
				43,
				117,
				63,
				32,
				7,
				3,
				0,
				3,
				7,
				2,
				1,
				2,
				23,
				16,
				0,
				2,
				0,
				95,
				7,
				3,
				38,
				17,
				0,
				2,
				0,
				29,
				0,
				11,
				39,
				8,
				0,
				22,
				0,
				12,
				45,
				20,
				0,
				19,
				72,
				200,
				32,
				32,
				8,
				2,
				36,
				18,
				0,
				50,
				29,
				113,
				6,
				2,
				1,
				2,
				37,
				22,
				0,
				26,
				5,
				2,
				1,
				2,
				31,
				15,
				0,
				328,
				18,
				16,
				0,
				2,
				12,
				2,
				33,
				125,
				0,
				80,
				921,
				103,
				110,
				18,
				195,
				2637,
				96,
				16,
				1071,
				18,
				5,
				26,
				3994,
				6,
				582,
				6842,
				29,
				1763,
				568,
				8,
				30,
				18,
				78,
				18,
				29,
				19,
				47,
				17,
				3,
				32,
				20,
				6,
				18,
				433,
				44,
				212,
				63,
				129,
				74,
				6,
				0,
				67,
				12,
				65,
				1,
				2,
				0,
				29,
				6135,
				9,
				1237,
				42,
				9,
				8936,
				3,
				2,
				6,
				2,
				1,
				2,
				290,
				16,
				0,
				30,
				2,
				3,
				0,
				15,
				3,
				9,
				395,
				2309,
				106,
				6,
				12,
				4,
				8,
				8,
				9,
				5991,
				84,
				2,
				70,
				2,
				1,
				3,
				0,
				3,
				1,
				3,
				3,
				2,
				11,
				2,
				0,
				2,
				6,
				2,
				64,
				2,
				3,
				3,
				7,
				2,
				6,
				2,
				27,
				2,
				3,
				2,
				4,
				2,
				0,
				4,
				6,
				2,
				339,
				3,
				24,
				2,
				24,
				2,
				30,
				2,
				24,
				2,
				30,
				2,
				24,
				2,
				30,
				2,
				24,
				2,
				30,
				2,
				24,
				2,
				7,
				1845,
				30,
				7,
				5,
				262,
				61,
				147,
				44,
				11,
				6,
				17,
				0,
				322,
				29,
				19,
				43,
				485,
				27,
				229,
				29,
				3,
				0,
				496,
				6,
				2,
				3,
				2,
				1,
				2,
				14,
				2,
				196,
				60,
				67,
				8,
				0,
				1205,
				3,
				2,
				26,
				2,
				1,
				2,
				0,
				3,
				0,
				2,
				9,
				2,
				3,
				2,
				0,
				2,
				0,
				7,
				0,
				5,
				0,
				2,
				0,
				2,
				0,
				2,
				2,
				2,
				1,
				2,
				0,
				3,
				0,
				2,
				0,
				2,
				0,
				2,
				0,
				2,
				0,
				2,
				1,
				2,
				0,
				3,
				3,
				2,
				6,
				2,
				3,
				2,
				3,
				2,
				0,
				2,
				9,
				2,
				16,
				6,
				2,
				2,
				4,
				2,
				16,
				4421,
				42719,
				33,
				4153,
				7,
				221,
				3,
				5761,
				15,
				7472,
				16,
				621,
				2467,
				541,
				1507,
				4938,
				6,
				4191
			], x = "ªµºÀ-ÖØ-öø-ˁˆ-ˑˠ-ˤˬˮͰ-ʹͶͷͺ-ͽͿΆΈ-ΊΌΎ-ΡΣ-ϵϷ-ҁҊ-ԯԱ-Ֆՙՠ-ֈא-תׯ-ײؠ-يٮٯٱ-ۓەۥۦۮۯۺ-ۼۿܐܒ-ܯݍ-ޥޱߊ-ߪߴߵߺࠀ-ࠕࠚࠤࠨࡀ-ࡘࡠ-ࡪࡰ-ࢇࢉ-ࢎࢠ-ࣉऄ-हऽॐक़-ॡॱ-ঀঅ-ঌএঐও-নপ-রলশ-হঽৎড়ঢ়য়-ৡৰৱৼਅ-ਊਏਐਓ-ਨਪ-ਰਲਲ਼ਵਸ਼ਸਹਖ਼-ੜਫ਼ੲ-ੴઅ-ઍએ-ઑઓ-નપ-રલળવ-હઽૐૠૡૹଅ-ଌଏଐଓ-ନପ-ରଲଳଵ-ହଽଡ଼ଢ଼ୟ-ୡୱஃஅ-ஊஎ-ஐஒ-கஙசஜஞடணதந-பம-ஹௐఅ-ఌఎ-ఐఒ-నప-హఽౘ-ౚౝౠౡಀಅ-ಌಎ-ಐಒ-ನಪ-ಳವ-ಹಽೝೞೠೡೱೲഄ-ഌഎ-ഐഒ-ഺഽൎൔ-ൖൟ-ൡൺ-ൿඅ-ඖක-නඳ-රලව-ෆก-ะาำเ-ๆກຂຄຆ-ຊຌ-ຣລວ-ະາຳຽເ-ໄໆໜ-ໟༀཀ-ཇཉ-ཬྈ-ྌက-ဪဿၐ-ၕၚ-ၝၡၥၦၮ-ၰၵ-ႁႎႠ-ჅჇჍა-ჺჼ-ቈቊ-ቍቐ-ቖቘቚ-ቝበ-ኈኊ-ኍነ-ኰኲ-ኵኸ-ኾዀዂ-ዅወ-ዖዘ-ጐጒ-ጕጘ-ፚᎀ-ᎏᎠ-Ᏽᏸ-ᏽᐁ-ᙬᙯ-ᙿᚁ-ᚚᚠ-ᛪᛮ-ᛸᜀ-ᜑᜟ-ᜱᝀ-ᝑᝠ-ᝬᝮ-ᝰក-ឳៗៜᠠ-ᡸᢀ-ᢨᢪᢰ-ᣵᤀ-ᤞᥐ-ᥭᥰ-ᥴᦀ-ᦫᦰ-ᧉᨀ-ᨖᨠ-ᩔᪧᬅ-ᬳᭅ-ᭌᮃ-ᮠᮮᮯᮺ-ᯥᰀ-ᰣᱍ-ᱏᱚ-ᱽᲀ-ᲊᲐ-ᲺᲽ-Ჿᳩ-ᳬᳮ-ᳳᳵᳶᳺᴀ-ᶿḀ-ἕἘ-Ἕἠ-ὅὈ-Ὅὐ-ὗὙὛὝὟ-ώᾀ-ᾴᾶ-ᾼιῂ-ῄῆ-ῌῐ-ΐῖ-Ίῠ-Ῥῲ-ῴῶ-ῼⁱⁿₐ-ₜℂℇℊ-ℓℕ℘-ℝℤΩℨK-ℹℼ-ℿⅅ-ⅉⅎⅠ-ↈⰀ-ⳤⳫ-ⳮⳲⳳⴀ-ⴥⴧⴭⴰ-ⵧⵯⶀ-ⶖⶠ-ⶦⶨ-ⶮⶰ-ⶶⶸ-ⶾⷀ-ⷆⷈ-ⷎⷐ-ⷖⷘ-ⷞ々-〇〡-〩〱-〵〸-〼ぁ-ゖ゛-ゟァ-ヺー-ヿㄅ-ㄯㄱ-ㆎㆠ-ㆿㇰ-ㇿ㐀-䶿一-ꒌꓐ-ꓽꔀ-ꘌꘐ-ꘟꘪꘫꙀ-ꙮꙿ-ꚝꚠ-ꛯꜗ-ꜟꜢ-ꞈꞋ-ꟍꟐꟑꟓꟕ-Ƛꟲ-ꠁꠃ-ꠅꠇ-ꠊꠌ-ꠢꡀ-ꡳꢂ-ꢳꣲ-ꣷꣻꣽꣾꤊ-ꤥꤰ-ꥆꥠ-ꥼꦄ-ꦲꧏꧠ-ꧤꧦ-ꧯꧺ-ꧾꨀ-ꨨꩀ-ꩂꩄ-ꩋꩠ-ꩶꩺꩾ-ꪯꪱꪵꪶꪹ-ꪽꫀꫂꫛ-ꫝꫠ-ꫪꫲ-ꫴꬁ-ꬆꬉ-ꬎꬑ-ꬖꬠ-ꬦꬨ-ꬮꬰ-ꭚꭜ-ꭩꭰ-ꯢ가-힣ힰ-ퟆퟋ-ퟻ豈-舘並-龎ﬀ-ﬆﬓ-ﬗיִײַ-ﬨשׁ-זּטּ-לּמּנּסּףּפּצּ-ﮱﯓ-ﴽﵐ-ﶏﶒ-ﷇﷰ-ﷻﹰ-ﹴﹶ-ﻼＡ-Ｚａ-ｚｦ-ﾾￂ-ￇￊ-ￏￒ-ￗￚ-ￜ", v = {
				3: "abstract boolean byte char class double enum export extends final float goto implements import int interface long native package private protected public short static super synchronized throws transient volatile",
				5: "class enum extends super const export import",
				6: "enum",
				strict: "implements interface let package private protected public static yield",
				strictBind: "eval arguments"
			}, E = "break case catch continue debugger default do else finally for function if return switch throw try var while with null true false instanceof typeof void delete new in this", T = {
				5: E,
				"5module": E + " export import",
				6: E + " const class extends export import super"
			}, S = /^in(stanceof)?$/, P = new RegExp("[" + x + "]"), _ = new RegExp("[" + x + "‌‍·̀-ͯ·҃-֑҇-ׇֽֿׁׂׅׄؐ-ًؚ-٩ٰۖ-ۜ۟-۪ۤۧۨ-ۭ۰-۹ܑܰ-݊ަ-ް߀-߉߫-߽߳ࠖ-࠙ࠛ-ࠣࠥ-ࠧࠩ-࡙࠭-࡛ࢗ-࢟࣊-ࣣ࣡-ःऺ-़ा-ॏ॑-ॗॢॣ०-९ঁ-ঃ়া-ৄেৈো-্ৗৢৣ০-৯৾ਁ-ਃ਼ਾ-ੂੇੈੋ-੍ੑ੦-ੱੵઁ-ઃ઼ા-ૅે-ૉો-્ૢૣ૦-૯ૺ-૿ଁ-ଃ଼ା-ୄେୈୋ-୍୕-ୗୢୣ୦-୯ஂா-ூெ-ைொ-்ௗ௦-௯ఀ-ఄ఼ా-ౄె-ైొ-్ౕౖౢౣ౦-౯ಁ-ಃ಼ಾ-ೄೆ-ೈೊ-್ೕೖೢೣ೦-೯ೳഀ-ഃ഻഼ാ-ൄെ-ൈൊ-്ൗൢൣ൦-൯ඁ-ඃ්ා-ුූෘ-ෟ෦-෯ෲෳัิ-ฺ็-๎๐-๙ັິ-ຼ່-໎໐-໙༘༙༠-༩༹༵༷༾༿ཱ-྄྆྇ྍ-ྗྙ-ྼ࿆ါ-ှ၀-၉ၖ-ၙၞ-ၠၢ-ၤၧ-ၭၱ-ၴႂ-ႍႏ-ႝ፝-፟፩-፱ᜒ-᜕ᜲ-᜴ᝒᝓᝲᝳ឴-៓៝០-៩᠋-᠍᠏-᠙ᢩᤠ-ᤫᤰ-᤻᥆-᥏᧐-᧚ᨗ-ᨛᩕ-ᩞ᩠-᩿᩼-᪉᪐-᪙᪰-᪽ᪿ-ᫎᬀ-ᬄ᬴-᭄᭐-᭙᭫-᭳ᮀ-ᮂᮡ-ᮭ᮰-᮹᯦-᯳ᰤ-᰷᱀-᱉᱐-᱙᳐-᳔᳒-᳨᳭᳴᳷-᳹᷀-᷿‌‍‿⁀⁔⃐-⃥⃜⃡-⃰⳯-⵿⳱ⷠ-〪ⷿ-゙゚〯・꘠-꘩꙯ꙴ-꙽ꚞꚟ꛰꛱ꠂ꠆ꠋꠣ-ꠧ꠬ꢀꢁꢴ-ꣅ꣐-꣙꣠-꣱ꣿ-꤉ꤦ-꤭ꥇ-꥓ꦀ-ꦃ꦳-꧀꧐-꧙ꧥ꧰-꧹ꨩ-ꨶꩃꩌꩍ꩐-꩙ꩻ-ꩽꪰꪲ-ꪴꪷꪸꪾ꪿꫁ꫫ-ꫯꫵ꫶ꯣ-ꯪ꯬꯭꯰-꯹ﬞ︀-️︠-︯︳︴﹍-﹏０-９＿･]");
			function isInAstralSet(e, t) {
				for (var r = 65536, n = 0; n < t.length; n += 2) {
					if ((r += t[n]) > e) return !1;
					if ((r += t[n + 1]) >= e) return !0;
				}
				return !1;
			}
			function isIdentifierStart(e, t) {
				return e < 65 ? 36 === e : e < 91 || (e < 97 ? 95 === e : e < 123 || (e <= 65535 ? e >= 170 && P.test(String.fromCharCode(e)) : !1 !== t && isInAstralSet(e, g)));
			}
			function isIdentifierChar(e, t) {
				return e < 48 ? 36 === e : e < 58 || !(e < 65) && (e < 91 || (e < 97 ? 95 === e : e < 123 || (e <= 65535 ? e >= 170 && _.test(String.fromCharCode(e)) : !1 !== t && (isInAstralSet(e, g) || isInAstralSet(e, b)))));
			}
			var acorn_TokenType = function(e, t) {
				void 0 === t && (t = {}), this.label = e, this.keyword = t.keyword, this.beforeExpr = !!t.beforeExpr, this.startsExpr = !!t.startsExpr, this.isLoop = !!t.isLoop, this.isAssign = !!t.isAssign, this.prefix = !!t.prefix, this.postfix = !!t.postfix, this.binop = t.binop || null, this.updateContext = null;
			};
			function binop(e, t) {
				return new acorn_TokenType(e, {
					beforeExpr: !0,
					binop: t
				});
			}
			var A = { beforeExpr: !0 }, C = { startsExpr: !0 }, w = {};
			function kw(e, t) {
				return void 0 === t && (t = {}), t.keyword = e, w[e] = new acorn_TokenType(e, t);
			}
			var I = {
				num: new acorn_TokenType("num", C),
				regexp: new acorn_TokenType("regexp", C),
				string: new acorn_TokenType("string", C),
				name: new acorn_TokenType("name", C),
				privateId: new acorn_TokenType("privateId", C),
				eof: new acorn_TokenType("eof"),
				bracketL: new acorn_TokenType("[", {
					beforeExpr: !0,
					startsExpr: !0
				}),
				bracketR: new acorn_TokenType("]"),
				braceL: new acorn_TokenType("{", {
					beforeExpr: !0,
					startsExpr: !0
				}),
				braceR: new acorn_TokenType("}"),
				parenL: new acorn_TokenType("(", {
					beforeExpr: !0,
					startsExpr: !0
				}),
				parenR: new acorn_TokenType(")"),
				comma: new acorn_TokenType(",", A),
				semi: new acorn_TokenType(";", A),
				colon: new acorn_TokenType(":", A),
				dot: new acorn_TokenType("."),
				question: new acorn_TokenType("?", A),
				questionDot: new acorn_TokenType("?."),
				arrow: new acorn_TokenType("=>", A),
				template: new acorn_TokenType("template"),
				invalidTemplate: new acorn_TokenType("invalidTemplate"),
				ellipsis: new acorn_TokenType("...", A),
				backQuote: new acorn_TokenType("`", C),
				dollarBraceL: new acorn_TokenType("${", {
					beforeExpr: !0,
					startsExpr: !0
				}),
				eq: new acorn_TokenType("=", {
					beforeExpr: !0,
					isAssign: !0
				}),
				assign: new acorn_TokenType("_=", {
					beforeExpr: !0,
					isAssign: !0
				}),
				incDec: new acorn_TokenType("++/--", {
					prefix: !0,
					postfix: !0,
					startsExpr: !0
				}),
				prefix: new acorn_TokenType("!/~", {
					beforeExpr: !0,
					prefix: !0,
					startsExpr: !0
				}),
				logicalOR: binop("||", 1),
				logicalAND: binop("&&", 2),
				bitwiseOR: binop("|", 3),
				bitwiseXOR: binop("^", 4),
				bitwiseAND: binop("&", 5),
				equality: binop("==/!=/===/!==", 6),
				relational: binop("</>/<=/>=", 7),
				bitShift: binop("<</>>/>>>", 8),
				plusMin: new acorn_TokenType("+/-", {
					beforeExpr: !0,
					binop: 9,
					prefix: !0,
					startsExpr: !0
				}),
				modulo: binop("%", 10),
				star: binop("*", 10),
				slash: binop("/", 10),
				starstar: new acorn_TokenType("**", { beforeExpr: !0 }),
				coalesce: binop("??", 1),
				_break: kw("break"),
				_case: kw("case", A),
				_catch: kw("catch"),
				_continue: kw("continue"),
				_debugger: kw("debugger"),
				_default: kw("default", A),
				_do: kw("do", {
					isLoop: !0,
					beforeExpr: !0
				}),
				_else: kw("else", A),
				_finally: kw("finally"),
				_for: kw("for", { isLoop: !0 }),
				_function: kw("function", C),
				_if: kw("if"),
				_return: kw("return", A),
				_switch: kw("switch"),
				_throw: kw("throw", A),
				_try: kw("try"),
				_var: kw("var"),
				_const: kw("const"),
				_while: kw("while", { isLoop: !0 }),
				_with: kw("with"),
				_new: kw("new", {
					beforeExpr: !0,
					startsExpr: !0
				}),
				_this: kw("this", C),
				_super: kw("super", C),
				_class: kw("class", C),
				_extends: kw("extends", A),
				_export: kw("export"),
				_import: kw("import", C),
				_null: kw("null", C),
				_true: kw("true", C),
				_false: kw("false", C),
				_in: kw("in", {
					beforeExpr: !0,
					binop: 7
				}),
				_instanceof: kw("instanceof", {
					beforeExpr: !0,
					binop: 7
				}),
				_typeof: kw("typeof", {
					beforeExpr: !0,
					prefix: !0,
					startsExpr: !0
				}),
				_void: kw("void", {
					beforeExpr: !0,
					prefix: !0,
					startsExpr: !0
				}),
				_delete: kw("delete", {
					beforeExpr: !0,
					prefix: !0,
					startsExpr: !0
				})
			}, D = /\r\n?|\n|\u2028|\u2029/, k = new RegExp(D.source, "g");
			function isNewLine(e) {
				return 10 === e || 13 === e || 8232 === e || 8233 === e;
			}
			function nextLineBreak(e, t, r) {
				void 0 === r && (r = e.length);
				for (var n = t; n < r; n++) {
					var s = e.charCodeAt(n);
					if (isNewLine(s)) return n < r - 1 && 13 === s && 10 === e.charCodeAt(n + 1) ? n + 2 : n + 1;
				}
				return -1;
			}
			var N = /[\u1680\u2000-\u200a\u202f\u205f\u3000\ufeff]/, O = /(?:\s|\/\/.*|\/\*[^]*?\*\/)*/g, j = Object.prototype, F = j.hasOwnProperty, L = j.toString, M = Object.hasOwn || function(e, t) {
				return F.call(e, t);
			}, B = Array.isArray || function(e) {
				return "[object Array]" === L.call(e);
			}, R = Object.create(null);
			function wordsRegexp(e) {
				return R[e] || (R[e] = new RegExp("^(?:" + e.replace(/ /g, "|") + ")$"));
			}
			function codePointToString(e) {
				return e <= 65535 ? String.fromCharCode(e) : (e -= 65536, String.fromCharCode(55296 + (e >> 10), 56320 + (1023 & e)));
			}
			var U = /(?:[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])/, acorn_Position = function(e, t) {
				this.line = e, this.column = t;
			};
			acorn_Position.prototype.offset = function(e) {
				return new acorn_Position(this.line, this.column + e);
			};
			var acorn_SourceLocation = function(e, t, r) {
				this.start = t, this.end = r, null !== e.sourceFile && (this.source = e.sourceFile);
			};
			function getLineInfo(e, t) {
				for (var r = 1, n = 0;;) {
					var s = nextLineBreak(e, n, t);
					if (s < 0) return new acorn_Position(r, t - n);
					++r, n = s;
				}
			}
			var V = {
				ecmaVersion: null,
				sourceType: "script",
				onInsertedSemicolon: null,
				onTrailingComma: null,
				allowReserved: null,
				allowReturnOutsideFunction: !1,
				allowImportExportEverywhere: !1,
				allowAwaitOutsideFunction: null,
				allowSuperOutsideMethod: null,
				allowHashBang: !1,
				checkPrivateFields: !0,
				locations: !1,
				onToken: null,
				onComment: null,
				ranges: !1,
				program: null,
				sourceFile: null,
				directSourceFile: null,
				preserveParens: !1
			}, $ = !1;
			function getOptions(e) {
				var t = {};
				for (var r in V) t[r] = e && M(e, r) ? e[r] : V[r];
				if ("latest" === t.ecmaVersion ? t.ecmaVersion = 1e8 : null == t.ecmaVersion ? (!$ && "object" == typeof console && console.warn && ($ = !0, console.warn("Since Acorn 8.0.0, options.ecmaVersion is required.\nDefaulting to 2020, but this will stop working in the future.")), t.ecmaVersion = 11) : t.ecmaVersion >= 2015 && (t.ecmaVersion -= 2009), t.allowReserved ?? (t.allowReserved = t.ecmaVersion < 5), e && null != e.allowHashBang || (t.allowHashBang = t.ecmaVersion >= 14), B(t.onToken)) {
					var n = t.onToken;
					t.onToken = function(e) {
						return n.push(e);
					};
				}
				return B(t.onComment) && (t.onComment = function(e, t) {
					return function(r, n, s, i, o, a) {
						var l = {
							type: r ? "Block" : "Line",
							value: n,
							start: s,
							end: i
						};
						e.locations && (l.loc = new acorn_SourceLocation(this, o, a)), e.ranges && (l.range = [s, i]), t.push(l);
					};
				}(t, t.onComment)), t;
			}
			var K = 256, W = 259;
			function functionFlags(e, t) {
				return 2 | (e ? 4 : 0) | (t ? 8 : 0);
			}
			var acorn_Parser = function(e, t, r) {
				this.options = e = getOptions(e), this.sourceFile = e.sourceFile, this.keywords = wordsRegexp(T[e.ecmaVersion >= 6 ? 6 : "module" === e.sourceType ? "5module" : 5]);
				var n = "";
				!0 !== e.allowReserved && (n = v[e.ecmaVersion >= 6 ? 6 : 5 === e.ecmaVersion ? 5 : 3], "module" === e.sourceType && (n += " await")), this.reservedWords = wordsRegexp(n);
				var s = (n ? n + " " : "") + v.strict;
				this.reservedWordsStrict = wordsRegexp(s), this.reservedWordsStrictBind = wordsRegexp(s + " " + v.strictBind), this.input = String(t), this.containsEsc = !1, r ? (this.pos = r, this.lineStart = this.input.lastIndexOf("\n", r - 1) + 1, this.curLine = this.input.slice(0, this.lineStart).split(D).length) : (this.pos = this.lineStart = 0, this.curLine = 1), this.type = I.eof, this.value = null, this.start = this.end = this.pos, this.startLoc = this.endLoc = this.curPosition(), this.lastTokEndLoc = this.lastTokStartLoc = null, this.lastTokStart = this.lastTokEnd = this.pos, this.context = this.initialContext(), this.exprAllowed = !0, this.inModule = "module" === e.sourceType, this.strict = this.inModule || this.strictDirective(this.pos), this.potentialArrowAt = -1, this.potentialArrowInForAwait = !1, this.yieldPos = this.awaitPos = this.awaitIdentPos = 0, this.labels = [], this.undefinedExports = Object.create(null), 0 === this.pos && e.allowHashBang && "#!" === this.input.slice(0, 2) && this.skipLineComment(2), this.scopeStack = [], this.enterScope(1), this.regexpState = null, this.privateNameStack = [];
			}, q = {
				inFunction: { configurable: !0 },
				inGenerator: { configurable: !0 },
				inAsync: { configurable: !0 },
				canAwait: { configurable: !0 },
				allowSuper: { configurable: !0 },
				allowDirectSuper: { configurable: !0 },
				treatFunctionsAsVar: { configurable: !0 },
				allowNewDotTarget: { configurable: !0 },
				inClassStaticBlock: { configurable: !0 }
			};
			acorn_Parser.prototype.parse = function() {
				var e = this.options.program || this.startNode();
				return this.nextToken(), this.parseTopLevel(e);
			}, q.inFunction.get = function() {
				return (2 & this.currentVarScope().flags) > 0;
			}, q.inGenerator.get = function() {
				return (8 & this.currentVarScope().flags) > 0;
			}, q.inAsync.get = function() {
				return (4 & this.currentVarScope().flags) > 0;
			}, q.canAwait.get = function() {
				for (var e = this.scopeStack.length - 1; e >= 0; e--) {
					var t = this.scopeStack[e].flags;
					if (768 & t) return !1;
					if (2 & t) return (4 & t) > 0;
				}
				return this.inModule && this.options.ecmaVersion >= 13 || this.options.allowAwaitOutsideFunction;
			}, q.allowSuper.get = function() {
				return (64 & this.currentThisScope().flags) > 0 || this.options.allowSuperOutsideMethod;
			}, q.allowDirectSuper.get = function() {
				return (128 & this.currentThisScope().flags) > 0;
			}, q.treatFunctionsAsVar.get = function() {
				return this.treatFunctionsAsVarInScope(this.currentScope());
			}, q.allowNewDotTarget.get = function() {
				for (var e = this.scopeStack.length - 1; e >= 0; e--) {
					var t = this.scopeStack[e].flags;
					if (768 & t || 2 & t && !(16 & t)) return !0;
				}
				return !1;
			}, q.inClassStaticBlock.get = function() {
				return (this.currentVarScope().flags & K) > 0;
			}, acorn_Parser.extend = function() {
				for (var e = [], t = arguments.length; t--;) e[t] = arguments[t];
				for (var r = this, n = 0; n < e.length; n++) r = e[n](r);
				return r;
			}, acorn_Parser.parse = function(e, t) {
				return new this(t, e).parse();
			}, acorn_Parser.parseExpressionAt = function(e, t, r) {
				var n = new this(r, e, t);
				return n.nextToken(), n.parseExpression();
			}, acorn_Parser.tokenizer = function(e, t) {
				return new this(t, e);
			}, Object.defineProperties(acorn_Parser.prototype, q);
			var H = acorn_Parser.prototype, z = /^(?:'((?:\\[^]|[^'\\])*?)'|"((?:\\[^]|[^"\\])*?)")/;
			H.strictDirective = function(e) {
				if (this.options.ecmaVersion < 5) return !1;
				for (;;) {
					O.lastIndex = e, e += O.exec(this.input)[0].length;
					var t = z.exec(this.input.slice(e));
					if (!t) return !1;
					if ("use strict" === (t[1] || t[2])) {
						O.lastIndex = e + t[0].length;
						var r = O.exec(this.input), n = r.index + r[0].length, s = this.input.charAt(n);
						return ";" === s || "}" === s || D.test(r[0]) && !(/[(`.[+\-/*%<>=,?^&]/.test(s) || "!" === s && "=" === this.input.charAt(n + 1));
					}
					e += t[0].length, O.lastIndex = e, e += O.exec(this.input)[0].length, ";" === this.input[e] && e++;
				}
			}, H.eat = function(e) {
				return this.type === e && (this.next(), !0);
			}, H.isContextual = function(e) {
				return this.type === I.name && this.value === e && !this.containsEsc;
			}, H.eatContextual = function(e) {
				return !!this.isContextual(e) && (this.next(), !0);
			}, H.expectContextual = function(e) {
				this.eatContextual(e) || this.unexpected();
			}, H.canInsertSemicolon = function() {
				return this.type === I.eof || this.type === I.braceR || D.test(this.input.slice(this.lastTokEnd, this.start));
			}, H.insertSemicolon = function() {
				if (this.canInsertSemicolon()) return this.options.onInsertedSemicolon && this.options.onInsertedSemicolon(this.lastTokEnd, this.lastTokEndLoc), !0;
			}, H.semicolon = function() {
				this.eat(I.semi) || this.insertSemicolon() || this.unexpected();
			}, H.afterTrailingComma = function(e, t) {
				if (this.type === e) return this.options.onTrailingComma && this.options.onTrailingComma(this.lastTokStart, this.lastTokStartLoc), t || this.next(), !0;
			}, H.expect = function(e) {
				this.eat(e) || this.unexpected();
			}, H.unexpected = function(e) {
				this.raise(null != e ? e : this.start, "Unexpected token");
			};
			var acorn_DestructuringErrors = function() {
				this.shorthandAssign = this.trailingComma = this.parenthesizedAssign = this.parenthesizedBind = this.doubleProto = -1;
			};
			H.checkPatternErrors = function(e, t) {
				if (e) {
					e.trailingComma > -1 && this.raiseRecoverable(e.trailingComma, "Comma is not permitted after the rest element");
					var r = t ? e.parenthesizedAssign : e.parenthesizedBind;
					r > -1 && this.raiseRecoverable(r, t ? "Assigning to rvalue" : "Parenthesized pattern");
				}
			}, H.checkExpressionErrors = function(e, t) {
				if (!e) return !1;
				var r = e.shorthandAssign, n = e.doubleProto;
				if (!t) return r >= 0 || n >= 0;
				r >= 0 && this.raise(r, "Shorthand property assignments are valid only in destructuring patterns"), n >= 0 && this.raiseRecoverable(n, "Redefinition of __proto__ property");
			}, H.checkYieldAwaitInDefaultParams = function() {
				this.yieldPos && (!this.awaitPos || this.yieldPos < this.awaitPos) && this.raise(this.yieldPos, "Yield expression cannot be a default value"), this.awaitPos && this.raise(this.awaitPos, "Await expression cannot be a default value");
			}, H.isSimpleAssignTarget = function(e) {
				return "ParenthesizedExpression" === e.type ? this.isSimpleAssignTarget(e.expression) : "Identifier" === e.type || "MemberExpression" === e.type;
			};
			var G = acorn_Parser.prototype;
			G.parseTopLevel = function(e) {
				var t = Object.create(null);
				for (e.body || (e.body = []); this.type !== I.eof;) {
					var r = this.parseStatement(null, !0, t);
					e.body.push(r);
				}
				if (this.inModule) for (var n = 0, s = Object.keys(this.undefinedExports); n < s.length; n += 1) {
					var i = s[n];
					this.raiseRecoverable(this.undefinedExports[i].start, "Export '" + i + "' is not defined");
				}
				return this.adaptDirectivePrologue(e.body), this.next(), e.sourceType = this.options.sourceType, this.finishNode(e, "Program");
			};
			var X = { kind: "loop" }, J = { kind: "switch" };
			G.isLet = function(e) {
				if (this.options.ecmaVersion < 6 || !this.isContextual("let")) return !1;
				O.lastIndex = this.pos;
				var t = O.exec(this.input), r = this.pos + t[0].length, n = this.input.charCodeAt(r);
				if (91 === n || 92 === n) return !0;
				if (e) return !1;
				if (123 === n || n > 55295 && n < 56320) return !0;
				if (isIdentifierStart(n, !0)) {
					for (var s = r + 1; isIdentifierChar(n = this.input.charCodeAt(s), !0);) ++s;
					if (92 === n || n > 55295 && n < 56320) return !0;
					var i = this.input.slice(r, s);
					if (!S.test(i)) return !0;
				}
				return !1;
			}, G.isAsyncFunction = function() {
				if (this.options.ecmaVersion < 8 || !this.isContextual("async")) return !1;
				O.lastIndex = this.pos;
				var e, t = O.exec(this.input), r = this.pos + t[0].length;
				return !(D.test(this.input.slice(this.pos, r)) || "function" !== this.input.slice(r, r + 8) || r + 8 !== this.input.length && (isIdentifierChar(e = this.input.charCodeAt(r + 8)) || e > 55295 && e < 56320));
			}, G.isUsingKeyword = function(e, t) {
				if (this.options.ecmaVersion < 17 || !this.isContextual(e ? "await" : "using")) return !1;
				O.lastIndex = this.pos;
				var r = O.exec(this.input), n = this.pos + r[0].length;
				if (D.test(this.input.slice(this.pos, n))) return !1;
				if (e) {
					var s, i = n + 5;
					if ("using" !== this.input.slice(n, i) || i === this.input.length || isIdentifierChar(s = this.input.charCodeAt(i)) || s > 55295 && s < 56320) return !1;
					O.lastIndex = i;
					var o = O.exec(this.input);
					if (o && D.test(this.input.slice(i, i + o[0].length))) return !1;
				}
				if (t) {
					var a, l = n + 2;
					if (!("of" !== this.input.slice(n, l) || l !== this.input.length && (isIdentifierChar(a = this.input.charCodeAt(l)) || a > 55295 && a < 56320))) return !1;
				}
				var p = this.input.charCodeAt(n);
				return isIdentifierStart(p, !0) || 92 === p;
			}, G.isAwaitUsing = function(e) {
				return this.isUsingKeyword(!0, e);
			}, G.isUsing = function(e) {
				return this.isUsingKeyword(!1, e);
			}, G.parseStatement = function(e, t, r) {
				var n, s = this.type, i = this.startNode();
				switch (this.isLet(e) && (s = I._var, n = "let"), s) {
					case I._break:
					case I._continue: return this.parseBreakContinueStatement(i, s.keyword);
					case I._debugger: return this.parseDebuggerStatement(i);
					case I._do: return this.parseDoStatement(i);
					case I._for: return this.parseForStatement(i);
					case I._function: return e && (this.strict || "if" !== e && "label" !== e) && this.options.ecmaVersion >= 6 && this.unexpected(), this.parseFunctionStatement(i, !1, !e);
					case I._class: return e && this.unexpected(), this.parseClass(i, !0);
					case I._if: return this.parseIfStatement(i);
					case I._return: return this.parseReturnStatement(i);
					case I._switch: return this.parseSwitchStatement(i);
					case I._throw: return this.parseThrowStatement(i);
					case I._try: return this.parseTryStatement(i);
					case I._const:
					case I._var: return n = n || this.value, e && "var" !== n && this.unexpected(), this.parseVarStatement(i, n);
					case I._while: return this.parseWhileStatement(i);
					case I._with: return this.parseWithStatement(i);
					case I.braceL: return this.parseBlock(!0, i);
					case I.semi: return this.parseEmptyStatement(i);
					case I._export:
					case I._import:
						if (this.options.ecmaVersion > 10 && s === I._import) {
							O.lastIndex = this.pos;
							var o = O.exec(this.input), a = this.pos + o[0].length, l = this.input.charCodeAt(a);
							if (40 === l || 46 === l) return this.parseExpressionStatement(i, this.parseExpression());
						}
						return this.options.allowImportExportEverywhere || (t || this.raise(this.start, "'import' and 'export' may only appear at the top level"), this.inModule || this.raise(this.start, "'import' and 'export' may appear only with 'sourceType: module'")), s === I._import ? this.parseImport(i) : this.parseExport(i, r);
					default:
						if (this.isAsyncFunction()) return e && this.unexpected(), this.next(), this.parseFunctionStatement(i, !0, !e);
						var p = this.isAwaitUsing(!1) ? "await using" : this.isUsing(!1) ? "using" : null;
						if (p) return t && "script" === this.options.sourceType && this.raise(this.start, "Using declaration cannot appear in the top level when source type is `script`"), "await using" === p && (this.canAwait || this.raise(this.start, "Await using cannot appear outside of async function"), this.next()), this.next(), this.parseVar(i, !1, p), this.semicolon(), this.finishNode(i, "VariableDeclaration");
						var c = this.value, u = this.parseExpression();
						return s === I.name && "Identifier" === u.type && this.eat(I.colon) ? this.parseLabeledStatement(i, c, u, e) : this.parseExpressionStatement(i, u);
				}
			}, G.parseBreakContinueStatement = function(e, t) {
				var r = "break" === t;
				this.next(), this.eat(I.semi) || this.insertSemicolon() ? e.label = null : this.type !== I.name ? this.unexpected() : (e.label = this.parseIdent(), this.semicolon());
				for (var n = 0; n < this.labels.length; ++n) {
					var s = this.labels[n];
					if (null == e.label || s.name === e.label.name) {
						if (null != s.kind && (r || "loop" === s.kind)) break;
						if (e.label && r) break;
					}
				}
				return n === this.labels.length && this.raise(e.start, "Unsyntactic " + t), this.finishNode(e, r ? "BreakStatement" : "ContinueStatement");
			}, G.parseDebuggerStatement = function(e) {
				return this.next(), this.semicolon(), this.finishNode(e, "DebuggerStatement");
			}, G.parseDoStatement = function(e) {
				return this.next(), this.labels.push(X), e.body = this.parseStatement("do"), this.labels.pop(), this.expect(I._while), e.test = this.parseParenExpression(), this.options.ecmaVersion >= 6 ? this.eat(I.semi) : this.semicolon(), this.finishNode(e, "DoWhileStatement");
			}, G.parseForStatement = function(e) {
				this.next();
				var t = this.options.ecmaVersion >= 9 && this.canAwait && this.eatContextual("await") ? this.lastTokStart : -1;
				if (this.labels.push(X), this.enterScope(0), this.expect(I.parenL), this.type === I.semi) return t > -1 && this.unexpected(t), this.parseFor(e, null);
				var r = this.isLet();
				if (this.type === I._var || this.type === I._const || r) {
					var n = this.startNode(), s = r ? "let" : this.value;
					return this.next(), this.parseVar(n, !0, s), this.finishNode(n, "VariableDeclaration"), this.parseForAfterInit(e, n, t);
				}
				var i = this.isContextual("let"), o = !1, a = this.isUsing(!0) ? "using" : this.isAwaitUsing(!0) ? "await using" : null;
				if (a) {
					var l = this.startNode();
					return this.next(), "await using" === a && this.next(), this.parseVar(l, !0, a), this.finishNode(l, "VariableDeclaration"), this.parseForAfterInit(e, l, t);
				}
				var p = this.containsEsc, c = new acorn_DestructuringErrors(), u = this.start, d = t > -1 ? this.parseExprSubscripts(c, "await") : this.parseExpression(!0, c);
				return this.type === I._in || (o = this.options.ecmaVersion >= 6 && this.isContextual("of")) ? (t > -1 ? (this.type === I._in && this.unexpected(t), e.await = !0) : o && this.options.ecmaVersion >= 8 && (d.start !== u || p || "Identifier" !== d.type || "async" !== d.name ? this.options.ecmaVersion >= 9 && (e.await = !1) : this.unexpected()), i && o && this.raise(d.start, "The left-hand side of a for-of loop may not start with 'let'."), this.toAssignable(d, !1, c), this.checkLValPattern(d), this.parseForIn(e, d)) : (this.checkExpressionErrors(c, !0), t > -1 && this.unexpected(t), this.parseFor(e, d));
			}, G.parseForAfterInit = function(e, t, r) {
				return (this.type === I._in || this.options.ecmaVersion >= 6 && this.isContextual("of")) && 1 === t.declarations.length ? (this.options.ecmaVersion >= 9 && (this.type === I._in ? r > -1 && this.unexpected(r) : e.await = r > -1), this.parseForIn(e, t)) : (r > -1 && this.unexpected(r), this.parseFor(e, t));
			}, G.parseFunctionStatement = function(e, t, r) {
				return this.next(), this.parseFunction(e, Q | (r ? 0 : Z), !1, t);
			}, G.parseIfStatement = function(e) {
				return this.next(), e.test = this.parseParenExpression(), e.consequent = this.parseStatement("if"), e.alternate = this.eat(I._else) ? this.parseStatement("if") : null, this.finishNode(e, "IfStatement");
			}, G.parseReturnStatement = function(e) {
				return this.inFunction || this.options.allowReturnOutsideFunction || this.raise(this.start, "'return' outside of function"), this.next(), this.eat(I.semi) || this.insertSemicolon() ? e.argument = null : (e.argument = this.parseExpression(), this.semicolon()), this.finishNode(e, "ReturnStatement");
			}, G.parseSwitchStatement = function(e) {
				var t;
				this.next(), e.discriminant = this.parseParenExpression(), e.cases = [], this.expect(I.braceL), this.labels.push(J), this.enterScope(0);
				for (var r = !1; this.type !== I.braceR;) if (this.type === I._case || this.type === I._default) {
					var n = this.type === I._case;
					t && this.finishNode(t, "SwitchCase"), e.cases.push(t = this.startNode()), t.consequent = [], this.next(), n ? t.test = this.parseExpression() : (r && this.raiseRecoverable(this.lastTokStart, "Multiple default clauses"), r = !0, t.test = null), this.expect(I.colon);
				} else t || this.unexpected(), t.consequent.push(this.parseStatement(null));
				return this.exitScope(), t && this.finishNode(t, "SwitchCase"), this.next(), this.labels.pop(), this.finishNode(e, "SwitchStatement");
			}, G.parseThrowStatement = function(e) {
				return this.next(), D.test(this.input.slice(this.lastTokEnd, this.start)) && this.raise(this.lastTokEnd, "Illegal newline after throw"), e.argument = this.parseExpression(), this.semicolon(), this.finishNode(e, "ThrowStatement");
			};
			var Y = [];
			G.parseCatchClauseParam = function() {
				var e = this.parseBindingAtom(), t = "Identifier" === e.type;
				return this.enterScope(t ? 32 : 0), this.checkLValPattern(e, t ? 4 : 2), this.expect(I.parenR), e;
			}, G.parseTryStatement = function(e) {
				if (this.next(), e.block = this.parseBlock(), e.handler = null, this.type === I._catch) {
					var t = this.startNode();
					this.next(), this.eat(I.parenL) ? t.param = this.parseCatchClauseParam() : (this.options.ecmaVersion < 10 && this.unexpected(), t.param = null, this.enterScope(0)), t.body = this.parseBlock(!1), this.exitScope(), e.handler = this.finishNode(t, "CatchClause");
				}
				return e.finalizer = this.eat(I._finally) ? this.parseBlock() : null, e.handler || e.finalizer || this.raise(e.start, "Missing catch or finally clause"), this.finishNode(e, "TryStatement");
			}, G.parseVarStatement = function(e, t, r) {
				return this.next(), this.parseVar(e, !1, t, r), this.semicolon(), this.finishNode(e, "VariableDeclaration");
			}, G.parseWhileStatement = function(e) {
				return this.next(), e.test = this.parseParenExpression(), this.labels.push(X), e.body = this.parseStatement("while"), this.labels.pop(), this.finishNode(e, "WhileStatement");
			}, G.parseWithStatement = function(e) {
				return this.strict && this.raise(this.start, "'with' in strict mode"), this.next(), e.object = this.parseParenExpression(), e.body = this.parseStatement("with"), this.finishNode(e, "WithStatement");
			}, G.parseEmptyStatement = function(e) {
				return this.next(), this.finishNode(e, "EmptyStatement");
			}, G.parseLabeledStatement = function(e, t, r, n) {
				for (var s = 0, i = this.labels; s < i.length; s += 1) i[s].name === t && this.raise(r.start, "Label '" + t + "' is already declared");
				for (var o = this.type.isLoop ? "loop" : this.type === I._switch ? "switch" : null, a = this.labels.length - 1; a >= 0; a--) {
					var l = this.labels[a];
					if (l.statementStart !== e.start) break;
					l.statementStart = this.start, l.kind = o;
				}
				return this.labels.push({
					name: t,
					kind: o,
					statementStart: this.start
				}), e.body = this.parseStatement(n ? -1 === n.indexOf("label") ? n + "label" : n : "label"), this.labels.pop(), e.label = r, this.finishNode(e, "LabeledStatement");
			}, G.parseExpressionStatement = function(e, t) {
				return e.expression = t, this.semicolon(), this.finishNode(e, "ExpressionStatement");
			}, G.parseBlock = function(e, t, r) {
				for (void 0 === e && (e = !0), void 0 === t && (t = this.startNode()), t.body = [], this.expect(I.braceL), e && this.enterScope(0); this.type !== I.braceR;) {
					var n = this.parseStatement(null);
					t.body.push(n);
				}
				return r && (this.strict = !1), this.next(), e && this.exitScope(), this.finishNode(t, "BlockStatement");
			}, G.parseFor = function(e, t) {
				return e.init = t, this.expect(I.semi), e.test = this.type === I.semi ? null : this.parseExpression(), this.expect(I.semi), e.update = this.type === I.parenR ? null : this.parseExpression(), this.expect(I.parenR), e.body = this.parseStatement("for"), this.exitScope(), this.labels.pop(), this.finishNode(e, "ForStatement");
			}, G.parseForIn = function(e, t) {
				var r = this.type === I._in;
				return this.next(), "VariableDeclaration" === t.type && null != t.declarations[0].init && (!r || this.options.ecmaVersion < 8 || this.strict || "var" !== t.kind || "Identifier" !== t.declarations[0].id.type) && this.raise(t.start, (r ? "for-in" : "for-of") + " loop variable declaration may not have an initializer"), e.left = t, e.right = r ? this.parseExpression() : this.parseMaybeAssign(), this.expect(I.parenR), e.body = this.parseStatement("for"), this.exitScope(), this.labels.pop(), this.finishNode(e, r ? "ForInStatement" : "ForOfStatement");
			}, G.parseVar = function(e, t, r, n) {
				for (e.declarations = [], e.kind = r;;) {
					var s = this.startNode();
					if (this.parseVarId(s, r), this.eat(I.eq) ? s.init = this.parseMaybeAssign(t) : n || "const" !== r || this.type === I._in || this.options.ecmaVersion >= 6 && this.isContextual("of") ? n || "using" !== r && "await using" !== r || !(this.options.ecmaVersion >= 17) || this.type === I._in || this.isContextual("of") ? n || "Identifier" === s.id.type || t && (this.type === I._in || this.isContextual("of")) ? s.init = null : this.raise(this.lastTokEnd, "Complex binding patterns require an initialization value") : this.raise(this.lastTokEnd, "Missing initializer in " + r + " declaration") : this.unexpected(), e.declarations.push(this.finishNode(s, "VariableDeclarator")), !this.eat(I.comma)) break;
				}
				return e;
			}, G.parseVarId = function(e, t) {
				e.id = "using" === t || "await using" === t ? this.parseIdent() : this.parseBindingAtom(), this.checkLValPattern(e.id, "var" === t ? 1 : 2, !1);
			};
			var Q = 1, Z = 2;
			function isPrivateNameConflicted(e, t) {
				var r = t.key.name, n = e[r], s = "true";
				return "MethodDefinition" !== t.type || "get" !== t.kind && "set" !== t.kind || (s = (t.static ? "s" : "i") + t.kind), "iget" === n && "iset" === s || "iset" === n && "iget" === s || "sget" === n && "sset" === s || "sset" === n && "sget" === s ? (e[r] = "true", !1) : !!n || (e[r] = s, !1);
			}
			function checkKeyName(e, t) {
				var r = e.computed, n = e.key;
				return !r && ("Identifier" === n.type && n.name === t || "Literal" === n.type && n.value === t);
			}
			G.parseFunction = function(e, t, r, n, s) {
				this.initFunction(e), (this.options.ecmaVersion >= 9 || this.options.ecmaVersion >= 6 && !n) && (this.type === I.star && t & Z && this.unexpected(), e.generator = this.eat(I.star)), this.options.ecmaVersion >= 8 && (e.async = !!n), t & Q && (e.id = 4 & t && this.type !== I.name ? null : this.parseIdent(), !e.id || t & Z || this.checkLValSimple(e.id, this.strict || e.generator || e.async ? this.treatFunctionsAsVar ? 1 : 2 : 3));
				var i = this.yieldPos, o = this.awaitPos, a = this.awaitIdentPos;
				return this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, this.enterScope(functionFlags(e.async, e.generator)), t & Q || (e.id = this.type === I.name ? this.parseIdent() : null), this.parseFunctionParams(e), this.parseFunctionBody(e, r, !1, s), this.yieldPos = i, this.awaitPos = o, this.awaitIdentPos = a, this.finishNode(e, t & Q ? "FunctionDeclaration" : "FunctionExpression");
			}, G.parseFunctionParams = function(e) {
				this.expect(I.parenL), e.params = this.parseBindingList(I.parenR, !1, this.options.ecmaVersion >= 8), this.checkYieldAwaitInDefaultParams();
			}, G.parseClass = function(e, t) {
				this.next();
				var r = this.strict;
				this.strict = !0, this.parseClassId(e, t), this.parseClassSuper(e);
				var n = this.enterClassBody(), s = this.startNode(), i = !1;
				for (s.body = [], this.expect(I.braceL); this.type !== I.braceR;) {
					var o = this.parseClassElement(null !== e.superClass);
					o && (s.body.push(o), "MethodDefinition" === o.type && "constructor" === o.kind ? (i && this.raiseRecoverable(o.start, "Duplicate constructor in the same class"), i = !0) : o.key && "PrivateIdentifier" === o.key.type && isPrivateNameConflicted(n, o) && this.raiseRecoverable(o.key.start, "Identifier '#" + o.key.name + "' has already been declared"));
				}
				return this.strict = r, this.next(), e.body = this.finishNode(s, "ClassBody"), this.exitClassBody(), this.finishNode(e, t ? "ClassDeclaration" : "ClassExpression");
			}, G.parseClassElement = function(e) {
				if (this.eat(I.semi)) return null;
				var t = this.options.ecmaVersion, r = this.startNode(), n = "", s = !1, i = !1, o = "method", a = !1;
				if (this.eatContextual("static")) {
					if (t >= 13 && this.eat(I.braceL)) return this.parseClassStaticBlock(r), r;
					this.isClassElementNameStart() || this.type === I.star ? a = !0 : n = "static";
				}
				if (r.static = a, !n && t >= 8 && this.eatContextual("async") && (!this.isClassElementNameStart() && this.type !== I.star || this.canInsertSemicolon() ? n = "async" : i = !0), !n && (t >= 9 || !i) && this.eat(I.star) && (s = !0), !n && !i && !s) {
					var l = this.value;
					(this.eatContextual("get") || this.eatContextual("set")) && (this.isClassElementNameStart() ? o = l : n = l);
				}
				if (n ? (r.computed = !1, r.key = this.startNodeAt(this.lastTokStart, this.lastTokStartLoc), r.key.name = n, this.finishNode(r.key, "Identifier")) : this.parseClassElementName(r), t < 13 || this.type === I.parenL || "method" !== o || s || i) {
					var p = !r.static && checkKeyName(r, "constructor"), c = p && e;
					p && "method" !== o && this.raise(r.key.start, "Constructor can't have get/set modifier"), r.kind = p ? "constructor" : o, this.parseClassMethod(r, s, i, c);
				} else this.parseClassField(r);
				return r;
			}, G.isClassElementNameStart = function() {
				return this.type === I.name || this.type === I.privateId || this.type === I.num || this.type === I.string || this.type === I.bracketL || this.type.keyword;
			}, G.parseClassElementName = function(e) {
				this.type === I.privateId ? ("constructor" === this.value && this.raise(this.start, "Classes can't have an element named '#constructor'"), e.computed = !1, e.key = this.parsePrivateIdent()) : this.parsePropertyName(e);
			}, G.parseClassMethod = function(e, t, r, n) {
				var s = e.key;
				"constructor" === e.kind ? (t && this.raise(s.start, "Constructor can't be a generator"), r && this.raise(s.start, "Constructor can't be an async method")) : e.static && checkKeyName(e, "prototype") && this.raise(s.start, "Classes may not have a static property named prototype");
				var i = e.value = this.parseMethod(t, r, n);
				return "get" === e.kind && 0 !== i.params.length && this.raiseRecoverable(i.start, "getter should have no params"), "set" === e.kind && 1 !== i.params.length && this.raiseRecoverable(i.start, "setter should have exactly one param"), "set" === e.kind && "RestElement" === i.params[0].type && this.raiseRecoverable(i.params[0].start, "Setter cannot use rest params"), this.finishNode(e, "MethodDefinition");
			}, G.parseClassField = function(e) {
				return checkKeyName(e, "constructor") ? this.raise(e.key.start, "Classes can't have a field named 'constructor'") : e.static && checkKeyName(e, "prototype") && this.raise(e.key.start, "Classes can't have a static field named 'prototype'"), this.eat(I.eq) ? (this.enterScope(576), e.value = this.parseMaybeAssign(), this.exitScope()) : e.value = null, this.semicolon(), this.finishNode(e, "PropertyDefinition");
			}, G.parseClassStaticBlock = function(e) {
				e.body = [];
				var t = this.labels;
				for (this.labels = [], this.enterScope(320); this.type !== I.braceR;) {
					var r = this.parseStatement(null);
					e.body.push(r);
				}
				return this.next(), this.exitScope(), this.labels = t, this.finishNode(e, "StaticBlock");
			}, G.parseClassId = function(e, t) {
				this.type === I.name ? (e.id = this.parseIdent(), t && this.checkLValSimple(e.id, 2, !1)) : (!0 === t && this.unexpected(), e.id = null);
			}, G.parseClassSuper = function(e) {
				e.superClass = this.eat(I._extends) ? this.parseExprSubscripts(null, !1) : null;
			}, G.enterClassBody = function() {
				var e = {
					declared: Object.create(null),
					used: []
				};
				return this.privateNameStack.push(e), e.declared;
			}, G.exitClassBody = function() {
				var e = this.privateNameStack.pop(), t = e.declared, r = e.used;
				if (this.options.checkPrivateFields) for (var n = this.privateNameStack.length, s = 0 === n ? null : this.privateNameStack[n - 1], i = 0; i < r.length; ++i) {
					var o = r[i];
					M(t, o.name) || (s ? s.used.push(o) : this.raiseRecoverable(o.start, "Private field '#" + o.name + "' must be declared in an enclosing class"));
				}
			}, G.parseExportAllDeclaration = function(e, t) {
				return this.options.ecmaVersion >= 11 && (this.eatContextual("as") ? (e.exported = this.parseModuleExportName(), this.checkExport(t, e.exported, this.lastTokStart)) : e.exported = null), this.expectContextual("from"), this.type !== I.string && this.unexpected(), e.source = this.parseExprAtom(), this.options.ecmaVersion >= 16 && (e.attributes = this.parseWithClause()), this.semicolon(), this.finishNode(e, "ExportAllDeclaration");
			}, G.parseExport = function(e, t) {
				if (this.next(), this.eat(I.star)) return this.parseExportAllDeclaration(e, t);
				if (this.eat(I._default)) return this.checkExport(t, "default", this.lastTokStart), e.declaration = this.parseExportDefaultDeclaration(), this.finishNode(e, "ExportDefaultDeclaration");
				if (this.shouldParseExportStatement()) e.declaration = this.parseExportDeclaration(e), "VariableDeclaration" === e.declaration.type ? this.checkVariableExport(t, e.declaration.declarations) : this.checkExport(t, e.declaration.id, e.declaration.id.start), e.specifiers = [], e.source = null, this.options.ecmaVersion >= 16 && (e.attributes = []);
				else {
					if (e.declaration = null, e.specifiers = this.parseExportSpecifiers(t), this.eatContextual("from")) this.type !== I.string && this.unexpected(), e.source = this.parseExprAtom(), this.options.ecmaVersion >= 16 && (e.attributes = this.parseWithClause());
					else {
						for (var r = 0, n = e.specifiers; r < n.length; r += 1) {
							var s = n[r];
							this.checkUnreserved(s.local), this.checkLocalExport(s.local), "Literal" === s.local.type && this.raise(s.local.start, "A string literal cannot be used as an exported binding without `from`.");
						}
						e.source = null, this.options.ecmaVersion >= 16 && (e.attributes = []);
					}
					this.semicolon();
				}
				return this.finishNode(e, "ExportNamedDeclaration");
			}, G.parseExportDeclaration = function(e) {
				return this.parseStatement(null);
			}, G.parseExportDefaultDeclaration = function() {
				var e;
				if (this.type === I._function || (e = this.isAsyncFunction())) {
					var t = this.startNode();
					return this.next(), e && this.next(), this.parseFunction(t, 4 | Q, !1, e);
				}
				if (this.type === I._class) {
					var r = this.startNode();
					return this.parseClass(r, "nullableID");
				}
				var n = this.parseMaybeAssign();
				return this.semicolon(), n;
			}, G.checkExport = function(e, t, r) {
				e && ("string" != typeof t && (t = "Identifier" === t.type ? t.name : t.value), M(e, t) && this.raiseRecoverable(r, "Duplicate export '" + t + "'"), e[t] = !0);
			}, G.checkPatternExport = function(e, t) {
				var r = t.type;
				if ("Identifier" === r) this.checkExport(e, t, t.start);
				else if ("ObjectPattern" === r) for (var n = 0, s = t.properties; n < s.length; n += 1) {
					var i = s[n];
					this.checkPatternExport(e, i);
				}
				else if ("ArrayPattern" === r) for (var o = 0, a = t.elements; o < a.length; o += 1) {
					var l = a[o];
					l && this.checkPatternExport(e, l);
				}
				else "Property" === r ? this.checkPatternExport(e, t.value) : "AssignmentPattern" === r ? this.checkPatternExport(e, t.left) : "RestElement" === r && this.checkPatternExport(e, t.argument);
			}, G.checkVariableExport = function(e, t) {
				if (e) for (var r = 0, n = t; r < n.length; r += 1) {
					var s = n[r];
					this.checkPatternExport(e, s.id);
				}
			}, G.shouldParseExportStatement = function() {
				return "var" === this.type.keyword || "const" === this.type.keyword || "class" === this.type.keyword || "function" === this.type.keyword || this.isLet() || this.isAsyncFunction();
			}, G.parseExportSpecifier = function(e) {
				var t = this.startNode();
				return t.local = this.parseModuleExportName(), t.exported = this.eatContextual("as") ? this.parseModuleExportName() : t.local, this.checkExport(e, t.exported, t.exported.start), this.finishNode(t, "ExportSpecifier");
			}, G.parseExportSpecifiers = function(e) {
				var t = [], r = !0;
				for (this.expect(I.braceL); !this.eat(I.braceR);) {
					if (r) r = !1;
					else if (this.expect(I.comma), this.afterTrailingComma(I.braceR)) break;
					t.push(this.parseExportSpecifier(e));
				}
				return t;
			}, G.parseImport = function(e) {
				return this.next(), this.type === I.string ? (e.specifiers = Y, e.source = this.parseExprAtom()) : (e.specifiers = this.parseImportSpecifiers(), this.expectContextual("from"), e.source = this.type === I.string ? this.parseExprAtom() : this.unexpected()), this.options.ecmaVersion >= 16 && (e.attributes = this.parseWithClause()), this.semicolon(), this.finishNode(e, "ImportDeclaration");
			}, G.parseImportSpecifier = function() {
				var e = this.startNode();
				return e.imported = this.parseModuleExportName(), this.eatContextual("as") ? e.local = this.parseIdent() : (this.checkUnreserved(e.imported), e.local = e.imported), this.checkLValSimple(e.local, 2), this.finishNode(e, "ImportSpecifier");
			}, G.parseImportDefaultSpecifier = function() {
				var e = this.startNode();
				return e.local = this.parseIdent(), this.checkLValSimple(e.local, 2), this.finishNode(e, "ImportDefaultSpecifier");
			}, G.parseImportNamespaceSpecifier = function() {
				var e = this.startNode();
				return this.next(), this.expectContextual("as"), e.local = this.parseIdent(), this.checkLValSimple(e.local, 2), this.finishNode(e, "ImportNamespaceSpecifier");
			}, G.parseImportSpecifiers = function() {
				var e = [], t = !0;
				if (this.type === I.name && (e.push(this.parseImportDefaultSpecifier()), !this.eat(I.comma))) return e;
				if (this.type === I.star) return e.push(this.parseImportNamespaceSpecifier()), e;
				for (this.expect(I.braceL); !this.eat(I.braceR);) {
					if (t) t = !1;
					else if (this.expect(I.comma), this.afterTrailingComma(I.braceR)) break;
					e.push(this.parseImportSpecifier());
				}
				return e;
			}, G.parseWithClause = function() {
				var e = [];
				if (!this.eat(I._with)) return e;
				this.expect(I.braceL);
				for (var t = {}, r = !0; !this.eat(I.braceR);) {
					if (r) r = !1;
					else if (this.expect(I.comma), this.afterTrailingComma(I.braceR)) break;
					var n = this.parseImportAttribute(), s = "Identifier" === n.key.type ? n.key.name : n.key.value;
					M(t, s) && this.raiseRecoverable(n.key.start, "Duplicate attribute key '" + s + "'"), t[s] = !0, e.push(n);
				}
				return e;
			}, G.parseImportAttribute = function() {
				var e = this.startNode();
				return e.key = this.type === I.string ? this.parseExprAtom() : this.parseIdent("never" !== this.options.allowReserved), this.expect(I.colon), this.type !== I.string && this.unexpected(), e.value = this.parseExprAtom(), this.finishNode(e, "ImportAttribute");
			}, G.parseModuleExportName = function() {
				if (this.options.ecmaVersion >= 13 && this.type === I.string) {
					var e = this.parseLiteral(this.value);
					return U.test(e.value) && this.raise(e.start, "An export name cannot include a lone surrogate."), e;
				}
				return this.parseIdent(!0);
			}, G.adaptDirectivePrologue = function(e) {
				for (var t = 0; t < e.length && this.isDirectiveCandidate(e[t]); ++t) e[t].directive = e[t].expression.raw.slice(1, -1);
			}, G.isDirectiveCandidate = function(e) {
				return this.options.ecmaVersion >= 5 && "ExpressionStatement" === e.type && "Literal" === e.expression.type && "string" == typeof e.expression.value && ("\"" === this.input[e.start] || "'" === this.input[e.start]);
			};
			var ee = acorn_Parser.prototype;
			ee.toAssignable = function(e, t, r) {
				if (this.options.ecmaVersion >= 6 && e) switch (e.type) {
					case "Identifier":
						this.inAsync && "await" === e.name && this.raise(e.start, "Cannot use 'await' as identifier inside an async function");
						break;
					case "ObjectPattern":
					case "ArrayPattern":
					case "AssignmentPattern":
					case "RestElement": break;
					case "ObjectExpression":
						e.type = "ObjectPattern", r && this.checkPatternErrors(r, !0);
						for (var n = 0, s = e.properties; n < s.length; n += 1) {
							var i = s[n];
							this.toAssignable(i, t), "RestElement" !== i.type || "ArrayPattern" !== i.argument.type && "ObjectPattern" !== i.argument.type || this.raise(i.argument.start, "Unexpected token");
						}
						break;
					case "Property":
						"init" !== e.kind && this.raise(e.key.start, "Object pattern can't contain getter or setter"), this.toAssignable(e.value, t);
						break;
					case "ArrayExpression":
						e.type = "ArrayPattern", r && this.checkPatternErrors(r, !0), this.toAssignableList(e.elements, t);
						break;
					case "SpreadElement":
						e.type = "RestElement", this.toAssignable(e.argument, t), "AssignmentPattern" === e.argument.type && this.raise(e.argument.start, "Rest elements cannot have a default value");
						break;
					case "AssignmentExpression":
						"=" !== e.operator && this.raise(e.left.end, "Only '=' operator can be used for specifying default value."), e.type = "AssignmentPattern", delete e.operator, this.toAssignable(e.left, t);
						break;
					case "ParenthesizedExpression":
						this.toAssignable(e.expression, t, r);
						break;
					case "ChainExpression":
						this.raiseRecoverable(e.start, "Optional chaining cannot appear in left-hand side");
						break;
					case "MemberExpression": if (!t) break;
					default: this.raise(e.start, "Assigning to rvalue");
				}
				else r && this.checkPatternErrors(r, !0);
				return e;
			}, ee.toAssignableList = function(e, t) {
				for (var r = e.length, n = 0; n < r; n++) {
					var s = e[n];
					s && this.toAssignable(s, t);
				}
				if (r) {
					var i = e[r - 1];
					6 === this.options.ecmaVersion && t && i && "RestElement" === i.type && "Identifier" !== i.argument.type && this.unexpected(i.argument.start);
				}
				return e;
			}, ee.parseSpread = function(e) {
				var t = this.startNode();
				return this.next(), t.argument = this.parseMaybeAssign(!1, e), this.finishNode(t, "SpreadElement");
			}, ee.parseRestBinding = function() {
				var e = this.startNode();
				return this.next(), 6 === this.options.ecmaVersion && this.type !== I.name && this.unexpected(), e.argument = this.parseBindingAtom(), this.finishNode(e, "RestElement");
			}, ee.parseBindingAtom = function() {
				if (this.options.ecmaVersion >= 6) switch (this.type) {
					case I.bracketL:
						var e = this.startNode();
						return this.next(), e.elements = this.parseBindingList(I.bracketR, !0, !0), this.finishNode(e, "ArrayPattern");
					case I.braceL: return this.parseObj(!0);
				}
				return this.parseIdent();
			}, ee.parseBindingList = function(e, t, r, n) {
				for (var s = [], i = !0; !this.eat(e);) if (i ? i = !1 : this.expect(I.comma), t && this.type === I.comma) s.push(null);
				else {
					if (r && this.afterTrailingComma(e)) break;
					if (this.type === I.ellipsis) {
						var o = this.parseRestBinding();
						this.parseBindingListItem(o), s.push(o), this.type === I.comma && this.raiseRecoverable(this.start, "Comma is not permitted after the rest element"), this.expect(e);
						break;
					}
					s.push(this.parseAssignableListItem(n));
				}
				return s;
			}, ee.parseAssignableListItem = function(e) {
				var t = this.parseMaybeDefault(this.start, this.startLoc);
				return this.parseBindingListItem(t), t;
			}, ee.parseBindingListItem = function(e) {
				return e;
			}, ee.parseMaybeDefault = function(e, t, r) {
				if (r = r || this.parseBindingAtom(), this.options.ecmaVersion < 6 || !this.eat(I.eq)) return r;
				var n = this.startNodeAt(e, t);
				return n.left = r, n.right = this.parseMaybeAssign(), this.finishNode(n, "AssignmentPattern");
			}, ee.checkLValSimple = function(e, t, r) {
				void 0 === t && (t = 0);
				var n = 0 !== t;
				switch (e.type) {
					case "Identifier":
						this.strict && this.reservedWordsStrictBind.test(e.name) && this.raiseRecoverable(e.start, (n ? "Binding " : "Assigning to ") + e.name + " in strict mode"), n && (2 === t && "let" === e.name && this.raiseRecoverable(e.start, "let is disallowed as a lexically bound name"), r && (M(r, e.name) && this.raiseRecoverable(e.start, "Argument name clash"), r[e.name] = !0), 5 !== t && this.declareName(e.name, t, e.start));
						break;
					case "ChainExpression":
						this.raiseRecoverable(e.start, "Optional chaining cannot appear in left-hand side");
						break;
					case "MemberExpression":
						n && this.raiseRecoverable(e.start, "Binding member expression");
						break;
					case "ParenthesizedExpression": return n && this.raiseRecoverable(e.start, "Binding parenthesized expression"), this.checkLValSimple(e.expression, t, r);
					default: this.raise(e.start, (n ? "Binding" : "Assigning to") + " rvalue");
				}
			}, ee.checkLValPattern = function(e, t, r) {
				switch (void 0 === t && (t = 0), e.type) {
					case "ObjectPattern":
						for (var n = 0, s = e.properties; n < s.length; n += 1) {
							var i = s[n];
							this.checkLValInnerPattern(i, t, r);
						}
						break;
					case "ArrayPattern":
						for (var o = 0, a = e.elements; o < a.length; o += 1) {
							var l = a[o];
							l && this.checkLValInnerPattern(l, t, r);
						}
						break;
					default: this.checkLValSimple(e, t, r);
				}
			}, ee.checkLValInnerPattern = function(e, t, r) {
				switch (void 0 === t && (t = 0), e.type) {
					case "Property":
						this.checkLValInnerPattern(e.value, t, r);
						break;
					case "AssignmentPattern":
						this.checkLValPattern(e.left, t, r);
						break;
					case "RestElement":
						this.checkLValPattern(e.argument, t, r);
						break;
					default: this.checkLValPattern(e, t, r);
				}
			};
			var acorn_TokContext = function(e, t, r, n, s) {
				this.token = e, this.isExpr = !!t, this.preserveSpace = !!r, this.override = n, this.generator = !!s;
			}, te = {
				b_stat: new acorn_TokContext("{", !1),
				b_expr: new acorn_TokContext("{", !0),
				b_tmpl: new acorn_TokContext("${", !1),
				p_stat: new acorn_TokContext("(", !1),
				p_expr: new acorn_TokContext("(", !0),
				q_tmpl: new acorn_TokContext("`", !0, !0, function(e) {
					return e.tryReadTemplateToken();
				}),
				f_stat: new acorn_TokContext("function", !1),
				f_expr: new acorn_TokContext("function", !0),
				f_expr_gen: new acorn_TokContext("function", !0, !1, null, !0),
				f_gen: new acorn_TokContext("function", !1, !1, null, !0)
			}, re = acorn_Parser.prototype;
			re.initialContext = function() {
				return [te.b_stat];
			}, re.curContext = function() {
				return this.context[this.context.length - 1];
			}, re.braceIsBlock = function(e) {
				var t = this.curContext();
				return t === te.f_expr || t === te.f_stat || (e !== I.colon || t !== te.b_stat && t !== te.b_expr ? e === I._return || e === I.name && this.exprAllowed ? D.test(this.input.slice(this.lastTokEnd, this.start)) : e === I._else || e === I.semi || e === I.eof || e === I.parenR || e === I.arrow || (e === I.braceL ? t === te.b_stat : e !== I._var && e !== I._const && e !== I.name && !this.exprAllowed) : !t.isExpr);
			}, re.inGeneratorContext = function() {
				for (var e = this.context.length - 1; e >= 1; e--) {
					var t = this.context[e];
					if ("function" === t.token) return t.generator;
				}
				return !1;
			}, re.updateContext = function(e) {
				var t, r = this.type;
				r.keyword && e === I.dot ? this.exprAllowed = !1 : (t = r.updateContext) ? t.call(this, e) : this.exprAllowed = r.beforeExpr;
			}, re.overrideContext = function(e) {
				this.curContext() !== e && (this.context[this.context.length - 1] = e);
			}, I.parenR.updateContext = I.braceR.updateContext = function() {
				if (1 !== this.context.length) {
					var e = this.context.pop();
					e === te.b_stat && "function" === this.curContext().token && (e = this.context.pop()), this.exprAllowed = !e.isExpr;
				} else this.exprAllowed = !0;
			}, I.braceL.updateContext = function(e) {
				this.context.push(this.braceIsBlock(e) ? te.b_stat : te.b_expr), this.exprAllowed = !0;
			}, I.dollarBraceL.updateContext = function() {
				this.context.push(te.b_tmpl), this.exprAllowed = !0;
			}, I.parenL.updateContext = function(e) {
				var t = e === I._if || e === I._for || e === I._with || e === I._while;
				this.context.push(t ? te.p_stat : te.p_expr), this.exprAllowed = !0;
			}, I.incDec.updateContext = function() {}, I._function.updateContext = I._class.updateContext = function(e) {
				!e.beforeExpr || e === I._else || e === I.semi && this.curContext() !== te.p_stat || e === I._return && D.test(this.input.slice(this.lastTokEnd, this.start)) || (e === I.colon || e === I.braceL) && this.curContext() === te.b_stat ? this.context.push(te.f_stat) : this.context.push(te.f_expr), this.exprAllowed = !1;
			}, I.colon.updateContext = function() {
				"function" === this.curContext().token && this.context.pop(), this.exprAllowed = !0;
			}, I.backQuote.updateContext = function() {
				this.curContext() === te.q_tmpl ? this.context.pop() : this.context.push(te.q_tmpl), this.exprAllowed = !1;
			}, I.star.updateContext = function(e) {
				if (e === I._function) {
					var t = this.context.length - 1;
					this.context[t] === te.f_expr ? this.context[t] = te.f_expr_gen : this.context[t] = te.f_gen;
				}
				this.exprAllowed = !0;
			}, I.name.updateContext = function(e) {
				var t = !1;
				this.options.ecmaVersion >= 6 && e !== I.dot && ("of" === this.value && !this.exprAllowed || "yield" === this.value && this.inGeneratorContext()) && (t = !0), this.exprAllowed = t;
			};
			var ne = acorn_Parser.prototype;
			function isLocalVariableAccess(e) {
				return "Identifier" === e.type || "ParenthesizedExpression" === e.type && isLocalVariableAccess(e.expression);
			}
			function isPrivateFieldAccess(e) {
				return "MemberExpression" === e.type && "PrivateIdentifier" === e.property.type || "ChainExpression" === e.type && isPrivateFieldAccess(e.expression) || "ParenthesizedExpression" === e.type && isPrivateFieldAccess(e.expression);
			}
			ne.checkPropClash = function(e, t, r) {
				if (!(this.options.ecmaVersion >= 9 && "SpreadElement" === e.type || this.options.ecmaVersion >= 6 && (e.computed || e.method || e.shorthand))) {
					var n, s = e.key;
					switch (s.type) {
						case "Identifier":
							n = s.name;
							break;
						case "Literal":
							n = String(s.value);
							break;
						default: return;
					}
					var i = e.kind;
					if (this.options.ecmaVersion >= 6) "__proto__" === n && "init" === i && (t.proto && (r ? r.doubleProto < 0 && (r.doubleProto = s.start) : this.raiseRecoverable(s.start, "Redefinition of __proto__ property")), t.proto = !0);
					else {
						var o = t[n = "$" + n];
						if (o) ("init" === i ? this.strict && o.init || o.get || o.set : o.init || o[i]) && this.raiseRecoverable(s.start, "Redefinition of property");
						else o = t[n] = {
							init: !1,
							get: !1,
							set: !1
						};
						o[i] = !0;
					}
				}
			}, ne.parseExpression = function(e, t) {
				var r = this.start, n = this.startLoc, s = this.parseMaybeAssign(e, t);
				if (this.type === I.comma) {
					var i = this.startNodeAt(r, n);
					for (i.expressions = [s]; this.eat(I.comma);) i.expressions.push(this.parseMaybeAssign(e, t));
					return this.finishNode(i, "SequenceExpression");
				}
				return s;
			}, ne.parseMaybeAssign = function(e, t, r) {
				if (this.isContextual("yield")) {
					if (this.inGenerator) return this.parseYield(e);
					this.exprAllowed = !1;
				}
				var n = !1, s = -1, i = -1, o = -1;
				t ? (s = t.parenthesizedAssign, i = t.trailingComma, o = t.doubleProto, t.parenthesizedAssign = t.trailingComma = -1) : (t = new acorn_DestructuringErrors(), n = !0);
				var a = this.start, l = this.startLoc;
				this.type !== I.parenL && this.type !== I.name || (this.potentialArrowAt = this.start, this.potentialArrowInForAwait = "await" === e);
				var p = this.parseMaybeConditional(e, t);
				if (r && (p = r.call(this, p, a, l)), this.type.isAssign) {
					var c = this.startNodeAt(a, l);
					return c.operator = this.value, this.type === I.eq && (p = this.toAssignable(p, !1, t)), n || (t.parenthesizedAssign = t.trailingComma = t.doubleProto = -1), t.shorthandAssign >= p.start && (t.shorthandAssign = -1), this.type === I.eq ? this.checkLValPattern(p) : this.checkLValSimple(p), c.left = p, this.next(), c.right = this.parseMaybeAssign(e), o > -1 && (t.doubleProto = o), this.finishNode(c, "AssignmentExpression");
				}
				return n && this.checkExpressionErrors(t, !0), s > -1 && (t.parenthesizedAssign = s), i > -1 && (t.trailingComma = i), p;
			}, ne.parseMaybeConditional = function(e, t) {
				var r = this.start, n = this.startLoc, s = this.parseExprOps(e, t);
				if (this.checkExpressionErrors(t)) return s;
				if (this.eat(I.question)) {
					var i = this.startNodeAt(r, n);
					return i.test = s, i.consequent = this.parseMaybeAssign(), this.expect(I.colon), i.alternate = this.parseMaybeAssign(e), this.finishNode(i, "ConditionalExpression");
				}
				return s;
			}, ne.parseExprOps = function(e, t) {
				var r = this.start, n = this.startLoc, s = this.parseMaybeUnary(t, !1, !1, e);
				return this.checkExpressionErrors(t) || s.start === r && "ArrowFunctionExpression" === s.type ? s : this.parseExprOp(s, r, n, -1, e);
			}, ne.parseExprOp = function(e, t, r, n, s) {
				var i = this.type.binop;
				if (null != i && (!s || this.type !== I._in) && i > n) {
					var o = this.type === I.logicalOR || this.type === I.logicalAND, a = this.type === I.coalesce;
					a && (i = I.logicalAND.binop);
					var l = this.value;
					this.next();
					var p = this.start, c = this.startLoc, u = this.parseExprOp(this.parseMaybeUnary(null, !1, !1, s), p, c, i, s), d = this.buildBinary(t, r, e, u, l, o || a);
					return (o && this.type === I.coalesce || a && (this.type === I.logicalOR || this.type === I.logicalAND)) && this.raiseRecoverable(this.start, "Logical expressions and coalesce expressions cannot be mixed. Wrap either by parentheses"), this.parseExprOp(d, t, r, n, s);
				}
				return e;
			}, ne.buildBinary = function(e, t, r, n, s, i) {
				"PrivateIdentifier" === n.type && this.raise(n.start, "Private identifier can only be left side of binary expression");
				var o = this.startNodeAt(e, t);
				return o.left = r, o.operator = s, o.right = n, this.finishNode(o, i ? "LogicalExpression" : "BinaryExpression");
			}, ne.parseMaybeUnary = function(e, t, r, n) {
				var s, i = this.start, o = this.startLoc;
				if (this.isContextual("await") && this.canAwait) s = this.parseAwait(n), t = !0;
				else if (this.type.prefix) {
					var a = this.startNode(), l = this.type === I.incDec;
					a.operator = this.value, a.prefix = !0, this.next(), a.argument = this.parseMaybeUnary(null, !0, l, n), this.checkExpressionErrors(e, !0), l ? this.checkLValSimple(a.argument) : this.strict && "delete" === a.operator && isLocalVariableAccess(a.argument) ? this.raiseRecoverable(a.start, "Deleting local variable in strict mode") : "delete" === a.operator && isPrivateFieldAccess(a.argument) ? this.raiseRecoverable(a.start, "Private fields can not be deleted") : t = !0, s = this.finishNode(a, l ? "UpdateExpression" : "UnaryExpression");
				} else if (t || this.type !== I.privateId) {
					if (s = this.parseExprSubscripts(e, n), this.checkExpressionErrors(e)) return s;
					for (; this.type.postfix && !this.canInsertSemicolon();) {
						var p = this.startNodeAt(i, o);
						p.operator = this.value, p.prefix = !1, p.argument = s, this.checkLValSimple(s), this.next(), s = this.finishNode(p, "UpdateExpression");
					}
				} else (n || 0 === this.privateNameStack.length) && this.options.checkPrivateFields && this.unexpected(), s = this.parsePrivateIdent(), this.type !== I._in && this.unexpected();
				return r || !this.eat(I.starstar) ? s : t ? void this.unexpected(this.lastTokStart) : this.buildBinary(i, o, s, this.parseMaybeUnary(null, !1, !1, n), "**", !1);
			}, ne.parseExprSubscripts = function(e, t) {
				var r = this.start, n = this.startLoc, s = this.parseExprAtom(e, t);
				if ("ArrowFunctionExpression" === s.type && ")" !== this.input.slice(this.lastTokStart, this.lastTokEnd)) return s;
				var i = this.parseSubscripts(s, r, n, !1, t);
				return e && "MemberExpression" === i.type && (e.parenthesizedAssign >= i.start && (e.parenthesizedAssign = -1), e.parenthesizedBind >= i.start && (e.parenthesizedBind = -1), e.trailingComma >= i.start && (e.trailingComma = -1)), i;
			}, ne.parseSubscripts = function(e, t, r, n, s) {
				for (var i = this.options.ecmaVersion >= 8 && "Identifier" === e.type && "async" === e.name && this.lastTokEnd === e.end && !this.canInsertSemicolon() && e.end - e.start === 5 && this.potentialArrowAt === e.start, o = !1;;) {
					var a = this.parseSubscript(e, t, r, n, i, o, s);
					if (a.optional && (o = !0), a === e || "ArrowFunctionExpression" === a.type) {
						if (o) {
							var l = this.startNodeAt(t, r);
							l.expression = a, a = this.finishNode(l, "ChainExpression");
						}
						return a;
					}
					e = a;
				}
			}, ne.shouldParseAsyncArrow = function() {
				return !this.canInsertSemicolon() && this.eat(I.arrow);
			}, ne.parseSubscriptAsyncArrow = function(e, t, r, n) {
				return this.parseArrowExpression(this.startNodeAt(e, t), r, !0, n);
			}, ne.parseSubscript = function(e, t, r, n, s, i, o) {
				var a = this.options.ecmaVersion >= 11, l = a && this.eat(I.questionDot);
				n && l && this.raise(this.lastTokStart, "Optional chaining cannot appear in the callee of new expressions");
				var p = this.eat(I.bracketL);
				if (p || l && this.type !== I.parenL && this.type !== I.backQuote || this.eat(I.dot)) {
					var c = this.startNodeAt(t, r);
					c.object = e, p ? (c.property = this.parseExpression(), this.expect(I.bracketR)) : this.type === I.privateId && "Super" !== e.type ? c.property = this.parsePrivateIdent() : c.property = this.parseIdent("never" !== this.options.allowReserved), c.computed = !!p, a && (c.optional = l), e = this.finishNode(c, "MemberExpression");
				} else if (!n && this.eat(I.parenL)) {
					var u = new acorn_DestructuringErrors(), d = this.yieldPos, h = this.awaitPos, m = this.awaitIdentPos;
					this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0;
					var f = this.parseExprList(I.parenR, this.options.ecmaVersion >= 8, !1, u);
					if (s && !l && this.shouldParseAsyncArrow()) return this.checkPatternErrors(u, !1), this.checkYieldAwaitInDefaultParams(), this.awaitIdentPos > 0 && this.raise(this.awaitIdentPos, "Cannot use 'await' as identifier inside an async function"), this.yieldPos = d, this.awaitPos = h, this.awaitIdentPos = m, this.parseSubscriptAsyncArrow(t, r, f, o);
					this.checkExpressionErrors(u, !0), this.yieldPos = d || this.yieldPos, this.awaitPos = h || this.awaitPos, this.awaitIdentPos = m || this.awaitIdentPos;
					var y = this.startNodeAt(t, r);
					y.callee = e, y.arguments = f, a && (y.optional = l), e = this.finishNode(y, "CallExpression");
				} else if (this.type === I.backQuote) {
					(l || i) && this.raise(this.start, "Optional chaining cannot appear in the tag of tagged template expressions");
					var b = this.startNodeAt(t, r);
					b.tag = e, b.quasi = this.parseTemplate({ isTagged: !0 }), e = this.finishNode(b, "TaggedTemplateExpression");
				}
				return e;
			}, ne.parseExprAtom = function(e, t, r) {
				this.type === I.slash && this.readRegexp();
				var n, s = this.potentialArrowAt === this.start;
				switch (this.type) {
					case I._super: return this.allowSuper || this.raise(this.start, "'super' keyword outside a method"), n = this.startNode(), this.next(), this.type !== I.parenL || this.allowDirectSuper || this.raise(n.start, "super() call outside constructor of a subclass"), this.type !== I.dot && this.type !== I.bracketL && this.type !== I.parenL && this.unexpected(), this.finishNode(n, "Super");
					case I._this: return n = this.startNode(), this.next(), this.finishNode(n, "ThisExpression");
					case I.name:
						var i = this.start, o = this.startLoc, a = this.containsEsc, l = this.parseIdent(!1);
						if (this.options.ecmaVersion >= 8 && !a && "async" === l.name && !this.canInsertSemicolon() && this.eat(I._function)) return this.overrideContext(te.f_expr), this.parseFunction(this.startNodeAt(i, o), 0, !1, !0, t);
						if (s && !this.canInsertSemicolon()) {
							if (this.eat(I.arrow)) return this.parseArrowExpression(this.startNodeAt(i, o), [l], !1, t);
							if (this.options.ecmaVersion >= 8 && "async" === l.name && this.type === I.name && !a && (!this.potentialArrowInForAwait || "of" !== this.value || this.containsEsc)) return l = this.parseIdent(!1), !this.canInsertSemicolon() && this.eat(I.arrow) || this.unexpected(), this.parseArrowExpression(this.startNodeAt(i, o), [l], !0, t);
						}
						return l;
					case I.regexp:
						var p = this.value;
						return (n = this.parseLiteral(p.value)).regex = {
							pattern: p.pattern,
							flags: p.flags
						}, n;
					case I.num:
					case I.string: return this.parseLiteral(this.value);
					case I._null:
					case I._true:
					case I._false: return (n = this.startNode()).value = this.type === I._null ? null : this.type === I._true, n.raw = this.type.keyword, this.next(), this.finishNode(n, "Literal");
					case I.parenL:
						var c = this.start, u = this.parseParenAndDistinguishExpression(s, t);
						return e && (e.parenthesizedAssign < 0 && !this.isSimpleAssignTarget(u) && (e.parenthesizedAssign = c), e.parenthesizedBind < 0 && (e.parenthesizedBind = c)), u;
					case I.bracketL: return n = this.startNode(), this.next(), n.elements = this.parseExprList(I.bracketR, !0, !0, e), this.finishNode(n, "ArrayExpression");
					case I.braceL: return this.overrideContext(te.b_expr), this.parseObj(!1, e);
					case I._function: return n = this.startNode(), this.next(), this.parseFunction(n, 0);
					case I._class: return this.parseClass(this.startNode(), !1);
					case I._new: return this.parseNew();
					case I.backQuote: return this.parseTemplate();
					case I._import: return this.options.ecmaVersion >= 11 ? this.parseExprImport(r) : this.unexpected();
					default: return this.parseExprAtomDefault();
				}
			}, ne.parseExprAtomDefault = function() {
				this.unexpected();
			}, ne.parseExprImport = function(e) {
				var t = this.startNode();
				if (this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword import"), this.next(), this.type === I.parenL && !e) return this.parseDynamicImport(t);
				if (this.type === I.dot) {
					var r = this.startNodeAt(t.start, t.loc && t.loc.start);
					return r.name = "import", t.meta = this.finishNode(r, "Identifier"), this.parseImportMeta(t);
				}
				this.unexpected();
			}, ne.parseDynamicImport = function(e) {
				if (this.next(), e.source = this.parseMaybeAssign(), this.options.ecmaVersion >= 16) this.eat(I.parenR) ? e.options = null : (this.expect(I.comma), this.afterTrailingComma(I.parenR) ? e.options = null : (e.options = this.parseMaybeAssign(), this.eat(I.parenR) || (this.expect(I.comma), this.afterTrailingComma(I.parenR) || this.unexpected())));
				else if (!this.eat(I.parenR)) {
					var t = this.start;
					this.eat(I.comma) && this.eat(I.parenR) ? this.raiseRecoverable(t, "Trailing comma is not allowed in import()") : this.unexpected(t);
				}
				return this.finishNode(e, "ImportExpression");
			}, ne.parseImportMeta = function(e) {
				this.next();
				var t = this.containsEsc;
				return e.property = this.parseIdent(!0), "meta" !== e.property.name && this.raiseRecoverable(e.property.start, "The only valid meta property for import is 'import.meta'"), t && this.raiseRecoverable(e.start, "'import.meta' must not contain escaped characters"), "module" === this.options.sourceType || this.options.allowImportExportEverywhere || this.raiseRecoverable(e.start, "Cannot use 'import.meta' outside a module"), this.finishNode(e, "MetaProperty");
			}, ne.parseLiteral = function(e) {
				var t = this.startNode();
				return t.value = e, t.raw = this.input.slice(this.start, this.end), 110 === t.raw.charCodeAt(t.raw.length - 1) && (t.bigint = null != t.value ? t.value.toString() : t.raw.slice(0, -1).replace(/_/g, "")), this.next(), this.finishNode(t, "Literal");
			}, ne.parseParenExpression = function() {
				this.expect(I.parenL);
				var e = this.parseExpression();
				return this.expect(I.parenR), e;
			}, ne.shouldParseArrow = function(e) {
				return !this.canInsertSemicolon();
			}, ne.parseParenAndDistinguishExpression = function(e, t) {
				var r, n = this.start, s = this.startLoc, i = this.options.ecmaVersion >= 8;
				if (this.options.ecmaVersion >= 6) {
					this.next();
					var o, a = this.start, l = this.startLoc, p = [], c = !0, u = !1, d = new acorn_DestructuringErrors(), h = this.yieldPos, m = this.awaitPos;
					for (this.yieldPos = 0, this.awaitPos = 0; this.type !== I.parenR;) {
						if (c ? c = !1 : this.expect(I.comma), i && this.afterTrailingComma(I.parenR, !0)) {
							u = !0;
							break;
						}
						if (this.type === I.ellipsis) {
							o = this.start, p.push(this.parseParenItem(this.parseRestBinding())), this.type === I.comma && this.raiseRecoverable(this.start, "Comma is not permitted after the rest element");
							break;
						}
						p.push(this.parseMaybeAssign(!1, d, this.parseParenItem));
					}
					var f = this.lastTokEnd, y = this.lastTokEndLoc;
					if (this.expect(I.parenR), e && this.shouldParseArrow(p) && this.eat(I.arrow)) return this.checkPatternErrors(d, !1), this.checkYieldAwaitInDefaultParams(), this.yieldPos = h, this.awaitPos = m, this.parseParenArrowList(n, s, p, t);
					p.length && !u || this.unexpected(this.lastTokStart), o && this.unexpected(o), this.checkExpressionErrors(d, !0), this.yieldPos = h || this.yieldPos, this.awaitPos = m || this.awaitPos, p.length > 1 ? ((r = this.startNodeAt(a, l)).expressions = p, this.finishNodeAt(r, "SequenceExpression", f, y)) : r = p[0];
				} else r = this.parseParenExpression();
				if (this.options.preserveParens) {
					var b = this.startNodeAt(n, s);
					return b.expression = r, this.finishNode(b, "ParenthesizedExpression");
				}
				return r;
			}, ne.parseParenItem = function(e) {
				return e;
			}, ne.parseParenArrowList = function(e, t, r, n) {
				return this.parseArrowExpression(this.startNodeAt(e, t), r, !1, n);
			};
			var se = [];
			ne.parseNew = function() {
				this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword new");
				var e = this.startNode();
				if (this.next(), this.options.ecmaVersion >= 6 && this.type === I.dot) {
					var t = this.startNodeAt(e.start, e.loc && e.loc.start);
					t.name = "new", e.meta = this.finishNode(t, "Identifier"), this.next();
					var r = this.containsEsc;
					return e.property = this.parseIdent(!0), "target" !== e.property.name && this.raiseRecoverable(e.property.start, "The only valid meta property for new is 'new.target'"), r && this.raiseRecoverable(e.start, "'new.target' must not contain escaped characters"), this.allowNewDotTarget || this.raiseRecoverable(e.start, "'new.target' can only be used in functions and class static block"), this.finishNode(e, "MetaProperty");
				}
				var n = this.start, s = this.startLoc;
				return e.callee = this.parseSubscripts(this.parseExprAtom(null, !1, !0), n, s, !0, !1), this.eat(I.parenL) ? e.arguments = this.parseExprList(I.parenR, this.options.ecmaVersion >= 8, !1) : e.arguments = se, this.finishNode(e, "NewExpression");
			}, ne.parseTemplateElement = function(e) {
				var t = e.isTagged, r = this.startNode();
				return this.type === I.invalidTemplate ? (t || this.raiseRecoverable(this.start, "Bad escape sequence in untagged template literal"), r.value = {
					raw: this.value.replace(/\r\n?/g, "\n"),
					cooked: null
				}) : r.value = {
					raw: this.input.slice(this.start, this.end).replace(/\r\n?/g, "\n"),
					cooked: this.value
				}, this.next(), r.tail = this.type === I.backQuote, this.finishNode(r, "TemplateElement");
			}, ne.parseTemplate = function(e) {
				void 0 === e && (e = {});
				var t = e.isTagged;
				void 0 === t && (t = !1);
				var r = this.startNode();
				this.next(), r.expressions = [];
				var n = this.parseTemplateElement({ isTagged: t });
				for (r.quasis = [n]; !n.tail;) this.type === I.eof && this.raise(this.pos, "Unterminated template literal"), this.expect(I.dollarBraceL), r.expressions.push(this.parseExpression()), this.expect(I.braceR), r.quasis.push(n = this.parseTemplateElement({ isTagged: t }));
				return this.next(), this.finishNode(r, "TemplateLiteral");
			}, ne.isAsyncProp = function(e) {
				return !e.computed && "Identifier" === e.key.type && "async" === e.key.name && (this.type === I.name || this.type === I.num || this.type === I.string || this.type === I.bracketL || this.type.keyword || this.options.ecmaVersion >= 9 && this.type === I.star) && !D.test(this.input.slice(this.lastTokEnd, this.start));
			}, ne.parseObj = function(e, t) {
				var r = this.startNode(), n = !0, s = {};
				for (r.properties = [], this.next(); !this.eat(I.braceR);) {
					if (n) n = !1;
					else if (this.expect(I.comma), this.options.ecmaVersion >= 5 && this.afterTrailingComma(I.braceR)) break;
					var i = this.parseProperty(e, t);
					e || this.checkPropClash(i, s, t), r.properties.push(i);
				}
				return this.finishNode(r, e ? "ObjectPattern" : "ObjectExpression");
			}, ne.parseProperty = function(e, t) {
				var r, n, s, i, o = this.startNode();
				if (this.options.ecmaVersion >= 9 && this.eat(I.ellipsis)) return e ? (o.argument = this.parseIdent(!1), this.type === I.comma && this.raiseRecoverable(this.start, "Comma is not permitted after the rest element"), this.finishNode(o, "RestElement")) : (o.argument = this.parseMaybeAssign(!1, t), this.type === I.comma && t && t.trailingComma < 0 && (t.trailingComma = this.start), this.finishNode(o, "SpreadElement"));
				this.options.ecmaVersion >= 6 && (o.method = !1, o.shorthand = !1, (e || t) && (s = this.start, i = this.startLoc), e || (r = this.eat(I.star)));
				var a = this.containsEsc;
				return this.parsePropertyName(o), !e && !a && this.options.ecmaVersion >= 8 && !r && this.isAsyncProp(o) ? (n = !0, r = this.options.ecmaVersion >= 9 && this.eat(I.star), this.parsePropertyName(o)) : n = !1, this.parsePropertyValue(o, e, r, n, s, i, t, a), this.finishNode(o, "Property");
			}, ne.parseGetterSetter = function(e) {
				var t = e.key.name;
				this.parsePropertyName(e), e.value = this.parseMethod(!1), e.kind = t;
				var r = "get" === e.kind ? 0 : 1;
				if (e.value.params.length !== r) {
					var n = e.value.start;
					"get" === e.kind ? this.raiseRecoverable(n, "getter should have no params") : this.raiseRecoverable(n, "setter should have exactly one param");
				} else "set" === e.kind && "RestElement" === e.value.params[0].type && this.raiseRecoverable(e.value.params[0].start, "Setter cannot use rest params");
			}, ne.parsePropertyValue = function(e, t, r, n, s, i, o, a) {
				(r || n) && this.type === I.colon && this.unexpected(), this.eat(I.colon) ? (e.value = t ? this.parseMaybeDefault(this.start, this.startLoc) : this.parseMaybeAssign(!1, o), e.kind = "init") : this.options.ecmaVersion >= 6 && this.type === I.parenL ? (t && this.unexpected(), e.method = !0, e.value = this.parseMethod(r, n), e.kind = "init") : t || a || !(this.options.ecmaVersion >= 5) || e.computed || "Identifier" !== e.key.type || "get" !== e.key.name && "set" !== e.key.name || this.type === I.comma || this.type === I.braceR || this.type === I.eq ? this.options.ecmaVersion >= 6 && !e.computed && "Identifier" === e.key.type ? ((r || n) && this.unexpected(), this.checkUnreserved(e.key), "await" !== e.key.name || this.awaitIdentPos || (this.awaitIdentPos = s), t ? e.value = this.parseMaybeDefault(s, i, this.copyNode(e.key)) : this.type === I.eq && o ? (o.shorthandAssign < 0 && (o.shorthandAssign = this.start), e.value = this.parseMaybeDefault(s, i, this.copyNode(e.key))) : e.value = this.copyNode(e.key), e.kind = "init", e.shorthand = !0) : this.unexpected() : ((r || n) && this.unexpected(), this.parseGetterSetter(e));
			}, ne.parsePropertyName = function(e) {
				if (this.options.ecmaVersion >= 6) {
					if (this.eat(I.bracketL)) return e.computed = !0, e.key = this.parseMaybeAssign(), this.expect(I.bracketR), e.key;
					e.computed = !1;
				}
				return e.key = this.type === I.num || this.type === I.string ? this.parseExprAtom() : this.parseIdent("never" !== this.options.allowReserved);
			}, ne.initFunction = function(e) {
				e.id = null, this.options.ecmaVersion >= 6 && (e.generator = e.expression = !1), this.options.ecmaVersion >= 8 && (e.async = !1);
			}, ne.parseMethod = function(e, t, r) {
				var n = this.startNode(), s = this.yieldPos, i = this.awaitPos, o = this.awaitIdentPos;
				return this.initFunction(n), this.options.ecmaVersion >= 6 && (n.generator = e), this.options.ecmaVersion >= 8 && (n.async = !!t), this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, this.enterScope(64 | functionFlags(t, n.generator) | (r ? 128 : 0)), this.expect(I.parenL), n.params = this.parseBindingList(I.parenR, !1, this.options.ecmaVersion >= 8), this.checkYieldAwaitInDefaultParams(), this.parseFunctionBody(n, !1, !0, !1), this.yieldPos = s, this.awaitPos = i, this.awaitIdentPos = o, this.finishNode(n, "FunctionExpression");
			}, ne.parseArrowExpression = function(e, t, r, n) {
				var s = this.yieldPos, i = this.awaitPos, o = this.awaitIdentPos;
				return this.enterScope(16 | functionFlags(r, !1)), this.initFunction(e), this.options.ecmaVersion >= 8 && (e.async = !!r), this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, e.params = this.toAssignableList(t, !0), this.parseFunctionBody(e, !0, !1, n), this.yieldPos = s, this.awaitPos = i, this.awaitIdentPos = o, this.finishNode(e, "ArrowFunctionExpression");
			}, ne.parseFunctionBody = function(e, t, r, n) {
				var s = t && this.type !== I.braceL, i = this.strict, o = !1;
				if (s) e.body = this.parseMaybeAssign(n), e.expression = !0, this.checkParams(e, !1);
				else {
					var a = this.options.ecmaVersion >= 7 && !this.isSimpleParamList(e.params);
					i && !a || (o = this.strictDirective(this.end)) && a && this.raiseRecoverable(e.start, "Illegal 'use strict' directive in function with non-simple parameter list");
					var l = this.labels;
					this.labels = [], o && (this.strict = !0), this.checkParams(e, !i && !o && !t && !r && this.isSimpleParamList(e.params)), this.strict && e.id && this.checkLValSimple(e.id, 5), e.body = this.parseBlock(!1, void 0, o && !i), e.expression = !1, this.adaptDirectivePrologue(e.body.body), this.labels = l;
				}
				this.exitScope();
			}, ne.isSimpleParamList = function(e) {
				for (var t = 0, r = e; t < r.length; t += 1) if ("Identifier" !== r[t].type) return !1;
				return !0;
			}, ne.checkParams = function(e, t) {
				for (var r = Object.create(null), n = 0, s = e.params; n < s.length; n += 1) {
					var i = s[n];
					this.checkLValInnerPattern(i, 1, t ? null : r);
				}
			}, ne.parseExprList = function(e, t, r, n) {
				for (var s = [], i = !0; !this.eat(e);) {
					if (i) i = !1;
					else if (this.expect(I.comma), t && this.afterTrailingComma(e)) break;
					var o = void 0;
					r && this.type === I.comma ? o = null : this.type === I.ellipsis ? (o = this.parseSpread(n), n && this.type === I.comma && n.trailingComma < 0 && (n.trailingComma = this.start)) : o = this.parseMaybeAssign(!1, n), s.push(o);
				}
				return s;
			}, ne.checkUnreserved = function(e) {
				var t = e.start, r = e.end, n = e.name;
				(this.inGenerator && "yield" === n && this.raiseRecoverable(t, "Cannot use 'yield' as identifier inside a generator"), this.inAsync && "await" === n && this.raiseRecoverable(t, "Cannot use 'await' as identifier inside an async function"), this.currentThisScope().flags & W || "arguments" !== n || this.raiseRecoverable(t, "Cannot use 'arguments' in class field initializer"), !this.inClassStaticBlock || "arguments" !== n && "await" !== n || this.raise(t, "Cannot use " + n + " in class static initialization block"), this.keywords.test(n) && this.raise(t, "Unexpected keyword '" + n + "'"), this.options.ecmaVersion < 6 && -1 !== this.input.slice(t, r).indexOf("\\")) || (this.strict ? this.reservedWordsStrict : this.reservedWords).test(n) && (this.inAsync || "await" !== n || this.raiseRecoverable(t, "Cannot use keyword 'await' outside an async function"), this.raiseRecoverable(t, "The keyword '" + n + "' is reserved"));
			}, ne.parseIdent = function(e) {
				var t = this.parseIdentNode();
				return this.next(!!e), this.finishNode(t, "Identifier"), e || (this.checkUnreserved(t), "await" !== t.name || this.awaitIdentPos || (this.awaitIdentPos = t.start)), t;
			}, ne.parseIdentNode = function() {
				var e = this.startNode();
				return this.type === I.name ? e.name = this.value : this.type.keyword ? (e.name = this.type.keyword, "class" !== e.name && "function" !== e.name || this.lastTokEnd === this.lastTokStart + 1 && 46 === this.input.charCodeAt(this.lastTokStart) || this.context.pop(), this.type = I.name) : this.unexpected(), e;
			}, ne.parsePrivateIdent = function() {
				var e = this.startNode();
				return this.type === I.privateId ? e.name = this.value : this.unexpected(), this.next(), this.finishNode(e, "PrivateIdentifier"), this.options.checkPrivateFields && (0 === this.privateNameStack.length ? this.raise(e.start, "Private field '#" + e.name + "' must be declared in an enclosing class") : this.privateNameStack[this.privateNameStack.length - 1].used.push(e)), e;
			}, ne.parseYield = function(e) {
				this.yieldPos || (this.yieldPos = this.start);
				var t = this.startNode();
				return this.next(), this.type === I.semi || this.canInsertSemicolon() || this.type !== I.star && !this.type.startsExpr ? (t.delegate = !1, t.argument = null) : (t.delegate = this.eat(I.star), t.argument = this.parseMaybeAssign(e)), this.finishNode(t, "YieldExpression");
			}, ne.parseAwait = function(e) {
				this.awaitPos || (this.awaitPos = this.start);
				var t = this.startNode();
				return this.next(), t.argument = this.parseMaybeUnary(null, !0, !1, e), this.finishNode(t, "AwaitExpression");
			};
			var ie = acorn_Parser.prototype;
			ie.raise = function(e, t) {
				var r = getLineInfo(this.input, e);
				t += " (" + r.line + ":" + r.column + ")", this.sourceFile && (t += " in " + this.sourceFile);
				var n = new SyntaxError(t);
				throw n.pos = e, n.loc = r, n.raisedAt = this.pos, n;
			}, ie.raiseRecoverable = ie.raise, ie.curPosition = function() {
				if (this.options.locations) return new acorn_Position(this.curLine, this.pos - this.lineStart);
			};
			var oe = acorn_Parser.prototype, acorn_Scope = function(e) {
				this.flags = e, this.var = [], this.lexical = [], this.functions = [];
			};
			oe.enterScope = function(e) {
				this.scopeStack.push(new acorn_Scope(e));
			}, oe.exitScope = function() {
				this.scopeStack.pop();
			}, oe.treatFunctionsAsVarInScope = function(e) {
				return 2 & e.flags || !this.inModule && 1 & e.flags;
			}, oe.declareName = function(e, t, r) {
				var n = !1;
				if (2 === t) {
					var s = this.currentScope();
					n = s.lexical.indexOf(e) > -1 || s.functions.indexOf(e) > -1 || s.var.indexOf(e) > -1, s.lexical.push(e), this.inModule && 1 & s.flags && delete this.undefinedExports[e];
				} else if (4 === t) this.currentScope().lexical.push(e);
				else if (3 === t) {
					var i = this.currentScope();
					n = this.treatFunctionsAsVar ? i.lexical.indexOf(e) > -1 : i.lexical.indexOf(e) > -1 || i.var.indexOf(e) > -1, i.functions.push(e);
				} else for (var o = this.scopeStack.length - 1; o >= 0; --o) {
					var a = this.scopeStack[o];
					if (a.lexical.indexOf(e) > -1 && !(32 & a.flags && a.lexical[0] === e) || !this.treatFunctionsAsVarInScope(a) && a.functions.indexOf(e) > -1) {
						n = !0;
						break;
					}
					if (a.var.push(e), this.inModule && 1 & a.flags && delete this.undefinedExports[e], a.flags & W) break;
				}
				n && this.raiseRecoverable(r, "Identifier '" + e + "' has already been declared");
			}, oe.checkLocalExport = function(e) {
				-1 === this.scopeStack[0].lexical.indexOf(e.name) && -1 === this.scopeStack[0].var.indexOf(e.name) && (this.undefinedExports[e.name] = e);
			}, oe.currentScope = function() {
				return this.scopeStack[this.scopeStack.length - 1];
			}, oe.currentVarScope = function() {
				for (var e = this.scopeStack.length - 1;; e--) {
					var t = this.scopeStack[e];
					if (771 & t.flags) return t;
				}
			}, oe.currentThisScope = function() {
				for (var e = this.scopeStack.length - 1;; e--) {
					var t = this.scopeStack[e];
					if (771 & t.flags && !(16 & t.flags)) return t;
				}
			};
			var acorn_Node = function(e, t, r) {
				this.type = "", this.start = t, this.end = 0, e.options.locations && (this.loc = new acorn_SourceLocation(e, r)), e.options.directSourceFile && (this.sourceFile = e.options.directSourceFile), e.options.ranges && (this.range = [t, 0]);
			}, ae = acorn_Parser.prototype;
			function finishNodeAt(e, t, r, n) {
				return e.type = t, e.end = r, this.options.locations && (e.loc.end = n), this.options.ranges && (e.range[1] = r), e;
			}
			ae.startNode = function() {
				return new acorn_Node(this, this.start, this.startLoc);
			}, ae.startNodeAt = function(e, t) {
				return new acorn_Node(this, e, t);
			}, ae.finishNode = function(e, t) {
				return finishNodeAt.call(this, e, t, this.lastTokEnd, this.lastTokEndLoc);
			}, ae.finishNodeAt = function(e, t, r, n) {
				return finishNodeAt.call(this, e, t, r, n);
			}, ae.copyNode = function(e) {
				var t = new acorn_Node(this, e.start, this.startLoc);
				for (var r in e) t[r] = e[r];
				return t;
			};
			var le = "ASCII ASCII_Hex_Digit AHex Alphabetic Alpha Any Assigned Bidi_Control Bidi_C Bidi_Mirrored Bidi_M Case_Ignorable CI Cased Changes_When_Casefolded CWCF Changes_When_Casemapped CWCM Changes_When_Lowercased CWL Changes_When_NFKC_Casefolded CWKCF Changes_When_Titlecased CWT Changes_When_Uppercased CWU Dash Default_Ignorable_Code_Point DI Deprecated Dep Diacritic Dia Emoji Emoji_Component Emoji_Modifier Emoji_Modifier_Base Emoji_Presentation Extender Ext Grapheme_Base Gr_Base Grapheme_Extend Gr_Ext Hex_Digit Hex IDS_Binary_Operator IDSB IDS_Trinary_Operator IDST ID_Continue IDC ID_Start IDS Ideographic Ideo Join_Control Join_C Logical_Order_Exception LOE Lowercase Lower Math Noncharacter_Code_Point NChar Pattern_Syntax Pat_Syn Pattern_White_Space Pat_WS Quotation_Mark QMark Radical Regional_Indicator RI Sentence_Terminal STerm Soft_Dotted SD Terminal_Punctuation Term Unified_Ideograph UIdeo Uppercase Upper Variation_Selector VS White_Space space XID_Continue XIDC XID_Start XIDS", pe = le + " Extended_Pictographic", ce = pe + " EBase EComp EMod EPres ExtPict", ue = {
				9: le,
				10: pe,
				11: pe,
				12: ce,
				13: ce,
				14: ce
			}, de = {
				9: "",
				10: "",
				11: "",
				12: "",
				13: "",
				14: "Basic_Emoji Emoji_Keycap_Sequence RGI_Emoji_Modifier_Sequence RGI_Emoji_Flag_Sequence RGI_Emoji_Tag_Sequence RGI_Emoji_ZWJ_Sequence RGI_Emoji"
			}, he = "Cased_Letter LC Close_Punctuation Pe Connector_Punctuation Pc Control Cc cntrl Currency_Symbol Sc Dash_Punctuation Pd Decimal_Number Nd digit Enclosing_Mark Me Final_Punctuation Pf Format Cf Initial_Punctuation Pi Letter L Letter_Number Nl Line_Separator Zl Lowercase_Letter Ll Mark M Combining_Mark Math_Symbol Sm Modifier_Letter Lm Modifier_Symbol Sk Nonspacing_Mark Mn Number N Open_Punctuation Ps Other C Other_Letter Lo Other_Number No Other_Punctuation Po Other_Symbol So Paragraph_Separator Zp Private_Use Co Punctuation P punct Separator Z Space_Separator Zs Spacing_Mark Mc Surrogate Cs Symbol S Titlecase_Letter Lt Unassigned Cn Uppercase_Letter Lu", me = "Adlam Adlm Ahom Anatolian_Hieroglyphs Hluw Arabic Arab Armenian Armn Avestan Avst Balinese Bali Bamum Bamu Bassa_Vah Bass Batak Batk Bengali Beng Bhaiksuki Bhks Bopomofo Bopo Brahmi Brah Braille Brai Buginese Bugi Buhid Buhd Canadian_Aboriginal Cans Carian Cari Caucasian_Albanian Aghb Chakma Cakm Cham Cham Cherokee Cher Common Zyyy Coptic Copt Qaac Cuneiform Xsux Cypriot Cprt Cyrillic Cyrl Deseret Dsrt Devanagari Deva Duployan Dupl Egyptian_Hieroglyphs Egyp Elbasan Elba Ethiopic Ethi Georgian Geor Glagolitic Glag Gothic Goth Grantha Gran Greek Grek Gujarati Gujr Gurmukhi Guru Han Hani Hangul Hang Hanunoo Hano Hatran Hatr Hebrew Hebr Hiragana Hira Imperial_Aramaic Armi Inherited Zinh Qaai Inscriptional_Pahlavi Phli Inscriptional_Parthian Prti Javanese Java Kaithi Kthi Kannada Knda Katakana Kana Kayah_Li Kali Kharoshthi Khar Khmer Khmr Khojki Khoj Khudawadi Sind Lao Laoo Latin Latn Lepcha Lepc Limbu Limb Linear_A Lina Linear_B Linb Lisu Lisu Lycian Lyci Lydian Lydi Mahajani Mahj Malayalam Mlym Mandaic Mand Manichaean Mani Marchen Marc Masaram_Gondi Gonm Meetei_Mayek Mtei Mende_Kikakui Mend Meroitic_Cursive Merc Meroitic_Hieroglyphs Mero Miao Plrd Modi Mongolian Mong Mro Mroo Multani Mult Myanmar Mymr Nabataean Nbat New_Tai_Lue Talu Newa Newa Nko Nkoo Nushu Nshu Ogham Ogam Ol_Chiki Olck Old_Hungarian Hung Old_Italic Ital Old_North_Arabian Narb Old_Permic Perm Old_Persian Xpeo Old_South_Arabian Sarb Old_Turkic Orkh Oriya Orya Osage Osge Osmanya Osma Pahawh_Hmong Hmng Palmyrene Palm Pau_Cin_Hau Pauc Phags_Pa Phag Phoenician Phnx Psalter_Pahlavi Phlp Rejang Rjng Runic Runr Samaritan Samr Saurashtra Saur Sharada Shrd Shavian Shaw Siddham Sidd SignWriting Sgnw Sinhala Sinh Sora_Sompeng Sora Soyombo Soyo Sundanese Sund Syloti_Nagri Sylo Syriac Syrc Tagalog Tglg Tagbanwa Tagb Tai_Le Tale Tai_Tham Lana Tai_Viet Tavt Takri Takr Tamil Taml Tangut Tang Telugu Telu Thaana Thaa Thai Thai Tibetan Tibt Tifinagh Tfng Tirhuta Tirh Ugaritic Ugar Vai Vaii Warang_Citi Wara Yi Yiii Zanabazar_Square Zanb", fe = me + " Dogra Dogr Gunjala_Gondi Gong Hanifi_Rohingya Rohg Makasar Maka Medefaidrin Medf Old_Sogdian Sogo Sogdian Sogd", ye = fe + " Elymaic Elym Nandinagari Nand Nyiakeng_Puachue_Hmong Hmnp Wancho Wcho", be = ye + " Chorasmian Chrs Diak Dives_Akuru Khitan_Small_Script Kits Yezi Yezidi", ge = be + " Cypro_Minoan Cpmn Old_Uyghur Ougr Tangsa Tnsa Toto Vithkuqi Vith", xe = {
				9: me,
				10: fe,
				11: ye,
				12: be,
				13: ge,
				14: ge + " Gara Garay Gukh Gurung_Khema Hrkt Katakana_Or_Hiragana Kawi Kirat_Rai Krai Nag_Mundari Nagm Ol_Onal Onao Sunu Sunuwar Todhri Todr Tulu_Tigalari Tutg Unknown Zzzz"
			}, ve = {};
			function buildUnicodeData(e) {
				var t = ve[e] = {
					binary: wordsRegexp(ue[e] + " " + he),
					binaryOfStrings: wordsRegexp(de[e]),
					nonBinary: {
						General_Category: wordsRegexp(he),
						Script: wordsRegexp(xe[e])
					}
				};
				t.nonBinary.Script_Extensions = t.nonBinary.Script, t.nonBinary.gc = t.nonBinary.General_Category, t.nonBinary.sc = t.nonBinary.Script, t.nonBinary.scx = t.nonBinary.Script_Extensions;
			}
			for (var Ee = 0, Te = [
				9,
				10,
				11,
				12,
				13,
				14
			]; Ee < Te.length; Ee += 1) buildUnicodeData(Te[Ee]);
			var Se = acorn_Parser.prototype, acorn_BranchID = function(e, t) {
				this.parent = e, this.base = t || this;
			};
			acorn_BranchID.prototype.separatedFrom = function(e) {
				for (var t = this; t; t = t.parent) for (var r = e; r; r = r.parent) if (t.base === r.base && t !== r) return !0;
				return !1;
			}, acorn_BranchID.prototype.sibling = function() {
				return new acorn_BranchID(this.parent, this.base);
			};
			var acorn_RegExpValidationState = function(e) {
				this.parser = e, this.validFlags = "gim" + (e.options.ecmaVersion >= 6 ? "uy" : "") + (e.options.ecmaVersion >= 9 ? "s" : "") + (e.options.ecmaVersion >= 13 ? "d" : "") + (e.options.ecmaVersion >= 15 ? "v" : ""), this.unicodeProperties = ve[e.options.ecmaVersion >= 14 ? 14 : e.options.ecmaVersion], this.source = "", this.flags = "", this.start = 0, this.switchU = !1, this.switchV = !1, this.switchN = !1, this.pos = 0, this.lastIntValue = 0, this.lastStringValue = "", this.lastAssertionIsQuantifiable = !1, this.numCapturingParens = 0, this.maxBackReference = 0, this.groupNames = Object.create(null), this.backReferenceNames = [], this.branchID = null;
			};
			function isRegularExpressionModifier(e) {
				return 105 === e || 109 === e || 115 === e;
			}
			function isSyntaxCharacter(e) {
				return 36 === e || e >= 40 && e <= 43 || 46 === e || 63 === e || e >= 91 && e <= 94 || e >= 123 && e <= 125;
			}
			function isControlLetter(e) {
				return e >= 65 && e <= 90 || e >= 97 && e <= 122;
			}
			acorn_RegExpValidationState.prototype.reset = function(e, t, r) {
				var n = -1 !== r.indexOf("v"), s = -1 !== r.indexOf("u");
				this.start = 0 | e, this.source = t + "", this.flags = r, n && this.parser.options.ecmaVersion >= 15 ? (this.switchU = !0, this.switchV = !0, this.switchN = !0) : (this.switchU = s && this.parser.options.ecmaVersion >= 6, this.switchV = !1, this.switchN = s && this.parser.options.ecmaVersion >= 9);
			}, acorn_RegExpValidationState.prototype.raise = function(e) {
				this.parser.raiseRecoverable(this.start, "Invalid regular expression: /" + this.source + "/: " + e);
			}, acorn_RegExpValidationState.prototype.at = function(e, t) {
				void 0 === t && (t = !1);
				var r = this.source, n = r.length;
				if (e >= n) return -1;
				var s = r.charCodeAt(e);
				if (!t && !this.switchU || s <= 55295 || s >= 57344 || e + 1 >= n) return s;
				var i = r.charCodeAt(e + 1);
				return i >= 56320 && i <= 57343 ? (s << 10) + i - 56613888 : s;
			}, acorn_RegExpValidationState.prototype.nextIndex = function(e, t) {
				void 0 === t && (t = !1);
				var r = this.source, n = r.length;
				if (e >= n) return n;
				var s, i = r.charCodeAt(e);
				return !t && !this.switchU || i <= 55295 || i >= 57344 || e + 1 >= n || (s = r.charCodeAt(e + 1)) < 56320 || s > 57343 ? e + 1 : e + 2;
			}, acorn_RegExpValidationState.prototype.current = function(e) {
				return void 0 === e && (e = !1), this.at(this.pos, e);
			}, acorn_RegExpValidationState.prototype.lookahead = function(e) {
				return void 0 === e && (e = !1), this.at(this.nextIndex(this.pos, e), e);
			}, acorn_RegExpValidationState.prototype.advance = function(e) {
				void 0 === e && (e = !1), this.pos = this.nextIndex(this.pos, e);
			}, acorn_RegExpValidationState.prototype.eat = function(e, t) {
				return void 0 === t && (t = !1), this.current(t) === e && (this.advance(t), !0);
			}, acorn_RegExpValidationState.prototype.eatChars = function(e, t) {
				void 0 === t && (t = !1);
				for (var r = this.pos, n = 0, s = e; n < s.length; n += 1) {
					var i = s[n], o = this.at(r, t);
					if (-1 === o || o !== i) return !1;
					r = this.nextIndex(r, t);
				}
				return this.pos = r, !0;
			}, Se.validateRegExpFlags = function(e) {
				for (var t = e.validFlags, r = e.flags, n = !1, s = !1, i = 0; i < r.length; i++) {
					var o = r.charAt(i);
					-1 === t.indexOf(o) && this.raise(e.start, "Invalid regular expression flag"), r.indexOf(o, i + 1) > -1 && this.raise(e.start, "Duplicate regular expression flag"), "u" === o && (n = !0), "v" === o && (s = !0);
				}
				this.options.ecmaVersion >= 15 && n && s && this.raise(e.start, "Invalid regular expression flag");
			}, Se.validateRegExpPattern = function(e) {
				this.regexp_pattern(e), !e.switchN && this.options.ecmaVersion >= 9 && function(e) {
					for (var t in e) return !0;
					return !1;
				}(e.groupNames) && (e.switchN = !0, this.regexp_pattern(e));
			}, Se.regexp_pattern = function(e) {
				e.pos = 0, e.lastIntValue = 0, e.lastStringValue = "", e.lastAssertionIsQuantifiable = !1, e.numCapturingParens = 0, e.maxBackReference = 0, e.groupNames = Object.create(null), e.backReferenceNames.length = 0, e.branchID = null, this.regexp_disjunction(e), e.pos !== e.source.length && (e.eat(41) && e.raise("Unmatched ')'"), (e.eat(93) || e.eat(125)) && e.raise("Lone quantifier brackets")), e.maxBackReference > e.numCapturingParens && e.raise("Invalid escape");
				for (var t = 0, r = e.backReferenceNames; t < r.length; t += 1) {
					var n = r[t];
					e.groupNames[n] || e.raise("Invalid named capture referenced");
				}
			}, Se.regexp_disjunction = function(e) {
				var t = this.options.ecmaVersion >= 16;
				for (t && (e.branchID = new acorn_BranchID(e.branchID, null)), this.regexp_alternative(e); e.eat(124);) t && (e.branchID = e.branchID.sibling()), this.regexp_alternative(e);
				t && (e.branchID = e.branchID.parent), this.regexp_eatQuantifier(e, !0) && e.raise("Nothing to repeat"), e.eat(123) && e.raise("Lone quantifier brackets");
			}, Se.regexp_alternative = function(e) {
				for (; e.pos < e.source.length && this.regexp_eatTerm(e););
			}, Se.regexp_eatTerm = function(e) {
				return this.regexp_eatAssertion(e) ? (e.lastAssertionIsQuantifiable && this.regexp_eatQuantifier(e) && e.switchU && e.raise("Invalid quantifier"), !0) : !!(e.switchU ? this.regexp_eatAtom(e) : this.regexp_eatExtendedAtom(e)) && (this.regexp_eatQuantifier(e), !0);
			}, Se.regexp_eatAssertion = function(e) {
				var t = e.pos;
				if (e.lastAssertionIsQuantifiable = !1, e.eat(94) || e.eat(36)) return !0;
				if (e.eat(92)) {
					if (e.eat(66) || e.eat(98)) return !0;
					e.pos = t;
				}
				if (e.eat(40) && e.eat(63)) {
					var r = !1;
					if (this.options.ecmaVersion >= 9 && (r = e.eat(60)), e.eat(61) || e.eat(33)) return this.regexp_disjunction(e), e.eat(41) || e.raise("Unterminated group"), e.lastAssertionIsQuantifiable = !r, !0;
				}
				return e.pos = t, !1;
			}, Se.regexp_eatQuantifier = function(e, t) {
				return void 0 === t && (t = !1), !!this.regexp_eatQuantifierPrefix(e, t) && (e.eat(63), !0);
			}, Se.regexp_eatQuantifierPrefix = function(e, t) {
				return e.eat(42) || e.eat(43) || e.eat(63) || this.regexp_eatBracedQuantifier(e, t);
			}, Se.regexp_eatBracedQuantifier = function(e, t) {
				var r = e.pos;
				if (e.eat(123)) {
					var n = 0, s = -1;
					if (this.regexp_eatDecimalDigits(e) && (n = e.lastIntValue, e.eat(44) && this.regexp_eatDecimalDigits(e) && (s = e.lastIntValue), e.eat(125))) return -1 !== s && s < n && !t && e.raise("numbers out of order in {} quantifier"), !0;
					e.switchU && !t && e.raise("Incomplete quantifier"), e.pos = r;
				}
				return !1;
			}, Se.regexp_eatAtom = function(e) {
				return this.regexp_eatPatternCharacters(e) || e.eat(46) || this.regexp_eatReverseSolidusAtomEscape(e) || this.regexp_eatCharacterClass(e) || this.regexp_eatUncapturingGroup(e) || this.regexp_eatCapturingGroup(e);
			}, Se.regexp_eatReverseSolidusAtomEscape = function(e) {
				var t = e.pos;
				if (e.eat(92)) {
					if (this.regexp_eatAtomEscape(e)) return !0;
					e.pos = t;
				}
				return !1;
			}, Se.regexp_eatUncapturingGroup = function(e) {
				var t = e.pos;
				if (e.eat(40)) {
					if (e.eat(63)) {
						if (this.options.ecmaVersion >= 16) {
							var r = this.regexp_eatModifiers(e), n = e.eat(45);
							if (r || n) {
								for (var s = 0; s < r.length; s++) {
									var i = r.charAt(s);
									r.indexOf(i, s + 1) > -1 && e.raise("Duplicate regular expression modifiers");
								}
								if (n) {
									var o = this.regexp_eatModifiers(e);
									r || o || 58 !== e.current() || e.raise("Invalid regular expression modifiers");
									for (var a = 0; a < o.length; a++) {
										var l = o.charAt(a);
										(o.indexOf(l, a + 1) > -1 || r.indexOf(l) > -1) && e.raise("Duplicate regular expression modifiers");
									}
								}
							}
						}
						if (e.eat(58)) {
							if (this.regexp_disjunction(e), e.eat(41)) return !0;
							e.raise("Unterminated group");
						}
					}
					e.pos = t;
				}
				return !1;
			}, Se.regexp_eatCapturingGroup = function(e) {
				if (e.eat(40)) {
					if (this.options.ecmaVersion >= 9 ? this.regexp_groupSpecifier(e) : 63 === e.current() && e.raise("Invalid group"), this.regexp_disjunction(e), e.eat(41)) return e.numCapturingParens += 1, !0;
					e.raise("Unterminated group");
				}
				return !1;
			}, Se.regexp_eatModifiers = function(e) {
				for (var t = "", r = 0; -1 !== (r = e.current()) && isRegularExpressionModifier(r);) t += codePointToString(r), e.advance();
				return t;
			}, Se.regexp_eatExtendedAtom = function(e) {
				return e.eat(46) || this.regexp_eatReverseSolidusAtomEscape(e) || this.regexp_eatCharacterClass(e) || this.regexp_eatUncapturingGroup(e) || this.regexp_eatCapturingGroup(e) || this.regexp_eatInvalidBracedQuantifier(e) || this.regexp_eatExtendedPatternCharacter(e);
			}, Se.regexp_eatInvalidBracedQuantifier = function(e) {
				return this.regexp_eatBracedQuantifier(e, !0) && e.raise("Nothing to repeat"), !1;
			}, Se.regexp_eatSyntaxCharacter = function(e) {
				var t = e.current();
				return !!isSyntaxCharacter(t) && (e.lastIntValue = t, e.advance(), !0);
			}, Se.regexp_eatPatternCharacters = function(e) {
				for (var t = e.pos, r = 0; -1 !== (r = e.current()) && !isSyntaxCharacter(r);) e.advance();
				return e.pos !== t;
			}, Se.regexp_eatExtendedPatternCharacter = function(e) {
				var t = e.current();
				return !(-1 === t || 36 === t || t >= 40 && t <= 43 || 46 === t || 63 === t || 91 === t || 94 === t || 124 === t) && (e.advance(), !0);
			}, Se.regexp_groupSpecifier = function(e) {
				if (e.eat(63)) {
					this.regexp_eatGroupName(e) || e.raise("Invalid group");
					var t = this.options.ecmaVersion >= 16, r = e.groupNames[e.lastStringValue];
					if (r) if (t) for (var n = 0, s = r; n < s.length; n += 1) s[n].separatedFrom(e.branchID) || e.raise("Duplicate capture group name");
					else e.raise("Duplicate capture group name");
					t ? (r || (e.groupNames[e.lastStringValue] = [])).push(e.branchID) : e.groupNames[e.lastStringValue] = !0;
				}
			}, Se.regexp_eatGroupName = function(e) {
				if (e.lastStringValue = "", e.eat(60)) {
					if (this.regexp_eatRegExpIdentifierName(e) && e.eat(62)) return !0;
					e.raise("Invalid capture group name");
				}
				return !1;
			}, Se.regexp_eatRegExpIdentifierName = function(e) {
				if (e.lastStringValue = "", this.regexp_eatRegExpIdentifierStart(e)) {
					for (e.lastStringValue += codePointToString(e.lastIntValue); this.regexp_eatRegExpIdentifierPart(e);) e.lastStringValue += codePointToString(e.lastIntValue);
					return !0;
				}
				return !1;
			}, Se.regexp_eatRegExpIdentifierStart = function(e) {
				var t = e.pos, r = this.options.ecmaVersion >= 11, n = e.current(r);
				return e.advance(r), 92 === n && this.regexp_eatRegExpUnicodeEscapeSequence(e, r) && (n = e.lastIntValue), function(e) {
					return isIdentifierStart(e, !0) || 36 === e || 95 === e;
				}(n) ? (e.lastIntValue = n, !0) : (e.pos = t, !1);
			}, Se.regexp_eatRegExpIdentifierPart = function(e) {
				var t = e.pos, r = this.options.ecmaVersion >= 11, n = e.current(r);
				return e.advance(r), 92 === n && this.regexp_eatRegExpUnicodeEscapeSequence(e, r) && (n = e.lastIntValue), function(e) {
					return isIdentifierChar(e, !0) || 36 === e || 95 === e || 8204 === e || 8205 === e;
				}(n) ? (e.lastIntValue = n, !0) : (e.pos = t, !1);
			}, Se.regexp_eatAtomEscape = function(e) {
				return !!(this.regexp_eatBackReference(e) || this.regexp_eatCharacterClassEscape(e) || this.regexp_eatCharacterEscape(e) || e.switchN && this.regexp_eatKGroupName(e)) || (e.switchU && (99 === e.current() && e.raise("Invalid unicode escape"), e.raise("Invalid escape")), !1);
			}, Se.regexp_eatBackReference = function(e) {
				var t = e.pos;
				if (this.regexp_eatDecimalEscape(e)) {
					var r = e.lastIntValue;
					if (e.switchU) return r > e.maxBackReference && (e.maxBackReference = r), !0;
					if (r <= e.numCapturingParens) return !0;
					e.pos = t;
				}
				return !1;
			}, Se.regexp_eatKGroupName = function(e) {
				if (e.eat(107)) {
					if (this.regexp_eatGroupName(e)) return e.backReferenceNames.push(e.lastStringValue), !0;
					e.raise("Invalid named reference");
				}
				return !1;
			}, Se.regexp_eatCharacterEscape = function(e) {
				return this.regexp_eatControlEscape(e) || this.regexp_eatCControlLetter(e) || this.regexp_eatZero(e) || this.regexp_eatHexEscapeSequence(e) || this.regexp_eatRegExpUnicodeEscapeSequence(e, !1) || !e.switchU && this.regexp_eatLegacyOctalEscapeSequence(e) || this.regexp_eatIdentityEscape(e);
			}, Se.regexp_eatCControlLetter = function(e) {
				var t = e.pos;
				if (e.eat(99)) {
					if (this.regexp_eatControlLetter(e)) return !0;
					e.pos = t;
				}
				return !1;
			}, Se.regexp_eatZero = function(e) {
				return 48 === e.current() && !isDecimalDigit(e.lookahead()) && (e.lastIntValue = 0, e.advance(), !0);
			}, Se.regexp_eatControlEscape = function(e) {
				var t = e.current();
				return 116 === t ? (e.lastIntValue = 9, e.advance(), !0) : 110 === t ? (e.lastIntValue = 10, e.advance(), !0) : 118 === t ? (e.lastIntValue = 11, e.advance(), !0) : 102 === t ? (e.lastIntValue = 12, e.advance(), !0) : 114 === t && (e.lastIntValue = 13, e.advance(), !0);
			}, Se.regexp_eatControlLetter = function(e) {
				var t = e.current();
				return !!isControlLetter(t) && (e.lastIntValue = t % 32, e.advance(), !0);
			}, Se.regexp_eatRegExpUnicodeEscapeSequence = function(e, t) {
				void 0 === t && (t = !1);
				var r, n = e.pos, s = t || e.switchU;
				if (e.eat(117)) {
					if (this.regexp_eatFixedHexDigits(e, 4)) {
						var i = e.lastIntValue;
						if (s && i >= 55296 && i <= 56319) {
							var o = e.pos;
							if (e.eat(92) && e.eat(117) && this.regexp_eatFixedHexDigits(e, 4)) {
								var a = e.lastIntValue;
								if (a >= 56320 && a <= 57343) return e.lastIntValue = 1024 * (i - 55296) + (a - 56320) + 65536, !0;
							}
							e.pos = o, e.lastIntValue = i;
						}
						return !0;
					}
					if (s && e.eat(123) && this.regexp_eatHexDigits(e) && e.eat(125) && (r = e.lastIntValue) >= 0 && r <= 1114111) return !0;
					s && e.raise("Invalid unicode escape"), e.pos = n;
				}
				return !1;
			}, Se.regexp_eatIdentityEscape = function(e) {
				if (e.switchU) return !!this.regexp_eatSyntaxCharacter(e) || !!e.eat(47) && (e.lastIntValue = 47, !0);
				var t = e.current();
				return !(99 === t || e.switchN && 107 === t) && (e.lastIntValue = t, e.advance(), !0);
			}, Se.regexp_eatDecimalEscape = function(e) {
				e.lastIntValue = 0;
				var t = e.current();
				if (t >= 49 && t <= 57) {
					do
						e.lastIntValue = 10 * e.lastIntValue + (t - 48), e.advance();
					while ((t = e.current()) >= 48 && t <= 57);
					return !0;
				}
				return !1;
			};
			function isUnicodePropertyNameCharacter(e) {
				return isControlLetter(e) || 95 === e;
			}
			function isUnicodePropertyValueCharacter(e) {
				return isUnicodePropertyNameCharacter(e) || isDecimalDigit(e);
			}
			function isDecimalDigit(e) {
				return e >= 48 && e <= 57;
			}
			function isHexDigit(e) {
				return e >= 48 && e <= 57 || e >= 65 && e <= 70 || e >= 97 && e <= 102;
			}
			function hexToInt(e) {
				return e >= 65 && e <= 70 ? e - 65 + 10 : e >= 97 && e <= 102 ? e - 97 + 10 : e - 48;
			}
			function isOctalDigit(e) {
				return e >= 48 && e <= 55;
			}
			Se.regexp_eatCharacterClassEscape = function(e) {
				var t = e.current();
				if (function(e) {
					return 100 === e || 68 === e || 115 === e || 83 === e || 119 === e || 87 === e;
				}(t)) return e.lastIntValue = -1, e.advance(), 1;
				var r = !1;
				if (e.switchU && this.options.ecmaVersion >= 9 && ((r = 80 === t) || 112 === t)) {
					var n;
					if (e.lastIntValue = -1, e.advance(), e.eat(123) && (n = this.regexp_eatUnicodePropertyValueExpression(e)) && e.eat(125)) return r && 2 === n && e.raise("Invalid property name"), n;
					e.raise("Invalid property name");
				}
				return 0;
			}, Se.regexp_eatUnicodePropertyValueExpression = function(e) {
				var t = e.pos;
				if (this.regexp_eatUnicodePropertyName(e) && e.eat(61)) {
					var r = e.lastStringValue;
					if (this.regexp_eatUnicodePropertyValue(e)) {
						var n = e.lastStringValue;
						return this.regexp_validateUnicodePropertyNameAndValue(e, r, n), 1;
					}
				}
				if (e.pos = t, this.regexp_eatLoneUnicodePropertyNameOrValue(e)) {
					var s = e.lastStringValue;
					return this.regexp_validateUnicodePropertyNameOrValue(e, s);
				}
				return 0;
			}, Se.regexp_validateUnicodePropertyNameAndValue = function(e, t, r) {
				M(e.unicodeProperties.nonBinary, t) || e.raise("Invalid property name"), e.unicodeProperties.nonBinary[t].test(r) || e.raise("Invalid property value");
			}, Se.regexp_validateUnicodePropertyNameOrValue = function(e, t) {
				return e.unicodeProperties.binary.test(t) ? 1 : e.switchV && e.unicodeProperties.binaryOfStrings.test(t) ? 2 : void e.raise("Invalid property name");
			}, Se.regexp_eatUnicodePropertyName = function(e) {
				var t = 0;
				for (e.lastStringValue = ""; isUnicodePropertyNameCharacter(t = e.current());) e.lastStringValue += codePointToString(t), e.advance();
				return "" !== e.lastStringValue;
			}, Se.regexp_eatUnicodePropertyValue = function(e) {
				var t = 0;
				for (e.lastStringValue = ""; isUnicodePropertyValueCharacter(t = e.current());) e.lastStringValue += codePointToString(t), e.advance();
				return "" !== e.lastStringValue;
			}, Se.regexp_eatLoneUnicodePropertyNameOrValue = function(e) {
				return this.regexp_eatUnicodePropertyValue(e);
			}, Se.regexp_eatCharacterClass = function(e) {
				if (e.eat(91)) {
					var t = e.eat(94), r = this.regexp_classContents(e);
					return e.eat(93) || e.raise("Unterminated character class"), t && 2 === r && e.raise("Negated character class may contain strings"), !0;
				}
				return !1;
			}, Se.regexp_classContents = function(e) {
				return 93 === e.current() ? 1 : e.switchV ? this.regexp_classSetExpression(e) : (this.regexp_nonEmptyClassRanges(e), 1);
			}, Se.regexp_nonEmptyClassRanges = function(e) {
				for (; this.regexp_eatClassAtom(e);) {
					var t = e.lastIntValue;
					if (e.eat(45) && this.regexp_eatClassAtom(e)) {
						var r = e.lastIntValue;
						!e.switchU || -1 !== t && -1 !== r || e.raise("Invalid character class"), -1 !== t && -1 !== r && t > r && e.raise("Range out of order in character class");
					}
				}
			}, Se.regexp_eatClassAtom = function(e) {
				var t = e.pos;
				if (e.eat(92)) {
					if (this.regexp_eatClassEscape(e)) return !0;
					if (e.switchU) {
						var r = e.current();
						(99 === r || isOctalDigit(r)) && e.raise("Invalid class escape"), e.raise("Invalid escape");
					}
					e.pos = t;
				}
				var n = e.current();
				return 93 !== n && (e.lastIntValue = n, e.advance(), !0);
			}, Se.regexp_eatClassEscape = function(e) {
				var t = e.pos;
				if (e.eat(98)) return e.lastIntValue = 8, !0;
				if (e.switchU && e.eat(45)) return e.lastIntValue = 45, !0;
				if (!e.switchU && e.eat(99)) {
					if (this.regexp_eatClassControlLetter(e)) return !0;
					e.pos = t;
				}
				return this.regexp_eatCharacterClassEscape(e) || this.regexp_eatCharacterEscape(e);
			}, Se.regexp_classSetExpression = function(e) {
				var t, r = 1;
				if (this.regexp_eatClassSetRange(e));
				else if (t = this.regexp_eatClassSetOperand(e)) {
					2 === t && (r = 2);
					for (var n = e.pos; e.eatChars([38, 38]);) 38 !== e.current() && (t = this.regexp_eatClassSetOperand(e)) ? 2 !== t && (r = 1) : e.raise("Invalid character in character class");
					if (n !== e.pos) return r;
					for (; e.eatChars([45, 45]);) this.regexp_eatClassSetOperand(e) || e.raise("Invalid character in character class");
					if (n !== e.pos) return r;
				} else e.raise("Invalid character in character class");
				for (;;) if (!this.regexp_eatClassSetRange(e)) {
					if (!(t = this.regexp_eatClassSetOperand(e))) return r;
					2 === t && (r = 2);
				}
			}, Se.regexp_eatClassSetRange = function(e) {
				var t = e.pos;
				if (this.regexp_eatClassSetCharacter(e)) {
					var r = e.lastIntValue;
					if (e.eat(45) && this.regexp_eatClassSetCharacter(e)) {
						var n = e.lastIntValue;
						return -1 !== r && -1 !== n && r > n && e.raise("Range out of order in character class"), !0;
					}
					e.pos = t;
				}
				return !1;
			}, Se.regexp_eatClassSetOperand = function(e) {
				return this.regexp_eatClassSetCharacter(e) ? 1 : this.regexp_eatClassStringDisjunction(e) || this.regexp_eatNestedClass(e);
			}, Se.regexp_eatNestedClass = function(e) {
				var t = e.pos;
				if (e.eat(91)) {
					var r = e.eat(94), n = this.regexp_classContents(e);
					if (e.eat(93)) return r && 2 === n && e.raise("Negated character class may contain strings"), n;
					e.pos = t;
				}
				if (e.eat(92)) {
					var s = this.regexp_eatCharacterClassEscape(e);
					if (s) return s;
					e.pos = t;
				}
				return null;
			}, Se.regexp_eatClassStringDisjunction = function(e) {
				var t = e.pos;
				if (e.eatChars([92, 113])) {
					if (e.eat(123)) {
						var r = this.regexp_classStringDisjunctionContents(e);
						if (e.eat(125)) return r;
					} else e.raise("Invalid escape");
					e.pos = t;
				}
				return null;
			}, Se.regexp_classStringDisjunctionContents = function(e) {
				for (var t = this.regexp_classString(e); e.eat(124);) 2 === this.regexp_classString(e) && (t = 2);
				return t;
			}, Se.regexp_classString = function(e) {
				for (var t = 0; this.regexp_eatClassSetCharacter(e);) t++;
				return 1 === t ? 1 : 2;
			}, Se.regexp_eatClassSetCharacter = function(e) {
				var t = e.pos;
				if (e.eat(92)) return !(!this.regexp_eatCharacterEscape(e) && !this.regexp_eatClassSetReservedPunctuator(e)) || (e.eat(98) ? (e.lastIntValue = 8, !0) : (e.pos = t, !1));
				var r = e.current();
				return !(r < 0 || r === e.lookahead() && function(e) {
					return 33 === e || e >= 35 && e <= 38 || e >= 42 && e <= 44 || 46 === e || e >= 58 && e <= 64 || 94 === e || 96 === e || 126 === e;
				}(r)) && !function(e) {
					return 40 === e || 41 === e || 45 === e || 47 === e || e >= 91 && e <= 93 || e >= 123 && e <= 125;
				}(r) && (e.advance(), e.lastIntValue = r, !0);
			}, Se.regexp_eatClassSetReservedPunctuator = function(e) {
				var t = e.current();
				return !!function(e) {
					return 33 === e || 35 === e || 37 === e || 38 === e || 44 === e || 45 === e || e >= 58 && e <= 62 || 64 === e || 96 === e || 126 === e;
				}(t) && (e.lastIntValue = t, e.advance(), !0);
			}, Se.regexp_eatClassControlLetter = function(e) {
				var t = e.current();
				return !(!isDecimalDigit(t) && 95 !== t) && (e.lastIntValue = t % 32, e.advance(), !0);
			}, Se.regexp_eatHexEscapeSequence = function(e) {
				var t = e.pos;
				if (e.eat(120)) {
					if (this.regexp_eatFixedHexDigits(e, 2)) return !0;
					e.switchU && e.raise("Invalid escape"), e.pos = t;
				}
				return !1;
			}, Se.regexp_eatDecimalDigits = function(e) {
				var t = e.pos, r = 0;
				for (e.lastIntValue = 0; isDecimalDigit(r = e.current());) e.lastIntValue = 10 * e.lastIntValue + (r - 48), e.advance();
				return e.pos !== t;
			}, Se.regexp_eatHexDigits = function(e) {
				var t = e.pos, r = 0;
				for (e.lastIntValue = 0; isHexDigit(r = e.current());) e.lastIntValue = 16 * e.lastIntValue + hexToInt(r), e.advance();
				return e.pos !== t;
			}, Se.regexp_eatLegacyOctalEscapeSequence = function(e) {
				if (this.regexp_eatOctalDigit(e)) {
					var t = e.lastIntValue;
					if (this.regexp_eatOctalDigit(e)) {
						var r = e.lastIntValue;
						t <= 3 && this.regexp_eatOctalDigit(e) ? e.lastIntValue = 64 * t + 8 * r + e.lastIntValue : e.lastIntValue = 8 * t + r;
					} else e.lastIntValue = t;
					return !0;
				}
				return !1;
			}, Se.regexp_eatOctalDigit = function(e) {
				var t = e.current();
				return isOctalDigit(t) ? (e.lastIntValue = t - 48, e.advance(), !0) : (e.lastIntValue = 0, !1);
			}, Se.regexp_eatFixedHexDigits = function(e, t) {
				var r = e.pos;
				e.lastIntValue = 0;
				for (var n = 0; n < t; ++n) {
					var s = e.current();
					if (!isHexDigit(s)) return e.pos = r, !1;
					e.lastIntValue = 16 * e.lastIntValue + hexToInt(s), e.advance();
				}
				return !0;
			};
			var acorn_Token = function(e) {
				this.type = e.type, this.value = e.value, this.start = e.start, this.end = e.end, e.options.locations && (this.loc = new acorn_SourceLocation(e, e.startLoc, e.endLoc)), e.options.ranges && (this.range = [e.start, e.end]);
			}, Pe = acorn_Parser.prototype;
			function stringToBigInt(e) {
				return "function" != typeof BigInt ? null : BigInt(e.replace(/_/g, ""));
			}
			Pe.next = function(e) {
				!e && this.type.keyword && this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword " + this.type.keyword), this.options.onToken && this.options.onToken(new acorn_Token(this)), this.lastTokEnd = this.end, this.lastTokStart = this.start, this.lastTokEndLoc = this.endLoc, this.lastTokStartLoc = this.startLoc, this.nextToken();
			}, Pe.getToken = function() {
				return this.next(), new acorn_Token(this);
			}, "undefined" != typeof Symbol && (Pe[Symbol.iterator] = function() {
				var e = this;
				return { next: function() {
					var t = e.getToken();
					return {
						done: t.type === I.eof,
						value: t
					};
				} };
			}), Pe.nextToken = function() {
				var e = this.curContext();
				return e && e.preserveSpace || this.skipSpace(), this.start = this.pos, this.options.locations && (this.startLoc = this.curPosition()), this.pos >= this.input.length ? this.finishToken(I.eof) : e.override ? e.override(this) : void this.readToken(this.fullCharCodeAtPos());
			}, Pe.readToken = function(e) {
				return isIdentifierStart(e, this.options.ecmaVersion >= 6) || 92 === e ? this.readWord() : this.getTokenFromCode(e);
			}, Pe.fullCharCodeAtPos = function() {
				var e = this.input.charCodeAt(this.pos);
				if (e <= 55295 || e >= 56320) return e;
				var t = this.input.charCodeAt(this.pos + 1);
				return t <= 56319 || t >= 57344 ? e : (e << 10) + t - 56613888;
			}, Pe.skipBlockComment = function() {
				var e = this.options.onComment && this.curPosition(), t = this.pos, r = this.input.indexOf("*/", this.pos += 2);
				if (-1 === r && this.raise(this.pos - 2, "Unterminated comment"), this.pos = r + 2, this.options.locations) for (var n = void 0, s = t; (n = nextLineBreak(this.input, s, this.pos)) > -1;) ++this.curLine, s = this.lineStart = n;
				this.options.onComment && this.options.onComment(!0, this.input.slice(t + 2, r), t, this.pos, e, this.curPosition());
			}, Pe.skipLineComment = function(e) {
				for (var t = this.pos, r = this.options.onComment && this.curPosition(), n = this.input.charCodeAt(this.pos += e); this.pos < this.input.length && !isNewLine(n);) n = this.input.charCodeAt(++this.pos);
				this.options.onComment && this.options.onComment(!1, this.input.slice(t + e, this.pos), t, this.pos, r, this.curPosition());
			}, Pe.skipSpace = function() {
				e: for (; this.pos < this.input.length;) {
					var e = this.input.charCodeAt(this.pos);
					switch (e) {
						case 32:
						case 160:
							++this.pos;
							break;
						case 13: 10 === this.input.charCodeAt(this.pos + 1) && ++this.pos;
						case 10:
						case 8232:
						case 8233:
							++this.pos, this.options.locations && (++this.curLine, this.lineStart = this.pos);
							break;
						case 47:
							switch (this.input.charCodeAt(this.pos + 1)) {
								case 42:
									this.skipBlockComment();
									break;
								case 47:
									this.skipLineComment(2);
									break;
								default: break e;
							}
							break;
						default:
							if (!(e > 8 && e < 14 || e >= 5760 && N.test(String.fromCharCode(e)))) break e;
							++this.pos;
					}
				}
			}, Pe.finishToken = function(e, t) {
				this.end = this.pos, this.options.locations && (this.endLoc = this.curPosition());
				var r = this.type;
				this.type = e, this.value = t, this.updateContext(r);
			}, Pe.readToken_dot = function() {
				var e = this.input.charCodeAt(this.pos + 1);
				if (e >= 48 && e <= 57) return this.readNumber(!0);
				var t = this.input.charCodeAt(this.pos + 2);
				return this.options.ecmaVersion >= 6 && 46 === e && 46 === t ? (this.pos += 3, this.finishToken(I.ellipsis)) : (++this.pos, this.finishToken(I.dot));
			}, Pe.readToken_slash = function() {
				var e = this.input.charCodeAt(this.pos + 1);
				return this.exprAllowed ? (++this.pos, this.readRegexp()) : 61 === e ? this.finishOp(I.assign, 2) : this.finishOp(I.slash, 1);
			}, Pe.readToken_mult_modulo_exp = function(e) {
				var t = this.input.charCodeAt(this.pos + 1), r = 1, n = 42 === e ? I.star : I.modulo;
				return this.options.ecmaVersion >= 7 && 42 === e && 42 === t && (++r, n = I.starstar, t = this.input.charCodeAt(this.pos + 2)), 61 === t ? this.finishOp(I.assign, r + 1) : this.finishOp(n, r);
			}, Pe.readToken_pipe_amp = function(e) {
				var t = this.input.charCodeAt(this.pos + 1);
				if (t === e) {
					if (this.options.ecmaVersion >= 12) {
						if (61 === this.input.charCodeAt(this.pos + 2)) return this.finishOp(I.assign, 3);
					}
					return this.finishOp(124 === e ? I.logicalOR : I.logicalAND, 2);
				}
				return 61 === t ? this.finishOp(I.assign, 2) : this.finishOp(124 === e ? I.bitwiseOR : I.bitwiseAND, 1);
			}, Pe.readToken_caret = function() {
				return 61 === this.input.charCodeAt(this.pos + 1) ? this.finishOp(I.assign, 2) : this.finishOp(I.bitwiseXOR, 1);
			}, Pe.readToken_plus_min = function(e) {
				var t = this.input.charCodeAt(this.pos + 1);
				return t === e ? 45 !== t || this.inModule || 62 !== this.input.charCodeAt(this.pos + 2) || 0 !== this.lastTokEnd && !D.test(this.input.slice(this.lastTokEnd, this.pos)) ? this.finishOp(I.incDec, 2) : (this.skipLineComment(3), this.skipSpace(), this.nextToken()) : 61 === t ? this.finishOp(I.assign, 2) : this.finishOp(I.plusMin, 1);
			}, Pe.readToken_lt_gt = function(e) {
				var t = this.input.charCodeAt(this.pos + 1), r = 1;
				return t === e ? (r = 62 === e && 62 === this.input.charCodeAt(this.pos + 2) ? 3 : 2, 61 === this.input.charCodeAt(this.pos + r) ? this.finishOp(I.assign, r + 1) : this.finishOp(I.bitShift, r)) : 33 !== t || 60 !== e || this.inModule || 45 !== this.input.charCodeAt(this.pos + 2) || 45 !== this.input.charCodeAt(this.pos + 3) ? (61 === t && (r = 2), this.finishOp(I.relational, r)) : (this.skipLineComment(4), this.skipSpace(), this.nextToken());
			}, Pe.readToken_eq_excl = function(e) {
				var t = this.input.charCodeAt(this.pos + 1);
				return 61 === t ? this.finishOp(I.equality, 61 === this.input.charCodeAt(this.pos + 2) ? 3 : 2) : 61 === e && 62 === t && this.options.ecmaVersion >= 6 ? (this.pos += 2, this.finishToken(I.arrow)) : this.finishOp(61 === e ? I.eq : I.prefix, 1);
			}, Pe.readToken_question = function() {
				var e = this.options.ecmaVersion;
				if (e >= 11) {
					var t = this.input.charCodeAt(this.pos + 1);
					if (46 === t) {
						var r = this.input.charCodeAt(this.pos + 2);
						if (r < 48 || r > 57) return this.finishOp(I.questionDot, 2);
					}
					if (63 === t) {
						if (e >= 12) {
							if (61 === this.input.charCodeAt(this.pos + 2)) return this.finishOp(I.assign, 3);
						}
						return this.finishOp(I.coalesce, 2);
					}
				}
				return this.finishOp(I.question, 1);
			}, Pe.readToken_numberSign = function() {
				var e = 35;
				if (this.options.ecmaVersion >= 13 && (++this.pos, isIdentifierStart(e = this.fullCharCodeAtPos(), !0) || 92 === e)) return this.finishToken(I.privateId, this.readWord1());
				this.raise(this.pos, "Unexpected character '" + codePointToString(e) + "'");
			}, Pe.getTokenFromCode = function(e) {
				switch (e) {
					case 46: return this.readToken_dot();
					case 40: return ++this.pos, this.finishToken(I.parenL);
					case 41: return ++this.pos, this.finishToken(I.parenR);
					case 59: return ++this.pos, this.finishToken(I.semi);
					case 44: return ++this.pos, this.finishToken(I.comma);
					case 91: return ++this.pos, this.finishToken(I.bracketL);
					case 93: return ++this.pos, this.finishToken(I.bracketR);
					case 123: return ++this.pos, this.finishToken(I.braceL);
					case 125: return ++this.pos, this.finishToken(I.braceR);
					case 58: return ++this.pos, this.finishToken(I.colon);
					case 96:
						if (this.options.ecmaVersion < 6) break;
						return ++this.pos, this.finishToken(I.backQuote);
					case 48:
						var t = this.input.charCodeAt(this.pos + 1);
						if (120 === t || 88 === t) return this.readRadixNumber(16);
						if (this.options.ecmaVersion >= 6) {
							if (111 === t || 79 === t) return this.readRadixNumber(8);
							if (98 === t || 66 === t) return this.readRadixNumber(2);
						}
					case 49:
					case 50:
					case 51:
					case 52:
					case 53:
					case 54:
					case 55:
					case 56:
					case 57: return this.readNumber(!1);
					case 34:
					case 39: return this.readString(e);
					case 47: return this.readToken_slash();
					case 37:
					case 42: return this.readToken_mult_modulo_exp(e);
					case 124:
					case 38: return this.readToken_pipe_amp(e);
					case 94: return this.readToken_caret();
					case 43:
					case 45: return this.readToken_plus_min(e);
					case 60:
					case 62: return this.readToken_lt_gt(e);
					case 61:
					case 33: return this.readToken_eq_excl(e);
					case 63: return this.readToken_question();
					case 126: return this.finishOp(I.prefix, 1);
					case 35: return this.readToken_numberSign();
				}
				this.raise(this.pos, "Unexpected character '" + codePointToString(e) + "'");
			}, Pe.finishOp = function(e, t) {
				var r = this.input.slice(this.pos, this.pos + t);
				return this.pos += t, this.finishToken(e, r);
			}, Pe.readRegexp = function() {
				for (var e, t, r = this.pos;;) {
					this.pos >= this.input.length && this.raise(r, "Unterminated regular expression");
					var n = this.input.charAt(this.pos);
					if (D.test(n) && this.raise(r, "Unterminated regular expression"), e) e = !1;
					else {
						if ("[" === n) t = !0;
						else if ("]" === n && t) t = !1;
						else if ("/" === n && !t) break;
						e = "\\" === n;
					}
					++this.pos;
				}
				var s = this.input.slice(r, this.pos);
				++this.pos;
				var i = this.pos, o = this.readWord1();
				this.containsEsc && this.unexpected(i);
				var a = this.regexpState || (this.regexpState = new acorn_RegExpValidationState(this));
				a.reset(r, s, o), this.validateRegExpFlags(a), this.validateRegExpPattern(a);
				var l = null;
				try {
					l = new RegExp(s, o);
				} catch (e) {}
				return this.finishToken(I.regexp, {
					pattern: s,
					flags: o,
					value: l
				});
			}, Pe.readInt = function(e, t, r) {
				for (var n = this.options.ecmaVersion >= 12 && void 0 === t, s = r && 48 === this.input.charCodeAt(this.pos), i = this.pos, o = 0, a = 0, l = 0, p = null == t ? Infinity : t; l < p; ++l, ++this.pos) {
					var c = this.input.charCodeAt(this.pos), u = void 0;
					if (n && 95 === c) s && this.raiseRecoverable(this.pos, "Numeric separator is not allowed in legacy octal numeric literals"), 95 === a && this.raiseRecoverable(this.pos, "Numeric separator must be exactly one underscore"), 0 === l && this.raiseRecoverable(this.pos, "Numeric separator is not allowed at the first of digits"), a = c;
					else {
						if ((u = c >= 97 ? c - 97 + 10 : c >= 65 ? c - 65 + 10 : c >= 48 && c <= 57 ? c - 48 : Infinity) >= e) break;
						a = c, o = o * e + u;
					}
				}
				return n && 95 === a && this.raiseRecoverable(this.pos - 1, "Numeric separator is not allowed at the last of digits"), this.pos === i || null != t && this.pos - i !== t ? null : o;
			}, Pe.readRadixNumber = function(e) {
				var t = this.pos;
				this.pos += 2;
				var r = this.readInt(e);
				return r ?? this.raise(this.start + 2, "Expected number in radix " + e), this.options.ecmaVersion >= 11 && 110 === this.input.charCodeAt(this.pos) ? (r = stringToBigInt(this.input.slice(t, this.pos)), ++this.pos) : isIdentifierStart(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number"), this.finishToken(I.num, r);
			}, Pe.readNumber = function(e) {
				var t = this.pos;
				e || null !== this.readInt(10, void 0, !0) || this.raise(t, "Invalid number");
				var r = this.pos - t >= 2 && 48 === this.input.charCodeAt(t);
				r && this.strict && this.raise(t, "Invalid number");
				var n = this.input.charCodeAt(this.pos);
				if (!r && !e && this.options.ecmaVersion >= 11 && 110 === n) {
					var s = stringToBigInt(this.input.slice(t, this.pos));
					return ++this.pos, isIdentifierStart(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number"), this.finishToken(I.num, s);
				}
				r && /[89]/.test(this.input.slice(t, this.pos)) && (r = !1), 46 !== n || r || (++this.pos, this.readInt(10), n = this.input.charCodeAt(this.pos)), 69 !== n && 101 !== n || r || (43 !== (n = this.input.charCodeAt(++this.pos)) && 45 !== n || ++this.pos, null === this.readInt(10) && this.raise(t, "Invalid number")), isIdentifierStart(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number");
				var i, o = (i = this.input.slice(t, this.pos), r ? parseInt(i, 8) : parseFloat(i.replace(/_/g, "")));
				return this.finishToken(I.num, o);
			}, Pe.readCodePoint = function() {
				var e;
				if (123 === this.input.charCodeAt(this.pos)) {
					this.options.ecmaVersion < 6 && this.unexpected();
					var t = ++this.pos;
					e = this.readHexChar(this.input.indexOf("}", this.pos) - this.pos), ++this.pos, e > 1114111 && this.invalidStringToken(t, "Code point out of bounds");
				} else e = this.readHexChar(4);
				return e;
			}, Pe.readString = function(e) {
				for (var t = "", r = ++this.pos;;) {
					this.pos >= this.input.length && this.raise(this.start, "Unterminated string constant");
					var n = this.input.charCodeAt(this.pos);
					if (n === e) break;
					92 === n ? (t += this.input.slice(r, this.pos), t += this.readEscapedChar(!1), r = this.pos) : 8232 === n || 8233 === n ? (this.options.ecmaVersion < 10 && this.raise(this.start, "Unterminated string constant"), ++this.pos, this.options.locations && (this.curLine++, this.lineStart = this.pos)) : (isNewLine(n) && this.raise(this.start, "Unterminated string constant"), ++this.pos);
				}
				return t += this.input.slice(r, this.pos++), this.finishToken(I.string, t);
			};
			var _e = {};
			Pe.tryReadTemplateToken = function() {
				this.inTemplateElement = !0;
				try {
					this.readTmplToken();
				} catch (e) {
					if (e !== _e) throw e;
					this.readInvalidTemplateToken();
				}
				this.inTemplateElement = !1;
			}, Pe.invalidStringToken = function(e, t) {
				if (this.inTemplateElement && this.options.ecmaVersion >= 9) throw _e;
				this.raise(e, t);
			}, Pe.readTmplToken = function() {
				for (var e = "", t = this.pos;;) {
					this.pos >= this.input.length && this.raise(this.start, "Unterminated template");
					var r = this.input.charCodeAt(this.pos);
					if (96 === r || 36 === r && 123 === this.input.charCodeAt(this.pos + 1)) return this.pos !== this.start || this.type !== I.template && this.type !== I.invalidTemplate ? (e += this.input.slice(t, this.pos), this.finishToken(I.template, e)) : 36 === r ? (this.pos += 2, this.finishToken(I.dollarBraceL)) : (++this.pos, this.finishToken(I.backQuote));
					if (92 === r) e += this.input.slice(t, this.pos), e += this.readEscapedChar(!0), t = this.pos;
					else if (isNewLine(r)) {
						switch (e += this.input.slice(t, this.pos), ++this.pos, r) {
							case 13: 10 === this.input.charCodeAt(this.pos) && ++this.pos;
							case 10:
								e += "\n";
								break;
							default: e += String.fromCharCode(r);
						}
						this.options.locations && (++this.curLine, this.lineStart = this.pos), t = this.pos;
					} else ++this.pos;
				}
			}, Pe.readInvalidTemplateToken = function() {
				for (; this.pos < this.input.length; this.pos++) switch (this.input[this.pos]) {
					case "\\":
						++this.pos;
						break;
					case "$": if ("{" !== this.input[this.pos + 1]) break;
					case "`": return this.finishToken(I.invalidTemplate, this.input.slice(this.start, this.pos));
					case "\r": "\n" === this.input[this.pos + 1] && ++this.pos;
					case "\n":
					case "\u2028":
					case "\u2029": ++this.curLine, this.lineStart = this.pos + 1;
				}
				this.raise(this.start, "Unterminated template");
			}, Pe.readEscapedChar = function(e) {
				var t = this.input.charCodeAt(++this.pos);
				switch (++this.pos, t) {
					case 110: return "\n";
					case 114: return "\r";
					case 120: return String.fromCharCode(this.readHexChar(2));
					case 117: return codePointToString(this.readCodePoint());
					case 116: return "	";
					case 98: return "\b";
					case 118: return "\v";
					case 102: return "\f";
					case 13: 10 === this.input.charCodeAt(this.pos) && ++this.pos;
					case 10: return this.options.locations && (this.lineStart = this.pos, ++this.curLine), "";
					case 56:
					case 57: if (this.strict && this.invalidStringToken(this.pos - 1, "Invalid escape sequence"), e) {
						var r = this.pos - 1;
						this.invalidStringToken(r, "Invalid escape sequence in template string");
					}
					default:
						if (t >= 48 && t <= 55) {
							var n = this.input.substr(this.pos - 1, 3).match(/^[0-7]+/)[0], s = parseInt(n, 8);
							return s > 255 && (n = n.slice(0, -1), s = parseInt(n, 8)), this.pos += n.length - 1, t = this.input.charCodeAt(this.pos), "0" === n && 56 !== t && 57 !== t || !this.strict && !e || this.invalidStringToken(this.pos - 1 - n.length, e ? "Octal literal in template string" : "Octal literal in strict mode"), String.fromCharCode(s);
						}
						return isNewLine(t) ? (this.options.locations && (this.lineStart = this.pos, ++this.curLine), "") : String.fromCharCode(t);
				}
			}, Pe.readHexChar = function(e) {
				var t = this.pos, r = this.readInt(16, e);
				return null === r && this.invalidStringToken(t, "Bad character escape sequence"), r;
			}, Pe.readWord1 = function() {
				this.containsEsc = !1;
				for (var e = "", t = !0, r = this.pos, n = this.options.ecmaVersion >= 6; this.pos < this.input.length;) {
					var s = this.fullCharCodeAtPos();
					if (isIdentifierChar(s, n)) this.pos += s <= 65535 ? 1 : 2;
					else {
						if (92 !== s) break;
						this.containsEsc = !0, e += this.input.slice(r, this.pos);
						var i = this.pos;
						117 !== this.input.charCodeAt(++this.pos) && this.invalidStringToken(this.pos, "Expecting Unicode escape sequence \\uXXXX"), ++this.pos;
						var o = this.readCodePoint();
						(t ? isIdentifierStart : isIdentifierChar)(o, n) || this.invalidStringToken(i, "Invalid Unicode escape"), e += codePointToString(o), r = this.pos;
					}
					t = !1;
				}
				return e + this.input.slice(r, this.pos);
			}, Pe.readWord = function() {
				var e = this.readWord1(), t = I.name;
				return this.keywords.test(e) && (t = w[e]), this.finishToken(t, e);
			};
			acorn_Parser.acorn = {
				Parser: acorn_Parser,
				version: "8.15.0",
				defaultOptions: V,
				Position: acorn_Position,
				SourceLocation: acorn_SourceLocation,
				getLineInfo,
				Node: acorn_Node,
				TokenType: acorn_TokenType,
				tokTypes: I,
				keywordTypes: w,
				TokContext: acorn_TokContext,
				tokContexts: te,
				isIdentifierChar,
				isIdentifierStart,
				Token: acorn_Token,
				isNewLine,
				lineBreak: D,
				lineBreakG: k,
				nonASCIIwhitespace: N
			};
			const Ae = __require("node:module"), Ce = (__require("node:fs"), __require("node:url")), we = __require("node:assert"), Ie = (__require("node:process"), __require("node:path"), __require("node:v8")), De = __require("node:util");
			new Set(Ae.builtinModules);
			function normalizeSlash(e) {
				return e.replace(/\\/g, "/");
			}
			const ke = {}.hasOwnProperty, Ne = /^([A-Z][a-z\d]*)+$/, Oe = new Set([
				"string",
				"function",
				"number",
				"object",
				"Function",
				"Object",
				"boolean",
				"bigint",
				"symbol"
			]), je = {};
			function formatList(e, t = "and") {
				return e.length < 3 ? e.join(` ${t} `) : `${e.slice(0, -1).join(", ")}, ${t} ${e[e.length - 1]}`;
			}
			const Fe = /* @__PURE__ */ new Map();
			let Le;
			function createError(e, t, r) {
				return Fe.set(e, t), function(e, t) {
					return NodeError;
					function NodeError(...r) {
						const n = Error.stackTraceLimit;
						isErrorStackTraceLimitWritable() && (Error.stackTraceLimit = 0);
						const s = new e();
						isErrorStackTraceLimitWritable() && (Error.stackTraceLimit = n);
						const i = function(e, t, r) {
							const n = Fe.get(e);
							if (we(void 0 !== n, "expected `message` to be found"), "function" == typeof n) return we(n.length <= t.length, `Code: ${e}; The provided arguments length (${t.length}) does not match the required ones (${n.length}).`), Reflect.apply(n, r, t);
							const s = /%[dfijoOs]/g;
							let i = 0;
							for (; null !== s.exec(n);) i++;
							return we(i === t.length, `Code: ${e}; The provided arguments length (${t.length}) does not match the required ones (${i}).`), 0 === t.length ? n : (t.unshift(n), Reflect.apply(De.format, null, t));
						}(t, r, s);
						return Object.defineProperties(s, {
							message: {
								value: i,
								enumerable: !1,
								writable: !0,
								configurable: !0
							},
							toString: {
								value() {
									return `${this.name} [${t}]: ${this.message}`;
								},
								enumerable: !1,
								writable: !0,
								configurable: !0
							}
						}), Me(s), s.code = t, s;
					}
				}(r, e);
			}
			function isErrorStackTraceLimitWritable() {
				try {
					if (Ie.startupSnapshot.isBuildingSnapshot()) return !1;
				} catch {}
				const e = Object.getOwnPropertyDescriptor(Error, "stackTraceLimit");
				return void 0 === e ? Object.isExtensible(Error) : ke.call(e, "writable") && void 0 !== e.writable ? e.writable : void 0 !== e.set;
			}
			je.ERR_INVALID_ARG_TYPE = createError("ERR_INVALID_ARG_TYPE", (e, t, r) => {
				we("string" == typeof e, "'name' must be a string"), Array.isArray(t) || (t = [t]);
				let n = "The ";
				if (e.endsWith(" argument")) n += `${e} `;
				else {
					const t = e.includes(".") ? "property" : "argument";
					n += `"${e}" ${t} `;
				}
				n += "must be ";
				const s = [], i = [], o = [];
				for (const e of t) we("string" == typeof e, "All expected entries have to be of type string"), Oe.has(e) ? s.push(e.toLowerCase()) : null === Ne.exec(e) ? (we("object" !== e, "The value \"object\" should be written as \"Object\""), o.push(e)) : i.push(e);
				if (i.length > 0) {
					const e = s.indexOf("object");
					-1 !== e && (s.slice(e, 1), i.push("Object"));
				}
				return s.length > 0 && (n += `${s.length > 1 ? "one of type" : "of type"} ${formatList(s, "or")}`, (i.length > 0 || o.length > 0) && (n += " or ")), i.length > 0 && (n += `an instance of ${formatList(i, "or")}`, o.length > 0 && (n += " or ")), o.length > 0 && (o.length > 1 ? n += `one of ${formatList(o, "or")}` : (o[0].toLowerCase() !== o[0] && (n += "an "), n += `${o[0]}`)), n += `. Received ${function(e) {
					if (null == e) return String(e);
					if ("function" == typeof e && e.name) return `function ${e.name}`;
					if ("object" == typeof e) return e.constructor && e.constructor.name ? `an instance of ${e.constructor.name}` : `${(0, De.inspect)(e, { depth: -1 })}`;
					let t = (0, De.inspect)(e, { colors: !1 });
					t.length > 28 && (t = `${t.slice(0, 25)}...`);
					return `type ${typeof e} (${t})`;
				}(r)}`, n;
			}, TypeError), je.ERR_INVALID_MODULE_SPECIFIER = createError("ERR_INVALID_MODULE_SPECIFIER", (e, t, r = void 0) => `Invalid module "${e}" ${t}${r ? ` imported from ${r}` : ""}`, TypeError), je.ERR_INVALID_PACKAGE_CONFIG = createError("ERR_INVALID_PACKAGE_CONFIG", (e, t, r) => `Invalid package config ${e}${t ? ` while importing ${t}` : ""}${r ? `. ${r}` : ""}`, Error), je.ERR_INVALID_PACKAGE_TARGET = createError("ERR_INVALID_PACKAGE_TARGET", (e, t, r, n = !1, s = void 0) => {
				const i = "string" == typeof r && !n && r.length > 0 && !r.startsWith("./");
				return "." === t ? (we(!1 === n), `Invalid "exports" main target ${JSON.stringify(r)} defined in the package config ${e}package.json${s ? ` imported from ${s}` : ""}${i ? "; targets must start with \"./\"" : ""}`) : `Invalid "${n ? "imports" : "exports"}" target ${JSON.stringify(r)} defined for '${t}' in the package config ${e}package.json${s ? ` imported from ${s}` : ""}${i ? "; targets must start with \"./\"" : ""}`;
			}, Error), je.ERR_MODULE_NOT_FOUND = createError("ERR_MODULE_NOT_FOUND", (e, t, r = !1) => `Cannot find ${r ? "module" : "package"} '${e}' imported from ${t}`, Error), je.ERR_NETWORK_IMPORT_DISALLOWED = createError("ERR_NETWORK_IMPORT_DISALLOWED", "import of '%s' by %s is not supported: %s", Error), je.ERR_PACKAGE_IMPORT_NOT_DEFINED = createError("ERR_PACKAGE_IMPORT_NOT_DEFINED", (e, t, r) => `Package import specifier "${e}" is not defined${t ? ` in package ${t}package.json` : ""} imported from ${r}`, TypeError), je.ERR_PACKAGE_PATH_NOT_EXPORTED = createError("ERR_PACKAGE_PATH_NOT_EXPORTED", (e, t, r = void 0) => "." === t ? `No "exports" main defined in ${e}package.json${r ? ` imported from ${r}` : ""}` : `Package subpath '${t}' is not defined by "exports" in ${e}package.json${r ? ` imported from ${r}` : ""}`, Error), je.ERR_UNSUPPORTED_DIR_IMPORT = createError("ERR_UNSUPPORTED_DIR_IMPORT", "Directory import '%s' is not supported resolving ES modules imported from %s", Error), je.ERR_UNSUPPORTED_RESOLVE_REQUEST = createError("ERR_UNSUPPORTED_RESOLVE_REQUEST", "Failed to resolve module specifier \"%s\" from \"%s\": Invalid relative URL or base scheme is not hierarchical.", TypeError), je.ERR_UNKNOWN_FILE_EXTENSION = createError("ERR_UNKNOWN_FILE_EXTENSION", (e, t) => `Unknown file extension "${e}" for ${t}`, TypeError), je.ERR_INVALID_ARG_VALUE = createError("ERR_INVALID_ARG_VALUE", (e, t, r = "is invalid") => {
				let n = (0, De.inspect)(t);
				n.length > 128 && (n = `${n.slice(0, 128)}...`);
				return `The ${e.includes(".") ? "property" : "argument"} '${e}' ${r}. Received ${n}`;
			}, TypeError);
			const Me = function(e) {
				const t = "__node_internal_" + e.name;
				return Object.defineProperty(e, "name", { value: t }), e;
			}(function(e) {
				const t = isErrorStackTraceLimitWritable();
				return t && (Le = Error.stackTraceLimit, Error.stackTraceLimit = Number.POSITIVE_INFINITY), Error.captureStackTrace(e), t && (Error.stackTraceLimit = Le), e;
			});
			const { ERR_INVALID_PACKAGE_CONFIG: Be } = je;
			const { ERR_UNKNOWN_FILE_EXTENSION: Re } = je;
			RegExp.prototype[Symbol.replace];
			const { ERR_INVALID_MODULE_SPECIFIER: Ue, ERR_INVALID_PACKAGE_CONFIG: Ve, ERR_INVALID_PACKAGE_TARGET: $e, ERR_MODULE_NOT_FOUND: Ke, ERR_PACKAGE_IMPORT_NOT_DEFINED: We, ERR_PACKAGE_PATH_NOT_EXPORTED: qe, ERR_UNSUPPORTED_DIR_IMPORT: He, ERR_UNSUPPORTED_RESOLVE_REQUEST: ze } = je;
			function fileURLToPath(e) {
				return "string" != typeof e || e.startsWith("file://") ? normalizeSlash((0, Ce.fileURLToPath)(e)) : normalizeSlash(e);
			}
			function pathToFileURL(e) {
				return (0, Ce.pathToFileURL)(fileURLToPath(e)).toString();
			}
			function importMetaPathsPlugin(e, t) {
				return {
					name: "import-meta-paths",
					visitor: { Program(e) {
						const r = [], n = [], s = [];
						e.traverse({ MemberExpression(e) {
							const { node: t } = e;
							if ("MetaProperty" === t.object.type && "import" === t.object.meta.name && "meta" === t.object.property.name && "Identifier" === t.property.type) switch (t.property.name) {
								case "url":
									r.push(e);
									break;
								case "dirname":
									n.push(e);
									break;
								case "filename": s.push(e);
							}
						} });
						for (const e of r) e.replaceWith(h.smart.ast`${t.filename ? JSON.stringify(pathToFileURL(t.filename)) : "require('url').pathToFileURL(__filename).toString()"}`);
						for (const e of n) e.replaceWith(h.smart.ast`${t.filename ? JSON.stringify(pathe_M_eThtNZ_dirname(fileURLToPath(pathToFileURL(t.filename)))) : "__dirname"}`);
						for (const e of s) e.replaceWith(h.smart.ast`${t.filename ? JSON.stringify(fileURLToPath(pathToFileURL(t.filename))) : "__filename"}`);
					} }
				};
			}
			var Ge = __webpack_require__("./node_modules/.pnpm/@babel+helper-module-imports@7.27.1/node_modules/@babel/helper-module-imports/lib/index.js"), Xe = __webpack_require__("./node_modules/.pnpm/@babel+helper-module-transforms@7.28.3_@babel+core@7.28.4/node_modules/@babel/helper-module-transforms/lib/index.js"), Je = __webpack_require__("./node_modules/.pnpm/@babel+helper-simple-access@7.27.1/node_modules/@babel/helper-simple-access/lib/index.js");
			function transformDynamicImport(t, r, n) {
				t.replaceWith((0, Xe.buildDynamicImport)(t.node, !0, !1, (t) => ((t, r, n) => {
					const s = e.template.expression.ast`jitiImport(${t})`;
					return n ? s : e.types.callExpression(e.types.memberExpression(s, e.types.identifier("then")), [e.types.arrowFunctionExpression([e.types.identifier("m")], e.types.callExpression(r.addHelper("interopRequireWildcard"), [e.types.identifier("m")]))]);
				})(t, n, r)));
			}
			const Ye = "@babel/plugin-transform-modules-commonjs/customWrapperPlugin";
			function findMap(e, t) {
				if (e) for (const r of e) {
					const e = t(r);
					if (null != e) return e;
				}
			}
			const Qe = (0, u.declare)((t, r) => {
				const { strictNamespace: n = !1, mjsStrictNamespace: s = n, allowTopLevelThis: i, strict: o, strictMode: a, noInterop: l, importInterop: p, lazy: c = !1, allowCommonJSExports: u = !0, loose: d = !1, async: h = !1 } = r, m = t.assumption("constantReexports") ?? d, f = t.assumption("enumerableModuleMeta") ?? d, y = t.assumption("noIncompleteNsImportDetection") ?? !1;
				if (!("boolean" == typeof c || "function" == typeof c || Array.isArray(c) && c.every((e) => "string" == typeof e))) throw new Error(".lazy must be a boolean, array of strings, or a function");
				if ("boolean" != typeof n) throw new TypeError(".strictNamespace must be a boolean, or undefined");
				if ("boolean" != typeof s) throw new TypeError(".mjsStrictNamespace must be a boolean, or undefined");
				const getAssertion = (t) => e.template.expression.ast`
    (function(){
      throw new Error(
        "The CommonJS '" + "${t}" + "' variable is not available in ES6 modules." +
        "Consider setting setting sourceType:script or sourceType:unambiguous in your " +
        "Babel config for this file.");
    })()
  `, b = {
					ReferencedIdentifier(e) {
						const t = e.node.name;
						if ("module" !== t && "exports" !== t) return;
						const r = e.scope.getBinding(t);
						this.scope.getBinding(t) !== r || e.parentPath.isObjectProperty({ value: e.node }) && e.parentPath.parentPath.isObjectPattern() || e.parentPath.isAssignmentExpression({ left: e.node }) || e.isAssignmentExpression({ left: e.node }) || e.replaceWith(getAssertion(t));
					},
					UpdateExpression(t) {
						const r = t.get("argument");
						if (!r.isIdentifier()) return;
						const n = r.node.name;
						if ("module" !== n && "exports" !== n) return;
						const s = t.scope.getBinding(n);
						this.scope.getBinding(n) === s && t.replaceWith(e.types.assignmentExpression(t.node.operator[0] + "=", r.node, getAssertion(n)));
					},
					AssignmentExpression(t) {
						const r = t.get("left");
						if (r.isIdentifier()) {
							const n = r.node.name;
							if ("module" !== n && "exports" !== n) return;
							const s = t.scope.getBinding(n);
							if (this.scope.getBinding(n) !== s) return;
							const i = t.get("right");
							i.replaceWith(e.types.sequenceExpression([i.node, getAssertion(n)]));
						} else if (r.isPattern()) {
							const n = r.getOuterBindingIdentifiers(), s = Object.keys(n).find((e) => ("module" === e || "exports" === e) && this.scope.getBinding(e) === t.scope.getBinding(e));
							if (s) {
								const r = t.get("right");
								r.replaceWith(e.types.sequenceExpression([r.node, getAssertion(s)]));
							}
						}
					}
				};
				return {
					name: "transform-modules-commonjs",
					pre() {
						this.file.set("@babel/plugin-transform-modules-*", "commonjs"), c && function(e, t) {
							let r = e.get(Ye);
							r || e.set(Ye, r = []), r.push(t);
						}(this.file, ((t) => ({
							name: "babel-plugin-transform-modules-commonjs/lazy",
							version: "7.24.7",
							getWrapperPayload: (e, r) => (0, Xe.isSideEffectImport)(r) || r.reexportAll ? null : !0 === t ? e.includes(".") ? null : "lazy/function" : Array.isArray(t) ? t.includes(e) ? "lazy/function" : null : "function" == typeof t ? t(e) ? "lazy/function" : null : void 0,
							buildRequireWrapper(t, r, n, s) {
								if ("lazy/function" === n) return !!s && e.template.statement.ast`
        function ${t}() {
          const data = ${r};
          ${t} = function(){ return data; };
          return data;
        }
      `;
							},
							wrapReference(t, r) {
								if ("lazy/function" === r) return e.types.callExpression(t, []);
							}
						}))(c));
					},
					visitor: {
						["CallExpression" + (t.types.importExpression ? "|ImportExpression" : "")](t) {
							if (t.isCallExpression() && !e.types.isImport(t.node.callee)) return;
							let { scope: r } = t;
							do
								r.rename("require");
							while (r = r.parent);
							transformDynamicImport(t, l, this.file);
						},
						Program: { exit(t, d) {
							if (!(0, Ge.isModule)(t)) return;
							t.scope.rename("exports"), t.scope.rename("module"), t.scope.rename("require"), t.scope.rename("__filename"), t.scope.rename("__dirname"), u || (process.env.BABEL_8_BREAKING ? (0, Je.default)(t, new Set(["module", "exports"])) : (0, Je.default)(t, new Set(["module", "exports"]), !1), t.traverse(b, { scope: t.scope }));
							let g = (0, Xe.getModuleName)(this.file.opts, r);
							g && (g = e.types.stringLiteral(g));
							const x = function(e) {
								const t = e.get(Ye);
								return {
									getWrapperPayload: (...e) => findMap(t, (t) => {
										var _t$getWrapperPayload;
										return (_t$getWrapperPayload = t.getWrapperPayload) === null || _t$getWrapperPayload === void 0 ? void 0 : _t$getWrapperPayload.call(t, ...e);
									}),
									wrapReference: (...e) => findMap(t, (t) => {
										var _t$wrapReference;
										return (_t$wrapReference = t.wrapReference) === null || _t$wrapReference === void 0 ? void 0 : _t$wrapReference.call(t, ...e);
									}),
									buildRequireWrapper: (...e) => findMap(t, (t) => {
										var _t$buildRequireWrappe;
										return (_t$buildRequireWrappe = t.buildRequireWrapper) === null || _t$buildRequireWrappe === void 0 ? void 0 : _t$buildRequireWrappe.call(t, ...e);
									})
								};
							}(this.file), { meta: v, headers: E } = (0, Xe.rewriteModuleStatementsAndPrepareHeader)(t, {
								exportName: "exports",
								constantReexports: m,
								enumerableModuleMeta: f,
								strict: o,
								strictMode: a,
								allowTopLevelThis: i,
								noInterop: l,
								importInterop: p,
								wrapReference: x.wrapReference,
								getWrapperPayload: x.getWrapperPayload,
								esNamespaceOnly: "string" == typeof d.filename && /\.mjs$/.test(d.filename) ? s : n,
								noIncompleteNsImportDetection: y,
								filename: this.file.opts.filename
							});
							for (const [r, n] of v.source) {
								const s = h ? e.types.awaitExpression(e.types.callExpression(e.types.identifier("jitiImport"), [e.types.stringLiteral(r)])) : e.types.callExpression(e.types.identifier("require"), [e.types.stringLiteral(r)]);
								let i;
								if ((0, Xe.isSideEffectImport)(n)) {
									if (c && "function" === n.wrap) throw new Error("Assertion failure");
									i = e.types.expressionStatement(s);
								} else {
									const r = (0, Xe.wrapInterop)(t, s, n.interop) || s;
									if (n.wrap) {
										const e = x.buildRequireWrapper(n.name, r, n.wrap, n.referenced);
										if (!1 === e) continue;
										i = e;
									}
									i ?? (i = e.template.statement.ast`
                var ${n.name} = ${r};
              `);
								}
								i.loc = n.loc, E.push(i, ...(0, Xe.buildNamespaceInitStatements)(v, n, m, x.wrapReference));
							}
							(0, Xe.ensureStatementsHoisted)(E), t.unshiftContainer("body", E), t.get("body").forEach((e) => {
								E.includes(e.node) && e.isVariableDeclaration() && e.scope.registerDeclaration(e);
							});
						} }
					}
				};
			});
			function transform(r) {
				var _p$plugins;
				const p = {
					babelrc: !1,
					configFile: !1,
					compact: !1,
					retainLines: "boolean" != typeof r.retainLines || r.retainLines,
					filename: "",
					cwd: "/",
					...r.babel,
					plugins: [
						[Qe, {
							allowTopLevelThis: !0,
							noInterop: !r.interopDefault,
							async: r.async
						}],
						[importMetaPathsPlugin, { filename: r.filename }],
						[importMetaEnvPlugin],
						[importMetaResolvePlugin],
						[n.default],
						[o.default]
					]
				};
				r.jsx && p.plugins.push([i.default], [a.default, Object.assign({}, r.jsx)]), r.ts && (p.plugins.push([l.default, {
					allowDeclareFields: !0,
					isTSX: r.jsx && /\.[cm]?tsx$/.test(r.filename || "")
				}]), p.plugins.unshift([d], [t.default, { legacy: !0 }]), p.plugins.push(c(), s.default)), r.babel && Array.isArray(r.babel.plugins) && ((_p$plugins = p.plugins) === null || _p$plugins === void 0 || _p$plugins.push(...r.babel.plugins));
				try {
					var _ref;
					return { code: ((_ref = (0, e.transformSync)(r.source, p)) === null || _ref === void 0 ? void 0 : _ref.code) || "" };
				} catch (e) {
					var _e$loc, _e$loc2, _e$code, _e$message;
					return {
						error: e,
						code: "exports.__JITI_ERROR__ = " + JSON.stringify({
							filename: r.filename,
							line: ((_e$loc = e.loc) === null || _e$loc === void 0 ? void 0 : _e$loc.line) || 0,
							column: ((_e$loc2 = e.loc) === null || _e$loc2 === void 0 ? void 0 : _e$loc2.column) || 0,
							code: (_e$code = e.code) === null || _e$code === void 0 ? void 0 : _e$code.replace("BABEL_", "").replace("PARSE_ERROR", "ParseError"),
							message: (_e$message = e.message) === null || _e$message === void 0 ? void 0 : _e$message.replace("/: ", "").replace(/\(.+\)\s*$/, "")
						})
					};
				}
			}
		})(), module.exports = r.default;
	})();
}));
var import_jiti = /* @__PURE__ */ __toESM(require_jiti(), 1);
function onError(err) {
	throw err;
}
const nativeImport = (id) => import(id);
let _transform;
function lazyTransform(...args) {
	if (!_transform) _transform = require_babel();
	return _transform(...args);
}
function createJiti(id, opts = {}) {
	if (!opts.transform) opts = {
		...opts,
		transform: lazyTransform
	};
	return (0, import_jiti.default)(id, opts, {
		onError,
		nativeImport,
		createRequire
	});
}
//#endregion
export { createJiti as t };
