import { r as __exportAll } from "./chunk-DSjvVL_1-CHQFAj82.js";
import { a as resolveJsFrom, i as resolveCssFrom } from "./resolve-pWjAK-4f-Uu3Cl5SX.js";
import { t as createJiti } from "./jiti-Bb1dT6Cw-DzTewG1l.js";
import { pathToFileURL } from "node:url";
import * as path from "node:path";
import * as fs from "node:fs/promises";
//#region ../../node_modules/.pnpm/prettier-plugin-tailwindcss@0.0.0-insiders.3997fbd_prettier@3.8.2/node_modules/prettier-plugin-tailwindcss/dist/v4-C-HWEQJm.mjs
var l$1 = {
	inherit: "inherit",
	current: "currentcolor",
	transparent: "transparent",
	black: "#000",
	white: "#fff",
	slate: {
		50: "oklch(98.4% 0.003 247.858)",
		100: "oklch(96.8% 0.007 247.896)",
		200: "oklch(92.9% 0.013 255.508)",
		300: "oklch(86.9% 0.022 252.894)",
		400: "oklch(70.4% 0.04 256.788)",
		500: "oklch(55.4% 0.046 257.417)",
		600: "oklch(44.6% 0.043 257.281)",
		700: "oklch(37.2% 0.044 257.287)",
		800: "oklch(27.9% 0.041 260.031)",
		900: "oklch(20.8% 0.042 265.755)",
		950: "oklch(12.9% 0.042 264.695)"
	},
	gray: {
		50: "oklch(98.5% 0.002 247.839)",
		100: "oklch(96.7% 0.003 264.542)",
		200: "oklch(92.8% 0.006 264.531)",
		300: "oklch(87.2% 0.01 258.338)",
		400: "oklch(70.7% 0.022 261.325)",
		500: "oklch(55.1% 0.027 264.364)",
		600: "oklch(44.6% 0.03 256.802)",
		700: "oklch(37.3% 0.034 259.733)",
		800: "oklch(27.8% 0.033 256.848)",
		900: "oklch(21% 0.034 264.665)",
		950: "oklch(13% 0.028 261.692)"
	},
	zinc: {
		50: "oklch(98.5% 0 0)",
		100: "oklch(96.7% 0.001 286.375)",
		200: "oklch(92% 0.004 286.32)",
		300: "oklch(87.1% 0.006 286.286)",
		400: "oklch(70.5% 0.015 286.067)",
		500: "oklch(55.2% 0.016 285.938)",
		600: "oklch(44.2% 0.017 285.786)",
		700: "oklch(37% 0.013 285.805)",
		800: "oklch(27.4% 0.006 286.033)",
		900: "oklch(21% 0.006 285.885)",
		950: "oklch(14.1% 0.005 285.823)"
	},
	neutral: {
		50: "oklch(98.5% 0 0)",
		100: "oklch(97% 0 0)",
		200: "oklch(92.2% 0 0)",
		300: "oklch(87% 0 0)",
		400: "oklch(70.8% 0 0)",
		500: "oklch(55.6% 0 0)",
		600: "oklch(43.9% 0 0)",
		700: "oklch(37.1% 0 0)",
		800: "oklch(26.9% 0 0)",
		900: "oklch(20.5% 0 0)",
		950: "oklch(14.5% 0 0)"
	},
	stone: {
		50: "oklch(98.5% 0.001 106.423)",
		100: "oklch(97% 0.001 106.424)",
		200: "oklch(92.3% 0.003 48.717)",
		300: "oklch(86.9% 0.005 56.366)",
		400: "oklch(70.9% 0.01 56.259)",
		500: "oklch(55.3% 0.013 58.071)",
		600: "oklch(44.4% 0.011 73.639)",
		700: "oklch(37.4% 0.01 67.558)",
		800: "oklch(26.8% 0.007 34.298)",
		900: "oklch(21.6% 0.006 56.043)",
		950: "oklch(14.7% 0.004 49.25)"
	},
	red: {
		50: "oklch(97.1% 0.013 17.38)",
		100: "oklch(93.6% 0.032 17.717)",
		200: "oklch(88.5% 0.062 18.334)",
		300: "oklch(80.8% 0.114 19.571)",
		400: "oklch(70.4% 0.191 22.216)",
		500: "oklch(63.7% 0.237 25.331)",
		600: "oklch(57.7% 0.245 27.325)",
		700: "oklch(50.5% 0.213 27.518)",
		800: "oklch(44.4% 0.177 26.899)",
		900: "oklch(39.6% 0.141 25.723)",
		950: "oklch(25.8% 0.092 26.042)"
	},
	orange: {
		50: "oklch(98% 0.016 73.684)",
		100: "oklch(95.4% 0.038 75.164)",
		200: "oklch(90.1% 0.076 70.697)",
		300: "oklch(83.7% 0.128 66.29)",
		400: "oklch(75% 0.183 55.934)",
		500: "oklch(70.5% 0.213 47.604)",
		600: "oklch(64.6% 0.222 41.116)",
		700: "oklch(55.3% 0.195 38.402)",
		800: "oklch(47% 0.157 37.304)",
		900: "oklch(40.8% 0.123 38.172)",
		950: "oklch(26.6% 0.079 36.259)"
	},
	amber: {
		50: "oklch(98.7% 0.022 95.277)",
		100: "oklch(96.2% 0.059 95.617)",
		200: "oklch(92.4% 0.12 95.746)",
		300: "oklch(87.9% 0.169 91.605)",
		400: "oklch(82.8% 0.189 84.429)",
		500: "oklch(76.9% 0.188 70.08)",
		600: "oklch(66.6% 0.179 58.318)",
		700: "oklch(55.5% 0.163 48.998)",
		800: "oklch(47.3% 0.137 46.201)",
		900: "oklch(41.4% 0.112 45.904)",
		950: "oklch(27.9% 0.077 45.635)"
	},
	yellow: {
		50: "oklch(98.7% 0.026 102.212)",
		100: "oklch(97.3% 0.071 103.193)",
		200: "oklch(94.5% 0.129 101.54)",
		300: "oklch(90.5% 0.182 98.111)",
		400: "oklch(85.2% 0.199 91.936)",
		500: "oklch(79.5% 0.184 86.047)",
		600: "oklch(68.1% 0.162 75.834)",
		700: "oklch(55.4% 0.135 66.442)",
		800: "oklch(47.6% 0.114 61.907)",
		900: "oklch(42.1% 0.095 57.708)",
		950: "oklch(28.6% 0.066 53.813)"
	},
	lime: {
		50: "oklch(98.6% 0.031 120.757)",
		100: "oklch(96.7% 0.067 122.328)",
		200: "oklch(93.8% 0.127 124.321)",
		300: "oklch(89.7% 0.196 126.665)",
		400: "oklch(84.1% 0.238 128.85)",
		500: "oklch(76.8% 0.233 130.85)",
		600: "oklch(64.8% 0.2 131.684)",
		700: "oklch(53.2% 0.157 131.589)",
		800: "oklch(45.3% 0.124 130.933)",
		900: "oklch(40.5% 0.101 131.063)",
		950: "oklch(27.4% 0.072 132.109)"
	},
	green: {
		50: "oklch(98.2% 0.018 155.826)",
		100: "oklch(96.2% 0.044 156.743)",
		200: "oklch(92.5% 0.084 155.995)",
		300: "oklch(87.1% 0.15 154.449)",
		400: "oklch(79.2% 0.209 151.711)",
		500: "oklch(72.3% 0.219 149.579)",
		600: "oklch(62.7% 0.194 149.214)",
		700: "oklch(52.7% 0.154 150.069)",
		800: "oklch(44.8% 0.119 151.328)",
		900: "oklch(39.3% 0.095 152.535)",
		950: "oklch(26.6% 0.065 152.934)"
	},
	emerald: {
		50: "oklch(97.9% 0.021 166.113)",
		100: "oklch(95% 0.052 163.051)",
		200: "oklch(90.5% 0.093 164.15)",
		300: "oklch(84.5% 0.143 164.978)",
		400: "oklch(76.5% 0.177 163.223)",
		500: "oklch(69.6% 0.17 162.48)",
		600: "oklch(59.6% 0.145 163.225)",
		700: "oklch(50.8% 0.118 165.612)",
		800: "oklch(43.2% 0.095 166.913)",
		900: "oklch(37.8% 0.077 168.94)",
		950: "oklch(26.2% 0.051 172.552)"
	},
	teal: {
		50: "oklch(98.4% 0.014 180.72)",
		100: "oklch(95.3% 0.051 180.801)",
		200: "oklch(91% 0.096 180.426)",
		300: "oklch(85.5% 0.138 181.071)",
		400: "oklch(77.7% 0.152 181.912)",
		500: "oklch(70.4% 0.14 182.503)",
		600: "oklch(60% 0.118 184.704)",
		700: "oklch(51.1% 0.096 186.391)",
		800: "oklch(43.7% 0.078 188.216)",
		900: "oklch(38.6% 0.063 188.416)",
		950: "oklch(27.7% 0.046 192.524)"
	},
	cyan: {
		50: "oklch(98.4% 0.019 200.873)",
		100: "oklch(95.6% 0.045 203.388)",
		200: "oklch(91.7% 0.08 205.041)",
		300: "oklch(86.5% 0.127 207.078)",
		400: "oklch(78.9% 0.154 211.53)",
		500: "oklch(71.5% 0.143 215.221)",
		600: "oklch(60.9% 0.126 221.723)",
		700: "oklch(52% 0.105 223.128)",
		800: "oklch(45% 0.085 224.283)",
		900: "oklch(39.8% 0.07 227.392)",
		950: "oklch(30.2% 0.056 229.695)"
	},
	sky: {
		50: "oklch(97.7% 0.013 236.62)",
		100: "oklch(95.1% 0.026 236.824)",
		200: "oklch(90.1% 0.058 230.902)",
		300: "oklch(82.8% 0.111 230.318)",
		400: "oklch(74.6% 0.16 232.661)",
		500: "oklch(68.5% 0.169 237.323)",
		600: "oklch(58.8% 0.158 241.966)",
		700: "oklch(50% 0.134 242.749)",
		800: "oklch(44.3% 0.11 240.79)",
		900: "oklch(39.1% 0.09 240.876)",
		950: "oklch(29.3% 0.066 243.157)"
	},
	blue: {
		50: "oklch(97% 0.014 254.604)",
		100: "oklch(93.2% 0.032 255.585)",
		200: "oklch(88.2% 0.059 254.128)",
		300: "oklch(80.9% 0.105 251.813)",
		400: "oklch(70.7% 0.165 254.624)",
		500: "oklch(62.3% 0.214 259.815)",
		600: "oklch(54.6% 0.245 262.881)",
		700: "oklch(48.8% 0.243 264.376)",
		800: "oklch(42.4% 0.199 265.638)",
		900: "oklch(37.9% 0.146 265.522)",
		950: "oklch(28.2% 0.091 267.935)"
	},
	indigo: {
		50: "oklch(96.2% 0.018 272.314)",
		100: "oklch(93% 0.034 272.788)",
		200: "oklch(87% 0.065 274.039)",
		300: "oklch(78.5% 0.115 274.713)",
		400: "oklch(67.3% 0.182 276.935)",
		500: "oklch(58.5% 0.233 277.117)",
		600: "oklch(51.1% 0.262 276.966)",
		700: "oklch(45.7% 0.24 277.023)",
		800: "oklch(39.8% 0.195 277.366)",
		900: "oklch(35.9% 0.144 278.697)",
		950: "oklch(25.7% 0.09 281.288)"
	},
	violet: {
		50: "oklch(96.9% 0.016 293.756)",
		100: "oklch(94.3% 0.029 294.588)",
		200: "oklch(89.4% 0.057 293.283)",
		300: "oklch(81.1% 0.111 293.571)",
		400: "oklch(70.2% 0.183 293.541)",
		500: "oklch(60.6% 0.25 292.717)",
		600: "oklch(54.1% 0.281 293.009)",
		700: "oklch(49.1% 0.27 292.581)",
		800: "oklch(43.2% 0.232 292.759)",
		900: "oklch(38% 0.189 293.745)",
		950: "oklch(28.3% 0.141 291.089)"
	},
	purple: {
		50: "oklch(97.7% 0.014 308.299)",
		100: "oklch(94.6% 0.033 307.174)",
		200: "oklch(90.2% 0.063 306.703)",
		300: "oklch(82.7% 0.119 306.383)",
		400: "oklch(71.4% 0.203 305.504)",
		500: "oklch(62.7% 0.265 303.9)",
		600: "oklch(55.8% 0.288 302.321)",
		700: "oklch(49.6% 0.265 301.924)",
		800: "oklch(43.8% 0.218 303.724)",
		900: "oklch(38.1% 0.176 304.987)",
		950: "oklch(29.1% 0.149 302.717)"
	},
	fuchsia: {
		50: "oklch(97.7% 0.017 320.058)",
		100: "oklch(95.2% 0.037 318.852)",
		200: "oklch(90.3% 0.076 319.62)",
		300: "oklch(83.3% 0.145 321.434)",
		400: "oklch(74% 0.238 322.16)",
		500: "oklch(66.7% 0.295 322.15)",
		600: "oklch(59.1% 0.293 322.896)",
		700: "oklch(51.8% 0.253 323.949)",
		800: "oklch(45.2% 0.211 324.591)",
		900: "oklch(40.1% 0.17 325.612)",
		950: "oklch(29.3% 0.136 325.661)"
	},
	pink: {
		50: "oklch(97.1% 0.014 343.198)",
		100: "oklch(94.8% 0.028 342.258)",
		200: "oklch(89.9% 0.061 343.231)",
		300: "oklch(82.3% 0.12 346.018)",
		400: "oklch(71.8% 0.202 349.761)",
		500: "oklch(65.6% 0.241 354.308)",
		600: "oklch(59.2% 0.249 0.584)",
		700: "oklch(52.5% 0.223 3.958)",
		800: "oklch(45.9% 0.187 3.815)",
		900: "oklch(40.8% 0.153 2.432)",
		950: "oklch(28.4% 0.109 3.907)"
	},
	rose: {
		50: "oklch(96.9% 0.015 12.422)",
		100: "oklch(94.1% 0.03 12.58)",
		200: "oklch(89.2% 0.058 10.001)",
		300: "oklch(81% 0.117 11.638)",
		400: "oklch(71.2% 0.194 13.428)",
		500: "oklch(64.5% 0.246 16.439)",
		600: "oklch(58.6% 0.253 17.585)",
		700: "oklch(51.4% 0.222 16.935)",
		800: "oklch(45.5% 0.188 13.697)",
		900: "oklch(41% 0.159 10.272)",
		950: "oklch(27.1% 0.105 12.094)"
	}
};
var _ = new Set([
	"black",
	"silver",
	"gray",
	"white",
	"maroon",
	"red",
	"purple",
	"fuchsia",
	"green",
	"lime",
	"olive",
	"yellow",
	"navy",
	"blue",
	"teal",
	"aqua",
	"aliceblue",
	"antiquewhite",
	"aqua",
	"aquamarine",
	"azure",
	"beige",
	"bisque",
	"black",
	"blanchedalmond",
	"blue",
	"blueviolet",
	"brown",
	"burlywood",
	"cadetblue",
	"chartreuse",
	"chocolate",
	"coral",
	"cornflowerblue",
	"cornsilk",
	"crimson",
	"cyan",
	"darkblue",
	"darkcyan",
	"darkgoldenrod",
	"darkgray",
	"darkgreen",
	"darkgrey",
	"darkkhaki",
	"darkmagenta",
	"darkolivegreen",
	"darkorange",
	"darkorchid",
	"darkred",
	"darksalmon",
	"darkseagreen",
	"darkslateblue",
	"darkslategray",
	"darkslategrey",
	"darkturquoise",
	"darkviolet",
	"deeppink",
	"deepskyblue",
	"dimgray",
	"dimgrey",
	"dodgerblue",
	"firebrick",
	"floralwhite",
	"forestgreen",
	"fuchsia",
	"gainsboro",
	"ghostwhite",
	"gold",
	"goldenrod",
	"gray",
	"green",
	"greenyellow",
	"grey",
	"honeydew",
	"hotpink",
	"indianred",
	"indigo",
	"ivory",
	"khaki",
	"lavender",
	"lavenderblush",
	"lawngreen",
	"lemonchiffon",
	"lightblue",
	"lightcoral",
	"lightcyan",
	"lightgoldenrodyellow",
	"lightgray",
	"lightgreen",
	"lightgrey",
	"lightpink",
	"lightsalmon",
	"lightseagreen",
	"lightskyblue",
	"lightslategray",
	"lightslategrey",
	"lightsteelblue",
	"lightyellow",
	"lime",
	"limegreen",
	"linen",
	"magenta",
	"maroon",
	"mediumaquamarine",
	"mediumblue",
	"mediumorchid",
	"mediumpurple",
	"mediumseagreen",
	"mediumslateblue",
	"mediumspringgreen",
	"mediumturquoise",
	"mediumvioletred",
	"midnightblue",
	"mintcream",
	"mistyrose",
	"moccasin",
	"navajowhite",
	"navy",
	"oldlace",
	"olive",
	"olivedrab",
	"orange",
	"orangered",
	"orchid",
	"palegoldenrod",
	"palegreen",
	"paleturquoise",
	"palevioletred",
	"papayawhip",
	"peachpuff",
	"peru",
	"pink",
	"plum",
	"powderblue",
	"purple",
	"rebeccapurple",
	"red",
	"rosybrown",
	"royalblue",
	"saddlebrown",
	"salmon",
	"sandybrown",
	"seagreen",
	"seashell",
	"sienna",
	"silver",
	"skyblue",
	"slateblue",
	"slategray",
	"slategrey",
	"snow",
	"springgreen",
	"steelblue",
	"tan",
	"teal",
	"thistle",
	"tomato",
	"turquoise",
	"violet",
	"wheat",
	"white",
	"whitesmoke",
	"yellow",
	"yellowgreen",
	"transparent",
	"currentcolor",
	"canvas",
	"canvastext",
	"linktext",
	"visitedtext",
	"activetext",
	"buttonface",
	"buttontext",
	"buttonborder",
	"field",
	"fieldtext",
	"highlight",
	"highlighttext",
	"selecteditem",
	"selecteditemtext",
	"mark",
	"marktext",
	"graytext",
	"accentcolor",
	"accentcolortext"
]), U = /^(rgba?|hsla?|hwb|color|(ok)?(lab|lch)|light-dark|color-mix)\(/i;
function S$1(e) {
	return e.charCodeAt(0) === 35 || U.test(e) || _.has(e.toLowerCase());
}
var A = [
	"calc",
	"min",
	"max",
	"clamp",
	"mod",
	"rem",
	"sin",
	"cos",
	"tan",
	"asin",
	"acos",
	"atan",
	"atan2",
	"pow",
	"sqrt",
	"hypot",
	"log",
	"exp",
	"round"
];
function b(e) {
	return e.indexOf("(") !== -1 && A.some((t) => e.includes(`${t}(`));
}
function oe(e) {
	if (!A.some((n) => e.includes(n))) return e;
	let t = "", r = [], s = null, m = null;
	for (let n = 0; n < e.length; n++) {
		let a = e.charCodeAt(n);
		if (a >= 48 && a <= 57 || s !== null && (a === 37 || a >= 97 && a <= 122 || a >= 65 && a <= 90) ? s = n : (m = s, s = null), a === 40) {
			t += e[n];
			let i = n;
			for (let p = n - 1; p >= 0; p--) {
				let c = e.charCodeAt(p);
				if (c >= 48 && c <= 57) i = p;
				else if (c >= 97 && c <= 122) i = p;
				else break;
			}
			let o = e.slice(i, n);
			if (A.includes(o)) {
				r.unshift(!0);
				continue;
			} else if (r[0] && o === "") {
				r.unshift(!0);
				continue;
			}
			r.unshift(!1);
			continue;
		} else if (a === 41) t += e[n], r.shift();
		else if (a === 44 && r[0]) {
			t += ", ";
			continue;
		} else {
			if (a === 32 && r[0] && t.charCodeAt(t.length - 1) === 32) continue;
			if ((a === 43 || a === 42 || a === 47 || a === 45) && r[0]) {
				let i = t.trimEnd(), o = i.charCodeAt(i.length - 1), p = i.charCodeAt(i.length - 2), c = e.charCodeAt(n + 1);
				if ((o === 101 || o === 69) && p >= 48 && p <= 57) {
					t += e[n];
					continue;
				} else if (o === 43 || o === 42 || o === 47 || o === 45) {
					t += e[n];
					continue;
				} else if (o === 40 || o === 44) {
					t += e[n];
					continue;
				} else e.charCodeAt(n - 1) === 32 ? t += `${e[n]} ` : o >= 48 && o <= 57 || c >= 48 && c <= 57 || o === 41 || c === 40 || c === 43 || c === 42 || c === 47 || c === 45 || m !== null && m === n - 1 ? t += ` ${e[n]} ` : t += e[n];
			} else t += e[n];
		}
	}
	return t;
}
var E$1 = new Uint8Array(256);
function d(e, t) {
	let r = 0, s = [], m = 0, n = e.length, a = t.charCodeAt(0);
	for (let i = 0; i < n; i++) {
		let o = e.charCodeAt(i);
		if (r === 0 && o === a) {
			s.push(e.slice(m, i)), m = i + 1;
			continue;
		}
		switch (o) {
			case 92:
				i += 1;
				break;
			case 39:
			case 34:
				for (; ++i < n;) {
					let p = e.charCodeAt(i);
					if (p === 92) {
						i += 1;
						continue;
					}
					if (p === o) break;
				}
				break;
			case 40:
				E$1[r] = 41, r++;
				break;
			case 91:
				E$1[r] = 93, r++;
				break;
			case 123:
				E$1[r] = 125, r++;
				break;
			case 93:
			case 125:
			case 41:
				r > 0 && o === E$1[r - 1] && r--;
				break;
		}
	}
	return s.push(e.slice(m)), s;
}
var P = {
	color: S$1,
	length: y,
	percentage: C,
	ratio: G$1,
	number: v,
	integer: u,
	url: R,
	position: K$1,
	"bg-size": Y,
	"line-width": T,
	image: F$1,
	"family-name": M,
	"generic-name": H,
	"absolute-size": $,
	"relative-size": W$1,
	angle: X$1,
	vector: te$1
};
function me$1(e, t) {
	var _P$r;
	if (e.startsWith("var(")) return null;
	for (let r of t) if ((_P$r = P[r]) === null || _P$r === void 0 ? void 0 : _P$r.call(P, e)) return r;
	return null;
}
var z = /^url\(.*\)$/;
function R(e) {
	return z.test(e);
}
function T(e) {
	return d(e, " ").every((t) => y(t) || v(t) || t === "thin" || t === "medium" || t === "thick");
}
var D = /^(?:element|image|cross-fade|image-set)\(/, I$1 = /^(repeating-)?(conic|linear|radial)-gradient\(/;
function F$1(e) {
	let t = 0;
	for (let r of d(e, ",")) if (!r.startsWith("var(")) {
		if (R(r)) {
			t += 1;
			continue;
		}
		if (I$1.test(r)) {
			t += 1;
			continue;
		}
		if (D.test(r)) {
			t += 1;
			continue;
		}
		return !1;
	}
	return t > 0;
}
function H(e) {
	return e === "serif" || e === "sans-serif" || e === "monospace" || e === "cursive" || e === "fantasy" || e === "system-ui" || e === "ui-serif" || e === "ui-sans-serif" || e === "ui-monospace" || e === "ui-rounded" || e === "math" || e === "emoji" || e === "fangsong";
}
function M(e) {
	let t = 0;
	for (let r of d(e, ",")) {
		let s = r.charCodeAt(0);
		if (s >= 48 && s <= 57) return !1;
		r.startsWith("var(") || (t += 1);
	}
	return t > 0;
}
function $(e) {
	return e === "xx-small" || e === "x-small" || e === "small" || e === "medium" || e === "large" || e === "x-large" || e === "xx-large" || e === "xxx-large";
}
function W$1(e) {
	return e === "larger" || e === "smaller";
}
var x = /[+-]?\d*\.?\d+(?:[eE][+-]?\d+)?/, B$1 = new RegExp(`^${x.source}$`);
function v(e) {
	return B$1.test(e) || b(e);
}
var q = new RegExp(`^${x.source}%$`);
function C(e) {
	return q.test(e) || b(e);
}
var V = new RegExp(`^${x.source}s*/s*${x.source}$`);
function G$1(e) {
	return V.test(e) || b(e);
}
var j = new RegExp(`^${x.source}(${[
	"cm",
	"mm",
	"Q",
	"in",
	"pc",
	"pt",
	"px",
	"em",
	"ex",
	"ch",
	"rem",
	"lh",
	"rlh",
	"vw",
	"vh",
	"vmin",
	"vmax",
	"vb",
	"vi",
	"svw",
	"svh",
	"lvw",
	"lvh",
	"dvw",
	"dvh",
	"cqw",
	"cqh",
	"cqi",
	"cqb",
	"cqmin",
	"cqmax"
].join("|")})$`);
function y(e) {
	return j.test(e) || b(e);
}
function K$1(e) {
	let t = 0;
	for (let r of d(e, " ")) {
		if (r === "center" || r === "top" || r === "right" || r === "bottom" || r === "left") {
			t += 1;
			continue;
		}
		if (!r.startsWith("var(")) {
			if (y(r) || C(r)) {
				t += 1;
				continue;
			}
			return !1;
		}
	}
	return t > 0;
}
function Y(e) {
	let t = 0;
	for (let r of d(e, ",")) {
		if (r === "cover" || r === "contain") {
			t += 1;
			continue;
		}
		let s = d(r, " ");
		if (s.length !== 1 && s.length !== 2) return !1;
		if (s.every((m) => m === "auto" || y(m) || C(m))) {
			t += 1;
			continue;
		}
	}
	return t > 0;
}
var J$1 = new RegExp(`^${x.source}(${[
	"deg",
	"rad",
	"grad",
	"turn"
].join("|")})$`);
function X$1(e) {
	return J$1.test(e);
}
var ee$1 = new RegExp(`^${x.source} +${x.source} +${x.source}$`);
function te$1(e) {
	return ee$1.test(e);
}
function u(e) {
	let t = Number(e);
	return Number.isInteger(t) && t >= 0 && String(t) === String(e);
}
function pe$1(e) {
	let t = Number(e);
	return Number.isInteger(t) && t > 0 && String(t) === String(e);
}
function ge(e) {
	return N(e, .25);
}
function ue$1(e) {
	return N(e, .25);
}
function N(e, t) {
	let r = Number(e);
	return r >= 0 && r % t === 0 && String(r) === String(e);
}
function h(e) {
	return { __BARE_VALUE__: e };
}
var g = h((e) => {
	if (u(e.value)) return e.value;
}), l = h((e) => {
	if (u(e.value)) return `${e.value}%`;
}), f = h((e) => {
	if (u(e.value)) return `${e.value}px`;
}), O = h((e) => {
	if (u(e.value)) return `${e.value}ms`;
}), w = h((e) => {
	if (u(e.value)) return `${e.value}deg`;
}), re$1 = h((e) => {
	if (e.fraction === null) return;
	let [t, r] = d(e.fraction, "/");
	if (!(!u(t) || !u(r))) return e.fraction;
}), L = h((e) => {
	if (u(Number(e.value))) return `repeat(${e.value}, minmax(0, 1fr))`;
}), be$1 = {
	accentColor: ({ theme: e }) => e("colors"),
	animation: {
		none: "none",
		spin: "spin 1s linear infinite",
		ping: "ping 1s cubic-bezier(0, 0, 0.2, 1) infinite",
		pulse: "pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite",
		bounce: "bounce 1s infinite"
	},
	aria: {
		busy: "busy=\"true\"",
		checked: "checked=\"true\"",
		disabled: "disabled=\"true\"",
		expanded: "expanded=\"true\"",
		hidden: "hidden=\"true\"",
		pressed: "pressed=\"true\"",
		readonly: "readonly=\"true\"",
		required: "required=\"true\"",
		selected: "selected=\"true\""
	},
	aspectRatio: {
		auto: "auto",
		square: "1 / 1",
		video: "16 / 9",
		...re$1
	},
	backdropBlur: ({ theme: e }) => e("blur"),
	backdropBrightness: ({ theme: e }) => ({
		...e("brightness"),
		...l
	}),
	backdropContrast: ({ theme: e }) => ({
		...e("contrast"),
		...l
	}),
	backdropGrayscale: ({ theme: e }) => ({
		...e("grayscale"),
		...l
	}),
	backdropHueRotate: ({ theme: e }) => ({
		...e("hueRotate"),
		...w
	}),
	backdropInvert: ({ theme: e }) => ({
		...e("invert"),
		...l
	}),
	backdropOpacity: ({ theme: e }) => ({
		...e("opacity"),
		...l
	}),
	backdropSaturate: ({ theme: e }) => ({
		...e("saturate"),
		...l
	}),
	backdropSepia: ({ theme: e }) => ({
		...e("sepia"),
		...l
	}),
	backgroundColor: ({ theme: e }) => e("colors"),
	backgroundImage: {
		none: "none",
		"gradient-to-t": "linear-gradient(to top, var(--tw-gradient-stops))",
		"gradient-to-tr": "linear-gradient(to top right, var(--tw-gradient-stops))",
		"gradient-to-r": "linear-gradient(to right, var(--tw-gradient-stops))",
		"gradient-to-br": "linear-gradient(to bottom right, var(--tw-gradient-stops))",
		"gradient-to-b": "linear-gradient(to bottom, var(--tw-gradient-stops))",
		"gradient-to-bl": "linear-gradient(to bottom left, var(--tw-gradient-stops))",
		"gradient-to-l": "linear-gradient(to left, var(--tw-gradient-stops))",
		"gradient-to-tl": "linear-gradient(to top left, var(--tw-gradient-stops))"
	},
	backgroundOpacity: ({ theme: e }) => e("opacity"),
	backgroundPosition: {
		bottom: "bottom",
		center: "center",
		left: "left",
		"left-bottom": "left bottom",
		"left-top": "left top",
		right: "right",
		"right-bottom": "right bottom",
		"right-top": "right top",
		top: "top"
	},
	backgroundSize: {
		auto: "auto",
		cover: "cover",
		contain: "contain"
	},
	blur: {
		0: "0",
		none: "",
		sm: "4px",
		DEFAULT: "8px",
		md: "12px",
		lg: "16px",
		xl: "24px",
		"2xl": "40px",
		"3xl": "64px"
	},
	borderColor: ({ theme: e }) => ({
		DEFAULT: "currentcolor",
		...e("colors")
	}),
	borderOpacity: ({ theme: e }) => e("opacity"),
	borderRadius: {
		none: "0px",
		sm: "0.125rem",
		DEFAULT: "0.25rem",
		md: "0.375rem",
		lg: "0.5rem",
		xl: "0.75rem",
		"2xl": "1rem",
		"3xl": "1.5rem",
		full: "9999px"
	},
	borderSpacing: ({ theme: e }) => e("spacing"),
	borderWidth: {
		DEFAULT: "1px",
		0: "0px",
		2: "2px",
		4: "4px",
		8: "8px",
		...f
	},
	boxShadow: {
		sm: "0 1px 2px 0 rgb(0 0 0 / 0.05)",
		DEFAULT: "0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1)",
		md: "0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1)",
		lg: "0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1)",
		xl: "0 20px 25px -5px rgb(0 0 0 / 0.1), 0 8px 10px -6px rgb(0 0 0 / 0.1)",
		"2xl": "0 25px 50px -12px rgb(0 0 0 / 0.25)",
		inner: "inset 0 2px 4px 0 rgb(0 0 0 / 0.05)",
		none: "none"
	},
	boxShadowColor: ({ theme: e }) => e("colors"),
	brightness: {
		0: "0",
		50: ".5",
		75: ".75",
		90: ".9",
		95: ".95",
		100: "1",
		105: "1.05",
		110: "1.1",
		125: "1.25",
		150: "1.5",
		200: "2",
		...l
	},
	caretColor: ({ theme: e }) => e("colors"),
	colors: () => ({ ...l$1 }),
	columns: {
		auto: "auto",
		1: "1",
		2: "2",
		3: "3",
		4: "4",
		5: "5",
		6: "6",
		7: "7",
		8: "8",
		9: "9",
		10: "10",
		11: "11",
		12: "12",
		"3xs": "16rem",
		"2xs": "18rem",
		xs: "20rem",
		sm: "24rem",
		md: "28rem",
		lg: "32rem",
		xl: "36rem",
		"2xl": "42rem",
		"3xl": "48rem",
		"4xl": "56rem",
		"5xl": "64rem",
		"6xl": "72rem",
		"7xl": "80rem",
		...g
	},
	container: {},
	content: { none: "none" },
	contrast: {
		0: "0",
		50: ".5",
		75: ".75",
		100: "1",
		125: "1.25",
		150: "1.5",
		200: "2",
		...l
	},
	cursor: {
		auto: "auto",
		default: "default",
		pointer: "pointer",
		wait: "wait",
		text: "text",
		move: "move",
		help: "help",
		"not-allowed": "not-allowed",
		none: "none",
		"context-menu": "context-menu",
		progress: "progress",
		cell: "cell",
		crosshair: "crosshair",
		"vertical-text": "vertical-text",
		alias: "alias",
		copy: "copy",
		"no-drop": "no-drop",
		grab: "grab",
		grabbing: "grabbing",
		"all-scroll": "all-scroll",
		"col-resize": "col-resize",
		"row-resize": "row-resize",
		"n-resize": "n-resize",
		"e-resize": "e-resize",
		"s-resize": "s-resize",
		"w-resize": "w-resize",
		"ne-resize": "ne-resize",
		"nw-resize": "nw-resize",
		"se-resize": "se-resize",
		"sw-resize": "sw-resize",
		"ew-resize": "ew-resize",
		"ns-resize": "ns-resize",
		"nesw-resize": "nesw-resize",
		"nwse-resize": "nwse-resize",
		"zoom-in": "zoom-in",
		"zoom-out": "zoom-out"
	},
	divideColor: ({ theme: e }) => e("borderColor"),
	divideOpacity: ({ theme: e }) => e("borderOpacity"),
	divideWidth: ({ theme: e }) => ({
		...e("borderWidth"),
		...f
	}),
	dropShadow: {
		sm: "0 1px 1px rgb(0 0 0 / 0.05)",
		DEFAULT: ["0 1px 2px rgb(0 0 0 / 0.1)", "0 1px 1px rgb(0 0 0 / 0.06)"],
		md: ["0 4px 3px rgb(0 0 0 / 0.07)", "0 2px 2px rgb(0 0 0 / 0.06)"],
		lg: ["0 10px 8px rgb(0 0 0 / 0.04)", "0 4px 3px rgb(0 0 0 / 0.1)"],
		xl: ["0 20px 13px rgb(0 0 0 / 0.03)", "0 8px 5px rgb(0 0 0 / 0.08)"],
		"2xl": "0 25px 25px rgb(0 0 0 / 0.15)",
		none: "0 0 #0000"
	},
	fill: ({ theme: e }) => e("colors"),
	flex: {
		1: "1 1 0%",
		auto: "1 1 auto",
		initial: "0 1 auto",
		none: "none"
	},
	flexBasis: ({ theme: e }) => ({
		auto: "auto",
		"1/2": "50%",
		"1/3": "33.333333%",
		"2/3": "66.666667%",
		"1/4": "25%",
		"2/4": "50%",
		"3/4": "75%",
		"1/5": "20%",
		"2/5": "40%",
		"3/5": "60%",
		"4/5": "80%",
		"1/6": "16.666667%",
		"2/6": "33.333333%",
		"3/6": "50%",
		"4/6": "66.666667%",
		"5/6": "83.333333%",
		"1/12": "8.333333%",
		"2/12": "16.666667%",
		"3/12": "25%",
		"4/12": "33.333333%",
		"5/12": "41.666667%",
		"6/12": "50%",
		"7/12": "58.333333%",
		"8/12": "66.666667%",
		"9/12": "75%",
		"10/12": "83.333333%",
		"11/12": "91.666667%",
		full: "100%",
		...e("spacing")
	}),
	flexGrow: {
		0: "0",
		DEFAULT: "1",
		...g
	},
	flexShrink: {
		0: "0",
		DEFAULT: "1",
		...g
	},
	fontFamily: {
		sans: [
			"ui-sans-serif",
			"system-ui",
			"sans-serif",
			"\"Apple Color Emoji\"",
			"\"Segoe UI Emoji\"",
			"\"Segoe UI Symbol\"",
			"\"Noto Color Emoji\""
		],
		serif: [
			"ui-serif",
			"Georgia",
			"Cambria",
			"\"Times New Roman\"",
			"Times",
			"serif"
		],
		mono: [
			"ui-monospace",
			"SFMono-Regular",
			"Menlo",
			"Monaco",
			"Consolas",
			"\"Liberation Mono\"",
			"\"Courier New\"",
			"monospace"
		]
	},
	fontSize: {
		xs: ["0.75rem", { lineHeight: "1rem" }],
		sm: ["0.875rem", { lineHeight: "1.25rem" }],
		base: ["1rem", { lineHeight: "1.5rem" }],
		lg: ["1.125rem", { lineHeight: "1.75rem" }],
		xl: ["1.25rem", { lineHeight: "1.75rem" }],
		"2xl": ["1.5rem", { lineHeight: "2rem" }],
		"3xl": ["1.875rem", { lineHeight: "2.25rem" }],
		"4xl": ["2.25rem", { lineHeight: "2.5rem" }],
		"5xl": ["3rem", { lineHeight: "1" }],
		"6xl": ["3.75rem", { lineHeight: "1" }],
		"7xl": ["4.5rem", { lineHeight: "1" }],
		"8xl": ["6rem", { lineHeight: "1" }],
		"9xl": ["8rem", { lineHeight: "1" }]
	},
	fontWeight: {
		thin: "100",
		extralight: "200",
		light: "300",
		normal: "400",
		medium: "500",
		semibold: "600",
		bold: "700",
		extrabold: "800",
		black: "900"
	},
	gap: ({ theme: e }) => e("spacing"),
	gradientColorStops: ({ theme: e }) => e("colors"),
	gradientColorStopPositions: {
		"0%": "0%",
		"5%": "5%",
		"10%": "10%",
		"15%": "15%",
		"20%": "20%",
		"25%": "25%",
		"30%": "30%",
		"35%": "35%",
		"40%": "40%",
		"45%": "45%",
		"50%": "50%",
		"55%": "55%",
		"60%": "60%",
		"65%": "65%",
		"70%": "70%",
		"75%": "75%",
		"80%": "80%",
		"85%": "85%",
		"90%": "90%",
		"95%": "95%",
		"100%": "100%",
		...l
	},
	grayscale: {
		0: "0",
		DEFAULT: "100%",
		...l
	},
	gridAutoColumns: {
		auto: "auto",
		min: "min-content",
		max: "max-content",
		fr: "minmax(0, 1fr)"
	},
	gridAutoRows: {
		auto: "auto",
		min: "min-content",
		max: "max-content",
		fr: "minmax(0, 1fr)"
	},
	gridColumn: {
		auto: "auto",
		"span-1": "span 1 / span 1",
		"span-2": "span 2 / span 2",
		"span-3": "span 3 / span 3",
		"span-4": "span 4 / span 4",
		"span-5": "span 5 / span 5",
		"span-6": "span 6 / span 6",
		"span-7": "span 7 / span 7",
		"span-8": "span 8 / span 8",
		"span-9": "span 9 / span 9",
		"span-10": "span 10 / span 10",
		"span-11": "span 11 / span 11",
		"span-12": "span 12 / span 12",
		"span-full": "1 / -1"
	},
	gridColumnEnd: {
		auto: "auto",
		1: "1",
		2: "2",
		3: "3",
		4: "4",
		5: "5",
		6: "6",
		7: "7",
		8: "8",
		9: "9",
		10: "10",
		11: "11",
		12: "12",
		13: "13",
		...g
	},
	gridColumnStart: {
		auto: "auto",
		1: "1",
		2: "2",
		3: "3",
		4: "4",
		5: "5",
		6: "6",
		7: "7",
		8: "8",
		9: "9",
		10: "10",
		11: "11",
		12: "12",
		13: "13",
		...g
	},
	gridRow: {
		auto: "auto",
		"span-1": "span 1 / span 1",
		"span-2": "span 2 / span 2",
		"span-3": "span 3 / span 3",
		"span-4": "span 4 / span 4",
		"span-5": "span 5 / span 5",
		"span-6": "span 6 / span 6",
		"span-7": "span 7 / span 7",
		"span-8": "span 8 / span 8",
		"span-9": "span 9 / span 9",
		"span-10": "span 10 / span 10",
		"span-11": "span 11 / span 11",
		"span-12": "span 12 / span 12",
		"span-full": "1 / -1"
	},
	gridRowEnd: {
		auto: "auto",
		1: "1",
		2: "2",
		3: "3",
		4: "4",
		5: "5",
		6: "6",
		7: "7",
		8: "8",
		9: "9",
		10: "10",
		11: "11",
		12: "12",
		13: "13",
		...g
	},
	gridRowStart: {
		auto: "auto",
		1: "1",
		2: "2",
		3: "3",
		4: "4",
		5: "5",
		6: "6",
		7: "7",
		8: "8",
		9: "9",
		10: "10",
		11: "11",
		12: "12",
		13: "13",
		...g
	},
	gridTemplateColumns: {
		none: "none",
		subgrid: "subgrid",
		1: "repeat(1, minmax(0, 1fr))",
		2: "repeat(2, minmax(0, 1fr))",
		3: "repeat(3, minmax(0, 1fr))",
		4: "repeat(4, minmax(0, 1fr))",
		5: "repeat(5, minmax(0, 1fr))",
		6: "repeat(6, minmax(0, 1fr))",
		7: "repeat(7, minmax(0, 1fr))",
		8: "repeat(8, minmax(0, 1fr))",
		9: "repeat(9, minmax(0, 1fr))",
		10: "repeat(10, minmax(0, 1fr))",
		11: "repeat(11, minmax(0, 1fr))",
		12: "repeat(12, minmax(0, 1fr))",
		...L
	},
	gridTemplateRows: {
		none: "none",
		subgrid: "subgrid",
		1: "repeat(1, minmax(0, 1fr))",
		2: "repeat(2, minmax(0, 1fr))",
		3: "repeat(3, minmax(0, 1fr))",
		4: "repeat(4, minmax(0, 1fr))",
		5: "repeat(5, minmax(0, 1fr))",
		6: "repeat(6, minmax(0, 1fr))",
		7: "repeat(7, minmax(0, 1fr))",
		8: "repeat(8, minmax(0, 1fr))",
		9: "repeat(9, minmax(0, 1fr))",
		10: "repeat(10, minmax(0, 1fr))",
		11: "repeat(11, minmax(0, 1fr))",
		12: "repeat(12, minmax(0, 1fr))",
		...L
	},
	height: ({ theme: e }) => ({
		auto: "auto",
		"1/2": "50%",
		"1/3": "33.333333%",
		"2/3": "66.666667%",
		"1/4": "25%",
		"2/4": "50%",
		"3/4": "75%",
		"1/5": "20%",
		"2/5": "40%",
		"3/5": "60%",
		"4/5": "80%",
		"1/6": "16.666667%",
		"2/6": "33.333333%",
		"3/6": "50%",
		"4/6": "66.666667%",
		"5/6": "83.333333%",
		full: "100%",
		screen: "100vh",
		svh: "100svh",
		lvh: "100lvh",
		dvh: "100dvh",
		min: "min-content",
		max: "max-content",
		fit: "fit-content",
		...e("spacing")
	}),
	hueRotate: {
		0: "0deg",
		15: "15deg",
		30: "30deg",
		60: "60deg",
		90: "90deg",
		180: "180deg",
		...w
	},
	inset: ({ theme: e }) => ({
		auto: "auto",
		"1/2": "50%",
		"1/3": "33.333333%",
		"2/3": "66.666667%",
		"1/4": "25%",
		"2/4": "50%",
		"3/4": "75%",
		full: "100%",
		...e("spacing")
	}),
	invert: {
		0: "0",
		DEFAULT: "100%",
		...l
	},
	keyframes: {
		spin: { to: { transform: "rotate(360deg)" } },
		ping: { "75%, 100%": {
			transform: "scale(2)",
			opacity: "0"
		} },
		pulse: { "50%": { opacity: ".5" } },
		bounce: {
			"0%, 100%": {
				transform: "translateY(-25%)",
				animationTimingFunction: "cubic-bezier(0.8,0,1,1)"
			},
			"50%": {
				transform: "none",
				animationTimingFunction: "cubic-bezier(0,0,0.2,1)"
			}
		}
	},
	letterSpacing: {
		tighter: "-0.05em",
		tight: "-0.025em",
		normal: "0em",
		wide: "0.025em",
		wider: "0.05em",
		widest: "0.1em"
	},
	lineHeight: {
		none: "1",
		tight: "1.25",
		snug: "1.375",
		normal: "1.5",
		relaxed: "1.625",
		loose: "2",
		3: ".75rem",
		4: "1rem",
		5: "1.25rem",
		6: "1.5rem",
		7: "1.75rem",
		8: "2rem",
		9: "2.25rem",
		10: "2.5rem"
	},
	listStyleType: {
		none: "none",
		disc: "disc",
		decimal: "decimal"
	},
	listStyleImage: { none: "none" },
	margin: ({ theme: e }) => ({
		auto: "auto",
		...e("spacing")
	}),
	lineClamp: {
		1: "1",
		2: "2",
		3: "3",
		4: "4",
		5: "5",
		6: "6",
		...g
	},
	maxHeight: ({ theme: e }) => ({
		none: "none",
		full: "100%",
		screen: "100vh",
		svh: "100svh",
		lvh: "100lvh",
		dvh: "100dvh",
		min: "min-content",
		max: "max-content",
		fit: "fit-content",
		...e("spacing")
	}),
	maxWidth: ({ theme: e }) => ({
		none: "none",
		xs: "20rem",
		sm: "24rem",
		md: "28rem",
		lg: "32rem",
		xl: "36rem",
		"2xl": "42rem",
		"3xl": "48rem",
		"4xl": "56rem",
		"5xl": "64rem",
		"6xl": "72rem",
		"7xl": "80rem",
		full: "100%",
		min: "min-content",
		max: "max-content",
		fit: "fit-content",
		prose: "65ch",
		...e("spacing")
	}),
	minHeight: ({ theme: e }) => ({
		full: "100%",
		screen: "100vh",
		svh: "100svh",
		lvh: "100lvh",
		dvh: "100dvh",
		min: "min-content",
		max: "max-content",
		fit: "fit-content",
		...e("spacing")
	}),
	minWidth: ({ theme: e }) => ({
		full: "100%",
		min: "min-content",
		max: "max-content",
		fit: "fit-content",
		...e("spacing")
	}),
	objectPosition: {
		bottom: "bottom",
		center: "center",
		left: "left",
		"left-bottom": "left bottom",
		"left-top": "left top",
		right: "right",
		"right-bottom": "right bottom",
		"right-top": "right top",
		top: "top"
	},
	opacity: {
		0: "0",
		5: "0.05",
		10: "0.1",
		15: "0.15",
		20: "0.2",
		25: "0.25",
		30: "0.3",
		35: "0.35",
		40: "0.4",
		45: "0.45",
		50: "0.5",
		55: "0.55",
		60: "0.6",
		65: "0.65",
		70: "0.7",
		75: "0.75",
		80: "0.8",
		85: "0.85",
		90: "0.9",
		95: "0.95",
		100: "1",
		...l
	},
	order: {
		first: "-9999",
		last: "9999",
		none: "0",
		1: "1",
		2: "2",
		3: "3",
		4: "4",
		5: "5",
		6: "6",
		7: "7",
		8: "8",
		9: "9",
		10: "10",
		11: "11",
		12: "12",
		...g
	},
	outlineColor: ({ theme: e }) => e("colors"),
	outlineOffset: {
		0: "0px",
		1: "1px",
		2: "2px",
		4: "4px",
		8: "8px",
		...f
	},
	outlineWidth: {
		0: "0px",
		1: "1px",
		2: "2px",
		4: "4px",
		8: "8px",
		...f
	},
	padding: ({ theme: e }) => e("spacing"),
	placeholderColor: ({ theme: e }) => e("colors"),
	placeholderOpacity: ({ theme: e }) => e("opacity"),
	ringColor: ({ theme: e }) => ({
		DEFAULT: "currentcolor",
		...e("colors")
	}),
	ringOffsetColor: ({ theme: e }) => e("colors"),
	ringOffsetWidth: {
		0: "0px",
		1: "1px",
		2: "2px",
		4: "4px",
		8: "8px",
		...f
	},
	ringOpacity: ({ theme: e }) => ({
		DEFAULT: "0.5",
		...e("opacity")
	}),
	ringWidth: {
		DEFAULT: "3px",
		0: "0px",
		1: "1px",
		2: "2px",
		4: "4px",
		8: "8px",
		...f
	},
	rotate: {
		0: "0deg",
		1: "1deg",
		2: "2deg",
		3: "3deg",
		6: "6deg",
		12: "12deg",
		45: "45deg",
		90: "90deg",
		180: "180deg",
		...w
	},
	saturate: {
		0: "0",
		50: ".5",
		100: "1",
		150: "1.5",
		200: "2",
		...l
	},
	scale: {
		0: "0",
		50: ".5",
		75: ".75",
		90: ".9",
		95: ".95",
		100: "1",
		105: "1.05",
		110: "1.1",
		125: "1.25",
		150: "1.5",
		...l
	},
	screens: {
		sm: "40rem",
		md: "48rem",
		lg: "64rem",
		xl: "80rem",
		"2xl": "96rem"
	},
	scrollMargin: ({ theme: e }) => e("spacing"),
	scrollPadding: ({ theme: e }) => e("spacing"),
	sepia: {
		0: "0",
		DEFAULT: "100%",
		...l
	},
	skew: {
		0: "0deg",
		1: "1deg",
		2: "2deg",
		3: "3deg",
		6: "6deg",
		12: "12deg",
		...w
	},
	space: ({ theme: e }) => e("spacing"),
	spacing: {
		px: "1px",
		0: "0px",
		.5: "0.125rem",
		1: "0.25rem",
		1.5: "0.375rem",
		2: "0.5rem",
		2.5: "0.625rem",
		3: "0.75rem",
		3.5: "0.875rem",
		4: "1rem",
		5: "1.25rem",
		6: "1.5rem",
		7: "1.75rem",
		8: "2rem",
		9: "2.25rem",
		10: "2.5rem",
		11: "2.75rem",
		12: "3rem",
		14: "3.5rem",
		16: "4rem",
		20: "5rem",
		24: "6rem",
		28: "7rem",
		32: "8rem",
		36: "9rem",
		40: "10rem",
		44: "11rem",
		48: "12rem",
		52: "13rem",
		56: "14rem",
		60: "15rem",
		64: "16rem",
		72: "18rem",
		80: "20rem",
		96: "24rem"
	},
	stroke: ({ theme: e }) => ({
		none: "none",
		...e("colors")
	}),
	strokeWidth: {
		0: "0",
		1: "1",
		2: "2",
		...g
	},
	supports: {},
	data: {},
	textColor: ({ theme: e }) => e("colors"),
	textDecorationColor: ({ theme: e }) => e("colors"),
	textDecorationThickness: {
		auto: "auto",
		"from-font": "from-font",
		0: "0px",
		1: "1px",
		2: "2px",
		4: "4px",
		8: "8px",
		...f
	},
	textIndent: ({ theme: e }) => e("spacing"),
	textOpacity: ({ theme: e }) => e("opacity"),
	textUnderlineOffset: {
		auto: "auto",
		0: "0px",
		1: "1px",
		2: "2px",
		4: "4px",
		8: "8px",
		...f
	},
	transformOrigin: {
		center: "center",
		top: "top",
		"top-right": "top right",
		right: "right",
		"bottom-right": "bottom right",
		bottom: "bottom",
		"bottom-left": "bottom left",
		left: "left",
		"top-left": "top left"
	},
	transitionDelay: {
		0: "0s",
		75: "75ms",
		100: "100ms",
		150: "150ms",
		200: "200ms",
		300: "300ms",
		500: "500ms",
		700: "700ms",
		1e3: "1000ms",
		...O
	},
	transitionDuration: {
		DEFAULT: "150ms",
		0: "0s",
		75: "75ms",
		100: "100ms",
		150: "150ms",
		200: "200ms",
		300: "300ms",
		500: "500ms",
		700: "700ms",
		1e3: "1000ms",
		...O
	},
	transitionProperty: {
		none: "none",
		all: "all",
		DEFAULT: "color, background-color, border-color, outline-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter",
		colors: "color, background-color, border-color, outline-color, text-decoration-color, fill, stroke",
		opacity: "opacity",
		shadow: "box-shadow",
		transform: "transform"
	},
	transitionTimingFunction: {
		DEFAULT: "cubic-bezier(0.4, 0, 0.2, 1)",
		linear: "linear",
		in: "cubic-bezier(0.4, 0, 1, 1)",
		out: "cubic-bezier(0, 0, 0.2, 1)",
		"in-out": "cubic-bezier(0.4, 0, 0.2, 1)"
	},
	translate: ({ theme: e }) => ({
		"1/2": "50%",
		"1/3": "33.333333%",
		"2/3": "66.666667%",
		"1/4": "25%",
		"2/4": "50%",
		"3/4": "75%",
		full: "100%",
		...e("spacing")
	}),
	size: ({ theme: e }) => ({
		auto: "auto",
		"1/2": "50%",
		"1/3": "33.333333%",
		"2/3": "66.666667%",
		"1/4": "25%",
		"2/4": "50%",
		"3/4": "75%",
		"1/5": "20%",
		"2/5": "40%",
		"3/5": "60%",
		"4/5": "80%",
		"1/6": "16.666667%",
		"2/6": "33.333333%",
		"3/6": "50%",
		"4/6": "66.666667%",
		"5/6": "83.333333%",
		"1/12": "8.333333%",
		"2/12": "16.666667%",
		"3/12": "25%",
		"4/12": "33.333333%",
		"5/12": "41.666667%",
		"6/12": "50%",
		"7/12": "58.333333%",
		"8/12": "66.666667%",
		"9/12": "75%",
		"10/12": "83.333333%",
		"11/12": "91.666667%",
		full: "100%",
		min: "min-content",
		max: "max-content",
		fit: "fit-content",
		...e("spacing")
	}),
	width: ({ theme: e }) => ({
		auto: "auto",
		"1/2": "50%",
		"1/3": "33.333333%",
		"2/3": "66.666667%",
		"1/4": "25%",
		"2/4": "50%",
		"3/4": "75%",
		"1/5": "20%",
		"2/5": "40%",
		"3/5": "60%",
		"4/5": "80%",
		"1/6": "16.666667%",
		"2/6": "33.333333%",
		"3/6": "50%",
		"4/6": "66.666667%",
		"5/6": "83.333333%",
		"1/12": "8.333333%",
		"2/12": "16.666667%",
		"3/12": "25%",
		"4/12": "33.333333%",
		"5/12": "41.666667%",
		"6/12": "50%",
		"7/12": "58.333333%",
		"8/12": "66.666667%",
		"9/12": "75%",
		"10/12": "83.333333%",
		"11/12": "91.666667%",
		full: "100%",
		screen: "100vw",
		svw: "100svw",
		lvw: "100lvw",
		dvw: "100dvw",
		min: "min-content",
		max: "max-content",
		fit: "fit-content",
		...e("spacing")
	}),
	willChange: {
		auto: "auto",
		scroll: "scroll-position",
		contents: "contents",
		transform: "transform"
	},
	zIndex: {
		auto: "auto",
		0: "0",
		10: "10",
		20: "20",
		30: "30",
		40: "40",
		50: "50",
		...g
	}
};
var ir = "4.1.18";
function tt(t) {
	let r = [0];
	for (let n = 0; n < t.length; n++) t.charCodeAt(n) === 10 && r.push(n + 1);
	function i(n) {
		let s = 0, a = r.length;
		for (; a > 0;) {
			let u = (a | 0) >> 1, f = s + u;
			r[f] <= n ? (s = f + 1, a = a - u - 1) : a = u;
		}
		s -= 1;
		let p = n - r[s];
		return {
			line: s + 1,
			column: p
		};
	}
	function e({ line: n, column: s }) {
		n -= 1, n = Math.min(Math.max(n, 0), r.length - 1);
		let a = r[n], p = r[n + 1] ?? a;
		return Math.min(Math.max(a + s, 0), p);
	}
	return {
		find: i,
		findOffset: e
	};
}
var Fe = 92, rt = 47, it = 42, nr = 34, ar = 39, Yi = 58, nt = 59, le = 10, at = 13, We = 32, Be = 9, or = 123, $t = 125, Vt = 40, lr = 41, Gi = 91, qi = 93, sr = 45, St = 64, Zi = 33, se = class t extends Error {
	loc;
	constructor(r, i) {
		if (i) {
			let e = i[0], n = tt(e.code).find(i[1]);
			r = `${e.file}:${n.line}:${n.column + 1}: ${r}`;
		}
		super(r), this.name = "CssSyntaxError", this.loc = i, Error.captureStackTrace && Error.captureStackTrace(this, t);
	}
};
function $e(t, r) {
	let i = (r === null || r === void 0 ? void 0 : r.from) ? {
		file: r.from,
		code: t
	} : null;
	t[0] === "﻿" && (t = " " + t.slice(1));
	let e = [], n = [], s = [], a = null, p = null, u = "", f = "", m = 0, d;
	for (let c = 0; c < t.length; c++) {
		let w = t.charCodeAt(c);
		if (!(w === at && (d = t.charCodeAt(c + 1), d === le))) if (w === Fe) u === "" && (m = c), u += t.slice(c, c + 2), c += 1;
		else if (w === rt && t.charCodeAt(c + 1) === it) {
			let h = c;
			for (let x = c + 2; x < t.length; x++) if (d = t.charCodeAt(x), d === Fe) x += 1;
			else if (d === it && t.charCodeAt(x + 1) === rt) {
				c = x + 1;
				break;
			}
			let y = t.slice(h, c + 1);
			if (y.charCodeAt(2) === Zi) {
				let x = ot(y.slice(2, -2));
				n.push(x), i && (x.src = [
					i,
					h,
					c + 1
				], x.dst = [
					i,
					h,
					c + 1
				]);
			}
		} else if (w === ar || w === nr) {
			let h = ur(t, c, w, i);
			u += t.slice(c, h + 1), c = h;
		} else {
			if ((w === We || w === le || w === Be) && (d = t.charCodeAt(c + 1)) && (d === We || d === le || d === Be || d === at && (d = t.charCodeAt(c + 2)) && d == le)) continue;
			if (w === le) {
				if (u.length === 0) continue;
				d = u.charCodeAt(u.length - 1), d !== We && d !== le && d !== Be && (u += " ");
			} else if (w === sr && t.charCodeAt(c + 1) === sr && u.length === 0) {
				let h = "", y = c, x = -1;
				for (let A = c + 2; A < t.length; A++) if (d = t.charCodeAt(A), d === Fe) A += 1;
				else if (d === ar || d === nr) A = ur(t, A, d, i);
				else if (d === rt && t.charCodeAt(A + 1) === it) {
					for (let k = A + 2; k < t.length; k++) if (d = t.charCodeAt(k), d === Fe) k += 1;
					else if (d === it && t.charCodeAt(k + 1) === rt) {
						A = k + 1;
						break;
					}
				} else if (x === -1 && d === Yi) x = u.length + A - y;
				else if (d === nt && h.length === 0) {
					u += t.slice(y, A), c = A;
					break;
				} else if (d === Vt) h += ")";
				else if (d === Gi) h += "]";
				else if (d === or) h += "}";
				else if ((d === $t || t.length - 1 === A) && h.length === 0) {
					c = A - 1, u += t.slice(y, A);
					break;
				} else (d === lr || d === qi || d === $t) && h.length > 0 && t[A] === h[h.length - 1] && (h = h.slice(0, -1));
				let $ = Tt(u, x);
				if (!$) throw new se("Invalid custom property, expected a value", i ? [
					i,
					y,
					c
				] : null);
				i && ($.src = [
					i,
					y,
					c
				], $.dst = [
					i,
					y,
					c
				]), a ? a.nodes.push($) : e.push($), u = "";
			} else if (w === nt && u.charCodeAt(0) === St) p = Ye(u), i && (p.src = [
				i,
				m,
				c
			], p.dst = [
				i,
				m,
				c
			]), a ? a.nodes.push(p) : e.push(p), u = "", p = null;
			else if (w === nt && f[f.length - 1] !== ")") {
				let h = Tt(u);
				if (!h) {
					if (u.length === 0) continue;
					throw new se(`Invalid declaration: \`${u.trim()}\``, i ? [
						i,
						m,
						c
					] : null);
				}
				i && (h.src = [
					i,
					m,
					c
				], h.dst = [
					i,
					m,
					c
				]), a ? a.nodes.push(h) : e.push(h), u = "";
			} else if (w === or && f[f.length - 1] !== ")") f += "}", p = J(u.trim()), i && (p.src = [
				i,
				m,
				c
			], p.dst = [
				i,
				m,
				c
			]), a && a.nodes.push(p), s.push(a), a = p, u = "", p = null;
			else if (w === $t && f[f.length - 1] !== ")") {
				if (f === "") throw new se("Missing opening {", i ? [
					i,
					c,
					c
				] : null);
				if (f = f.slice(0, -1), u.length > 0) if (u.charCodeAt(0) === St) p = Ye(u), i && (p.src = [
					i,
					m,
					c
				], p.dst = [
					i,
					m,
					c
				]), a ? a.nodes.push(p) : e.push(p), u = "", p = null;
				else {
					let y = u.indexOf(":");
					if (a) {
						let x = Tt(u, y);
						if (!x) throw new se(`Invalid declaration: \`${u.trim()}\``, i ? [
							i,
							m,
							c
						] : null);
						i && (x.src = [
							i,
							m,
							c
						], x.dst = [
							i,
							m,
							c
						]), a.nodes.push(x);
					}
				}
				let h = s.pop() ?? null;
				h === null && a && e.push(a), a = h, u = "", p = null;
			} else if (w === Vt) f += ")", u += "(";
			else if (w === lr) {
				if (f[f.length - 1] !== ")") throw new se("Missing opening (", i ? [
					i,
					c,
					c
				] : null);
				f = f.slice(0, -1), u += ")";
			} else {
				if (u.length === 0 && (w === We || w === le || w === Be)) continue;
				u === "" && (m = c), u += String.fromCharCode(w);
			}
		}
	}
	if (u.charCodeAt(0) === St) {
		let c = Ye(u);
		i && (c.src = [
			i,
			m,
			t.length
		], c.dst = [
			i,
			m,
			t.length
		]), e.push(c);
	}
	if (f.length > 0 && a) {
		if (a.kind === "rule") throw new se(`Missing closing } at ${a.selector}`, a.src ? [
			a.src[0],
			a.src[1],
			a.src[1]
		] : null);
		if (a.kind === "at-rule") throw new se(`Missing closing } at ${a.name} ${a.params}`, a.src ? [
			a.src[0],
			a.src[1],
			a.src[1]
		] : null);
	}
	return n.length > 0 ? n.concat(e) : e;
}
function Ye(t, r = []) {
	let i = t, e = "";
	for (let n = 5; n < t.length; n++) {
		let s = t.charCodeAt(n);
		if (s === We || s === Be || s === Vt) {
			i = t.slice(0, n), e = t.slice(n);
			break;
		}
	}
	return F(i.trim(), e.trim(), r);
}
function Tt(t, r = t.indexOf(":")) {
	if (r === -1) return null;
	let i = t.indexOf("!important", r + 1);
	return o(t.slice(0, r).trim(), t.slice(r + 1, i === -1 ? t.length : i).trim(), i !== -1);
}
function ur(t, r, i, e = null) {
	let n;
	for (let s = r + 1; s < t.length; s++) if (n = t.charCodeAt(s), n === Fe) s += 1;
	else {
		if (n === i) return s;
		if (n === nt && (t.charCodeAt(s + 1) === le || t.charCodeAt(s + 1) === at && t.charCodeAt(s + 2) === le)) throw new se(`Unterminated string: ${t.slice(r, s + 1) + String.fromCharCode(i)}`, e ? [
			e,
			r,
			s + 1
		] : null);
		if (n === le || n === at && t.charCodeAt(s + 1) === le) throw new se(`Unterminated string: ${t.slice(r, s) + String.fromCharCode(i)}`, e ? [
			e,
			r,
			s + 1
		] : null);
	}
	return r;
}
function ye(t) {
	if (arguments.length === 0) throw new TypeError("`CSS.escape` requires an argument.");
	let r = String(t), i = r.length, e = -1, n, s = "", a = r.charCodeAt(0);
	if (i === 1 && a === 45) return "\\" + r;
	for (; ++e < i;) {
		if (n = r.charCodeAt(e), n === 0) {
			s += "�";
			continue;
		}
		if (n >= 1 && n <= 31 || n === 127 || e === 0 && n >= 48 && n <= 57 || e === 1 && n >= 48 && n <= 57 && a === 45) {
			s += "\\" + n.toString(16) + " ";
			continue;
		}
		if (n >= 128 || n === 45 || n === 95 || n >= 48 && n <= 57 || n >= 65 && n <= 90 || n >= 97 && n <= 122) {
			s += r.charAt(e);
			continue;
		}
		s += "\\" + r.charAt(e);
	}
	return s;
}
function Se(t) {
	return t.replace(/\\([\dA-Fa-f]{1,6}[\t\n\f\r ]?|[\S\s])/g, (r) => r.length > 2 ? String.fromCodePoint(Number.parseInt(r.slice(1).trim(), 16)) : r[1]);
}
var cr = new Map([
	["--font", ["--font-weight", "--font-size"]],
	["--inset", ["--inset-shadow", "--inset-ring"]],
	["--text", [
		"--text-color",
		"--text-decoration-color",
		"--text-decoration-thickness",
		"--text-indent",
		"--text-shadow",
		"--text-underline-offset"
	]],
	["--grid-column", ["--grid-column-start", "--grid-column-end"]],
	["--grid-row", ["--grid-row-start", "--grid-row-end"]]
]);
function fr(t, r) {
	return (cr.get(r) ?? []).some((i) => t === i || t.startsWith(`${i}-`));
}
var lt = class {
	constructor(r = /* @__PURE__ */ new Map(), i = /* @__PURE__ */ new Set([])) {
		this.values = r;
		this.keyframes = i;
	}
	prefix = null;
	get size() {
		return this.values.size;
	}
	add(r, i, e = 0, n) {
		if (r.endsWith("-*")) {
			if (i !== "initial") throw new Error(`Invalid theme value \`${i}\` for namespace \`${r}\``);
			r === "--*" ? this.values.clear() : this.clearNamespace(r.slice(0, -2), 0);
		}
		if (e & 4) {
			let s = this.values.get(r);
			if (s && !(s.options & 4)) return;
		}
		i === "initial" ? this.values.delete(r) : this.values.set(r, {
			value: i,
			options: e,
			src: n
		});
	}
	keysInNamespaces(r) {
		let i = [];
		for (let e of r) {
			let n = `${e}-`;
			for (let s of this.values.keys()) s.startsWith(n) && s.indexOf("--", 2) === -1 && (fr(s, e) || i.push(s.slice(n.length)));
		}
		return i;
	}
	get(r) {
		for (let i of r) {
			let e = this.values.get(i);
			if (e) return e.value;
		}
		return null;
	}
	hasDefault(r) {
		return (this.getOptions(r) & 4) === 4;
	}
	getOptions(r) {
		var _this$values$get;
		return r = Se(this.#r(r)), ((_this$values$get = this.values.get(r)) === null || _this$values$get === void 0 ? void 0 : _this$values$get.options) ?? 0;
	}
	entries() {
		return this.prefix ? Array.from(this.values, (r) => (r[0] = this.prefixKey(r[0]), r)) : this.values.entries();
	}
	prefixKey(r) {
		return this.prefix ? `--${this.prefix}-${r.slice(2)}` : r;
	}
	#r(r) {
		return this.prefix ? `--${r.slice(3 + this.prefix.length)}` : r;
	}
	clearNamespace(r, i) {
		let e = cr.get(r) ?? [];
		e: for (let n of this.values.keys()) if (n.startsWith(r)) {
			if (i !== 0 && (this.getOptions(n) & i) !== i) continue;
			for (let s of e) if (n.startsWith(s)) continue e;
			this.values.delete(n);
		}
	}
	#e(r, i) {
		for (let e of i) {
			let n = r !== null ? `${e}-${r}` : e;
			if (!this.values.has(n)) if (r !== null && r.includes(".")) {
				if (n = `${e}-${r.replaceAll(".", "_")}`, !this.values.has(n)) continue;
			} else continue;
			if (!fr(n, e)) return n;
		}
		return null;
	}
	#t(r) {
		let i = this.values.get(r);
		if (!i) return null;
		let e = null;
		return i.options & 2 && (e = i.value), `var(${ye(this.prefixKey(r))}${e ? `, ${e}` : ""})`;
	}
	markUsedVariable(r) {
		let i = Se(this.#r(r)), e = this.values.get(i);
		if (!e) return !1;
		let n = e.options & 16;
		return e.options |= 16, !n;
	}
	resolve(r, i, e = 0) {
		let n = this.#e(r, i);
		if (!n) return null;
		let s = this.values.get(n);
		return (e | s.options) & 1 ? s.value : this.#t(n);
	}
	resolveValue(r, i) {
		let e = this.#e(r, i);
		return e ? this.values.get(e).value : null;
	}
	resolveWith(r, i, e = []) {
		let n = this.#e(r, i);
		if (!n) return null;
		let s = {};
		for (let p of e) {
			let u = `${n}${p}`, f = this.values.get(u);
			f && (f.options & 1 ? s[p] = f.value : s[p] = this.#t(u));
		}
		let a = this.values.get(n);
		return a.options & 1 ? [a.value, s] : [this.#t(n), s];
	}
	namespace(r) {
		let i = /* @__PURE__ */ new Map(), e = `${r}-`;
		for (let [n, s] of this.values) n === r ? i.set(null, s.value) : n.startsWith(`${e}-`) ? i.set(n.slice(r.length), s.value) : n.startsWith(e) && i.set(n.slice(e.length), s.value);
		return i;
	}
	addKeyframes(r) {
		this.keyframes.add(r);
	}
	getKeyframes() {
		return Array.from(this.keyframes);
	}
};
var K = class extends Map {
	constructor(i) {
		super();
		this.factory = i;
	}
	get(i) {
		let e = super.get(i);
		return e === void 0 && (e = this.factory(i, this), this.set(i, e)), e;
	}
};
function ne(t) {
	return {
		kind: "word",
		value: t
	};
}
function Hi(t, r) {
	return {
		kind: "function",
		value: t,
		nodes: r
	};
}
function Ji(t) {
	return {
		kind: "separator",
		value: t
	};
}
function Z(t) {
	let r = "";
	for (let i of t) switch (i.kind) {
		case "word":
		case "separator":
			r += i.value;
			break;
		case "function": r += i.value + "(" + Z(i.nodes) + ")";
	}
	return r;
}
var pr = 92, Qi = 41, dr = 58, mr = 44, Xi = 34, gr = 61, hr = 62, vr = 60, wr = 10, en = 40, tn = 39, rn = 47, yr = 32, kr = 9;
function B(t) {
	t = t.replaceAll(`\r
`, `
`);
	let r = [], i = [], e = null, n = "", s;
	for (let a = 0; a < t.length; a++) {
		let p = t.charCodeAt(a);
		switch (p) {
			case pr:
				n += t[a] + t[a + 1], a++;
				break;
			case rn: {
				if (n.length > 0) {
					let f = ne(n);
					e ? e.nodes.push(f) : r.push(f), n = "";
				}
				let u = ne(t[a]);
				e ? e.nodes.push(u) : r.push(u);
				break;
			}
			case dr:
			case mr:
			case gr:
			case hr:
			case vr:
			case wr:
			case yr:
			case kr: {
				if (n.length > 0) {
					let d = ne(n);
					e ? e.nodes.push(d) : r.push(d), n = "";
				}
				let u = a, f = a + 1;
				for (; f < t.length && (s = t.charCodeAt(f), !(s !== dr && s !== mr && s !== gr && s !== hr && s !== vr && s !== wr && s !== yr && s !== kr)); f++);
				a = f - 1;
				let m = Ji(t.slice(u, f));
				e ? e.nodes.push(m) : r.push(m);
				break;
			}
			case tn:
			case Xi: {
				let u = a;
				for (let f = a + 1; f < t.length; f++) if (s = t.charCodeAt(f), s === pr) f += 1;
				else if (s === p) {
					a = f;
					break;
				}
				n += t.slice(u, a + 1);
				break;
			}
			case en: {
				let u = Hi(n, []);
				n = "", e ? e.nodes.push(u) : r.push(u), i.push(u), e = u;
				break;
			}
			case Qi: {
				let u = i.pop();
				if (n.length > 0) {
					let f = ne(n);
					u === null || u === void 0 || u.nodes.push(f), n = "";
				}
				i.length > 0 ? e = i[i.length - 1] : e = null;
				break;
			}
			default: n += String.fromCharCode(p);
		}
	}
	return n.length > 0 && r.push(ne(n)), r;
}
var Et = ((a) => (a[a.Continue = 0] = "Continue", a[a.Skip = 1] = "Skip", a[a.Stop = 2] = "Stop", a[a.Replace = 3] = "Replace", a[a.ReplaceSkip = 4] = "ReplaceSkip", a[a.ReplaceStop = 5] = "ReplaceStop", a))(Et || {}), E = {
	Continue: { kind: 0 },
	Skip: { kind: 1 },
	Stop: { kind: 2 },
	Replace: (t) => ({
		kind: 3,
		nodes: Array.isArray(t) ? t : [t]
	}),
	ReplaceSkip: (t) => ({
		kind: 4,
		nodes: Array.isArray(t) ? t : [t]
	}),
	ReplaceStop: (t) => ({
		kind: 5,
		nodes: Array.isArray(t) ? t : [t]
	})
};
function I(t, r) {
	typeof r == "function" ? br(t, r) : br(t, r.enter, r.exit);
}
function br(t, r = () => E.Continue, i = () => E.Continue) {
	let e = [[
		t,
		0,
		null
	]], n = {
		parent: null,
		depth: 0,
		path() {
			let s = [];
			for (let a = 1; a < e.length; a++) {
				let p = e[a][2];
				p && s.push(p);
			}
			return s;
		}
	};
	for (; e.length > 0;) {
		let s = e.length - 1, a = e[s], p = a[0], u = a[1], f = a[2];
		if (u >= p.length) {
			e.pop();
			continue;
		}
		if (n.parent = f, n.depth = s, u >= 0) {
			let w = p[u], h = r(w, n) ?? E.Continue;
			switch (h.kind) {
				case 0:
					w.nodes && w.nodes.length > 0 && e.push([
						w.nodes,
						0,
						w
					]), a[1] = ~u;
					continue;
				case 2: return;
				case 1:
					a[1] = ~u;
					continue;
				case 3:
					p.splice(u, 1, ...h.nodes);
					continue;
				case 5:
					p.splice(u, 1, ...h.nodes);
					return;
				case 4:
					p.splice(u, 1, ...h.nodes), a[1] += h.nodes.length;
					continue;
				default: throw new Error(`Invalid \`WalkAction.${Et[h.kind] ?? `Unknown(${h.kind})`}\` in enter.`);
			}
		}
		let m = ~u, d = p[m], c = i(d, n) ?? E.Continue;
		switch (c.kind) {
			case 0:
				a[1] = m + 1;
				continue;
			case 2: return;
			case 3:
				p.splice(m, 1, ...c.nodes), a[1] = m + c.nodes.length;
				continue;
			case 5:
				p.splice(m, 1, ...c.nodes);
				return;
			case 4:
				p.splice(m, 1, ...c.nodes), a[1] = m + c.nodes.length;
				continue;
			default: throw new Error(`Invalid \`WalkAction.${Et[c.kind] ?? `Unknown(${c.kind})`}\` in exit.`);
		}
	}
}
function st(t) {
	let r = [];
	return I(B(t), (i) => {
		if (!(i.kind !== "function" || i.value !== "var")) return I(i.nodes, (e) => {
			e.kind !== "word" || e.value[0] !== "-" || e.value[1] !== "-" || r.push(e.value);
		}), E.Skip;
	}), r;
}
var nn = 64;
function G(t, r = []) {
	return {
		kind: "rule",
		selector: t,
		nodes: r
	};
}
function F(t, r = "", i = []) {
	return {
		kind: "at-rule",
		name: t,
		params: r,
		nodes: i
	};
}
function J(t, r = []) {
	return t.charCodeAt(0) === nn ? Ye(t, r) : G(t, r);
}
function o(t, r, i = !1) {
	return {
		kind: "declaration",
		property: t,
		value: r,
		important: i
	};
}
function ot(t) {
	return {
		kind: "comment",
		value: t
	};
}
function ce(t, r) {
	return {
		kind: "context",
		context: t,
		nodes: r
	};
}
function W(t) {
	return {
		kind: "at-root",
		nodes: t
	};
}
function ee(t) {
	switch (t.kind) {
		case "rule": return {
			kind: t.kind,
			selector: t.selector,
			nodes: t.nodes.map(ee),
			src: t.src,
			dst: t.dst
		};
		case "at-rule": return {
			kind: t.kind,
			name: t.name,
			params: t.params,
			nodes: t.nodes.map(ee),
			src: t.src,
			dst: t.dst
		};
		case "at-root": return {
			kind: t.kind,
			nodes: t.nodes.map(ee),
			src: t.src,
			dst: t.dst
		};
		case "context": return {
			kind: t.kind,
			context: { ...t.context },
			nodes: t.nodes.map(ee),
			src: t.src,
			dst: t.dst
		};
		case "declaration": return {
			kind: t.kind,
			property: t.property,
			value: t.value,
			important: t.important,
			src: t.src,
			dst: t.dst
		};
		case "comment": return {
			kind: t.kind,
			value: t.value,
			src: t.src,
			dst: t.dst
		};
		default: throw new Error(`Unknown node kind: ${t.kind}`);
	}
}
function qe(t) {
	return {
		depth: t.depth,
		get context() {
			let r = {};
			for (let i of t.path()) i.kind === "context" && Object.assign(r, i.context);
			return Object.defineProperty(this, "context", { value: r }), r;
		},
		get parent() {
			let r = this.path().pop() ?? null;
			return Object.defineProperty(this, "parent", { value: r }), r;
		},
		path() {
			return t.path().filter((r) => r.kind !== "context");
		}
	};
}
function Te(t, r, i = 3) {
	let e = [], n = /* @__PURE__ */ new Set(), s = new K(() => /* @__PURE__ */ new Set()), a = new K(() => /* @__PURE__ */ new Set()), p = /* @__PURE__ */ new Set(), u = /* @__PURE__ */ new Set(), f = [], m = [], d = new K(() => /* @__PURE__ */ new Set());
	function c(h, y, x = {}, $ = 0) {
		if (h.kind === "declaration") {
			if (h.property === "--tw-sort" || h.value === void 0 || h.value === null) return;
			if (x.theme && h.property[0] === "-" && h.property[1] === "-") {
				if (h.value === "initial") {
					h.value = void 0;
					return;
				}
				x.keyframes || s.get(y).add(h);
			}
			if (h.value.includes("var(")) if (x.theme && h.property[0] === "-" && h.property[1] === "-") for (let A of st(h.value)) d.get(A).add(h.property);
			else r.trackUsedVariables(h.value);
			if (h.property === "animation") for (let A of xr(h.value)) u.add(A);
			i & 2 && h.value.includes("color-mix(") && !x.keyframes && a.get(y).add(h), y.push(h);
		} else if (h.kind === "rule") {
			let A = [];
			for (let N of h.nodes) c(N, A, x, $ + 1);
			let k = {}, U = /* @__PURE__ */ new Set();
			for (let N of A) {
				if (N.kind !== "declaration") continue;
				let O = `${N.property}:${N.value}:${N.important}`;
				k[O] ?? (k[O] = []), k[O].push(N);
			}
			for (let N in k) for (let O = 0; O < k[N].length - 1; ++O) U.add(k[N][O]);
			if (U.size > 0 && (A = A.filter((N) => !U.has(N))), A.length === 0) return;
			h.selector === "&" ? y.push(...A) : y.push({
				...h,
				nodes: A
			});
		} else if (h.kind === "at-rule" && h.name === "@property" && $ === 0) {
			if (n.has(h.params)) return;
			if (i & 1) {
				let k = h.params, U = null, N = !1;
				for (let L of h.nodes) L.kind === "declaration" && (L.property === "initial-value" ? U = L.value : L.property === "inherits" && (N = L.value === "true"));
				let O = o(k, U ?? "initial");
				O.src = h.src, N ? f.push(O) : m.push(O);
			}
			n.add(h.params);
			let A = {
				...h,
				nodes: []
			};
			for (let k of h.nodes) c(k, A.nodes, x, $ + 1);
			y.push(A);
		} else if (h.kind === "at-rule") {
			h.name === "@keyframes" && (x = {
				...x,
				keyframes: !0
			});
			let A = {
				...h,
				nodes: []
			};
			for (let k of h.nodes) c(k, A.nodes, x, $ + 1);
			h.name === "@keyframes" && x.theme && p.add(A), (A.nodes.length > 0 || A.name === "@layer" || A.name === "@charset" || A.name === "@custom-media" || A.name === "@namespace" || A.name === "@import") && y.push(A);
		} else if (h.kind === "at-root") for (let A of h.nodes) {
			let k = [];
			c(A, k, x, 0);
			for (let U of k) e.push(U);
		}
		else if (h.kind === "context") {
			if (h.context.reference) return;
			for (let A of h.nodes) c(A, y, {
				...x,
				...h.context
			}, $);
		} else h.kind === "comment" && y.push(h);
	}
	let w = [];
	for (let h of t) c(h, w, {}, 0);
	e: for (let [h, y] of s) for (let x of y) {
		if (Ar(x.property, r.theme, d)) {
			if (x.property.startsWith(r.theme.prefixKey("--animate-"))) for (let k of xr(x.value)) u.add(k);
			continue;
		}
		let A = h.indexOf(x);
		if (h.splice(A, 1), h.length === 0) {
			let k = an(w, (U) => U.kind === "rule" && U.nodes === h);
			if (!k || k.length === 0) continue e;
			k.unshift({
				kind: "at-root",
				nodes: w
			});
			do {
				let U = k.pop();
				if (!U) break;
				let N = k[k.length - 1];
				if (!N || N.kind !== "at-root" && N.kind !== "at-rule") break;
				let O = N.nodes.indexOf(U);
				if (O === -1) break;
				N.nodes.splice(O, 1);
			} while (!0);
			continue e;
		}
	}
	for (let h of p) if (!u.has(h.params)) {
		let y = e.indexOf(h);
		e.splice(y, 1);
	}
	if (w = w.concat(e), i & 2) for (let [h, y] of a) for (let x of y) {
		let $ = h.indexOf(x);
		if ($ === -1 || x.value == null) continue;
		let A = B(x.value), k = !1;
		if (I(A, (O) => {
			if (O.kind !== "function" || O.value !== "color-mix") return;
			let L = !1, _ = !1;
			if (I(O.nodes, (z) => {
				if (z.kind == "word" && z.value.toLowerCase() === "currentcolor") {
					_ = !0, k = !0;
					return;
				}
				let Y = z, q = null, ae = /* @__PURE__ */ new Set();
				do {
					if (Y.kind !== "function" || Y.value !== "var") return;
					let oe = Y.nodes[0];
					if (!oe || oe.kind !== "word") return;
					let l = oe.value;
					if (ae.has(l)) {
						L = !0;
						return;
					}
					if (ae.add(l), k = !0, q = r.theme.resolveValue(null, [oe.value]), !q) {
						L = !0;
						return;
					}
					if (q.toLowerCase() === "currentcolor") {
						_ = !0;
						return;
					}
					q.startsWith("var(") ? Y = B(q)[0] : Y = null;
				} while (Y);
				return E.Replace({
					kind: "word",
					value: q
				});
			}), L || _) {
				let z = O.nodes.findIndex((q) => q.kind === "separator" && q.value.trim().includes(","));
				if (z === -1) return;
				let Y = O.nodes.length > z ? O.nodes[z + 1] : null;
				return Y ? E.Replace(Y) : void 0;
			} else if (k) {
				let z = O.nodes[2];
				z.kind === "word" && (z.value === "oklab" || z.value === "oklch" || z.value === "lab" || z.value === "lch") && (z.value = "srgb");
			}
		}), !k) continue;
		let U = {
			...x,
			value: Z(A)
		}, N = J("@supports (color: color-mix(in lab, red, red))", [x]);
		N.src = x.src, h.splice($, 1, U, N);
	}
	if (i & 1) {
		let h = [];
		if (f.length > 0) {
			let y = J(":root, :host", f);
			y.src = f[0].src, h.push(y);
		}
		if (m.length > 0) {
			let y = J("*, ::before, ::after, ::backdrop", m);
			y.src = m[0].src, h.push(y);
		}
		if (h.length > 0) {
			let y = w.findIndex((A) => !(A.kind === "comment" || A.kind === "at-rule" && (A.name === "@charset" || A.name === "@import"))), x = F("@layer", "properties", []);
			x.src = h[0].src, w.splice(y < 0 ? w.length : y, 0, x);
			let $ = J("@layer properties", [F("@supports", "((-webkit-hyphens: none) and (not (margin-trim: inline))) or ((-moz-orient: inline) and (not (color:rgb(from red r g b))))", h)]);
			$.src = h[0].src, $.nodes[0].src = h[0].src, w.push($);
		}
	}
	return w;
}
function re(t, r) {
	let i = 0, e = {
		file: null,
		code: ""
	};
	function n(a, p = 0) {
		let u = "", f = "  ".repeat(p);
		if (a.kind === "declaration") {
			if (u += `${f}${a.property}: ${a.value}${a.important ? " !important" : ""};
`, r) {
				var _a$value;
				i += f.length;
				let m = i;
				i += a.property.length, i += 2, i += ((_a$value = a.value) === null || _a$value === void 0 ? void 0 : _a$value.length) ?? 0, a.important && (i += 11);
				let d = i;
				i += 2, a.dst = [
					e,
					m,
					d
				];
			}
		} else if (a.kind === "rule") {
			if (u += `${f}${a.selector} {
`, r) {
				i += f.length;
				let m = i;
				i += a.selector.length, i += 1;
				a.dst = [
					e,
					m,
					i
				], i += 2;
			}
			for (let m of a.nodes) u += n(m, p + 1);
			u += `${f}}
`, r && (i += f.length, i += 2);
		} else if (a.kind === "at-rule") {
			if (a.nodes.length === 0) {
				let m = `${f}${a.name} ${a.params};
`;
				if (r) {
					i += f.length;
					let d = i;
					i += a.name.length, i += 1, i += a.params.length;
					let c = i;
					i += 2, a.dst = [
						e,
						d,
						c
					];
				}
				return m;
			}
			if (u += `${f}${a.name}${a.params ? ` ${a.params} ` : " "}{
`, r) {
				i += f.length;
				let m = i;
				i += a.name.length, a.params && (i += 1, i += a.params.length), i += 1;
				a.dst = [
					e,
					m,
					i
				], i += 2;
			}
			for (let m of a.nodes) u += n(m, p + 1);
			u += `${f}}
`, r && (i += f.length, i += 2);
		} else if (a.kind === "comment") {
			if (u += `${f}/*${a.value}*/
`, r) {
				i += f.length;
				let m = i;
				i += 2 + a.value.length + 2;
				a.dst = [
					e,
					m,
					i
				], i += 1;
			}
		} else if (a.kind === "context" || a.kind === "at-root") return "";
		return u;
	}
	let s = "";
	for (let a of t) s += n(a, 0);
	return e.code = s, s;
}
function an(t, r) {
	let i = [];
	return I(t, (e, n) => {
		if (r(e)) return i = n.path(), i.push(e), E.Stop;
	}), i;
}
function Ar(t, r, i, e = /* @__PURE__ */ new Set()) {
	if (e.has(t) || (e.add(t), r.getOptions(t) & 24)) return !0;
	{
		let s = i.get(t) ?? [];
		for (let a of s) if (Ar(a, r, i, e)) return !0;
	}
	return !1;
}
function xr(t) {
	return t.split(/[\s,]+/);
}
function ke(t) {
	if (t.indexOf("(") === -1) return Ie(t);
	let r = B(t);
	return Ot(r), t = Z(r), t = oe(t), t;
}
function Ie(t, r = !1) {
	let i = "";
	for (let e = 0; e < t.length; e++) {
		let n = t[e];
		n === "\\" && t[e + 1] === "_" ? (i += "_", e += 1) : n === "_" && !r ? i += " " : i += n;
	}
	return i;
}
function Ot(t) {
	for (let r of t) switch (r.kind) {
		case "function":
			if (r.value === "url" || r.value.endsWith("_url")) {
				r.value = Ie(r.value);
				break;
			}
			if (r.value === "var" || r.value.endsWith("_var") || r.value === "theme" || r.value.endsWith("_theme")) {
				r.value = Ie(r.value);
				for (let i = 0; i < r.nodes.length; i++) {
					if (i == 0 && r.nodes[i].kind === "word") {
						r.nodes[i].value = Ie(r.nodes[i].value, !0);
						continue;
					}
					Ot([r.nodes[i]]);
				}
				break;
			}
			r.value = Ie(r.value), Ot(r.nodes);
			break;
		case "separator":
		case "word":
			r.value = Ie(r.value);
			break;
		default: on(r);
	}
}
function on(t) {
	throw new Error(`Unexpected value: ${t}`);
}
var Pt = new Uint8Array(256);
function he(t) {
	let r = 0, i = t.length;
	for (let e = 0; e < i; e++) {
		let n = t.charCodeAt(e);
		switch (n) {
			case 92:
				e += 1;
				break;
			case 39:
			case 34:
				for (; ++e < i;) {
					let s = t.charCodeAt(e);
					if (s === 92) {
						e += 1;
						continue;
					}
					if (s === n) break;
				}
				break;
			case 40:
				Pt[r] = 41, r++;
				break;
			case 91:
				Pt[r] = 93, r++;
				break;
			case 123: break;
			case 93:
			case 125:
			case 41:
				if (r === 0) return !1;
				r > 0 && n === Pt[r - 1] && r--;
				break;
			case 59:
				if (r === 0) return !1;
				break;
		}
	}
	return !0;
}
var ln = 58, Cr = 45, $r = 97, Sr = 122, Dt = /^[a-zA-Z0-9_.%-]+$/;
function Tr(t) {
	switch (t.kind) {
		case "arbitrary": return {
			kind: t.kind,
			property: t.property,
			value: t.value,
			modifier: t.modifier ? {
				kind: t.modifier.kind,
				value: t.modifier.value
			} : null,
			variants: t.variants.map(_e),
			important: t.important,
			raw: t.raw
		};
		case "static": return {
			kind: t.kind,
			root: t.root,
			variants: t.variants.map(_e),
			important: t.important,
			raw: t.raw
		};
		case "functional": return {
			kind: t.kind,
			root: t.root,
			value: t.value ? t.value.kind === "arbitrary" ? {
				kind: t.value.kind,
				dataType: t.value.dataType,
				value: t.value.value
			} : {
				kind: t.value.kind,
				value: t.value.value,
				fraction: t.value.fraction
			} : null,
			modifier: t.modifier ? {
				kind: t.modifier.kind,
				value: t.modifier.value
			} : null,
			variants: t.variants.map(_e),
			important: t.important,
			raw: t.raw
		};
		default: throw new Error("Unknown candidate kind");
	}
}
function _e(t) {
	switch (t.kind) {
		case "arbitrary": return {
			kind: t.kind,
			selector: t.selector,
			relative: t.relative
		};
		case "static": return {
			kind: t.kind,
			root: t.root
		};
		case "functional": return {
			kind: t.kind,
			root: t.root,
			value: t.value ? {
				kind: t.value.kind,
				value: t.value.value
			} : null,
			modifier: t.modifier ? {
				kind: t.modifier.kind,
				value: t.modifier.value
			} : null
		};
		case "compound": return {
			kind: t.kind,
			root: t.root,
			variant: _e(t.variant),
			modifier: t.modifier ? {
				kind: t.modifier.kind,
				value: t.modifier.value
			} : null
		};
		default: throw new Error("Unknown variant kind");
	}
}
function* Vr(t, r) {
	let i = d(t, ":");
	if (r.theme.prefix) {
		if (i.length === 1 || i[0] !== r.theme.prefix) return null;
		i.shift();
	}
	let e = i.pop(), n = [];
	for (let d = i.length - 1; d >= 0; --d) {
		let c = r.parseVariant(i[d]);
		if (c === null) return;
		n.push(c);
	}
	let s = !1;
	e[e.length - 1] === "!" ? (s = !0, e = e.slice(0, -1)) : e[0] === "!" && (s = !0, e = e.slice(1)), r.utilities.has(e, "static") && !e.includes("[") && (yield {
		kind: "static",
		root: e,
		variants: n,
		important: s,
		raw: t
	});
	let [a, p = null, u] = d(e, "/");
	if (u) return;
	let f = p === null ? null : It(p);
	if (p !== null && f === null) return;
	if (a[0] === "[") {
		if (a[a.length - 1] !== "]") return;
		let d = a.charCodeAt(1);
		if (d !== Cr && !(d >= $r && d <= Sr)) return;
		a = a.slice(1, -1);
		let c = a.indexOf(":");
		if (c === -1 || c === 0 || c === a.length - 1) return;
		let w = a.slice(0, c), h = ke(a.slice(c + 1));
		if (!he(h)) return;
		yield {
			kind: "arbitrary",
			property: w,
			value: h,
			modifier: f,
			variants: n,
			important: s,
			raw: t
		};
		return;
	}
	let m;
	if (a[a.length - 1] === "]") {
		let d = a.indexOf("-[");
		if (d === -1) return;
		let c = a.slice(0, d);
		if (!r.utilities.has(c, "functional")) return;
		m = [[c, a.slice(d + 1)]];
	} else if (a[a.length - 1] === ")") {
		let d$1 = a.indexOf("-(");
		if (d$1 === -1) return;
		let c = a.slice(0, d$1);
		if (!r.utilities.has(c, "functional")) return;
		let w = a.slice(d$1 + 2, -1), h = d(w, ":"), y = null;
		if (h.length === 2 && (y = h[0], w = h[1]), w[0] !== "-" || w[1] !== "-" || !he(w)) return;
		m = [[c, y === null ? `[var(${w})]` : `[${y}:var(${w})]`]];
	} else m = Er(a, (d) => r.utilities.has(d, "functional"));
	for (let [d, c] of m) {
		let w = {
			kind: "functional",
			root: d,
			modifier: f,
			value: null,
			variants: n,
			important: s,
			raw: t
		};
		if (c === null) {
			yield w;
			continue;
		}
		{
			let h = c.indexOf("[");
			if (h !== -1) {
				if (c[c.length - 1] !== "]") return;
				let x = ke(c.slice(h + 1, -1));
				if (!he(x)) continue;
				let $ = null;
				for (let A = 0; A < x.length; A++) {
					let k = x.charCodeAt(A);
					if (k === ln) {
						$ = x.slice(0, A), x = x.slice(A + 1);
						break;
					}
					if (!(k === Cr || k >= $r && k <= Sr)) break;
				}
				if (x.length === 0 || x.trim().length === 0 || $ === "") continue;
				w.value = {
					kind: "arbitrary",
					dataType: $ || null,
					value: x
				};
			} else {
				var _w$modifier;
				let x = p === null || ((_w$modifier = w.modifier) === null || _w$modifier === void 0 ? void 0 : _w$modifier.kind) === "arbitrary" ? null : `${c}/${p}`;
				if (!Dt.test(c)) continue;
				w.value = {
					kind: "named",
					value: c,
					fraction: x
				};
			}
		}
		yield w;
	}
}
function It(t) {
	if (t[0] === "[" && t[t.length - 1] === "]") {
		let r = ke(t.slice(1, -1));
		return !he(r) || r.length === 0 || r.trim().length === 0 ? null : {
			kind: "arbitrary",
			value: r
		};
	}
	return t[0] === "(" && t[t.length - 1] === ")" ? (t = t.slice(1, -1), t[0] !== "-" || t[1] !== "-" || !he(t) ? null : (t = `var(${t})`, {
		kind: "arbitrary",
		value: ke(t)
	})) : Dt.test(t) ? {
		kind: "named",
		value: t
	} : null;
}
function Nr(t, r) {
	if (t[0] === "[" && t[t.length - 1] === "]") {
		if (t[1] === "@" && t.includes("&")) return null;
		let i = ke(t.slice(1, -1));
		if (!he(i) || i.length === 0 || i.trim().length === 0) return null;
		let e = i[0] === ">" || i[0] === "+" || i[0] === "~";
		return !e && i[0] !== "@" && !i.includes("&") && (i = `&:is(${i})`), {
			kind: "arbitrary",
			selector: i,
			relative: e
		};
	}
	{
		let [i, e = null, n] = d(t, "/");
		if (n) return null;
		let s = Er(i, (a) => r.variants.has(a));
		for (let [a, p] of s) switch (r.variants.kind(a)) {
			case "static": return p !== null || e !== null ? null : {
				kind: "static",
				root: a
			};
			case "functional": {
				let u = e === null ? null : It(e);
				if (e !== null && u === null) return null;
				if (p === null) return {
					kind: "functional",
					root: a,
					modifier: u,
					value: null
				};
				if (p[p.length - 1] === "]") {
					if (p[0] !== "[") continue;
					let f = ke(p.slice(1, -1));
					return !he(f) || f.length === 0 || f.trim().length === 0 ? null : {
						kind: "functional",
						root: a,
						modifier: u,
						value: {
							kind: "arbitrary",
							value: f
						}
					};
				}
				if (p[p.length - 1] === ")") {
					if (p[0] !== "(") continue;
					let f = ke(p.slice(1, -1));
					return !he(f) || f.length === 0 || f.trim().length === 0 || f[0] !== "-" || f[1] !== "-" ? null : {
						kind: "functional",
						root: a,
						modifier: u,
						value: {
							kind: "arbitrary",
							value: `var(${f})`
						}
					};
				}
				if (!Dt.test(p)) continue;
				return {
					kind: "functional",
					root: a,
					modifier: u,
					value: {
						kind: "named",
						value: p
					}
				};
			}
			case "compound": {
				if (p === null) return null;
				e && (a === "not" || a === "has" || a === "in") && (p = `${p}/${e}`, e = null);
				let u = r.parseVariant(p);
				if (u === null || !r.variants.compoundsWith(a, u)) return null;
				let f = e === null ? null : It(e);
				return e !== null && f === null ? null : {
					kind: "compound",
					root: a,
					modifier: f,
					variant: u
				};
			}
		}
	}
	return null;
}
function* Er(t, r) {
	r(t) && (yield [t, null]);
	let i = t.lastIndexOf("-");
	for (; i > 0;) {
		let e = t.slice(0, i);
		if (r(e)) {
			let n = [e, t.slice(i + 1)];
			if (n[1] === "" || n[0] === "@" && r("@") && t[i] === "-") break;
			yield n;
		}
		i = t.lastIndexOf("-", i - 1);
	}
	t[0] === "@" && r("@") && (yield ["@", t.slice(1)]);
}
function Rr(t, r) {
	let i = [];
	for (let n of r.variants) i.unshift(ut(n));
	t.theme.prefix && i.unshift(t.theme.prefix);
	let e = "";
	if (r.kind === "static" && (e += r.root), r.kind === "functional" && (e += r.root, r.value)) if (r.value.kind === "arbitrary") {
		if (r.value !== null) {
			let n = Kt(r.value.value), s = n ? r.value.value.slice(4, -1) : r.value.value, [a, p] = n ? ["(", ")"] : ["[", "]"];
			r.value.dataType ? e += `-${a}${r.value.dataType}:${be(s)}${p}` : e += `-${a}${be(s)}${p}`;
		}
	} else r.value.kind === "named" && (e += `-${r.value.value}`);
	return r.kind === "arbitrary" && (e += `[${r.property}:${be(r.value)}]`), (r.kind === "arbitrary" || r.kind === "functional") && (e += He(r.modifier)), r.important && (e += "!"), i.push(e), i.join(":");
}
function He(t) {
	if (t === null) return "";
	let r = Kt(t.value), i = r ? t.value.slice(4, -1) : t.value, [e, n] = r ? ["(", ")"] : ["[", "]"];
	return t.kind === "arbitrary" ? `/${e}${be(i)}${n}` : t.kind === "named" ? `/${t.value}` : "";
}
function ut(t) {
	if (t.kind === "static") return t.root;
	if (t.kind === "arbitrary") return `[${be(fn(t.selector))}]`;
	let r = "";
	if (t.kind === "functional") {
		r += t.root;
		let i = t.root !== "@";
		if (t.value) if (t.value.kind === "arbitrary") {
			let e = Kt(t.value.value), n = e ? t.value.value.slice(4, -1) : t.value.value, [s, a] = e ? ["(", ")"] : ["[", "]"];
			r += `${i ? "-" : ""}${s}${be(n)}${a}`;
		} else t.value.kind === "named" && (r += `${i ? "-" : ""}${t.value.value}`);
	}
	return t.kind === "compound" && (r += t.root, r += "-", r += ut(t.variant)), (t.kind === "functional" || t.kind === "compound") && (r += He(t.modifier)), r;
}
var sn = new K((t) => {
	let r = B(t), i = /* @__PURE__ */ new Set();
	return I(r, (e, n) => {
		let s = n.parent === null ? r : n.parent.nodes ?? [];
		if (e.kind === "word" && (e.value === "+" || e.value === "-" || e.value === "*" || e.value === "/")) {
			let a = s.indexOf(e) ?? -1;
			if (a === -1) return;
			let p = s[a - 1];
			if ((p === null || p === void 0 ? void 0 : p.kind) !== "separator" || p.value !== " ") return;
			let u = s[a + 1];
			if ((u === null || u === void 0 ? void 0 : u.kind) !== "separator" || u.value !== " ") return;
			i.add(p), i.add(u);
		} else e.kind === "separator" && e.value.length > 0 && e.value.trim() === "" ? (s[0] === e || s[s.length - 1] === e) && i.add(e) : e.kind === "separator" && e.value.trim() === "," && (e.value = ",");
	}), i.size > 0 && I(r, (e) => {
		if (i.has(e)) return i.delete(e), E.ReplaceSkip([]);
	}), _t(r), Z(r);
});
function be(t) {
	return sn.get(t);
}
var un = new K((t) => {
	let r = B(t);
	return r.length === 3 && r[0].kind === "word" && r[0].value === "&" && r[1].kind === "separator" && r[1].value === ":" && r[2].kind === "function" && r[2].value === "is" ? Z(r[2].nodes) : t;
});
function fn(t) {
	return un.get(t);
}
function _t(t) {
	for (let r of t) switch (r.kind) {
		case "function":
			if (r.value === "url" || r.value.endsWith("_url")) {
				r.value = Ze(r.value);
				break;
			}
			if (r.value === "var" || r.value.endsWith("_var") || r.value === "theme" || r.value.endsWith("_theme")) {
				r.value = Ze(r.value);
				for (let i = 0; i < r.nodes.length; i++) _t([r.nodes[i]]);
				break;
			}
			r.value = Ze(r.value), _t(r.nodes);
			break;
		case "separator":
			r.value = Ze(r.value);
			break;
		case "word":
			(r.value[0] !== "-" || r.value[1] !== "-") && (r.value = Ze(r.value));
			break;
		default: pn(r);
	}
}
var cn = new K((t) => {
	let r = B(t);
	return r.length === 1 && r[0].kind === "function" && r[0].value === "var";
});
function Kt(t) {
	return cn.get(t);
}
function pn(t) {
	throw new Error(`Unexpected value: ${t}`);
}
function Ze(t) {
	return t.replaceAll("_", String.raw`\_`).replaceAll(" ", "_");
}
function Ve(t, r, i) {
	if (t === r) return 0;
	let e = t.indexOf("("), n = r.indexOf("("), s = e === -1 ? t.replace(/[\d.]+/g, "") : t.slice(0, e), a = n === -1 ? r.replace(/[\d.]+/g, "") : r.slice(0, n), p = (s === a ? 0 : s < a ? -1 : 1) || (i === "asc" ? parseInt(t) - parseInt(r) : parseInt(r) - parseInt(t));
	return Number.isNaN(p) ? t < r ? -1 : 1 : p;
}
var dn = new Set([
	"inset",
	"inherit",
	"initial",
	"revert",
	"unset"
]), Or = /^-?(\d+|\.\d+)(.*?)$/g;
function Je(t, r) {
	return d(t, ",").map((e) => {
		e = e.trim();
		let n = d(e, " ").filter((f) => f.trim() !== ""), s = null, a = null, p = null;
		for (let f of n) dn.has(f) || (Or.test(f) ? (a === null ? a = f : p === null && (p = f), Or.lastIndex = 0) : s === null && (s = f));
		if (a === null || p === null) return e;
		let u = r(s ?? "currentcolor");
		return s !== null ? e.replace(s, u) : `${e} ${u}`;
	}).join(", ");
}
var gn = /^-?[a-z][a-zA-Z0-9/%._-]*$/, hn = /^-?[a-z][a-zA-Z0-9/%._-]*-\*$/, ct = [
	"0",
	"0.5",
	"1",
	"1.5",
	"2",
	"2.5",
	"3",
	"3.5",
	"4",
	"5",
	"6",
	"7",
	"8",
	"9",
	"10",
	"11",
	"12",
	"14",
	"16",
	"20",
	"24",
	"28",
	"32",
	"36",
	"40",
	"44",
	"48",
	"52",
	"56",
	"60",
	"64",
	"72",
	"80",
	"96"
], Ut = class {
	utilities = new K(() => []);
	completions = /* @__PURE__ */ new Map();
	static(r, i) {
		this.utilities.get(r).push({
			kind: "static",
			compileFn: i
		});
	}
	functional(r, i, e) {
		this.utilities.get(r).push({
			kind: "functional",
			compileFn: i,
			options: e
		});
	}
	has(r, i) {
		return this.utilities.has(r) && this.utilities.get(r).some((e) => e.kind === i);
	}
	get(r) {
		return this.utilities.has(r) ? this.utilities.get(r) : [];
	}
	getCompletions(r) {
		var _this$completions$get, _this$completions$get2;
		return this.has(r, "static") ? ((_this$completions$get = this.completions.get(r)) === null || _this$completions$get === void 0 ? void 0 : _this$completions$get()) ?? [{
			supportsNegative: !1,
			values: [],
			modifiers: []
		}] : ((_this$completions$get2 = this.completions.get(r)) === null || _this$completions$get2 === void 0 ? void 0 : _this$completions$get2()) ?? [];
	}
	suggest(r, i) {
		let e = this.completions.get(r);
		e ? this.completions.set(r, () => [...e === null || e === void 0 ? void 0 : e(), ...i === null || i === void 0 ? void 0 : i()]) : this.completions.set(r, i);
	}
	keys(r) {
		let i = [];
		for (let [e, n] of this.utilities.entries()) for (let s of n) if (s.kind === r) {
			i.push(e);
			break;
		}
		return i;
	}
};
function S(t, r, i) {
	return F("@property", t, [
		o("syntax", i ? `"${i}"` : "\"*\""),
		o("inherits", "false"),
		...r ? [o("initial-value", r)] : []
	]);
}
function Q(t, r) {
	if (r === null) return t;
	let i = Number(r);
	return Number.isNaN(i) || (r = `${i * 100}%`), r === "100%" ? t : `color-mix(in oklab, ${t} ${r}, transparent)`;
}
function Ir(t, r) {
	let i = Number(r);
	return Number.isNaN(i) || (r = `${i * 100}%`), `oklab(from ${t} l a b / ${r})`;
}
function X(t, r, i) {
	if (!r) return t;
	if (r.kind === "arbitrary") return Q(t, r.value);
	let e = i.resolve(r.value, ["--opacity"]);
	return e ? Q(t, e) : ue$1(r.value) ? Q(t, `${r.value}%`) : null;
}
function te(t, r, i) {
	let e = null;
	switch (t.value.value) {
		case "inherit":
			e = "inherit";
			break;
		case "transparent":
			e = "transparent";
			break;
		case "current":
			e = "currentcolor";
			break;
		default:
			e = r.resolve(t.value.value, i);
			break;
	}
	return e ? X(e, t.modifier, r) : null;
}
var _r = /(\d+)_(\d+)/g;
function Dr(t) {
	let r = new Ut();
	function i(l, g) {
		function* v(b) {
			for (let T of t.keysInNamespaces(b)) yield T.replace(_r, (D, V, R) => `${V}.${R}`);
		}
		let C = [
			"1/2",
			"1/3",
			"2/3",
			"1/4",
			"2/4",
			"3/4",
			"1/5",
			"2/5",
			"3/5",
			"4/5",
			"1/6",
			"2/6",
			"3/6",
			"4/6",
			"5/6",
			"1/12",
			"2/12",
			"3/12",
			"4/12",
			"5/12",
			"6/12",
			"7/12",
			"8/12",
			"9/12",
			"10/12",
			"11/12"
		];
		r.suggest(l, () => {
			let b = [];
			for (let T of g()) {
				if (typeof T == "string") {
					b.push({
						values: [T],
						modifiers: []
					});
					continue;
				}
				let D = [...T.values ?? [], ...v(T.valueThemeKeys ?? [])], V = [...T.modifiers ?? [], ...v(T.modifierThemeKeys ?? [])];
				T.supportsFractions && D.push(...C), T.hasDefaultValue && D.unshift(null), b.push({
					supportsNegative: T.supportsNegative,
					values: D,
					modifiers: V
				});
			}
			return b;
		});
	}
	function e(l, g) {
		r.static(l, () => g.map((v) => typeof v == "function" ? v() : o(v[0], v[1])));
	}
	function n(l, g) {
		function v({ negative: C }) {
			return (b) => {
				let T = null, D = null;
				if (b.value) if (b.value.kind === "arbitrary") {
					if (b.modifier) return;
					T = b.value.value, D = b.value.dataType;
				} else {
					if (T = t.resolve(b.value.fraction ?? b.value.value, g.themeKeys ?? []), T === null && g.supportsFractions && b.value.fraction) {
						let [V, R] = d(b.value.fraction, "/");
						if (!u(V) || !u(R)) return;
						T = `calc(${b.value.fraction} * 100%)`;
					}
					if (T === null && C && g.handleNegativeBareValue) {
						if (T = g.handleNegativeBareValue(b.value), !(T === null || T === void 0 ? void 0 : T.includes("/")) && b.modifier) return;
						if (T !== null) return g.handle(T, null);
					}
					if (T === null && g.handleBareValue && (T = g.handleBareValue(b.value), !(T === null || T === void 0 ? void 0 : T.includes("/")) && b.modifier)) return;
					if (T === null && !C && g.staticValues && !b.modifier) {
						let V = g.staticValues[b.value.value];
						if (V) return V.map(ee);
					}
				}
				else {
					if (b.modifier) return;
					T = g.defaultValue !== void 0 ? g.defaultValue : t.resolve(null, g.themeKeys ?? []);
				}
				if (T !== null) return g.handle(C ? `calc(${T} * -1)` : T, D);
			};
		}
		if (g.supportsNegative && r.functional(`-${l}`, v({ negative: !0 })), r.functional(l, v({ negative: !1 })), i(l, () => [{
			supportsNegative: g.supportsNegative,
			valueThemeKeys: g.themeKeys ?? [],
			hasDefaultValue: g.defaultValue !== void 0 && g.defaultValue !== null,
			supportsFractions: g.supportsFractions
		}]), g.staticValues && Object.keys(g.staticValues).length > 0) {
			let C = Object.keys(g.staticValues);
			i(l, () => [{ values: C }]);
		}
	}
	function s(l, g) {
		r.functional(l, (v) => {
			if (!v.value) return;
			let C = null;
			if (v.value.kind === "arbitrary" ? (C = v.value.value, C = X(C, v.modifier, t)) : C = te(v, t, g.themeKeys), C !== null) return g.handle(C);
		}), i(l, () => [{
			values: [
				"current",
				"inherit",
				"transparent"
			],
			valueThemeKeys: g.themeKeys,
			modifiers: Array.from({ length: 21 }, (v, C) => `${C * 5}`)
		}]);
	}
	function a(l, g, v, { supportsNegative: C = !1, supportsFractions: b = !1, staticValues: T } = {}) {
		C && r.static(`-${l}-px`, () => v("-1px")), r.static(`${l}-px`, () => v("1px")), n(l, {
			themeKeys: g,
			supportsFractions: b,
			supportsNegative: C,
			defaultValue: null,
			handleBareValue: ({ value: D }) => {
				let V = t.resolve(null, ["--spacing"]);
				return !V || !ge(D) ? null : `calc(${V} * ${D})`;
			},
			handleNegativeBareValue: ({ value: D }) => {
				let V = t.resolve(null, ["--spacing"]);
				return !V || !ge(D) ? null : `calc(${V} * -${D})`;
			},
			handle: v,
			staticValues: T
		}), i(l, () => [{
			values: t.get(["--spacing"]) ? ct : [],
			supportsNegative: C,
			supportsFractions: b,
			valueThemeKeys: g
		}]);
	}
	e("sr-only", [
		["position", "absolute"],
		["width", "1px"],
		["height", "1px"],
		["padding", "0"],
		["margin", "-1px"],
		["overflow", "hidden"],
		["clip-path", "inset(50%)"],
		["white-space", "nowrap"],
		["border-width", "0"]
	]), e("not-sr-only", [
		["position", "static"],
		["width", "auto"],
		["height", "auto"],
		["padding", "0"],
		["margin", "0"],
		["overflow", "visible"],
		["clip-path", "none"],
		["white-space", "normal"]
	]), e("pointer-events-none", [["pointer-events", "none"]]), e("pointer-events-auto", [["pointer-events", "auto"]]), e("visible", [["visibility", "visible"]]), e("invisible", [["visibility", "hidden"]]), e("collapse", [["visibility", "collapse"]]), e("static", [["position", "static"]]), e("fixed", [["position", "fixed"]]), e("absolute", [["position", "absolute"]]), e("relative", [["position", "relative"]]), e("sticky", [["position", "sticky"]]);
	for (let [l, g] of [
		["inset", "inset"],
		["inset-x", "inset-inline"],
		["inset-y", "inset-block"],
		["start", "inset-inline-start"],
		["end", "inset-inline-end"],
		["top", "top"],
		["right", "right"],
		["bottom", "bottom"],
		["left", "left"]
	]) e(`${l}-auto`, [[g, "auto"]]), e(`${l}-full`, [[g, "100%"]]), e(`-${l}-full`, [[g, "-100%"]]), a(l, ["--inset", "--spacing"], (v) => [o(g, v)], {
		supportsNegative: !0,
		supportsFractions: !0
	});
	e("isolate", [["isolation", "isolate"]]), e("isolation-auto", [["isolation", "auto"]]), n("z", {
		supportsNegative: !0,
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		themeKeys: ["--z-index"],
		handle: (l) => [o("z-index", l)],
		staticValues: { auto: [o("z-index", "auto")] }
	}), i("z", () => [{
		supportsNegative: !0,
		values: [
			"0",
			"10",
			"20",
			"30",
			"40",
			"50"
		],
		valueThemeKeys: ["--z-index"]
	}]), n("order", {
		supportsNegative: !0,
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		themeKeys: ["--order"],
		handle: (l) => [o("order", l)],
		staticValues: {
			first: [o("order", "-9999")],
			last: [o("order", "9999")]
		}
	}), i("order", () => [{
		supportsNegative: !0,
		values: Array.from({ length: 12 }, (l, g) => `${g + 1}`),
		valueThemeKeys: ["--order"]
	}]), n("col", {
		supportsNegative: !0,
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		themeKeys: ["--grid-column"],
		handle: (l) => [o("grid-column", l)],
		staticValues: { auto: [o("grid-column", "auto")] }
	}), n("col-span", {
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		handle: (l) => [o("grid-column", `span ${l} / span ${l}`)],
		staticValues: { full: [o("grid-column", "1 / -1")] }
	}), n("col-start", {
		supportsNegative: !0,
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		themeKeys: ["--grid-column-start"],
		handle: (l) => [o("grid-column-start", l)],
		staticValues: { auto: [o("grid-column-start", "auto")] }
	}), n("col-end", {
		supportsNegative: !0,
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		themeKeys: ["--grid-column-end"],
		handle: (l) => [o("grid-column-end", l)],
		staticValues: { auto: [o("grid-column-end", "auto")] }
	}), i("col-span", () => [{
		values: Array.from({ length: 12 }, (l, g) => `${g + 1}`),
		valueThemeKeys: []
	}]), i("col-start", () => [{
		supportsNegative: !0,
		values: Array.from({ length: 13 }, (l, g) => `${g + 1}`),
		valueThemeKeys: ["--grid-column-start"]
	}]), i("col-end", () => [{
		supportsNegative: !0,
		values: Array.from({ length: 13 }, (l, g) => `${g + 1}`),
		valueThemeKeys: ["--grid-column-end"]
	}]), n("row", {
		supportsNegative: !0,
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		themeKeys: ["--grid-row"],
		handle: (l) => [o("grid-row", l)],
		staticValues: { auto: [o("grid-row", "auto")] }
	}), n("row-span", {
		themeKeys: [],
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		handle: (l) => [o("grid-row", `span ${l} / span ${l}`)],
		staticValues: { full: [o("grid-row", "1 / -1")] }
	}), n("row-start", {
		supportsNegative: !0,
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		themeKeys: ["--grid-row-start"],
		handle: (l) => [o("grid-row-start", l)],
		staticValues: { auto: [o("grid-row-start", "auto")] }
	}), n("row-end", {
		supportsNegative: !0,
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		themeKeys: ["--grid-row-end"],
		handle: (l) => [o("grid-row-end", l)],
		staticValues: { auto: [o("grid-row-end", "auto")] }
	}), i("row-span", () => [{
		values: Array.from({ length: 12 }, (l, g) => `${g + 1}`),
		valueThemeKeys: []
	}]), i("row-start", () => [{
		supportsNegative: !0,
		values: Array.from({ length: 13 }, (l, g) => `${g + 1}`),
		valueThemeKeys: ["--grid-row-start"]
	}]), i("row-end", () => [{
		supportsNegative: !0,
		values: Array.from({ length: 13 }, (l, g) => `${g + 1}`),
		valueThemeKeys: ["--grid-row-end"]
	}]), e("float-start", [["float", "inline-start"]]), e("float-end", [["float", "inline-end"]]), e("float-right", [["float", "right"]]), e("float-left", [["float", "left"]]), e("float-none", [["float", "none"]]), e("clear-start", [["clear", "inline-start"]]), e("clear-end", [["clear", "inline-end"]]), e("clear-right", [["clear", "right"]]), e("clear-left", [["clear", "left"]]), e("clear-both", [["clear", "both"]]), e("clear-none", [["clear", "none"]]);
	for (let [l, g] of [
		["m", "margin"],
		["mx", "margin-inline"],
		["my", "margin-block"],
		["ms", "margin-inline-start"],
		["me", "margin-inline-end"],
		["mt", "margin-top"],
		["mr", "margin-right"],
		["mb", "margin-bottom"],
		["ml", "margin-left"]
	]) e(`${l}-auto`, [[g, "auto"]]), a(l, ["--margin", "--spacing"], (v) => [o(g, v)], { supportsNegative: !0 });
	e("box-border", [["box-sizing", "border-box"]]), e("box-content", [["box-sizing", "content-box"]]), n("line-clamp", {
		themeKeys: ["--line-clamp"],
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		handle: (l) => [
			o("overflow", "hidden"),
			o("display", "-webkit-box"),
			o("-webkit-box-orient", "vertical"),
			o("-webkit-line-clamp", l)
		],
		staticValues: { none: [
			o("overflow", "visible"),
			o("display", "block"),
			o("-webkit-box-orient", "horizontal"),
			o("-webkit-line-clamp", "unset")
		] }
	}), i("line-clamp", () => [{
		values: [
			"1",
			"2",
			"3",
			"4",
			"5",
			"6"
		],
		valueThemeKeys: ["--line-clamp"]
	}]), e("block", [["display", "block"]]), e("inline-block", [["display", "inline-block"]]), e("inline", [["display", "inline"]]), e("hidden", [["display", "none"]]), e("inline-flex", [["display", "inline-flex"]]), e("table", [["display", "table"]]), e("inline-table", [["display", "inline-table"]]), e("table-caption", [["display", "table-caption"]]), e("table-cell", [["display", "table-cell"]]), e("table-column", [["display", "table-column"]]), e("table-column-group", [["display", "table-column-group"]]), e("table-footer-group", [["display", "table-footer-group"]]), e("table-header-group", [["display", "table-header-group"]]), e("table-row-group", [["display", "table-row-group"]]), e("table-row", [["display", "table-row"]]), e("flow-root", [["display", "flow-root"]]), e("flex", [["display", "flex"]]), e("grid", [["display", "grid"]]), e("inline-grid", [["display", "inline-grid"]]), e("contents", [["display", "contents"]]), e("list-item", [["display", "list-item"]]), e("field-sizing-content", [["field-sizing", "content"]]), e("field-sizing-fixed", [["field-sizing", "fixed"]]), n("aspect", {
		themeKeys: ["--aspect"],
		handleBareValue: ({ fraction: l }) => {
			if (l === null) return null;
			let [g, v] = d(l, "/");
			return !u(g) || !u(v) ? null : l;
		},
		handle: (l) => [o("aspect-ratio", l)],
		staticValues: {
			auto: [o("aspect-ratio", "auto")],
			square: [o("aspect-ratio", "1 / 1")]
		}
	});
	for (let [l, g] of [
		["full", "100%"],
		["svw", "100svw"],
		["lvw", "100lvw"],
		["dvw", "100dvw"],
		["svh", "100svh"],
		["lvh", "100lvh"],
		["dvh", "100dvh"],
		["min", "min-content"],
		["max", "max-content"],
		["fit", "fit-content"]
	]) e(`size-${l}`, [
		["--tw-sort", "size"],
		["width", g],
		["height", g]
	]), e(`w-${l}`, [["width", g]]), e(`h-${l}`, [["height", g]]), e(`min-w-${l}`, [["min-width", g]]), e(`min-h-${l}`, [["min-height", g]]), e(`max-w-${l}`, [["max-width", g]]), e(`max-h-${l}`, [["max-height", g]]);
	e("size-auto", [
		["--tw-sort", "size"],
		["width", "auto"],
		["height", "auto"]
	]), e("w-auto", [["width", "auto"]]), e("h-auto", [["height", "auto"]]), e("min-w-auto", [["min-width", "auto"]]), e("min-h-auto", [["min-height", "auto"]]), e("h-lh", [["height", "1lh"]]), e("min-h-lh", [["min-height", "1lh"]]), e("max-h-lh", [["max-height", "1lh"]]), e("w-screen", [["width", "100vw"]]), e("min-w-screen", [["min-width", "100vw"]]), e("max-w-screen", [["max-width", "100vw"]]), e("h-screen", [["height", "100vh"]]), e("min-h-screen", [["min-height", "100vh"]]), e("max-h-screen", [["max-height", "100vh"]]), e("max-w-none", [["max-width", "none"]]), e("max-h-none", [["max-height", "none"]]), a("size", ["--size", "--spacing"], (l) => [
		o("--tw-sort", "size"),
		o("width", l),
		o("height", l)
	], { supportsFractions: !0 });
	for (let [l, g, v] of [
		[
			"w",
			[
				"--width",
				"--spacing",
				"--container"
			],
			"width"
		],
		[
			"min-w",
			[
				"--min-width",
				"--spacing",
				"--container"
			],
			"min-width"
		],
		[
			"max-w",
			[
				"--max-width",
				"--spacing",
				"--container"
			],
			"max-width"
		],
		[
			"h",
			["--height", "--spacing"],
			"height"
		],
		[
			"min-h",
			[
				"--min-height",
				"--height",
				"--spacing"
			],
			"min-height"
		],
		[
			"max-h",
			[
				"--max-height",
				"--height",
				"--spacing"
			],
			"max-height"
		]
	]) a(l, g, (C) => [o(v, C)], { supportsFractions: !0 });
	r.static("container", () => {
		let l = [...t.namespace("--breakpoint").values()];
		l.sort((v, C) => Ve(v, C, "asc"));
		let g = [o("--tw-sort", "--tw-container-component"), o("width", "100%")];
		for (let v of l) g.push(F("@media", `(width >= ${v})`, [o("max-width", v)]));
		return g;
	}), e("flex-auto", [["flex", "auto"]]), e("flex-initial", [["flex", "0 auto"]]), e("flex-none", [["flex", "none"]]), r.functional("flex", (l) => {
		if (l.value) {
			if (l.value.kind === "arbitrary") return l.modifier ? void 0 : [o("flex", l.value.value)];
			if (l.value.fraction) {
				let [g, v] = d(l.value.fraction, "/");
				return !u(g) || !u(v) ? void 0 : [o("flex", `calc(${l.value.fraction} * 100%)`)];
			}
			if (u(l.value.value)) return l.modifier ? void 0 : [o("flex", l.value.value)];
		}
	}), i("flex", () => [{ supportsFractions: !0 }, { values: Array.from({ length: 12 }, (l, g) => `${g + 1}`) }]), n("shrink", {
		defaultValue: "1",
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		handle: (l) => [o("flex-shrink", l)]
	}), n("grow", {
		defaultValue: "1",
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		handle: (l) => [o("flex-grow", l)]
	}), i("shrink", () => [{
		values: ["0"],
		valueThemeKeys: [],
		hasDefaultValue: !0
	}]), i("grow", () => [{
		values: ["0"],
		valueThemeKeys: [],
		hasDefaultValue: !0
	}]), e("basis-auto", [["flex-basis", "auto"]]), e("basis-full", [["flex-basis", "100%"]]), a("basis", [
		"--flex-basis",
		"--spacing",
		"--container"
	], (l) => [o("flex-basis", l)], { supportsFractions: !0 }), e("table-auto", [["table-layout", "auto"]]), e("table-fixed", [["table-layout", "fixed"]]), e("caption-top", [["caption-side", "top"]]), e("caption-bottom", [["caption-side", "bottom"]]), e("border-collapse", [["border-collapse", "collapse"]]), e("border-separate", [["border-collapse", "separate"]]);
	let p = () => W([S("--tw-border-spacing-x", "0", "<length>"), S("--tw-border-spacing-y", "0", "<length>")]);
	a("border-spacing", ["--border-spacing", "--spacing"], (l) => [
		p(),
		o("--tw-border-spacing-x", l),
		o("--tw-border-spacing-y", l),
		o("border-spacing", "var(--tw-border-spacing-x) var(--tw-border-spacing-y)")
	]), a("border-spacing-x", ["--border-spacing", "--spacing"], (l) => [
		p(),
		o("--tw-border-spacing-x", l),
		o("border-spacing", "var(--tw-border-spacing-x) var(--tw-border-spacing-y)")
	]), a("border-spacing-y", ["--border-spacing", "--spacing"], (l) => [
		p(),
		o("--tw-border-spacing-y", l),
		o("border-spacing", "var(--tw-border-spacing-x) var(--tw-border-spacing-y)")
	]), n("origin", {
		themeKeys: ["--transform-origin"],
		handle: (l) => [o("transform-origin", l)],
		staticValues: {
			center: [o("transform-origin", "center")],
			top: [o("transform-origin", "top")],
			"top-right": [o("transform-origin", "100% 0")],
			right: [o("transform-origin", "100%")],
			"bottom-right": [o("transform-origin", "100% 100%")],
			bottom: [o("transform-origin", "bottom")],
			"bottom-left": [o("transform-origin", "0 100%")],
			left: [o("transform-origin", "0")],
			"top-left": [o("transform-origin", "0 0")]
		}
	}), n("perspective-origin", {
		themeKeys: ["--perspective-origin"],
		handle: (l) => [o("perspective-origin", l)],
		staticValues: {
			center: [o("perspective-origin", "center")],
			top: [o("perspective-origin", "top")],
			"top-right": [o("perspective-origin", "100% 0")],
			right: [o("perspective-origin", "100%")],
			"bottom-right": [o("perspective-origin", "100% 100%")],
			bottom: [o("perspective-origin", "bottom")],
			"bottom-left": [o("perspective-origin", "0 100%")],
			left: [o("perspective-origin", "0")],
			"top-left": [o("perspective-origin", "0 0")]
		}
	}), n("perspective", {
		themeKeys: ["--perspective"],
		handle: (l) => [o("perspective", l)],
		staticValues: { none: [o("perspective", "none")] }
	});
	let u$1 = () => W([
		S("--tw-translate-x", "0"),
		S("--tw-translate-y", "0"),
		S("--tw-translate-z", "0")
	]);
	e("translate-none", [["translate", "none"]]), e("-translate-full", [
		u$1,
		["--tw-translate-x", "-100%"],
		["--tw-translate-y", "-100%"],
		["translate", "var(--tw-translate-x) var(--tw-translate-y)"]
	]), e("translate-full", [
		u$1,
		["--tw-translate-x", "100%"],
		["--tw-translate-y", "100%"],
		["translate", "var(--tw-translate-x) var(--tw-translate-y)"]
	]), a("translate", ["--translate", "--spacing"], (l) => [
		u$1(),
		o("--tw-translate-x", l),
		o("--tw-translate-y", l),
		o("translate", "var(--tw-translate-x) var(--tw-translate-y)")
	], {
		supportsNegative: !0,
		supportsFractions: !0
	});
	for (let l of ["x", "y"]) e(`-translate-${l}-full`, [
		u$1,
		[`--tw-translate-${l}`, "-100%"],
		["translate", "var(--tw-translate-x) var(--tw-translate-y)"]
	]), e(`translate-${l}-full`, [
		u$1,
		[`--tw-translate-${l}`, "100%"],
		["translate", "var(--tw-translate-x) var(--tw-translate-y)"]
	]), a(`translate-${l}`, ["--translate", "--spacing"], (g) => [
		u$1(),
		o(`--tw-translate-${l}`, g),
		o("translate", "var(--tw-translate-x) var(--tw-translate-y)")
	], {
		supportsNegative: !0,
		supportsFractions: !0
	});
	a("translate-z", ["--translate", "--spacing"], (l) => [
		u$1(),
		o("--tw-translate-z", l),
		o("translate", "var(--tw-translate-x) var(--tw-translate-y) var(--tw-translate-z)")
	], { supportsNegative: !0 }), e("translate-3d", [u$1, ["translate", "var(--tw-translate-x) var(--tw-translate-y) var(--tw-translate-z)"]]);
	let f = () => W([
		S("--tw-scale-x", "1"),
		S("--tw-scale-y", "1"),
		S("--tw-scale-z", "1")
	]);
	e("scale-none", [["scale", "none"]]);
	function m({ negative: l }) {
		return (g) => {
			if (!g.value || g.modifier) return;
			let v;
			return g.value.kind === "arbitrary" ? (v = g.value.value, v = l ? `calc(${v} * -1)` : v, [o("scale", v)]) : (v = t.resolve(g.value.value, ["--scale"]), !v && u(g.value.value) && (v = `${g.value.value}%`), v ? (v = l ? `calc(${v} * -1)` : v, [
				f(),
				o("--tw-scale-x", v),
				o("--tw-scale-y", v),
				o("--tw-scale-z", v),
				o("scale", "var(--tw-scale-x) var(--tw-scale-y)")
			]) : void 0);
		};
	}
	r.functional("-scale", m({ negative: !0 })), r.functional("scale", m({ negative: !1 })), i("scale", () => [{
		supportsNegative: !0,
		values: [
			"0",
			"50",
			"75",
			"90",
			"95",
			"100",
			"105",
			"110",
			"125",
			"150",
			"200"
		],
		valueThemeKeys: ["--scale"]
	}]);
	for (let l of [
		"x",
		"y",
		"z"
	]) n(`scale-${l}`, {
		supportsNegative: !0,
		themeKeys: ["--scale"],
		handleBareValue: ({ value: g }) => u(g) ? `${g}%` : null,
		handle: (g) => [
			f(),
			o(`--tw-scale-${l}`, g),
			o("scale", `var(--tw-scale-x) var(--tw-scale-y)${l === "z" ? " var(--tw-scale-z)" : ""}`)
		]
	}), i(`scale-${l}`, () => [{
		supportsNegative: !0,
		values: [
			"0",
			"50",
			"75",
			"90",
			"95",
			"100",
			"105",
			"110",
			"125",
			"150",
			"200"
		],
		valueThemeKeys: ["--scale"]
	}]);
	e("scale-3d", [f, ["scale", "var(--tw-scale-x) var(--tw-scale-y) var(--tw-scale-z)"]]), e("rotate-none", [["rotate", "none"]]);
	function d$2({ negative: l }) {
		return (g) => {
			if (!g.value || g.modifier) return;
			let v;
			if (g.value.kind === "arbitrary") {
				v = g.value.value;
				let C = g.value.dataType ?? me$1(v, ["angle", "vector"]);
				if (C === "vector") return [o("rotate", `${v} var(--tw-rotate)`)];
				if (C !== "angle") return [o("rotate", l ? `calc(${v} * -1)` : v)];
			} else if (v = t.resolve(g.value.value, ["--rotate"]), !v && u(g.value.value) && (v = `${g.value.value}deg`), !v) return;
			return [o("rotate", l ? `calc(${v} * -1)` : v)];
		};
	}
	r.functional("-rotate", d$2({ negative: !0 })), r.functional("rotate", d$2({ negative: !1 })), i("rotate", () => [{
		supportsNegative: !0,
		values: [
			"0",
			"1",
			"2",
			"3",
			"6",
			"12",
			"45",
			"90",
			"180"
		],
		valueThemeKeys: ["--rotate"]
	}]);
	{
		let l = [
			"var(--tw-rotate-x,)",
			"var(--tw-rotate-y,)",
			"var(--tw-rotate-z,)",
			"var(--tw-skew-x,)",
			"var(--tw-skew-y,)"
		].join(" "), g = () => W([
			S("--tw-rotate-x"),
			S("--tw-rotate-y"),
			S("--tw-rotate-z"),
			S("--tw-skew-x"),
			S("--tw-skew-y")
		]);
		for (let v of [
			"x",
			"y",
			"z"
		]) n(`rotate-${v}`, {
			supportsNegative: !0,
			themeKeys: ["--rotate"],
			handleBareValue: ({ value: C }) => u(C) ? `${C}deg` : null,
			handle: (C) => [
				g(),
				o(`--tw-rotate-${v}`, `rotate${v.toUpperCase()}(${C})`),
				o("transform", l)
			]
		}), i(`rotate-${v}`, () => [{
			supportsNegative: !0,
			values: [
				"0",
				"1",
				"2",
				"3",
				"6",
				"12",
				"45",
				"90",
				"180"
			],
			valueThemeKeys: ["--rotate"]
		}]);
		n("skew", {
			supportsNegative: !0,
			themeKeys: ["--skew"],
			handleBareValue: ({ value: v }) => u(v) ? `${v}deg` : null,
			handle: (v) => [
				g(),
				o("--tw-skew-x", `skewX(${v})`),
				o("--tw-skew-y", `skewY(${v})`),
				o("transform", l)
			]
		}), n("skew-x", {
			supportsNegative: !0,
			themeKeys: ["--skew"],
			handleBareValue: ({ value: v }) => u(v) ? `${v}deg` : null,
			handle: (v) => [
				g(),
				o("--tw-skew-x", `skewX(${v})`),
				o("transform", l)
			]
		}), n("skew-y", {
			supportsNegative: !0,
			themeKeys: ["--skew"],
			handleBareValue: ({ value: v }) => u(v) ? `${v}deg` : null,
			handle: (v) => [
				g(),
				o("--tw-skew-y", `skewY(${v})`),
				o("transform", l)
			]
		}), i("skew", () => [{
			supportsNegative: !0,
			values: [
				"0",
				"1",
				"2",
				"3",
				"6",
				"12"
			],
			valueThemeKeys: ["--skew"]
		}]), i("skew-x", () => [{
			supportsNegative: !0,
			values: [
				"0",
				"1",
				"2",
				"3",
				"6",
				"12"
			],
			valueThemeKeys: ["--skew"]
		}]), i("skew-y", () => [{
			supportsNegative: !0,
			values: [
				"0",
				"1",
				"2",
				"3",
				"6",
				"12"
			],
			valueThemeKeys: ["--skew"]
		}]), r.functional("transform", (v) => {
			if (v.modifier) return;
			let C = null;
			if (v.value ? v.value.kind === "arbitrary" && (C = v.value.value) : C = l, C !== null) return [g(), o("transform", C)];
		}), i("transform", () => [{ hasDefaultValue: !0 }]), e("transform-cpu", [["transform", l]]), e("transform-gpu", [["transform", `translateZ(0) ${l}`]]), e("transform-none", [["transform", "none"]]);
	}
	e("transform-flat", [["transform-style", "flat"]]), e("transform-3d", [["transform-style", "preserve-3d"]]), e("transform-content", [["transform-box", "content-box"]]), e("transform-border", [["transform-box", "border-box"]]), e("transform-fill", [["transform-box", "fill-box"]]), e("transform-stroke", [["transform-box", "stroke-box"]]), e("transform-view", [["transform-box", "view-box"]]), e("backface-visible", [["backface-visibility", "visible"]]), e("backface-hidden", [["backface-visibility", "hidden"]]);
	for (let l of [
		"auto",
		"default",
		"pointer",
		"wait",
		"text",
		"move",
		"help",
		"not-allowed",
		"none",
		"context-menu",
		"progress",
		"cell",
		"crosshair",
		"vertical-text",
		"alias",
		"copy",
		"no-drop",
		"grab",
		"grabbing",
		"all-scroll",
		"col-resize",
		"row-resize",
		"n-resize",
		"e-resize",
		"s-resize",
		"w-resize",
		"ne-resize",
		"nw-resize",
		"se-resize",
		"sw-resize",
		"ew-resize",
		"ns-resize",
		"nesw-resize",
		"nwse-resize",
		"zoom-in",
		"zoom-out"
	]) e(`cursor-${l}`, [["cursor", l]]);
	n("cursor", {
		themeKeys: ["--cursor"],
		handle: (l) => [o("cursor", l)]
	});
	for (let l of [
		"auto",
		"none",
		"manipulation"
	]) e(`touch-${l}`, [["touch-action", l]]);
	let c = () => W([
		S("--tw-pan-x"),
		S("--tw-pan-y"),
		S("--tw-pinch-zoom")
	]);
	for (let l of [
		"x",
		"left",
		"right"
	]) e(`touch-pan-${l}`, [
		c,
		["--tw-pan-x", `pan-${l}`],
		["touch-action", "var(--tw-pan-x,) var(--tw-pan-y,) var(--tw-pinch-zoom,)"]
	]);
	for (let l of [
		"y",
		"up",
		"down"
	]) e(`touch-pan-${l}`, [
		c,
		["--tw-pan-y", `pan-${l}`],
		["touch-action", "var(--tw-pan-x,) var(--tw-pan-y,) var(--tw-pinch-zoom,)"]
	]);
	e("touch-pinch-zoom", [
		c,
		["--tw-pinch-zoom", "pinch-zoom"],
		["touch-action", "var(--tw-pan-x,) var(--tw-pan-y,) var(--tw-pinch-zoom,)"]
	]);
	for (let l of [
		"none",
		"text",
		"all",
		"auto"
	]) e(`select-${l}`, [["-webkit-user-select", l], ["user-select", l]]);
	e("resize-none", [["resize", "none"]]), e("resize-x", [["resize", "horizontal"]]), e("resize-y", [["resize", "vertical"]]), e("resize", [["resize", "both"]]), e("snap-none", [["scroll-snap-type", "none"]]);
	let w = () => W([S("--tw-scroll-snap-strictness", "proximity", "*")]);
	for (let l of [
		"x",
		"y",
		"both"
	]) e(`snap-${l}`, [w, ["scroll-snap-type", `${l} var(--tw-scroll-snap-strictness)`]]);
	e("snap-mandatory", [w, ["--tw-scroll-snap-strictness", "mandatory"]]), e("snap-proximity", [w, ["--tw-scroll-snap-strictness", "proximity"]]), e("snap-align-none", [["scroll-snap-align", "none"]]), e("snap-start", [["scroll-snap-align", "start"]]), e("snap-end", [["scroll-snap-align", "end"]]), e("snap-center", [["scroll-snap-align", "center"]]), e("snap-normal", [["scroll-snap-stop", "normal"]]), e("snap-always", [["scroll-snap-stop", "always"]]);
	for (let [l, g] of [
		["scroll-m", "scroll-margin"],
		["scroll-mx", "scroll-margin-inline"],
		["scroll-my", "scroll-margin-block"],
		["scroll-ms", "scroll-margin-inline-start"],
		["scroll-me", "scroll-margin-inline-end"],
		["scroll-mt", "scroll-margin-top"],
		["scroll-mr", "scroll-margin-right"],
		["scroll-mb", "scroll-margin-bottom"],
		["scroll-ml", "scroll-margin-left"]
	]) a(l, ["--scroll-margin", "--spacing"], (v) => [o(g, v)], { supportsNegative: !0 });
	for (let [l, g] of [
		["scroll-p", "scroll-padding"],
		["scroll-px", "scroll-padding-inline"],
		["scroll-py", "scroll-padding-block"],
		["scroll-ps", "scroll-padding-inline-start"],
		["scroll-pe", "scroll-padding-inline-end"],
		["scroll-pt", "scroll-padding-top"],
		["scroll-pr", "scroll-padding-right"],
		["scroll-pb", "scroll-padding-bottom"],
		["scroll-pl", "scroll-padding-left"]
	]) a(l, ["--scroll-padding", "--spacing"], (v) => [o(g, v)]);
	e("list-inside", [["list-style-position", "inside"]]), e("list-outside", [["list-style-position", "outside"]]), n("list", {
		themeKeys: ["--list-style-type"],
		handle: (l) => [o("list-style-type", l)],
		staticValues: {
			none: [o("list-style-type", "none")],
			disc: [o("list-style-type", "disc")],
			decimal: [o("list-style-type", "decimal")]
		}
	}), n("list-image", {
		themeKeys: ["--list-style-image"],
		handle: (l) => [o("list-style-image", l)],
		staticValues: { none: [o("list-style-image", "none")] }
	}), e("appearance-none", [["appearance", "none"]]), e("appearance-auto", [["appearance", "auto"]]), e("scheme-normal", [["color-scheme", "normal"]]), e("scheme-dark", [["color-scheme", "dark"]]), e("scheme-light", [["color-scheme", "light"]]), e("scheme-light-dark", [["color-scheme", "light dark"]]), e("scheme-only-dark", [["color-scheme", "only dark"]]), e("scheme-only-light", [["color-scheme", "only light"]]), n("columns", {
		themeKeys: ["--columns", "--container"],
		handleBareValue: ({ value: l }) => u(l) ? l : null,
		handle: (l) => [o("columns", l)],
		staticValues: { auto: [o("columns", "auto")] }
	}), i("columns", () => [{
		values: Array.from({ length: 12 }, (l, g) => `${g + 1}`),
		valueThemeKeys: ["--columns", "--container"]
	}]);
	for (let l of [
		"auto",
		"avoid",
		"all",
		"avoid-page",
		"page",
		"left",
		"right",
		"column"
	]) e(`break-before-${l}`, [["break-before", l]]);
	for (let l of [
		"auto",
		"avoid",
		"avoid-page",
		"avoid-column"
	]) e(`break-inside-${l}`, [["break-inside", l]]);
	for (let l of [
		"auto",
		"avoid",
		"all",
		"avoid-page",
		"page",
		"left",
		"right",
		"column"
	]) e(`break-after-${l}`, [["break-after", l]]);
	e("grid-flow-row", [["grid-auto-flow", "row"]]), e("grid-flow-col", [["grid-auto-flow", "column"]]), e("grid-flow-dense", [["grid-auto-flow", "dense"]]), e("grid-flow-row-dense", [["grid-auto-flow", "row dense"]]), e("grid-flow-col-dense", [["grid-auto-flow", "column dense"]]), n("auto-cols", {
		themeKeys: ["--grid-auto-columns"],
		handle: (l) => [o("grid-auto-columns", l)],
		staticValues: {
			auto: [o("grid-auto-columns", "auto")],
			min: [o("grid-auto-columns", "min-content")],
			max: [o("grid-auto-columns", "max-content")],
			fr: [o("grid-auto-columns", "minmax(0, 1fr)")]
		}
	}), n("auto-rows", {
		themeKeys: ["--grid-auto-rows"],
		handle: (l) => [o("grid-auto-rows", l)],
		staticValues: {
			auto: [o("grid-auto-rows", "auto")],
			min: [o("grid-auto-rows", "min-content")],
			max: [o("grid-auto-rows", "max-content")],
			fr: [o("grid-auto-rows", "minmax(0, 1fr)")]
		}
	}), n("grid-cols", {
		themeKeys: ["--grid-template-columns"],
		handleBareValue: ({ value: l }) => pe$1(l) ? `repeat(${l}, minmax(0, 1fr))` : null,
		handle: (l) => [o("grid-template-columns", l)],
		staticValues: {
			none: [o("grid-template-columns", "none")],
			subgrid: [o("grid-template-columns", "subgrid")]
		}
	}), n("grid-rows", {
		themeKeys: ["--grid-template-rows"],
		handleBareValue: ({ value: l }) => pe$1(l) ? `repeat(${l}, minmax(0, 1fr))` : null,
		handle: (l) => [o("grid-template-rows", l)],
		staticValues: {
			none: [o("grid-template-rows", "none")],
			subgrid: [o("grid-template-rows", "subgrid")]
		}
	}), i("grid-cols", () => [{
		values: Array.from({ length: 12 }, (l, g) => `${g + 1}`),
		valueThemeKeys: ["--grid-template-columns"]
	}]), i("grid-rows", () => [{
		values: Array.from({ length: 12 }, (l, g) => `${g + 1}`),
		valueThemeKeys: ["--grid-template-rows"]
	}]), e("flex-row", [["flex-direction", "row"]]), e("flex-row-reverse", [["flex-direction", "row-reverse"]]), e("flex-col", [["flex-direction", "column"]]), e("flex-col-reverse", [["flex-direction", "column-reverse"]]), e("flex-wrap", [["flex-wrap", "wrap"]]), e("flex-nowrap", [["flex-wrap", "nowrap"]]), e("flex-wrap-reverse", [["flex-wrap", "wrap-reverse"]]), e("place-content-center", [["place-content", "center"]]), e("place-content-start", [["place-content", "start"]]), e("place-content-end", [["place-content", "end"]]), e("place-content-center-safe", [["place-content", "safe center"]]), e("place-content-end-safe", [["place-content", "safe end"]]), e("place-content-between", [["place-content", "space-between"]]), e("place-content-around", [["place-content", "space-around"]]), e("place-content-evenly", [["place-content", "space-evenly"]]), e("place-content-baseline", [["place-content", "baseline"]]), e("place-content-stretch", [["place-content", "stretch"]]), e("place-items-center", [["place-items", "center"]]), e("place-items-start", [["place-items", "start"]]), e("place-items-end", [["place-items", "end"]]), e("place-items-center-safe", [["place-items", "safe center"]]), e("place-items-end-safe", [["place-items", "safe end"]]), e("place-items-baseline", [["place-items", "baseline"]]), e("place-items-stretch", [["place-items", "stretch"]]), e("content-normal", [["align-content", "normal"]]), e("content-center", [["align-content", "center"]]), e("content-start", [["align-content", "flex-start"]]), e("content-end", [["align-content", "flex-end"]]), e("content-center-safe", [["align-content", "safe center"]]), e("content-end-safe", [["align-content", "safe flex-end"]]), e("content-between", [["align-content", "space-between"]]), e("content-around", [["align-content", "space-around"]]), e("content-evenly", [["align-content", "space-evenly"]]), e("content-baseline", [["align-content", "baseline"]]), e("content-stretch", [["align-content", "stretch"]]), e("items-center", [["align-items", "center"]]), e("items-start", [["align-items", "flex-start"]]), e("items-end", [["align-items", "flex-end"]]), e("items-center-safe", [["align-items", "safe center"]]), e("items-end-safe", [["align-items", "safe flex-end"]]), e("items-baseline", [["align-items", "baseline"]]), e("items-baseline-last", [["align-items", "last baseline"]]), e("items-stretch", [["align-items", "stretch"]]), e("justify-normal", [["justify-content", "normal"]]), e("justify-center", [["justify-content", "center"]]), e("justify-start", [["justify-content", "flex-start"]]), e("justify-end", [["justify-content", "flex-end"]]), e("justify-center-safe", [["justify-content", "safe center"]]), e("justify-end-safe", [["justify-content", "safe flex-end"]]), e("justify-between", [["justify-content", "space-between"]]), e("justify-around", [["justify-content", "space-around"]]), e("justify-evenly", [["justify-content", "space-evenly"]]), e("justify-baseline", [["justify-content", "baseline"]]), e("justify-stretch", [["justify-content", "stretch"]]), e("justify-items-normal", [["justify-items", "normal"]]), e("justify-items-center", [["justify-items", "center"]]), e("justify-items-start", [["justify-items", "start"]]), e("justify-items-end", [["justify-items", "end"]]), e("justify-items-center-safe", [["justify-items", "safe center"]]), e("justify-items-end-safe", [["justify-items", "safe end"]]), e("justify-items-stretch", [["justify-items", "stretch"]]), a("gap", ["--gap", "--spacing"], (l) => [o("gap", l)]), a("gap-x", ["--gap", "--spacing"], (l) => [o("column-gap", l)]), a("gap-y", ["--gap", "--spacing"], (l) => [o("row-gap", l)]), a("space-x", ["--space", "--spacing"], (l) => [W([S("--tw-space-x-reverse", "0")]), G(":where(& > :not(:last-child))", [
		o("--tw-sort", "row-gap"),
		o("--tw-space-x-reverse", "0"),
		o("margin-inline-start", `calc(${l} * var(--tw-space-x-reverse))`),
		o("margin-inline-end", `calc(${l} * calc(1 - var(--tw-space-x-reverse)))`)
	])], { supportsNegative: !0 }), a("space-y", ["--space", "--spacing"], (l) => [W([S("--tw-space-y-reverse", "0")]), G(":where(& > :not(:last-child))", [
		o("--tw-sort", "column-gap"),
		o("--tw-space-y-reverse", "0"),
		o("margin-block-start", `calc(${l} * var(--tw-space-y-reverse))`),
		o("margin-block-end", `calc(${l} * calc(1 - var(--tw-space-y-reverse)))`)
	])], { supportsNegative: !0 }), e("space-x-reverse", [() => W([S("--tw-space-x-reverse", "0")]), () => G(":where(& > :not(:last-child))", [o("--tw-sort", "row-gap"), o("--tw-space-x-reverse", "1")])]), e("space-y-reverse", [() => W([S("--tw-space-y-reverse", "0")]), () => G(":where(& > :not(:last-child))", [o("--tw-sort", "column-gap"), o("--tw-space-y-reverse", "1")])]), e("accent-auto", [["accent-color", "auto"]]), s("accent", {
		themeKeys: ["--accent-color", "--color"],
		handle: (l) => [o("accent-color", l)]
	}), s("caret", {
		themeKeys: ["--caret-color", "--color"],
		handle: (l) => [o("caret-color", l)]
	}), s("divide", {
		themeKeys: [
			"--divide-color",
			"--border-color",
			"--color"
		],
		handle: (l) => [G(":where(& > :not(:last-child))", [o("--tw-sort", "divide-color"), o("border-color", l)])]
	}), e("place-self-auto", [["place-self", "auto"]]), e("place-self-start", [["place-self", "start"]]), e("place-self-end", [["place-self", "end"]]), e("place-self-center", [["place-self", "center"]]), e("place-self-end-safe", [["place-self", "safe end"]]), e("place-self-center-safe", [["place-self", "safe center"]]), e("place-self-stretch", [["place-self", "stretch"]]), e("self-auto", [["align-self", "auto"]]), e("self-start", [["align-self", "flex-start"]]), e("self-end", [["align-self", "flex-end"]]), e("self-center", [["align-self", "center"]]), e("self-end-safe", [["align-self", "safe flex-end"]]), e("self-center-safe", [["align-self", "safe center"]]), e("self-stretch", [["align-self", "stretch"]]), e("self-baseline", [["align-self", "baseline"]]), e("self-baseline-last", [["align-self", "last baseline"]]), e("justify-self-auto", [["justify-self", "auto"]]), e("justify-self-start", [["justify-self", "flex-start"]]), e("justify-self-end", [["justify-self", "flex-end"]]), e("justify-self-center", [["justify-self", "center"]]), e("justify-self-end-safe", [["justify-self", "safe flex-end"]]), e("justify-self-center-safe", [["justify-self", "safe center"]]), e("justify-self-stretch", [["justify-self", "stretch"]]);
	for (let l of [
		"auto",
		"hidden",
		"clip",
		"visible",
		"scroll"
	]) e(`overflow-${l}`, [["overflow", l]]), e(`overflow-x-${l}`, [["overflow-x", l]]), e(`overflow-y-${l}`, [["overflow-y", l]]);
	for (let l of [
		"auto",
		"contain",
		"none"
	]) e(`overscroll-${l}`, [["overscroll-behavior", l]]), e(`overscroll-x-${l}`, [["overscroll-behavior-x", l]]), e(`overscroll-y-${l}`, [["overscroll-behavior-y", l]]);
	e("scroll-auto", [["scroll-behavior", "auto"]]), e("scroll-smooth", [["scroll-behavior", "smooth"]]), e("truncate", [
		["overflow", "hidden"],
		["text-overflow", "ellipsis"],
		["white-space", "nowrap"]
	]), e("text-ellipsis", [["text-overflow", "ellipsis"]]), e("text-clip", [["text-overflow", "clip"]]), e("hyphens-none", [["-webkit-hyphens", "none"], ["hyphens", "none"]]), e("hyphens-manual", [["-webkit-hyphens", "manual"], ["hyphens", "manual"]]), e("hyphens-auto", [["-webkit-hyphens", "auto"], ["hyphens", "auto"]]), e("whitespace-normal", [["white-space", "normal"]]), e("whitespace-nowrap", [["white-space", "nowrap"]]), e("whitespace-pre", [["white-space", "pre"]]), e("whitespace-pre-line", [["white-space", "pre-line"]]), e("whitespace-pre-wrap", [["white-space", "pre-wrap"]]), e("whitespace-break-spaces", [["white-space", "break-spaces"]]), e("text-wrap", [["text-wrap", "wrap"]]), e("text-nowrap", [["text-wrap", "nowrap"]]), e("text-balance", [["text-wrap", "balance"]]), e("text-pretty", [["text-wrap", "pretty"]]), e("break-normal", [["overflow-wrap", "normal"], ["word-break", "normal"]]), e("break-all", [["word-break", "break-all"]]), e("break-keep", [["word-break", "keep-all"]]), e("wrap-anywhere", [["overflow-wrap", "anywhere"]]), e("wrap-break-word", [["overflow-wrap", "break-word"]]), e("wrap-normal", [["overflow-wrap", "normal"]]);
	for (let [l, g] of [
		["rounded", ["border-radius"]],
		["rounded-s", ["border-start-start-radius", "border-end-start-radius"]],
		["rounded-e", ["border-start-end-radius", "border-end-end-radius"]],
		["rounded-t", ["border-top-left-radius", "border-top-right-radius"]],
		["rounded-r", ["border-top-right-radius", "border-bottom-right-radius"]],
		["rounded-b", ["border-bottom-right-radius", "border-bottom-left-radius"]],
		["rounded-l", ["border-top-left-radius", "border-bottom-left-radius"]],
		["rounded-ss", ["border-start-start-radius"]],
		["rounded-se", ["border-start-end-radius"]],
		["rounded-ee", ["border-end-end-radius"]],
		["rounded-es", ["border-end-start-radius"]],
		["rounded-tl", ["border-top-left-radius"]],
		["rounded-tr", ["border-top-right-radius"]],
		["rounded-br", ["border-bottom-right-radius"]],
		["rounded-bl", ["border-bottom-left-radius"]]
	]) n(l, {
		themeKeys: ["--radius"],
		handle: (v) => g.map((C) => o(C, v)),
		staticValues: {
			none: g.map((v) => o(v, "0")),
			full: g.map((v) => o(v, "calc(infinity * 1px)"))
		}
	});
	e("border-solid", [["--tw-border-style", "solid"], ["border-style", "solid"]]), e("border-dashed", [["--tw-border-style", "dashed"], ["border-style", "dashed"]]), e("border-dotted", [["--tw-border-style", "dotted"], ["border-style", "dotted"]]), e("border-double", [["--tw-border-style", "double"], ["border-style", "double"]]), e("border-hidden", [["--tw-border-style", "hidden"], ["border-style", "hidden"]]), e("border-none", [["--tw-border-style", "none"], ["border-style", "none"]]);
	{
		let g = function(v, C) {
			r.functional(v, (b) => {
				if (!b.value) {
					if (b.modifier) return;
					let T = t.get(["--default-border-width"]) ?? "1px", D = C.width(T);
					return D ? [l(), ...D] : void 0;
				}
				if (b.value.kind === "arbitrary") {
					let T = b.value.value;
					switch (b.value.dataType ?? me$1(T, [
						"color",
						"line-width",
						"length"
					])) {
						case "line-width":
						case "length": {
							if (b.modifier) return;
							let V = C.width(T);
							return V ? [l(), ...V] : void 0;
						}
						default: return T = X(T, b.modifier, t), T === null ? void 0 : C.color(T);
					}
				}
				{
					let T = te(b, t, ["--border-color", "--color"]);
					if (T) return C.color(T);
				}
				{
					if (b.modifier) return;
					let T = t.resolve(b.value.value, ["--border-width"]);
					if (T) {
						let D = C.width(T);
						return D ? [l(), ...D] : void 0;
					}
					if (u(b.value.value)) {
						let D = C.width(`${b.value.value}px`);
						return D ? [l(), ...D] : void 0;
					}
				}
			}), i(v, () => [{
				values: [
					"current",
					"inherit",
					"transparent"
				],
				valueThemeKeys: ["--border-color", "--color"],
				modifiers: Array.from({ length: 21 }, (b, T) => `${T * 5}`),
				hasDefaultValue: !0
			}, {
				values: [
					"0",
					"2",
					"4",
					"8"
				],
				valueThemeKeys: ["--border-width"]
			}]);
		};
		let l = () => W([S("--tw-border-style", "solid")]);
		g("border", {
			width: (v) => [o("border-style", "var(--tw-border-style)"), o("border-width", v)],
			color: (v) => [o("border-color", v)]
		}), g("border-x", {
			width: (v) => [o("border-inline-style", "var(--tw-border-style)"), o("border-inline-width", v)],
			color: (v) => [o("border-inline-color", v)]
		}), g("border-y", {
			width: (v) => [o("border-block-style", "var(--tw-border-style)"), o("border-block-width", v)],
			color: (v) => [o("border-block-color", v)]
		}), g("border-s", {
			width: (v) => [o("border-inline-start-style", "var(--tw-border-style)"), o("border-inline-start-width", v)],
			color: (v) => [o("border-inline-start-color", v)]
		}), g("border-e", {
			width: (v) => [o("border-inline-end-style", "var(--tw-border-style)"), o("border-inline-end-width", v)],
			color: (v) => [o("border-inline-end-color", v)]
		}), g("border-t", {
			width: (v) => [o("border-top-style", "var(--tw-border-style)"), o("border-top-width", v)],
			color: (v) => [o("border-top-color", v)]
		}), g("border-r", {
			width: (v) => [o("border-right-style", "var(--tw-border-style)"), o("border-right-width", v)],
			color: (v) => [o("border-right-color", v)]
		}), g("border-b", {
			width: (v) => [o("border-bottom-style", "var(--tw-border-style)"), o("border-bottom-width", v)],
			color: (v) => [o("border-bottom-color", v)]
		}), g("border-l", {
			width: (v) => [o("border-left-style", "var(--tw-border-style)"), o("border-left-width", v)],
			color: (v) => [o("border-left-color", v)]
		}), n("divide-x", {
			defaultValue: t.get(["--default-border-width"]) ?? "1px",
			themeKeys: ["--divide-width", "--border-width"],
			handleBareValue: ({ value: v }) => u(v) ? `${v}px` : null,
			handle: (v) => [W([S("--tw-divide-x-reverse", "0")]), G(":where(& > :not(:last-child))", [
				o("--tw-sort", "divide-x-width"),
				l(),
				o("--tw-divide-x-reverse", "0"),
				o("border-inline-style", "var(--tw-border-style)"),
				o("border-inline-start-width", `calc(${v} * var(--tw-divide-x-reverse))`),
				o("border-inline-end-width", `calc(${v} * calc(1 - var(--tw-divide-x-reverse)))`)
			])]
		}), n("divide-y", {
			defaultValue: t.get(["--default-border-width"]) ?? "1px",
			themeKeys: ["--divide-width", "--border-width"],
			handleBareValue: ({ value: v }) => u(v) ? `${v}px` : null,
			handle: (v) => [W([S("--tw-divide-y-reverse", "0")]), G(":where(& > :not(:last-child))", [
				o("--tw-sort", "divide-y-width"),
				l(),
				o("--tw-divide-y-reverse", "0"),
				o("border-bottom-style", "var(--tw-border-style)"),
				o("border-top-style", "var(--tw-border-style)"),
				o("border-top-width", `calc(${v} * var(--tw-divide-y-reverse))`),
				o("border-bottom-width", `calc(${v} * calc(1 - var(--tw-divide-y-reverse)))`)
			])]
		}), i("divide-x", () => [{
			values: [
				"0",
				"2",
				"4",
				"8"
			],
			valueThemeKeys: ["--divide-width", "--border-width"],
			hasDefaultValue: !0
		}]), i("divide-y", () => [{
			values: [
				"0",
				"2",
				"4",
				"8"
			],
			valueThemeKeys: ["--divide-width", "--border-width"],
			hasDefaultValue: !0
		}]), e("divide-x-reverse", [() => W([S("--tw-divide-x-reverse", "0")]), () => G(":where(& > :not(:last-child))", [o("--tw-divide-x-reverse", "1")])]), e("divide-y-reverse", [() => W([S("--tw-divide-y-reverse", "0")]), () => G(":where(& > :not(:last-child))", [o("--tw-divide-y-reverse", "1")])]);
		for (let v of [
			"solid",
			"dashed",
			"dotted",
			"double",
			"none"
		]) e(`divide-${v}`, [() => G(":where(& > :not(:last-child))", [
			o("--tw-sort", "divide-style"),
			o("--tw-border-style", v),
			o("border-style", v)
		])]);
	}
	e("bg-auto", [["background-size", "auto"]]), e("bg-cover", [["background-size", "cover"]]), e("bg-contain", [["background-size", "contain"]]), n("bg-size", { handle(l) {
		if (l) return [o("background-size", l)];
	} }), e("bg-fixed", [["background-attachment", "fixed"]]), e("bg-local", [["background-attachment", "local"]]), e("bg-scroll", [["background-attachment", "scroll"]]), e("bg-top", [["background-position", "top"]]), e("bg-top-left", [["background-position", "left top"]]), e("bg-top-right", [["background-position", "right top"]]), e("bg-bottom", [["background-position", "bottom"]]), e("bg-bottom-left", [["background-position", "left bottom"]]), e("bg-bottom-right", [["background-position", "right bottom"]]), e("bg-left", [["background-position", "left"]]), e("bg-right", [["background-position", "right"]]), e("bg-center", [["background-position", "center"]]), n("bg-position", { handle(l) {
		if (l) return [o("background-position", l)];
	} }), e("bg-repeat", [["background-repeat", "repeat"]]), e("bg-no-repeat", [["background-repeat", "no-repeat"]]), e("bg-repeat-x", [["background-repeat", "repeat-x"]]), e("bg-repeat-y", [["background-repeat", "repeat-y"]]), e("bg-repeat-round", [["background-repeat", "round"]]), e("bg-repeat-space", [["background-repeat", "space"]]), e("bg-none", [["background-image", "none"]]);
	{
		let v = function(T) {
			let D = "in oklab";
			if ((T === null || T === void 0 ? void 0 : T.kind) === "named") switch (T.value) {
				case "longer":
				case "shorter":
				case "increasing":
				case "decreasing":
					D = `in oklch ${T.value} hue`;
					break;
				default: D = `in ${T.value}`;
			}
			else (T === null || T === void 0 ? void 0 : T.kind) === "arbitrary" && (D = T.value);
			return D;
		}, C = function({ negative: T }) {
			return (D) => {
				if (!D.value) return;
				if (D.value.kind === "arbitrary") {
					if (D.modifier) return;
					let M = D.value.value;
					switch (D.value.dataType ?? me$1(M, ["angle"])) {
						case "angle": return M = T ? `calc(${M} * -1)` : `${M}`, [o("--tw-gradient-position", M), o("background-image", `linear-gradient(var(--tw-gradient-stops,${M}))`)];
						default: return T ? void 0 : [o("--tw-gradient-position", M), o("background-image", `linear-gradient(var(--tw-gradient-stops,${M}))`)];
					}
				}
				let V = D.value.value;
				if (!T && g.has(V)) V = g.get(V);
				else if (u(V)) V = T ? `calc(${V}deg * -1)` : `${V}deg`;
				else return;
				let R = v(D.modifier);
				return [
					o("--tw-gradient-position", `${V}`),
					J("@supports (background-image: linear-gradient(in lab, red, red))", [o("--tw-gradient-position", `${V} ${R}`)]),
					o("background-image", "linear-gradient(var(--tw-gradient-stops))")
				];
			};
		}, b = function({ negative: T }) {
			return (D) => {
				var _D$value;
				if (((_D$value = D.value) === null || _D$value === void 0 ? void 0 : _D$value.kind) === "arbitrary") {
					if (D.modifier) return;
					let M = D.value.value;
					return [o("--tw-gradient-position", M), o("background-image", `conic-gradient(var(--tw-gradient-stops,${M}))`)];
				}
				let V = v(D.modifier);
				if (!D.value) return [o("--tw-gradient-position", V), o("background-image", "conic-gradient(var(--tw-gradient-stops))")];
				let R = D.value.value;
				if (u(R)) return R = T ? `calc(${R}deg * -1)` : `${R}deg`, [o("--tw-gradient-position", `from ${R} ${V}`), o("background-image", "conic-gradient(var(--tw-gradient-stops))")];
			};
		};
		let l = [
			"oklab",
			"oklch",
			"srgb",
			"hsl",
			"longer",
			"shorter",
			"increasing",
			"decreasing"
		], g = new Map([
			["to-t", "to top"],
			["to-tr", "to top right"],
			["to-r", "to right"],
			["to-br", "to bottom right"],
			["to-b", "to bottom"],
			["to-bl", "to bottom left"],
			["to-l", "to left"],
			["to-tl", "to top left"]
		]);
		r.functional("-bg-linear", C({ negative: !0 })), r.functional("bg-linear", C({ negative: !1 })), i("bg-linear", () => [{
			values: [...g.keys()],
			modifiers: l
		}, {
			values: [
				"0",
				"30",
				"60",
				"90",
				"120",
				"150",
				"180",
				"210",
				"240",
				"270",
				"300",
				"330"
			],
			supportsNegative: !0,
			modifiers: l
		}]), r.functional("-bg-conic", b({ negative: !0 })), r.functional("bg-conic", b({ negative: !1 })), i("bg-conic", () => [{
			hasDefaultValue: !0,
			modifiers: l
		}, {
			values: [
				"0",
				"30",
				"60",
				"90",
				"120",
				"150",
				"180",
				"210",
				"240",
				"270",
				"300",
				"330"
			],
			supportsNegative: !0,
			modifiers: l
		}]), r.functional("bg-radial", (T) => {
			if (!T.value) return [o("--tw-gradient-position", v(T.modifier)), o("background-image", "radial-gradient(var(--tw-gradient-stops))")];
			if (T.value.kind === "arbitrary") {
				if (T.modifier) return;
				let D = T.value.value;
				return [o("--tw-gradient-position", D), o("background-image", `radial-gradient(var(--tw-gradient-stops,${D}))`)];
			}
		}), i("bg-radial", () => [{
			hasDefaultValue: !0,
			modifiers: l
		}]);
	}
	r.functional("bg", (l) => {
		if (l.value) {
			if (l.value.kind === "arbitrary") {
				let g = l.value.value;
				switch (l.value.dataType ?? me$1(g, [
					"image",
					"color",
					"percentage",
					"position",
					"bg-size",
					"length",
					"url"
				])) {
					case "percentage":
					case "position": return l.modifier ? void 0 : [o("background-position", g)];
					case "bg-size":
					case "length":
					case "size": return l.modifier ? void 0 : [o("background-size", g)];
					case "image":
					case "url": return l.modifier ? void 0 : [o("background-image", g)];
					default: return g = X(g, l.modifier, t), g === null ? void 0 : [o("background-color", g)];
				}
			}
			{
				let g = te(l, t, ["--background-color", "--color"]);
				if (g) return [o("background-color", g)];
			}
			{
				if (l.modifier) return;
				let g = t.resolve(l.value.value, ["--background-image"]);
				if (g) return [o("background-image", g)];
			}
		}
	}), i("bg", () => [{
		values: [
			"current",
			"inherit",
			"transparent"
		],
		valueThemeKeys: ["--background-color", "--color"],
		modifiers: Array.from({ length: 21 }, (l, g) => `${g * 5}`)
	}, {
		values: [],
		valueThemeKeys: ["--background-image"]
	}]);
	let h = () => W([
		S("--tw-gradient-position"),
		S("--tw-gradient-from", "#0000", "<color>"),
		S("--tw-gradient-via", "#0000", "<color>"),
		S("--tw-gradient-to", "#0000", "<color>"),
		S("--tw-gradient-stops"),
		S("--tw-gradient-via-stops"),
		S("--tw-gradient-from-position", "0%", "<length-percentage>"),
		S("--tw-gradient-via-position", "50%", "<length-percentage>"),
		S("--tw-gradient-to-position", "100%", "<length-percentage>")
	]);
	function y(l, g) {
		r.functional(l, (v) => {
			if (v.value) {
				if (v.value.kind === "arbitrary") {
					let C = v.value.value;
					switch (v.value.dataType ?? me$1(C, [
						"color",
						"length",
						"percentage"
					])) {
						case "length":
						case "percentage": return v.modifier ? void 0 : g.position(C);
						default: return C = X(C, v.modifier, t), C === null ? void 0 : g.color(C);
					}
				}
				{
					let C = te(v, t, ["--background-color", "--color"]);
					if (C) return g.color(C);
				}
				{
					if (v.modifier) return;
					let C = t.resolve(v.value.value, ["--gradient-color-stop-positions"]);
					if (C) return g.position(C);
					if (v.value.value[v.value.value.length - 1] === "%" && u(v.value.value.slice(0, -1))) return g.position(v.value.value);
				}
			}
		}), i(l, () => [{
			values: [
				"current",
				"inherit",
				"transparent"
			],
			valueThemeKeys: ["--background-color", "--color"],
			modifiers: Array.from({ length: 21 }, (v, C) => `${C * 5}`)
		}, {
			values: Array.from({ length: 21 }, (v, C) => `${C * 5}%`),
			valueThemeKeys: ["--gradient-color-stop-positions"]
		}]);
	}
	y("from", {
		color: (l) => [
			h(),
			o("--tw-sort", "--tw-gradient-from"),
			o("--tw-gradient-from", l),
			o("--tw-gradient-stops", "var(--tw-gradient-via-stops, var(--tw-gradient-position), var(--tw-gradient-from) var(--tw-gradient-from-position), var(--tw-gradient-to) var(--tw-gradient-to-position))")
		],
		position: (l) => [h(), o("--tw-gradient-from-position", l)]
	}), e("via-none", [["--tw-gradient-via-stops", "initial"]]), y("via", {
		color: (l) => [
			h(),
			o("--tw-sort", "--tw-gradient-via"),
			o("--tw-gradient-via", l),
			o("--tw-gradient-via-stops", "var(--tw-gradient-position), var(--tw-gradient-from) var(--tw-gradient-from-position), var(--tw-gradient-via) var(--tw-gradient-via-position), var(--tw-gradient-to) var(--tw-gradient-to-position)"),
			o("--tw-gradient-stops", "var(--tw-gradient-via-stops)")
		],
		position: (l) => [h(), o("--tw-gradient-via-position", l)]
	}), y("to", {
		color: (l) => [
			h(),
			o("--tw-sort", "--tw-gradient-to"),
			o("--tw-gradient-to", l),
			o("--tw-gradient-stops", "var(--tw-gradient-via-stops, var(--tw-gradient-position), var(--tw-gradient-from) var(--tw-gradient-from-position), var(--tw-gradient-to) var(--tw-gradient-to-position))")
		],
		position: (l) => [h(), o("--tw-gradient-to-position", l)]
	}), e("mask-none", [["mask-image", "none"]]), r.functional("mask", (l) => {
		if (!l.value || l.modifier || l.value.kind !== "arbitrary") return;
		let g = l.value.value;
		switch (l.value.dataType ?? me$1(g, [
			"image",
			"percentage",
			"position",
			"bg-size",
			"length",
			"url"
		])) {
			case "percentage":
			case "position": return l.modifier ? void 0 : [o("mask-position", g)];
			case "bg-size":
			case "length":
			case "size": return [o("mask-size", g)];
			default: return [o("mask-image", g)];
		}
	}), e("mask-add", [["mask-composite", "add"]]), e("mask-subtract", [["mask-composite", "subtract"]]), e("mask-intersect", [["mask-composite", "intersect"]]), e("mask-exclude", [["mask-composite", "exclude"]]), e("mask-alpha", [["mask-mode", "alpha"]]), e("mask-luminance", [["mask-mode", "luminance"]]), e("mask-match", [["mask-mode", "match-source"]]), e("mask-type-alpha", [["mask-type", "alpha"]]), e("mask-type-luminance", [["mask-type", "luminance"]]), e("mask-auto", [["mask-size", "auto"]]), e("mask-cover", [["mask-size", "cover"]]), e("mask-contain", [["mask-size", "contain"]]), n("mask-size", { handle(l) {
		if (l) return [o("mask-size", l)];
	} }), e("mask-top", [["mask-position", "top"]]), e("mask-top-left", [["mask-position", "left top"]]), e("mask-top-right", [["mask-position", "right top"]]), e("mask-bottom", [["mask-position", "bottom"]]), e("mask-bottom-left", [["mask-position", "left bottom"]]), e("mask-bottom-right", [["mask-position", "right bottom"]]), e("mask-left", [["mask-position", "left"]]), e("mask-right", [["mask-position", "right"]]), e("mask-center", [["mask-position", "center"]]), n("mask-position", { handle(l) {
		if (l) return [o("mask-position", l)];
	} }), e("mask-repeat", [["mask-repeat", "repeat"]]), e("mask-no-repeat", [["mask-repeat", "no-repeat"]]), e("mask-repeat-x", [["mask-repeat", "repeat-x"]]), e("mask-repeat-y", [["mask-repeat", "repeat-y"]]), e("mask-repeat-round", [["mask-repeat", "round"]]), e("mask-repeat-space", [["mask-repeat", "space"]]), e("mask-clip-border", [["mask-clip", "border-box"]]), e("mask-clip-padding", [["mask-clip", "padding-box"]]), e("mask-clip-content", [["mask-clip", "content-box"]]), e("mask-clip-fill", [["mask-clip", "fill-box"]]), e("mask-clip-stroke", [["mask-clip", "stroke-box"]]), e("mask-clip-view", [["mask-clip", "view-box"]]), e("mask-no-clip", [["mask-clip", "no-clip"]]), e("mask-origin-border", [["mask-origin", "border-box"]]), e("mask-origin-padding", [["mask-origin", "padding-box"]]), e("mask-origin-content", [["mask-origin", "content-box"]]), e("mask-origin-fill", [["mask-origin", "fill-box"]]), e("mask-origin-stroke", [["mask-origin", "stroke-box"]]), e("mask-origin-view", [["mask-origin", "view-box"]]);
	let x = () => W([
		S("--tw-mask-linear", "linear-gradient(#fff, #fff)"),
		S("--tw-mask-radial", "linear-gradient(#fff, #fff)"),
		S("--tw-mask-conic", "linear-gradient(#fff, #fff)")
	]);
	function $(l, g) {
		r.functional(l, (v) => {
			if (v.value) {
				if (v.value.kind === "arbitrary") {
					let C = v.value.value;
					switch (v.value.dataType ?? me$1(C, [
						"length",
						"percentage",
						"color"
					])) {
						case "color": return C = X(C, v.modifier, t), C === null ? void 0 : g.color(C);
						case "percentage": return v.modifier || !u(C.slice(0, -1)) ? void 0 : g.position(C);
						default: return v.modifier ? void 0 : g.position(C);
					}
				}
				{
					let C = te(v, t, ["--background-color", "--color"]);
					if (C) return g.color(C);
				}
				{
					if (v.modifier) return;
					let C = me$1(v.value.value, ["number", "percentage"]);
					if (!C) return;
					switch (C) {
						case "number": {
							let b = t.resolve(null, ["--spacing"]);
							return !b || !ge(v.value.value) ? void 0 : g.position(`calc(${b} * ${v.value.value})`);
						}
						case "percentage": return u(v.value.value.slice(0, -1)) ? g.position(v.value.value) : void 0;
						default: return;
					}
				}
			}
		}), i(l, () => [{
			values: [
				"current",
				"inherit",
				"transparent"
			],
			valueThemeKeys: ["--background-color", "--color"],
			modifiers: Array.from({ length: 21 }, (v, C) => `${C * 5}`)
		}, {
			values: Array.from({ length: 21 }, (v, C) => `${C * 5}%`),
			valueThemeKeys: ["--gradient-color-stop-positions"]
		}]), i(l, () => [
			{ values: Array.from({ length: 21 }, (v, C) => `${C * 5}%`) },
			{ values: t.get(["--spacing"]) ? ct : [] },
			{
				values: [
					"current",
					"inherit",
					"transparent"
				],
				valueThemeKeys: ["--background-color", "--color"],
				modifiers: Array.from({ length: 21 }, (v, C) => `${C * 5}`)
			}
		]);
	}
	let A = () => W([
		S("--tw-mask-left", "linear-gradient(#fff, #fff)"),
		S("--tw-mask-right", "linear-gradient(#fff, #fff)"),
		S("--tw-mask-bottom", "linear-gradient(#fff, #fff)"),
		S("--tw-mask-top", "linear-gradient(#fff, #fff)")
	]);
	function k(l, g, v) {
		$(l, {
			color(C) {
				let b = [
					x(),
					A(),
					o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
					o("mask-composite", "intersect"),
					o("--tw-mask-linear", "var(--tw-mask-left), var(--tw-mask-right), var(--tw-mask-bottom), var(--tw-mask-top)")
				];
				for (let T of [
					"top",
					"right",
					"bottom",
					"left"
				]) v[T] && (b.push(o(`--tw-mask-${T}`, `linear-gradient(to ${T}, var(--tw-mask-${T}-from-color) var(--tw-mask-${T}-from-position), var(--tw-mask-${T}-to-color) var(--tw-mask-${T}-to-position))`)), b.push(W([
					S(`--tw-mask-${T}-from-position`, "0%"),
					S(`--tw-mask-${T}-to-position`, "100%"),
					S(`--tw-mask-${T}-from-color`, "black"),
					S(`--tw-mask-${T}-to-color`, "transparent")
				])), b.push(o(`--tw-mask-${T}-${g}-color`, C)));
				return b;
			},
			position(C) {
				let b = [
					x(),
					A(),
					o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
					o("mask-composite", "intersect"),
					o("--tw-mask-linear", "var(--tw-mask-left), var(--tw-mask-right), var(--tw-mask-bottom), var(--tw-mask-top)")
				];
				for (let T of [
					"top",
					"right",
					"bottom",
					"left"
				]) v[T] && (b.push(o(`--tw-mask-${T}`, `linear-gradient(to ${T}, var(--tw-mask-${T}-from-color) var(--tw-mask-${T}-from-position), var(--tw-mask-${T}-to-color) var(--tw-mask-${T}-to-position))`)), b.push(W([
					S(`--tw-mask-${T}-from-position`, "0%"),
					S(`--tw-mask-${T}-to-position`, "100%"),
					S(`--tw-mask-${T}-from-color`, "black"),
					S(`--tw-mask-${T}-to-color`, "transparent")
				])), b.push(o(`--tw-mask-${T}-${g}-position`, C)));
				return b;
			}
		});
	}
	k("mask-x-from", "from", {
		top: !1,
		right: !0,
		bottom: !1,
		left: !0
	}), k("mask-x-to", "to", {
		top: !1,
		right: !0,
		bottom: !1,
		left: !0
	}), k("mask-y-from", "from", {
		top: !0,
		right: !1,
		bottom: !0,
		left: !1
	}), k("mask-y-to", "to", {
		top: !0,
		right: !1,
		bottom: !0,
		left: !1
	}), k("mask-t-from", "from", {
		top: !0,
		right: !1,
		bottom: !1,
		left: !1
	}), k("mask-t-to", "to", {
		top: !0,
		right: !1,
		bottom: !1,
		left: !1
	}), k("mask-r-from", "from", {
		top: !1,
		right: !0,
		bottom: !1,
		left: !1
	}), k("mask-r-to", "to", {
		top: !1,
		right: !0,
		bottom: !1,
		left: !1
	}), k("mask-b-from", "from", {
		top: !1,
		right: !1,
		bottom: !0,
		left: !1
	}), k("mask-b-to", "to", {
		top: !1,
		right: !1,
		bottom: !0,
		left: !1
	}), k("mask-l-from", "from", {
		top: !1,
		right: !1,
		bottom: !1,
		left: !0
	}), k("mask-l-to", "to", {
		top: !1,
		right: !1,
		bottom: !1,
		left: !0
	});
	let U = () => W([
		S("--tw-mask-linear-position", "0deg"),
		S("--tw-mask-linear-from-position", "0%"),
		S("--tw-mask-linear-to-position", "100%"),
		S("--tw-mask-linear-from-color", "black"),
		S("--tw-mask-linear-to-color", "transparent")
	]);
	n("mask-linear", {
		defaultValue: null,
		supportsNegative: !0,
		supportsFractions: !1,
		handleBareValue(l) {
			return u(l.value) ? `calc(1deg * ${l.value})` : null;
		},
		handleNegativeBareValue(l) {
			return u(l.value) ? `calc(1deg * -${l.value})` : null;
		},
		handle: (l) => [
			x(),
			U(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-linear", "linear-gradient(var(--tw-mask-linear-stops, var(--tw-mask-linear-position)))"),
			o("--tw-mask-linear-position", l)
		]
	}), i("mask-linear", () => [{
		supportsNegative: !0,
		values: [
			"0",
			"1",
			"2",
			"3",
			"6",
			"12",
			"45",
			"90",
			"180"
		]
	}]), $("mask-linear-from", {
		color: (l) => [
			x(),
			U(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-linear-stops", "var(--tw-mask-linear-position), var(--tw-mask-linear-from-color) var(--tw-mask-linear-from-position), var(--tw-mask-linear-to-color) var(--tw-mask-linear-to-position)"),
			o("--tw-mask-linear", "linear-gradient(var(--tw-mask-linear-stops))"),
			o("--tw-mask-linear-from-color", l)
		],
		position: (l) => [
			x(),
			U(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-linear-stops", "var(--tw-mask-linear-position), var(--tw-mask-linear-from-color) var(--tw-mask-linear-from-position), var(--tw-mask-linear-to-color) var(--tw-mask-linear-to-position)"),
			o("--tw-mask-linear", "linear-gradient(var(--tw-mask-linear-stops))"),
			o("--tw-mask-linear-from-position", l)
		]
	}), $("mask-linear-to", {
		color: (l) => [
			x(),
			U(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-linear-stops", "var(--tw-mask-linear-position), var(--tw-mask-linear-from-color) var(--tw-mask-linear-from-position), var(--tw-mask-linear-to-color) var(--tw-mask-linear-to-position)"),
			o("--tw-mask-linear", "linear-gradient(var(--tw-mask-linear-stops))"),
			o("--tw-mask-linear-to-color", l)
		],
		position: (l) => [
			x(),
			U(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-linear-stops", "var(--tw-mask-linear-position), var(--tw-mask-linear-from-color) var(--tw-mask-linear-from-position), var(--tw-mask-linear-to-color) var(--tw-mask-linear-to-position)"),
			o("--tw-mask-linear", "linear-gradient(var(--tw-mask-linear-stops))"),
			o("--tw-mask-linear-to-position", l)
		]
	});
	let N = () => W([
		S("--tw-mask-radial-from-position", "0%"),
		S("--tw-mask-radial-to-position", "100%"),
		S("--tw-mask-radial-from-color", "black"),
		S("--tw-mask-radial-to-color", "transparent"),
		S("--tw-mask-radial-shape", "ellipse"),
		S("--tw-mask-radial-size", "farthest-corner"),
		S("--tw-mask-radial-position", "center")
	]);
	e("mask-circle", [["--tw-mask-radial-shape", "circle"]]), e("mask-ellipse", [["--tw-mask-radial-shape", "ellipse"]]), e("mask-radial-closest-side", [["--tw-mask-radial-size", "closest-side"]]), e("mask-radial-farthest-side", [["--tw-mask-radial-size", "farthest-side"]]), e("mask-radial-closest-corner", [["--tw-mask-radial-size", "closest-corner"]]), e("mask-radial-farthest-corner", [["--tw-mask-radial-size", "farthest-corner"]]), e("mask-radial-at-top", [["--tw-mask-radial-position", "top"]]), e("mask-radial-at-top-left", [["--tw-mask-radial-position", "top left"]]), e("mask-radial-at-top-right", [["--tw-mask-radial-position", "top right"]]), e("mask-radial-at-bottom", [["--tw-mask-radial-position", "bottom"]]), e("mask-radial-at-bottom-left", [["--tw-mask-radial-position", "bottom left"]]), e("mask-radial-at-bottom-right", [["--tw-mask-radial-position", "bottom right"]]), e("mask-radial-at-left", [["--tw-mask-radial-position", "left"]]), e("mask-radial-at-right", [["--tw-mask-radial-position", "right"]]), e("mask-radial-at-center", [["--tw-mask-radial-position", "center"]]), n("mask-radial-at", {
		defaultValue: null,
		supportsNegative: !1,
		supportsFractions: !1,
		handle: (l) => [o("--tw-mask-radial-position", l)]
	}), n("mask-radial", {
		defaultValue: null,
		supportsNegative: !1,
		supportsFractions: !1,
		handle: (l) => [
			x(),
			N(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-radial", "radial-gradient(var(--tw-mask-radial-stops, var(--tw-mask-radial-size)))"),
			o("--tw-mask-radial-size", l)
		]
	}), $("mask-radial-from", {
		color: (l) => [
			x(),
			N(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-radial-stops", "var(--tw-mask-radial-shape) var(--tw-mask-radial-size) at var(--tw-mask-radial-position), var(--tw-mask-radial-from-color) var(--tw-mask-radial-from-position), var(--tw-mask-radial-to-color) var(--tw-mask-radial-to-position)"),
			o("--tw-mask-radial", "radial-gradient(var(--tw-mask-radial-stops))"),
			o("--tw-mask-radial-from-color", l)
		],
		position: (l) => [
			x(),
			N(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-radial-stops", "var(--tw-mask-radial-shape) var(--tw-mask-radial-size) at var(--tw-mask-radial-position), var(--tw-mask-radial-from-color) var(--tw-mask-radial-from-position), var(--tw-mask-radial-to-color) var(--tw-mask-radial-to-position)"),
			o("--tw-mask-radial", "radial-gradient(var(--tw-mask-radial-stops))"),
			o("--tw-mask-radial-from-position", l)
		]
	}), $("mask-radial-to", {
		color: (l) => [
			x(),
			N(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-radial-stops", "var(--tw-mask-radial-shape) var(--tw-mask-radial-size) at var(--tw-mask-radial-position), var(--tw-mask-radial-from-color) var(--tw-mask-radial-from-position), var(--tw-mask-radial-to-color) var(--tw-mask-radial-to-position)"),
			o("--tw-mask-radial", "radial-gradient(var(--tw-mask-radial-stops))"),
			o("--tw-mask-radial-to-color", l)
		],
		position: (l) => [
			x(),
			N(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-radial-stops", "var(--tw-mask-radial-shape) var(--tw-mask-radial-size) at var(--tw-mask-radial-position), var(--tw-mask-radial-from-color) var(--tw-mask-radial-from-position), var(--tw-mask-radial-to-color) var(--tw-mask-radial-to-position)"),
			o("--tw-mask-radial", "radial-gradient(var(--tw-mask-radial-stops))"),
			o("--tw-mask-radial-to-position", l)
		]
	});
	let O = () => W([
		S("--tw-mask-conic-position", "0deg"),
		S("--tw-mask-conic-from-position", "0%"),
		S("--tw-mask-conic-to-position", "100%"),
		S("--tw-mask-conic-from-color", "black"),
		S("--tw-mask-conic-to-color", "transparent")
	]);
	n("mask-conic", {
		defaultValue: null,
		supportsNegative: !0,
		supportsFractions: !1,
		handleBareValue(l) {
			return u(l.value) ? `calc(1deg * ${l.value})` : null;
		},
		handleNegativeBareValue(l) {
			return u(l.value) ? `calc(1deg * -${l.value})` : null;
		},
		handle: (l) => [
			x(),
			O(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-conic", "conic-gradient(var(--tw-mask-conic-stops, var(--tw-mask-conic-position)))"),
			o("--tw-mask-conic-position", l)
		]
	}), i("mask-conic", () => [{
		supportsNegative: !0,
		values: [
			"0",
			"1",
			"2",
			"3",
			"6",
			"12",
			"45",
			"90",
			"180"
		]
	}]), $("mask-conic-from", {
		color: (l) => [
			x(),
			O(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-conic-stops", "from var(--tw-mask-conic-position), var(--tw-mask-conic-from-color) var(--tw-mask-conic-from-position), var(--tw-mask-conic-to-color) var(--tw-mask-conic-to-position)"),
			o("--tw-mask-conic", "conic-gradient(var(--tw-mask-conic-stops))"),
			o("--tw-mask-conic-from-color", l)
		],
		position: (l) => [
			x(),
			O(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-conic-stops", "from var(--tw-mask-conic-position), var(--tw-mask-conic-from-color) var(--tw-mask-conic-from-position), var(--tw-mask-conic-to-color) var(--tw-mask-conic-to-position)"),
			o("--tw-mask-conic", "conic-gradient(var(--tw-mask-conic-stops))"),
			o("--tw-mask-conic-from-position", l)
		]
	}), $("mask-conic-to", {
		color: (l) => [
			x(),
			O(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-conic-stops", "from var(--tw-mask-conic-position), var(--tw-mask-conic-from-color) var(--tw-mask-conic-from-position), var(--tw-mask-conic-to-color) var(--tw-mask-conic-to-position)"),
			o("--tw-mask-conic", "conic-gradient(var(--tw-mask-conic-stops))"),
			o("--tw-mask-conic-to-color", l)
		],
		position: (l) => [
			x(),
			O(),
			o("mask-image", "var(--tw-mask-linear), var(--tw-mask-radial), var(--tw-mask-conic)"),
			o("mask-composite", "intersect"),
			o("--tw-mask-conic-stops", "from var(--tw-mask-conic-position), var(--tw-mask-conic-from-color) var(--tw-mask-conic-from-position), var(--tw-mask-conic-to-color) var(--tw-mask-conic-to-position)"),
			o("--tw-mask-conic", "conic-gradient(var(--tw-mask-conic-stops))"),
			o("--tw-mask-conic-to-position", l)
		]
	}), e("box-decoration-slice", [["-webkit-box-decoration-break", "slice"], ["box-decoration-break", "slice"]]), e("box-decoration-clone", [["-webkit-box-decoration-break", "clone"], ["box-decoration-break", "clone"]]), e("bg-clip-text", [["background-clip", "text"]]), e("bg-clip-border", [["background-clip", "border-box"]]), e("bg-clip-padding", [["background-clip", "padding-box"]]), e("bg-clip-content", [["background-clip", "content-box"]]), e("bg-origin-border", [["background-origin", "border-box"]]), e("bg-origin-padding", [["background-origin", "padding-box"]]), e("bg-origin-content", [["background-origin", "content-box"]]);
	for (let l of [
		"normal",
		"multiply",
		"screen",
		"overlay",
		"darken",
		"lighten",
		"color-dodge",
		"color-burn",
		"hard-light",
		"soft-light",
		"difference",
		"exclusion",
		"hue",
		"saturation",
		"color",
		"luminosity"
	]) e(`bg-blend-${l}`, [["background-blend-mode", l]]), e(`mix-blend-${l}`, [["mix-blend-mode", l]]);
	e("mix-blend-plus-darker", [["mix-blend-mode", "plus-darker"]]), e("mix-blend-plus-lighter", [["mix-blend-mode", "plus-lighter"]]), e("fill-none", [["fill", "none"]]), r.functional("fill", (l) => {
		if (!l.value) return;
		if (l.value.kind === "arbitrary") {
			let v = X(l.value.value, l.modifier, t);
			return v === null ? void 0 : [o("fill", v)];
		}
		let g = te(l, t, ["--fill", "--color"]);
		if (g) return [o("fill", g)];
	}), i("fill", () => [{
		values: [
			"current",
			"inherit",
			"transparent"
		],
		valueThemeKeys: ["--fill", "--color"],
		modifiers: Array.from({ length: 21 }, (l, g) => `${g * 5}`)
	}]), e("stroke-none", [["stroke", "none"]]), r.functional("stroke", (l) => {
		if (l.value) {
			if (l.value.kind === "arbitrary") {
				let g = l.value.value;
				switch (l.value.dataType ?? me$1(g, [
					"color",
					"number",
					"length",
					"percentage"
				])) {
					case "number":
					case "length":
					case "percentage": return l.modifier ? void 0 : [o("stroke-width", g)];
					default: return g = X(l.value.value, l.modifier, t), g === null ? void 0 : [o("stroke", g)];
				}
			}
			{
				let g = te(l, t, ["--stroke", "--color"]);
				if (g) return [o("stroke", g)];
			}
			{
				let g = t.resolve(l.value.value, ["--stroke-width"]);
				if (g) return [o("stroke-width", g)];
				if (u(l.value.value)) return [o("stroke-width", l.value.value)];
			}
		}
	}), i("stroke", () => [{
		values: [
			"current",
			"inherit",
			"transparent"
		],
		valueThemeKeys: ["--stroke", "--color"],
		modifiers: Array.from({ length: 21 }, (l, g) => `${g * 5}`)
	}, {
		values: [
			"0",
			"1",
			"2",
			"3"
		],
		valueThemeKeys: ["--stroke-width"]
	}]), e("object-contain", [["object-fit", "contain"]]), e("object-cover", [["object-fit", "cover"]]), e("object-fill", [["object-fit", "fill"]]), e("object-none", [["object-fit", "none"]]), e("object-scale-down", [["object-fit", "scale-down"]]), n("object", {
		themeKeys: ["--object-position"],
		handle: (l) => [o("object-position", l)],
		staticValues: {
			top: [o("object-position", "top")],
			"top-left": [o("object-position", "left top")],
			"top-right": [o("object-position", "right top")],
			bottom: [o("object-position", "bottom")],
			"bottom-left": [o("object-position", "left bottom")],
			"bottom-right": [o("object-position", "right bottom")],
			left: [o("object-position", "left")],
			right: [o("object-position", "right")],
			center: [o("object-position", "center")]
		}
	});
	for (let [l, g] of [
		["p", "padding"],
		["px", "padding-inline"],
		["py", "padding-block"],
		["ps", "padding-inline-start"],
		["pe", "padding-inline-end"],
		["pt", "padding-top"],
		["pr", "padding-right"],
		["pb", "padding-bottom"],
		["pl", "padding-left"]
	]) a(l, ["--padding", "--spacing"], (v) => [o(g, v)]);
	e("text-left", [["text-align", "left"]]), e("text-center", [["text-align", "center"]]), e("text-right", [["text-align", "right"]]), e("text-justify", [["text-align", "justify"]]), e("text-start", [["text-align", "start"]]), e("text-end", [["text-align", "end"]]), a("indent", ["--text-indent", "--spacing"], (l) => [o("text-indent", l)], { supportsNegative: !0 }), e("align-baseline", [["vertical-align", "baseline"]]), e("align-top", [["vertical-align", "top"]]), e("align-middle", [["vertical-align", "middle"]]), e("align-bottom", [["vertical-align", "bottom"]]), e("align-text-top", [["vertical-align", "text-top"]]), e("align-text-bottom", [["vertical-align", "text-bottom"]]), e("align-sub", [["vertical-align", "sub"]]), e("align-super", [["vertical-align", "super"]]), n("align", {
		themeKeys: [],
		handle: (l) => [o("vertical-align", l)]
	}), r.functional("font", (l) => {
		if (!(!l.value || l.modifier)) {
			if (l.value.kind === "arbitrary") {
				let g = l.value.value;
				switch (l.value.dataType ?? me$1(g, [
					"number",
					"generic-name",
					"family-name"
				])) {
					case "generic-name":
					case "family-name": return [o("font-family", g)];
					default: return [
						W([S("--tw-font-weight")]),
						o("--tw-font-weight", g),
						o("font-weight", g)
					];
				}
			}
			{
				let g = t.resolveWith(l.value.value, ["--font"], ["--font-feature-settings", "--font-variation-settings"]);
				if (g) {
					let [v, C = {}] = g;
					return [
						o("font-family", v),
						o("font-feature-settings", C["--font-feature-settings"]),
						o("font-variation-settings", C["--font-variation-settings"])
					];
				}
			}
			{
				let g = t.resolve(l.value.value, ["--font-weight"]);
				if (g) return [
					W([S("--tw-font-weight")]),
					o("--tw-font-weight", g),
					o("font-weight", g)
				];
			}
		}
	}), i("font", () => [{
		values: [],
		valueThemeKeys: ["--font"]
	}, {
		values: [],
		valueThemeKeys: ["--font-weight"]
	}]), e("uppercase", [["text-transform", "uppercase"]]), e("lowercase", [["text-transform", "lowercase"]]), e("capitalize", [["text-transform", "capitalize"]]), e("normal-case", [["text-transform", "none"]]), e("italic", [["font-style", "italic"]]), e("not-italic", [["font-style", "normal"]]), e("underline", [["text-decoration-line", "underline"]]), e("overline", [["text-decoration-line", "overline"]]), e("line-through", [["text-decoration-line", "line-through"]]), e("no-underline", [["text-decoration-line", "none"]]), e("font-stretch-normal", [["font-stretch", "normal"]]), e("font-stretch-ultra-condensed", [["font-stretch", "ultra-condensed"]]), e("font-stretch-extra-condensed", [["font-stretch", "extra-condensed"]]), e("font-stretch-condensed", [["font-stretch", "condensed"]]), e("font-stretch-semi-condensed", [["font-stretch", "semi-condensed"]]), e("font-stretch-semi-expanded", [["font-stretch", "semi-expanded"]]), e("font-stretch-expanded", [["font-stretch", "expanded"]]), e("font-stretch-extra-expanded", [["font-stretch", "extra-expanded"]]), e("font-stretch-ultra-expanded", [["font-stretch", "ultra-expanded"]]), n("font-stretch", {
		handleBareValue: ({ value: l }) => {
			if (!l.endsWith("%")) return null;
			let g = Number(l.slice(0, -1));
			return !u(g) || Number.isNaN(g) || g < 50 || g > 200 ? null : l;
		},
		handle: (l) => [o("font-stretch", l)]
	}), i("font-stretch", () => [{ values: [
		"50%",
		"75%",
		"90%",
		"95%",
		"100%",
		"105%",
		"110%",
		"125%",
		"150%",
		"200%"
	] }]), s("placeholder", {
		themeKeys: ["--background-color", "--color"],
		handle: (l) => [G("&::placeholder", [o("--tw-sort", "placeholder-color"), o("color", l)])]
	}), e("decoration-solid", [["text-decoration-style", "solid"]]), e("decoration-double", [["text-decoration-style", "double"]]), e("decoration-dotted", [["text-decoration-style", "dotted"]]), e("decoration-dashed", [["text-decoration-style", "dashed"]]), e("decoration-wavy", [["text-decoration-style", "wavy"]]), e("decoration-auto", [["text-decoration-thickness", "auto"]]), e("decoration-from-font", [["text-decoration-thickness", "from-font"]]), r.functional("decoration", (l) => {
		if (l.value) {
			if (l.value.kind === "arbitrary") {
				let g = l.value.value;
				switch (l.value.dataType ?? me$1(g, [
					"color",
					"length",
					"percentage"
				])) {
					case "length":
					case "percentage": return l.modifier ? void 0 : [o("text-decoration-thickness", g)];
					default: return g = X(g, l.modifier, t), g === null ? void 0 : [o("text-decoration-color", g)];
				}
			}
			{
				let g = t.resolve(l.value.value, ["--text-decoration-thickness"]);
				if (g) return l.modifier ? void 0 : [o("text-decoration-thickness", g)];
				if (u(l.value.value)) return l.modifier ? void 0 : [o("text-decoration-thickness", `${l.value.value}px`)];
			}
			{
				let g = te(l, t, ["--text-decoration-color", "--color"]);
				if (g) return [o("text-decoration-color", g)];
			}
		}
	}), i("decoration", () => [{
		values: [
			"current",
			"inherit",
			"transparent"
		],
		valueThemeKeys: ["--text-decoration-color", "--color"],
		modifiers: Array.from({ length: 21 }, (l, g) => `${g * 5}`)
	}, {
		values: [
			"0",
			"1",
			"2"
		],
		valueThemeKeys: ["--text-decoration-thickness"]
	}]), n("animate", {
		themeKeys: ["--animate"],
		handle: (l) => [o("animation", l)],
		staticValues: { none: [o("animation", "none")] }
	});
	{
		let l = [
			"var(--tw-blur,)",
			"var(--tw-brightness,)",
			"var(--tw-contrast,)",
			"var(--tw-grayscale,)",
			"var(--tw-hue-rotate,)",
			"var(--tw-invert,)",
			"var(--tw-saturate,)",
			"var(--tw-sepia,)",
			"var(--tw-drop-shadow,)"
		].join(" "), g = [
			"var(--tw-backdrop-blur,)",
			"var(--tw-backdrop-brightness,)",
			"var(--tw-backdrop-contrast,)",
			"var(--tw-backdrop-grayscale,)",
			"var(--tw-backdrop-hue-rotate,)",
			"var(--tw-backdrop-invert,)",
			"var(--tw-backdrop-opacity,)",
			"var(--tw-backdrop-saturate,)",
			"var(--tw-backdrop-sepia,)"
		].join(" "), v = () => W([
			S("--tw-blur"),
			S("--tw-brightness"),
			S("--tw-contrast"),
			S("--tw-grayscale"),
			S("--tw-hue-rotate"),
			S("--tw-invert"),
			S("--tw-opacity"),
			S("--tw-saturate"),
			S("--tw-sepia"),
			S("--tw-drop-shadow"),
			S("--tw-drop-shadow-color"),
			S("--tw-drop-shadow-alpha", "100%", "<percentage>"),
			S("--tw-drop-shadow-size")
		]), C = () => W([
			S("--tw-backdrop-blur"),
			S("--tw-backdrop-brightness"),
			S("--tw-backdrop-contrast"),
			S("--tw-backdrop-grayscale"),
			S("--tw-backdrop-hue-rotate"),
			S("--tw-backdrop-invert"),
			S("--tw-backdrop-opacity"),
			S("--tw-backdrop-saturate"),
			S("--tw-backdrop-sepia")
		]);
		r.functional("filter", (b) => {
			if (!b.modifier) {
				if (b.value === null) return [v(), o("filter", l)];
				if (b.value.kind === "arbitrary") return [o("filter", b.value.value)];
				switch (b.value.value) {
					case "none": return [o("filter", "none")];
				}
			}
		}), r.functional("backdrop-filter", (b) => {
			if (!b.modifier) {
				if (b.value === null) return [
					C(),
					o("-webkit-backdrop-filter", g),
					o("backdrop-filter", g)
				];
				if (b.value.kind === "arbitrary") return [o("-webkit-backdrop-filter", b.value.value), o("backdrop-filter", b.value.value)];
				switch (b.value.value) {
					case "none": return [o("-webkit-backdrop-filter", "none"), o("backdrop-filter", "none")];
				}
			}
		}), n("blur", {
			themeKeys: ["--blur"],
			handle: (b) => [
				v(),
				o("--tw-blur", `blur(${b})`),
				o("filter", l)
			],
			staticValues: { none: [
				v(),
				o("--tw-blur", " "),
				o("filter", l)
			] }
		}), n("backdrop-blur", {
			themeKeys: ["--backdrop-blur", "--blur"],
			handle: (b) => [
				C(),
				o("--tw-backdrop-blur", `blur(${b})`),
				o("-webkit-backdrop-filter", g),
				o("backdrop-filter", g)
			],
			staticValues: { none: [
				C(),
				o("--tw-backdrop-blur", " "),
				o("-webkit-backdrop-filter", g),
				o("backdrop-filter", g)
			] }
		}), n("brightness", {
			themeKeys: ["--brightness"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			handle: (b) => [
				v(),
				o("--tw-brightness", `brightness(${b})`),
				o("filter", l)
			]
		}), n("backdrop-brightness", {
			themeKeys: ["--backdrop-brightness", "--brightness"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			handle: (b) => [
				C(),
				o("--tw-backdrop-brightness", `brightness(${b})`),
				o("-webkit-backdrop-filter", g),
				o("backdrop-filter", g)
			]
		}), i("brightness", () => [{
			values: [
				"0",
				"50",
				"75",
				"90",
				"95",
				"100",
				"105",
				"110",
				"125",
				"150",
				"200"
			],
			valueThemeKeys: ["--brightness"]
		}]), i("backdrop-brightness", () => [{
			values: [
				"0",
				"50",
				"75",
				"90",
				"95",
				"100",
				"105",
				"110",
				"125",
				"150",
				"200"
			],
			valueThemeKeys: ["--backdrop-brightness", "--brightness"]
		}]), n("contrast", {
			themeKeys: ["--contrast"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			handle: (b) => [
				v(),
				o("--tw-contrast", `contrast(${b})`),
				o("filter", l)
			]
		}), n("backdrop-contrast", {
			themeKeys: ["--backdrop-contrast", "--contrast"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			handle: (b) => [
				C(),
				o("--tw-backdrop-contrast", `contrast(${b})`),
				o("-webkit-backdrop-filter", g),
				o("backdrop-filter", g)
			]
		}), i("contrast", () => [{
			values: [
				"0",
				"50",
				"75",
				"100",
				"125",
				"150",
				"200"
			],
			valueThemeKeys: ["--contrast"]
		}]), i("backdrop-contrast", () => [{
			values: [
				"0",
				"50",
				"75",
				"100",
				"125",
				"150",
				"200"
			],
			valueThemeKeys: ["--backdrop-contrast", "--contrast"]
		}]), n("grayscale", {
			themeKeys: ["--grayscale"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			defaultValue: "100%",
			handle: (b) => [
				v(),
				o("--tw-grayscale", `grayscale(${b})`),
				o("filter", l)
			]
		}), n("backdrop-grayscale", {
			themeKeys: ["--backdrop-grayscale", "--grayscale"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			defaultValue: "100%",
			handle: (b) => [
				C(),
				o("--tw-backdrop-grayscale", `grayscale(${b})`),
				o("-webkit-backdrop-filter", g),
				o("backdrop-filter", g)
			]
		}), i("grayscale", () => [{
			values: [
				"0",
				"25",
				"50",
				"75",
				"100"
			],
			valueThemeKeys: ["--grayscale"],
			hasDefaultValue: !0
		}]), i("backdrop-grayscale", () => [{
			values: [
				"0",
				"25",
				"50",
				"75",
				"100"
			],
			valueThemeKeys: ["--backdrop-grayscale", "--grayscale"],
			hasDefaultValue: !0
		}]), n("hue-rotate", {
			supportsNegative: !0,
			themeKeys: ["--hue-rotate"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}deg` : null,
			handle: (b) => [
				v(),
				o("--tw-hue-rotate", `hue-rotate(${b})`),
				o("filter", l)
			]
		}), n("backdrop-hue-rotate", {
			supportsNegative: !0,
			themeKeys: ["--backdrop-hue-rotate", "--hue-rotate"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}deg` : null,
			handle: (b) => [
				C(),
				o("--tw-backdrop-hue-rotate", `hue-rotate(${b})`),
				o("-webkit-backdrop-filter", g),
				o("backdrop-filter", g)
			]
		}), i("hue-rotate", () => [{
			values: [
				"0",
				"15",
				"30",
				"60",
				"90",
				"180"
			],
			valueThemeKeys: ["--hue-rotate"]
		}]), i("backdrop-hue-rotate", () => [{
			values: [
				"0",
				"15",
				"30",
				"60",
				"90",
				"180"
			],
			valueThemeKeys: ["--backdrop-hue-rotate", "--hue-rotate"]
		}]), n("invert", {
			themeKeys: ["--invert"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			defaultValue: "100%",
			handle: (b) => [
				v(),
				o("--tw-invert", `invert(${b})`),
				o("filter", l)
			]
		}), n("backdrop-invert", {
			themeKeys: ["--backdrop-invert", "--invert"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			defaultValue: "100%",
			handle: (b) => [
				C(),
				o("--tw-backdrop-invert", `invert(${b})`),
				o("-webkit-backdrop-filter", g),
				o("backdrop-filter", g)
			]
		}), i("invert", () => [{
			values: [
				"0",
				"25",
				"50",
				"75",
				"100"
			],
			valueThemeKeys: ["--invert"],
			hasDefaultValue: !0
		}]), i("backdrop-invert", () => [{
			values: [
				"0",
				"25",
				"50",
				"75",
				"100"
			],
			valueThemeKeys: ["--backdrop-invert", "--invert"],
			hasDefaultValue: !0
		}]), n("saturate", {
			themeKeys: ["--saturate"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			handle: (b) => [
				v(),
				o("--tw-saturate", `saturate(${b})`),
				o("filter", l)
			]
		}), n("backdrop-saturate", {
			themeKeys: ["--backdrop-saturate", "--saturate"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			handle: (b) => [
				C(),
				o("--tw-backdrop-saturate", `saturate(${b})`),
				o("-webkit-backdrop-filter", g),
				o("backdrop-filter", g)
			]
		}), i("saturate", () => [{
			values: [
				"0",
				"50",
				"100",
				"150",
				"200"
			],
			valueThemeKeys: ["--saturate"]
		}]), i("backdrop-saturate", () => [{
			values: [
				"0",
				"50",
				"100",
				"150",
				"200"
			],
			valueThemeKeys: ["--backdrop-saturate", "--saturate"]
		}]), n("sepia", {
			themeKeys: ["--sepia"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			defaultValue: "100%",
			handle: (b) => [
				v(),
				o("--tw-sepia", `sepia(${b})`),
				o("filter", l)
			]
		}), n("backdrop-sepia", {
			themeKeys: ["--backdrop-sepia", "--sepia"],
			handleBareValue: ({ value: b }) => u(b) ? `${b}%` : null,
			defaultValue: "100%",
			handle: (b) => [
				C(),
				o("--tw-backdrop-sepia", `sepia(${b})`),
				o("-webkit-backdrop-filter", g),
				o("backdrop-filter", g)
			]
		}), i("sepia", () => [{
			values: [
				"0",
				"50",
				"100"
			],
			valueThemeKeys: ["--sepia"],
			hasDefaultValue: !0
		}]), i("backdrop-sepia", () => [{
			values: [
				"0",
				"50",
				"100"
			],
			valueThemeKeys: ["--backdrop-sepia", "--sepia"],
			hasDefaultValue: !0
		}]), e("drop-shadow-none", [
			v,
			["--tw-drop-shadow", " "],
			["filter", l]
		]), r.functional("drop-shadow", (b) => {
			let T;
			if (b.modifier && (b.modifier.kind === "arbitrary" ? T = b.modifier.value : u(b.modifier.value) && (T = `${b.modifier.value}%`)), !b.value) {
				let D = t.get(["--drop-shadow"]), V = t.resolve(null, ["--drop-shadow"]);
				return D === null || V === null ? void 0 : [
					v(),
					o("--tw-drop-shadow-alpha", T),
					...ft("--tw-drop-shadow-size", D, T, (R) => `var(--tw-drop-shadow-color, ${R})`),
					o("--tw-drop-shadow", d(V, ",").map((R) => `drop-shadow(${R})`).join(" ")),
					o("filter", l)
				];
			}
			if (b.value.kind === "arbitrary") {
				let D = b.value.value;
				switch (b.value.dataType ?? me$1(D, ["color"])) {
					case "color": return D = X(D, b.modifier, t), D === null ? void 0 : [
						v(),
						o("--tw-drop-shadow-color", Q(D, "var(--tw-drop-shadow-alpha)")),
						o("--tw-drop-shadow", "var(--tw-drop-shadow-size)")
					];
					default: return b.modifier && !T ? void 0 : [
						v(),
						o("--tw-drop-shadow-alpha", T),
						...ft("--tw-drop-shadow-size", D, T, (R) => `var(--tw-drop-shadow-color, ${R})`),
						o("--tw-drop-shadow", "var(--tw-drop-shadow-size)"),
						o("filter", l)
					];
				}
			}
			{
				let D = t.get([`--drop-shadow-${b.value.value}`]), V = t.resolve(b.value.value, ["--drop-shadow"]);
				if (D && V) return b.modifier && !T ? void 0 : T ? [
					v(),
					o("--tw-drop-shadow-alpha", T),
					...ft("--tw-drop-shadow-size", D, T, (R) => `var(--tw-drop-shadow-color, ${R})`),
					o("--tw-drop-shadow", "var(--tw-drop-shadow-size)"),
					o("filter", l)
				] : [
					v(),
					o("--tw-drop-shadow-alpha", T),
					...ft("--tw-drop-shadow-size", D, T, (R) => `var(--tw-drop-shadow-color, ${R})`),
					o("--tw-drop-shadow", d(V, ",").map((R) => `drop-shadow(${R})`).join(" ")),
					o("filter", l)
				];
			}
			{
				let D = te(b, t, ["--drop-shadow-color", "--color"]);
				if (D) return D === "inherit" ? [
					v(),
					o("--tw-drop-shadow-color", "inherit"),
					o("--tw-drop-shadow", "var(--tw-drop-shadow-size)")
				] : [
					v(),
					o("--tw-drop-shadow-color", Q(D, "var(--tw-drop-shadow-alpha)")),
					o("--tw-drop-shadow", "var(--tw-drop-shadow-size)")
				];
			}
		}), i("drop-shadow", () => [{
			values: [
				"current",
				"inherit",
				"transparent"
			],
			valueThemeKeys: ["--drop-shadow-color", "--color"],
			modifiers: Array.from({ length: 21 }, (b, T) => `${T * 5}`)
		}, { valueThemeKeys: ["--drop-shadow"] }]), n("backdrop-opacity", {
			themeKeys: ["--backdrop-opacity", "--opacity"],
			handleBareValue: ({ value: b }) => ue$1(b) ? `${b}%` : null,
			handle: (b) => [
				C(),
				o("--tw-backdrop-opacity", `opacity(${b})`),
				o("-webkit-backdrop-filter", g),
				o("backdrop-filter", g)
			]
		}), i("backdrop-opacity", () => [{
			values: Array.from({ length: 21 }, (b, T) => `${T * 5}`),
			valueThemeKeys: ["--backdrop-opacity", "--opacity"]
		}]);
	}
	{
		let l = `var(--tw-ease, ${t.resolve(null, ["--default-transition-timing-function"]) ?? "ease"})`, g = `var(--tw-duration, ${t.resolve(null, ["--default-transition-duration"]) ?? "0s"})`;
		n("transition", {
			defaultValue: "color, background-color, border-color, outline-color, text-decoration-color, fill, stroke, --tw-gradient-from, --tw-gradient-via, --tw-gradient-to, opacity, box-shadow, transform, translate, scale, rotate, filter, -webkit-backdrop-filter, backdrop-filter, display, content-visibility, overlay, pointer-events",
			themeKeys: ["--transition-property"],
			handle: (v) => [
				o("transition-property", v),
				o("transition-timing-function", l),
				o("transition-duration", g)
			],
			staticValues: {
				none: [o("transition-property", "none")],
				all: [
					o("transition-property", "all"),
					o("transition-timing-function", l),
					o("transition-duration", g)
				],
				colors: [
					o("transition-property", "color, background-color, border-color, outline-color, text-decoration-color, fill, stroke, --tw-gradient-from, --tw-gradient-via, --tw-gradient-to"),
					o("transition-timing-function", l),
					o("transition-duration", g)
				],
				opacity: [
					o("transition-property", "opacity"),
					o("transition-timing-function", l),
					o("transition-duration", g)
				],
				shadow: [
					o("transition-property", "box-shadow"),
					o("transition-timing-function", l),
					o("transition-duration", g)
				],
				transform: [
					o("transition-property", "transform, translate, scale, rotate"),
					o("transition-timing-function", l),
					o("transition-duration", g)
				]
			}
		}), e("transition-discrete", [["transition-behavior", "allow-discrete"]]), e("transition-normal", [["transition-behavior", "normal"]]), n("delay", {
			handleBareValue: ({ value: v }) => u(v) ? `${v}ms` : null,
			themeKeys: ["--transition-delay"],
			handle: (v) => [o("transition-delay", v)]
		});
		{
			let v = () => W([S("--tw-duration")]);
			e("duration-initial", [v, ["--tw-duration", "initial"]]), r.functional("duration", (C) => {
				if (C.modifier || !C.value) return;
				let b = null;
				if (C.value.kind === "arbitrary" ? b = C.value.value : (b = t.resolve(C.value.fraction ?? C.value.value, ["--transition-duration"]), b === null && u(C.value.value) && (b = `${C.value.value}ms`)), b !== null) return [
					v(),
					o("--tw-duration", b),
					o("transition-duration", b)
				];
			});
		}
		i("delay", () => [{
			values: [
				"75",
				"100",
				"150",
				"200",
				"300",
				"500",
				"700",
				"1000"
			],
			valueThemeKeys: ["--transition-delay"]
		}]), i("duration", () => [{
			values: [
				"75",
				"100",
				"150",
				"200",
				"300",
				"500",
				"700",
				"1000"
			],
			valueThemeKeys: ["--transition-duration"]
		}]);
	}
	{
		let l = () => W([S("--tw-ease")]);
		n("ease", {
			themeKeys: ["--ease"],
			handle: (g) => [
				l(),
				o("--tw-ease", g),
				o("transition-timing-function", g)
			],
			staticValues: {
				initial: [l(), o("--tw-ease", "initial")],
				linear: [
					l(),
					o("--tw-ease", "linear"),
					o("transition-timing-function", "linear")
				]
			}
		});
	}
	e("will-change-auto", [["will-change", "auto"]]), e("will-change-scroll", [["will-change", "scroll-position"]]), e("will-change-contents", [["will-change", "contents"]]), e("will-change-transform", [["will-change", "transform"]]), n("will-change", {
		themeKeys: [],
		handle: (l) => [o("will-change", l)]
	}), e("content-none", [["--tw-content", "none"], ["content", "none"]]), n("content", {
		themeKeys: ["--content"],
		handle: (l) => [
			W([S("--tw-content", "\"\"")]),
			o("--tw-content", l),
			o("content", "var(--tw-content)")
		]
	});
	{
		let l = "var(--tw-contain-size,) var(--tw-contain-layout,) var(--tw-contain-paint,) var(--tw-contain-style,)", g = () => W([
			S("--tw-contain-size"),
			S("--tw-contain-layout"),
			S("--tw-contain-paint"),
			S("--tw-contain-style")
		]);
		e("contain-none", [["contain", "none"]]), e("contain-content", [["contain", "content"]]), e("contain-strict", [["contain", "strict"]]), e("contain-size", [
			g,
			["--tw-contain-size", "size"],
			["contain", l]
		]), e("contain-inline-size", [
			g,
			["--tw-contain-size", "inline-size"],
			["contain", l]
		]), e("contain-layout", [
			g,
			["--tw-contain-layout", "layout"],
			["contain", l]
		]), e("contain-paint", [
			g,
			["--tw-contain-paint", "paint"],
			["contain", l]
		]), e("contain-style", [
			g,
			["--tw-contain-style", "style"],
			["contain", l]
		]), n("contain", {
			themeKeys: [],
			handle: (v) => [o("contain", v)]
		});
	}
	e("forced-color-adjust-none", [["forced-color-adjust", "none"]]), e("forced-color-adjust-auto", [["forced-color-adjust", "auto"]]), a("leading", ["--leading", "--spacing"], (l) => [
		W([S("--tw-leading")]),
		o("--tw-leading", l),
		o("line-height", l)
	], { staticValues: { none: [
		W([S("--tw-leading")]),
		o("--tw-leading", "1"),
		o("line-height", "1")
	] } }), n("tracking", {
		supportsNegative: !0,
		themeKeys: ["--tracking"],
		handle: (l) => [
			W([S("--tw-tracking")]),
			o("--tw-tracking", l),
			o("letter-spacing", l)
		]
	}), e("antialiased", [["-webkit-font-smoothing", "antialiased"], ["-moz-osx-font-smoothing", "grayscale"]]), e("subpixel-antialiased", [["-webkit-font-smoothing", "auto"], ["-moz-osx-font-smoothing", "auto"]]);
	{
		let l = "var(--tw-ordinal,) var(--tw-slashed-zero,) var(--tw-numeric-figure,) var(--tw-numeric-spacing,) var(--tw-numeric-fraction,)", g = () => W([
			S("--tw-ordinal"),
			S("--tw-slashed-zero"),
			S("--tw-numeric-figure"),
			S("--tw-numeric-spacing"),
			S("--tw-numeric-fraction")
		]);
		e("normal-nums", [["font-variant-numeric", "normal"]]), e("ordinal", [
			g,
			["--tw-ordinal", "ordinal"],
			["font-variant-numeric", l]
		]), e("slashed-zero", [
			g,
			["--tw-slashed-zero", "slashed-zero"],
			["font-variant-numeric", l]
		]), e("lining-nums", [
			g,
			["--tw-numeric-figure", "lining-nums"],
			["font-variant-numeric", l]
		]), e("oldstyle-nums", [
			g,
			["--tw-numeric-figure", "oldstyle-nums"],
			["font-variant-numeric", l]
		]), e("proportional-nums", [
			g,
			["--tw-numeric-spacing", "proportional-nums"],
			["font-variant-numeric", l]
		]), e("tabular-nums", [
			g,
			["--tw-numeric-spacing", "tabular-nums"],
			["font-variant-numeric", l]
		]), e("diagonal-fractions", [
			g,
			["--tw-numeric-fraction", "diagonal-fractions"],
			["font-variant-numeric", l]
		]), e("stacked-fractions", [
			g,
			["--tw-numeric-fraction", "stacked-fractions"],
			["font-variant-numeric", l]
		]);
	}
	{
		let l = () => W([S("--tw-outline-style", "solid")]);
		r.static("outline-hidden", () => [
			o("--tw-outline-style", "none"),
			o("outline-style", "none"),
			F("@media", "(forced-colors: active)", [o("outline", "2px solid transparent"), o("outline-offset", "2px")])
		]), e("outline-none", [["--tw-outline-style", "none"], ["outline-style", "none"]]), e("outline-solid", [["--tw-outline-style", "solid"], ["outline-style", "solid"]]), e("outline-dashed", [["--tw-outline-style", "dashed"], ["outline-style", "dashed"]]), e("outline-dotted", [["--tw-outline-style", "dotted"], ["outline-style", "dotted"]]), e("outline-double", [["--tw-outline-style", "double"], ["outline-style", "double"]]), r.functional("outline", (g) => {
			if (g.value === null) {
				if (g.modifier) return;
				let v = t.get(["--default-outline-width"]) ?? "1px";
				return [
					l(),
					o("outline-style", "var(--tw-outline-style)"),
					o("outline-width", v)
				];
			}
			if (g.value.kind === "arbitrary") {
				let v = g.value.value;
				switch (g.value.dataType ?? me$1(v, [
					"color",
					"length",
					"number",
					"percentage"
				])) {
					case "length":
					case "number":
					case "percentage": return g.modifier ? void 0 : [
						l(),
						o("outline-style", "var(--tw-outline-style)"),
						o("outline-width", v)
					];
					default: return v = X(v, g.modifier, t), v === null ? void 0 : [o("outline-color", v)];
				}
			}
			{
				let v = te(g, t, ["--outline-color", "--color"]);
				if (v) return [o("outline-color", v)];
			}
			{
				if (g.modifier) return;
				let v = t.resolve(g.value.value, ["--outline-width"]);
				if (v) return [
					l(),
					o("outline-style", "var(--tw-outline-style)"),
					o("outline-width", v)
				];
				if (u(g.value.value)) return [
					l(),
					o("outline-style", "var(--tw-outline-style)"),
					o("outline-width", `${g.value.value}px`)
				];
			}
		}), i("outline", () => [{
			values: [
				"current",
				"inherit",
				"transparent"
			],
			valueThemeKeys: ["--outline-color", "--color"],
			modifiers: Array.from({ length: 21 }, (g, v) => `${v * 5}`),
			hasDefaultValue: !0
		}, {
			values: [
				"0",
				"1",
				"2",
				"4",
				"8"
			],
			valueThemeKeys: ["--outline-width"]
		}]), n("outline-offset", {
			supportsNegative: !0,
			themeKeys: ["--outline-offset"],
			handleBareValue: ({ value: g }) => u(g) ? `${g}px` : null,
			handle: (g) => [o("outline-offset", g)]
		}), i("outline-offset", () => [{
			supportsNegative: !0,
			values: [
				"0",
				"1",
				"2",
				"4",
				"8"
			],
			valueThemeKeys: ["--outline-offset"]
		}]);
	}
	n("opacity", {
		themeKeys: ["--opacity"],
		handleBareValue: ({ value: l }) => ue$1(l) ? `${l}%` : null,
		handle: (l) => [o("opacity", l)]
	}), i("opacity", () => [{
		values: Array.from({ length: 21 }, (l, g) => `${g * 5}`),
		valueThemeKeys: ["--opacity"]
	}]), n("underline-offset", {
		supportsNegative: !0,
		themeKeys: ["--text-underline-offset"],
		handleBareValue: ({ value: l }) => u(l) ? `${l}px` : null,
		handle: (l) => [o("text-underline-offset", l)],
		staticValues: { auto: [o("text-underline-offset", "auto")] }
	}), i("underline-offset", () => [{
		supportsNegative: !0,
		values: [
			"0",
			"1",
			"2",
			"4",
			"8"
		],
		valueThemeKeys: ["--text-underline-offset"]
	}]), r.functional("text", (l) => {
		if (l.value) {
			if (l.value.kind === "arbitrary") {
				let g = l.value.value;
				switch (l.value.dataType ?? me$1(g, [
					"color",
					"length",
					"percentage",
					"absolute-size",
					"relative-size"
				])) {
					case "size":
					case "length":
					case "percentage":
					case "absolute-size":
					case "relative-size":
						if (l.modifier) {
							let C = l.modifier.kind === "arbitrary" ? l.modifier.value : t.resolve(l.modifier.value, ["--leading"]);
							if (!C && ge(l.modifier.value)) {
								let b = t.resolve(null, ["--spacing"]);
								if (!b) return null;
								C = `calc(${b} * ${l.modifier.value})`;
							}
							return !C && l.modifier.value === "none" && (C = "1"), C ? [o("font-size", g), o("line-height", C)] : null;
						}
						return [o("font-size", g)];
					default: return g = X(g, l.modifier, t), g === null ? void 0 : [o("color", g)];
				}
			}
			{
				let g = te(l, t, ["--text-color", "--color"]);
				if (g) return [o("color", g)];
			}
			{
				let g = t.resolveWith(l.value.value, ["--text"], [
					"--line-height",
					"--letter-spacing",
					"--font-weight"
				]);
				if (g) {
					let [v, C = {}] = Array.isArray(g) ? g : [g];
					if (l.modifier) {
						let b = l.modifier.kind === "arbitrary" ? l.modifier.value : t.resolve(l.modifier.value, ["--leading"]);
						if (!b && ge(l.modifier.value)) {
							let D = t.resolve(null, ["--spacing"]);
							if (!D) return null;
							b = `calc(${D} * ${l.modifier.value})`;
						}
						if (!b && l.modifier.value === "none" && (b = "1"), !b) return null;
						let T = [o("font-size", v)];
						return b && T.push(o("line-height", b)), T;
					}
					return typeof C == "string" ? [o("font-size", v), o("line-height", C)] : [
						o("font-size", v),
						o("line-height", C["--line-height"] ? `var(--tw-leading, ${C["--line-height"]})` : void 0),
						o("letter-spacing", C["--letter-spacing"] ? `var(--tw-tracking, ${C["--letter-spacing"]})` : void 0),
						o("font-weight", C["--font-weight"] ? `var(--tw-font-weight, ${C["--font-weight"]})` : void 0)
					];
				}
			}
		}
	}), i("text", () => [{
		values: [
			"current",
			"inherit",
			"transparent"
		],
		valueThemeKeys: ["--text-color", "--color"],
		modifiers: Array.from({ length: 21 }, (l, g) => `${g * 5}`)
	}, {
		values: [],
		valueThemeKeys: ["--text"],
		modifiers: [],
		modifierThemeKeys: ["--leading"]
	}]);
	let L = () => W([S("--tw-text-shadow-color"), S("--tw-text-shadow-alpha", "100%", "<percentage>")]);
	e("text-shadow-initial", [L, ["--tw-text-shadow-color", "initial"]]), r.functional("text-shadow", (l) => {
		let g;
		if (l.modifier && (l.modifier.kind === "arbitrary" ? g = l.modifier.value : u(l.modifier.value) && (g = `${l.modifier.value}%`)), !l.value) {
			let v = t.get(["--text-shadow"]);
			return v === null ? void 0 : [
				L(),
				o("--tw-text-shadow-alpha", g),
				...ve("text-shadow", v, g, (C) => `var(--tw-text-shadow-color, ${C})`)
			];
		}
		if (l.value.kind === "arbitrary") {
			let v = l.value.value;
			switch (l.value.dataType ?? me$1(v, ["color"])) {
				case "color": return v = X(v, l.modifier, t), v === null ? void 0 : [L(), o("--tw-text-shadow-color", Q(v, "var(--tw-text-shadow-alpha)"))];
				default: return [
					L(),
					o("--tw-text-shadow-alpha", g),
					...ve("text-shadow", v, g, (b) => `var(--tw-text-shadow-color, ${b})`)
				];
			}
		}
		switch (l.value.value) {
			case "none": return l.modifier ? void 0 : [L(), o("text-shadow", "none")];
			case "inherit": return l.modifier ? void 0 : [L(), o("--tw-text-shadow-color", "inherit")];
		}
		{
			let v = t.get([`--text-shadow-${l.value.value}`]);
			if (v) return [
				L(),
				o("--tw-text-shadow-alpha", g),
				...ve("text-shadow", v, g, (C) => `var(--tw-text-shadow-color, ${C})`)
			];
		}
		{
			let v = te(l, t, ["--text-shadow-color", "--color"]);
			if (v) return [L(), o("--tw-text-shadow-color", Q(v, "var(--tw-text-shadow-alpha)"))];
		}
	}), i("text-shadow", () => [
		{
			values: [
				"current",
				"inherit",
				"transparent"
			],
			valueThemeKeys: ["--text-shadow-color", "--color"],
			modifiers: Array.from({ length: 21 }, (l, g) => `${g * 5}`)
		},
		{ values: ["none"] },
		{
			valueThemeKeys: ["--text-shadow"],
			modifiers: Array.from({ length: 21 }, (l, g) => `${g * 5}`),
			hasDefaultValue: t.get(["--text-shadow"]) !== null
		}
	]);
	{
		let b = function(V) {
			return `var(--tw-ring-inset,) 0 0 0 calc(${V} + var(--tw-ring-offset-width)) var(--tw-ring-color, ${C})`;
		}, T = function(V) {
			return `inset 0 0 0 ${V} var(--tw-inset-ring-color, currentcolor)`;
		};
		let l = [
			"var(--tw-inset-shadow)",
			"var(--tw-inset-ring-shadow)",
			"var(--tw-ring-offset-shadow)",
			"var(--tw-ring-shadow)",
			"var(--tw-shadow)"
		].join(", "), g = "0 0 #0000", v = () => W([
			S("--tw-shadow", g),
			S("--tw-shadow-color"),
			S("--tw-shadow-alpha", "100%", "<percentage>"),
			S("--tw-inset-shadow", g),
			S("--tw-inset-shadow-color"),
			S("--tw-inset-shadow-alpha", "100%", "<percentage>"),
			S("--tw-ring-color"),
			S("--tw-ring-shadow", g),
			S("--tw-inset-ring-color"),
			S("--tw-inset-ring-shadow", g),
			S("--tw-ring-inset"),
			S("--tw-ring-offset-width", "0px", "<length>"),
			S("--tw-ring-offset-color", "#fff"),
			S("--tw-ring-offset-shadow", g)
		]);
		e("shadow-initial", [v, ["--tw-shadow-color", "initial"]]), r.functional("shadow", (V) => {
			let R;
			if (V.modifier && (V.modifier.kind === "arbitrary" ? R = V.modifier.value : u(V.modifier.value) && (R = `${V.modifier.value}%`)), !V.value) {
				let M = t.get(["--shadow"]);
				return M === null ? void 0 : [
					v(),
					o("--tw-shadow-alpha", R),
					...ve("--tw-shadow", M, R, (fe) => `var(--tw-shadow-color, ${fe})`),
					o("box-shadow", l)
				];
			}
			if (V.value.kind === "arbitrary") {
				let M = V.value.value;
				switch (V.value.dataType ?? me$1(M, ["color"])) {
					case "color": return M = X(M, V.modifier, t), M === null ? void 0 : [v(), o("--tw-shadow-color", Q(M, "var(--tw-shadow-alpha)"))];
					default: return [
						v(),
						o("--tw-shadow-alpha", R),
						...ve("--tw-shadow", M, R, (At) => `var(--tw-shadow-color, ${At})`),
						o("box-shadow", l)
					];
				}
			}
			switch (V.value.value) {
				case "none": return V.modifier ? void 0 : [
					v(),
					o("--tw-shadow", g),
					o("box-shadow", l)
				];
				case "inherit": return V.modifier ? void 0 : [v(), o("--tw-shadow-color", "inherit")];
			}
			{
				let M = t.get([`--shadow-${V.value.value}`]);
				if (M) return [
					v(),
					o("--tw-shadow-alpha", R),
					...ve("--tw-shadow", M, R, (fe) => `var(--tw-shadow-color, ${fe})`),
					o("box-shadow", l)
				];
			}
			{
				let M = te(V, t, ["--box-shadow-color", "--color"]);
				if (M) return [v(), o("--tw-shadow-color", Q(M, "var(--tw-shadow-alpha)"))];
			}
		}), i("shadow", () => [
			{
				values: [
					"current",
					"inherit",
					"transparent"
				],
				valueThemeKeys: ["--box-shadow-color", "--color"],
				modifiers: Array.from({ length: 21 }, (V, R) => `${R * 5}`)
			},
			{ values: ["none"] },
			{
				valueThemeKeys: ["--shadow"],
				modifiers: Array.from({ length: 21 }, (V, R) => `${R * 5}`),
				hasDefaultValue: t.get(["--shadow"]) !== null
			}
		]), e("inset-shadow-initial", [v, ["--tw-inset-shadow-color", "initial"]]), r.functional("inset-shadow", (V) => {
			let R;
			if (V.modifier && (V.modifier.kind === "arbitrary" ? R = V.modifier.value : u(V.modifier.value) && (R = `${V.modifier.value}%`)), !V.value) {
				let M = t.get(["--inset-shadow"]);
				return M === null ? void 0 : [
					v(),
					o("--tw-inset-shadow-alpha", R),
					...ve("--tw-inset-shadow", M, R, (fe) => `var(--tw-inset-shadow-color, ${fe})`),
					o("box-shadow", l)
				];
			}
			if (V.value.kind === "arbitrary") {
				let M = V.value.value;
				switch (V.value.dataType ?? me$1(M, ["color"])) {
					case "color": return M = X(M, V.modifier, t), M === null ? void 0 : [v(), o("--tw-inset-shadow-color", Q(M, "var(--tw-inset-shadow-alpha)"))];
					default: return [
						v(),
						o("--tw-inset-shadow-alpha", R),
						...ve("--tw-inset-shadow", M, R, (At) => `var(--tw-inset-shadow-color, ${At})`, "inset "),
						o("box-shadow", l)
					];
				}
			}
			switch (V.value.value) {
				case "none": return V.modifier ? void 0 : [
					v(),
					o("--tw-inset-shadow", g),
					o("box-shadow", l)
				];
				case "inherit": return V.modifier ? void 0 : [v(), o("--tw-inset-shadow-color", "inherit")];
			}
			{
				let M = t.get([`--inset-shadow-${V.value.value}`]);
				if (M) return [
					v(),
					o("--tw-inset-shadow-alpha", R),
					...ve("--tw-inset-shadow", M, R, (fe) => `var(--tw-inset-shadow-color, ${fe})`),
					o("box-shadow", l)
				];
			}
			{
				let M = te(V, t, ["--box-shadow-color", "--color"]);
				if (M) return [v(), o("--tw-inset-shadow-color", Q(M, "var(--tw-inset-shadow-alpha)"))];
			}
		}), i("inset-shadow", () => [
			{
				values: [
					"current",
					"inherit",
					"transparent"
				],
				valueThemeKeys: ["--box-shadow-color", "--color"],
				modifiers: Array.from({ length: 21 }, (V, R) => `${R * 5}`)
			},
			{ values: ["none"] },
			{
				valueThemeKeys: ["--inset-shadow"],
				modifiers: Array.from({ length: 21 }, (V, R) => `${R * 5}`),
				hasDefaultValue: t.get(["--inset-shadow"]) !== null
			}
		]), e("ring-inset", [v, ["--tw-ring-inset", "inset"]]);
		let C = t.get(["--default-ring-color"]) ?? "currentcolor";
		r.functional("ring", (V) => {
			if (!V.value) {
				if (V.modifier) return;
				let R = t.get(["--default-ring-width"]) ?? "1px";
				return [
					v(),
					o("--tw-ring-shadow", b(R)),
					o("box-shadow", l)
				];
			}
			if (V.value.kind === "arbitrary") {
				let R = V.value.value;
				switch (V.value.dataType ?? me$1(R, ["color", "length"])) {
					case "length": return V.modifier ? void 0 : [
						v(),
						o("--tw-ring-shadow", b(R)),
						o("box-shadow", l)
					];
					default: return R = X(R, V.modifier, t), R === null ? void 0 : [o("--tw-ring-color", R)];
				}
			}
			{
				let R = te(V, t, ["--ring-color", "--color"]);
				if (R) return [o("--tw-ring-color", R)];
			}
			{
				if (V.modifier) return;
				let R = t.resolve(V.value.value, ["--ring-width"]);
				if (R === null && u(V.value.value) && (R = `${V.value.value}px`), R) return [
					v(),
					o("--tw-ring-shadow", b(R)),
					o("box-shadow", l)
				];
			}
		}), i("ring", () => [{
			values: [
				"current",
				"inherit",
				"transparent"
			],
			valueThemeKeys: ["--ring-color", "--color"],
			modifiers: Array.from({ length: 21 }, (V, R) => `${R * 5}`)
		}, {
			values: [
				"0",
				"1",
				"2",
				"4",
				"8"
			],
			valueThemeKeys: ["--ring-width"],
			hasDefaultValue: !0
		}]), r.functional("inset-ring", (V) => {
			if (!V.value) return V.modifier ? void 0 : [
				v(),
				o("--tw-inset-ring-shadow", T("1px")),
				o("box-shadow", l)
			];
			if (V.value.kind === "arbitrary") {
				let R = V.value.value;
				switch (V.value.dataType ?? me$1(R, ["color", "length"])) {
					case "length": return V.modifier ? void 0 : [
						v(),
						o("--tw-inset-ring-shadow", T(R)),
						o("box-shadow", l)
					];
					default: return R = X(R, V.modifier, t), R === null ? void 0 : [o("--tw-inset-ring-color", R)];
				}
			}
			{
				let R = te(V, t, ["--ring-color", "--color"]);
				if (R) return [o("--tw-inset-ring-color", R)];
			}
			{
				if (V.modifier) return;
				let R = t.resolve(V.value.value, ["--ring-width"]);
				if (R === null && u(V.value.value) && (R = `${V.value.value}px`), R) return [
					v(),
					o("--tw-inset-ring-shadow", T(R)),
					o("box-shadow", l)
				];
			}
		}), i("inset-ring", () => [{
			values: [
				"current",
				"inherit",
				"transparent"
			],
			valueThemeKeys: ["--ring-color", "--color"],
			modifiers: Array.from({ length: 21 }, (V, R) => `${R * 5}`)
		}, {
			values: [
				"0",
				"1",
				"2",
				"4",
				"8"
			],
			valueThemeKeys: ["--ring-width"],
			hasDefaultValue: !0
		}]);
		let D = "var(--tw-ring-inset,) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color)";
		r.functional("ring-offset", (V) => {
			if (V.value) {
				if (V.value.kind === "arbitrary") {
					let R = V.value.value;
					switch (V.value.dataType ?? me$1(R, ["color", "length"])) {
						case "length": return V.modifier ? void 0 : [o("--tw-ring-offset-width", R), o("--tw-ring-offset-shadow", D)];
						default: return R = X(R, V.modifier, t), R === null ? void 0 : [o("--tw-ring-offset-color", R)];
					}
				}
				{
					let R = t.resolve(V.value.value, ["--ring-offset-width"]);
					if (R) return V.modifier ? void 0 : [o("--tw-ring-offset-width", R), o("--tw-ring-offset-shadow", D)];
					if (u(V.value.value)) return V.modifier ? void 0 : [o("--tw-ring-offset-width", `${V.value.value}px`), o("--tw-ring-offset-shadow", D)];
				}
				{
					let R = te(V, t, ["--ring-offset-color", "--color"]);
					if (R) return [o("--tw-ring-offset-color", R)];
				}
			}
		});
	}
	return i("ring-offset", () => [{
		values: [
			"current",
			"inherit",
			"transparent"
		],
		valueThemeKeys: ["--ring-offset-color", "--color"],
		modifiers: Array.from({ length: 21 }, (l, g) => `${g * 5}`)
	}, {
		values: [
			"0",
			"1",
			"2",
			"4",
			"8"
		],
		valueThemeKeys: ["--ring-offset-width"]
	}]), r.functional("@container", (l) => {
		let g = null;
		if (l.value === null ? g = "inline-size" : l.value.kind === "arbitrary" ? g = l.value.value : l.value.kind === "named" && l.value.value === "normal" && (g = "normal"), g !== null) return l.modifier ? [o("container-type", g), o("container-name", l.modifier.value)] : [o("container-type", g)];
	}), i("@container", () => [{
		values: ["normal"],
		valueThemeKeys: [],
		hasDefaultValue: !0
	}]), r;
}
var Lt = [
	"number",
	"integer",
	"ratio",
	"percentage"
];
function Kr(t) {
	let r = t.params;
	return hn.test(r) ? (i) => {
		let e = {
			"--value": {
				usedSpacingInteger: !1,
				usedSpacingNumber: !1,
				themeKeys: /* @__PURE__ */ new Set(),
				literals: /* @__PURE__ */ new Set()
			},
			"--modifier": {
				usedSpacingInteger: !1,
				usedSpacingNumber: !1,
				themeKeys: /* @__PURE__ */ new Set(),
				literals: /* @__PURE__ */ new Set()
			}
		};
		I(t.nodes, (n) => {
			if (n.kind !== "declaration" || !n.value || !n.value.includes("--value(") && !n.value.includes("--modifier(")) return;
			let s = B(n.value);
			I(s, (a) => {
				if (a.kind !== "function") return;
				if (a.value === "--spacing" && !(e["--modifier"].usedSpacingNumber && e["--value"].usedSpacingNumber)) return I(a.nodes, (u) => {
					if (u.kind !== "function" || u.value !== "--value" && u.value !== "--modifier") return;
					let f = u.value;
					for (let m of u.nodes) if (m.kind === "word") {
						var _e$f, _e$f2;
						if (m.value === "integer") (_e$f = e[f]).usedSpacingInteger || (_e$f.usedSpacingInteger = !0);
						else if (m.value === "number" && ((_e$f2 = e[f]).usedSpacingNumber || (_e$f2.usedSpacingNumber = !0), e["--modifier"].usedSpacingNumber && e["--value"].usedSpacingNumber)) return E.Stop;
					}
				}), E.Continue;
				if (a.value !== "--value" && a.value !== "--modifier") return;
				let p = d(Z(a.nodes), ",");
				for (let [u, f] of p.entries()) f = f.replace(/\\\*/g, "*"), f = f.replace(/--(.*?)\s--(.*?)/g, "--$1-*--$2"), f = f.replace(/\s+/g, ""), f = f.replace(/(-\*){2,}/g, "-*"), f[0] === "-" && f[1] === "-" && !f.includes("-*") && (f += "-*"), p[u] = f;
				a.nodes = B(p.join(","));
				for (let u of a.nodes) if (u.kind === "word" && (u.value[0] === "\"" || u.value[0] === "'") && u.value[0] === u.value[u.value.length - 1]) {
					let f = u.value.slice(1, -1);
					e[a.value].literals.add(f);
				} else if (u.kind === "word" && u.value[0] === "-" && u.value[1] === "-") {
					let f = u.value.replace(/-\*.*$/g, "");
					e[a.value].themeKeys.add(f);
				} else if (u.kind === "word" && !(u.value[0] === "[" && u.value[u.value.length - 1] === "]") && !Lt.includes(u.value)) {
					console.warn(`Unsupported bare value data type: "${u.value}".
Only valid data types are: ${Lt.map((y) => `"${y}"`).join(", ")}.
`);
					let f = u.value, m = structuredClone(a), d = "¶";
					I(m.nodes, (y) => {
						if (y.kind === "word" && y.value === f) return E.ReplaceSkip({
							kind: "word",
							value: d
						});
					});
					let c = "^".repeat(Z([u]).length), w = Z([m]).indexOf(d), h = [
						"```css",
						Z([a]),
						" ".repeat(w) + c,
						"```"
					].join(`
`);
					console.warn(h);
				}
			}), n.value = Z(s);
		}), i.utilities.functional(r.slice(0, -2), (n) => {
			let s = ee(t), a = n.value, p = n.modifier;
			if (a === null) return;
			let u = !1, f = !1, m = !1, d = !1, c = /* @__PURE__ */ new Map(), w = !1;
			if (I([s], (h, y) => {
				let x = y.parent;
				if ((x === null || x === void 0 ? void 0 : x.kind) !== "rule" && (x === null || x === void 0 ? void 0 : x.kind) !== "at-rule" || h.kind !== "declaration" || !h.value) return;
				let $ = !1, A = B(h.value);
				if (I(A, (k) => {
					if (k.kind === "function") {
						if (k.value === "--value") {
							u = !0;
							let U = Pr(a, k, i);
							return U ? (f = !0, U.ratio ? w = !0 : c.set(h, x), E.ReplaceSkip(U.nodes)) : (u || (u = !1), $ = !0, E.Stop);
						} else if (k.value === "--modifier") {
							if (p === null) return $ = !0, E.Stop;
							m = !0;
							let U = Pr(p, k, i);
							return U ? (d = !0, E.ReplaceSkip(U.nodes)) : (m || (m = !1), $ = !0, E.Stop);
						}
					}
				}), $) return E.ReplaceSkip([]);
				h.value = Z(A);
			}), u && !f || m && !d || w && d || p && !w && !d) return null;
			if (w) for (let [h, y] of c) {
				let x = y.nodes.indexOf(h);
				x !== -1 && y.nodes.splice(x, 1);
			}
			return s.nodes;
		}), i.utilities.suggest(r.slice(0, -2), () => {
			let n = [], s = [];
			for (let [a, { literals: p, usedSpacingNumber: u$2, usedSpacingInteger: f, themeKeys: m }] of [[n, e["--value"]], [s, e["--modifier"]]]) {
				for (let d of p) a.push(d);
				if (u$2) a.push(...ct);
				else if (f) for (let d of ct) u(d) && a.push(d);
				for (let d of i.theme.keysInNamespaces(m)) a.push(d.replace(_r, (c, w, h) => `${w}.${h}`));
			}
			return [{
				values: n,
				modifiers: s
			}];
		});
	} : gn.test(r) ? (i) => {
		i.utilities.static(r, () => t.nodes.map(ee));
	} : null;
}
function Pr(t, r, i) {
	for (let e of r.nodes) {
		if (t.kind === "named" && e.kind === "word" && (e.value[0] === "'" || e.value[0] === "\"") && e.value[e.value.length - 1] === e.value[0] && e.value.slice(1, -1) === t.value) return { nodes: B(t.value) };
		if (t.kind === "named" && e.kind === "word" && e.value[0] === "-" && e.value[1] === "-") {
			let n = e.value;
			if (n.endsWith("-*")) {
				n = n.slice(0, -2);
				let s = i.theme.resolve(t.value, [n]);
				if (s) return { nodes: B(s) };
			} else {
				let s = n.split("-*");
				if (s.length <= 1) continue;
				let a = [s.shift()], p = i.theme.resolveWith(t.value, a, s);
				if (p) {
					let [, u = {}] = p;
					{
						let f = u[s.pop()];
						if (f) return { nodes: B(f) };
					}
				}
			}
		} else if (t.kind === "named" && e.kind === "word") {
			if (!Lt.includes(e.value)) continue;
			let n = e.value === "ratio" && "fraction" in t ? t.fraction : t.value;
			if (!n) continue;
			let s = me$1(n, [e.value]);
			if (s === null) continue;
			if (s === "ratio") {
				let [a, p] = d(n, "/");
				if (!u(a) || !u(p)) continue;
			} else {
				if (s === "number" && !ge(n)) continue;
				if (s === "percentage" && !u(n.slice(0, -1))) continue;
			}
			return {
				nodes: B(n),
				ratio: s === "ratio"
			};
		} else if (t.kind === "arbitrary" && e.kind === "word" && e.value[0] === "[" && e.value[e.value.length - 1] === "]") {
			let n = e.value.slice(1, -1);
			if (n === "*") return { nodes: B(t.value) };
			if ("dataType" in t && t.dataType && t.dataType !== n) continue;
			if ("dataType" in t && t.dataType) return { nodes: B(t.value) };
			if (me$1(t.value, [n]) !== null) return { nodes: B(t.value) };
		}
	}
}
function ve(t, r, i, e, n = "") {
	let s = !1, a = Je(r, (u) => i == null ? e(u) : u.startsWith("current") ? e(Q(u, i)) : ((u.startsWith("var(") || i.startsWith("var(")) && (s = !0), e(Ir(u, i))));
	function p(u) {
		return n ? d(u, ",").map((f) => n + f).join(",") : u;
	}
	return s ? [o(t, p(Je(r, e))), J("@supports (color: lab(from red l a b))", [o(t, p(a))])] : [o(t, p(a))];
}
function ft(t, r, i, e, n = "") {
	let s = !1, a = d(r, ",").map((p) => Je(p, (u) => i == null ? e(u) : u.startsWith("current") ? e(Q(u, i)) : ((u.startsWith("var(") || i.startsWith("var(")) && (s = !0), e(Ir(u, i))))).map((p) => `drop-shadow(${p})`).join(" ");
	return s ? [o(t, n + d(r, ",").map((p) => `drop-shadow(${Je(p, e)})`).join(" ")), J("@supports (color: lab(from red l a b))", [o(t, n + a)])] : [o(t, n + a)];
}
var jt = {
	"--alpha": vn,
	"--spacing": wn,
	"--theme": yn,
	theme: kn
};
function vn(t, r, i, ...e) {
	let [n, s] = d(i, "/").map((a) => a.trim());
	if (!n || !s) throw new Error(`The --alpha(\u2026) function requires a color and an alpha value, e.g.: \`--alpha(${n || "var(--my-color)"} / ${s || "50%"})\``);
	if (e.length > 0) throw new Error(`The --alpha(\u2026) function only accepts one argument, e.g.: \`--alpha(${n || "var(--my-color)"} / ${s || "50%"})\``);
	return Q(n, s);
}
function wn(t, r, i, ...e) {
	if (!i) throw new Error("The --spacing(…) function requires an argument, but received none.");
	if (e.length > 0) throw new Error(`The --spacing(\u2026) function only accepts a single argument, but received ${e.length + 1}.`);
	let n = t.theme.resolve(null, ["--spacing"]);
	if (!n) throw new Error("The --spacing(…) function requires that the `--spacing` theme variable exists, but it was not found.");
	return `calc(${n} * ${i})`;
}
function yn(t, r, i, ...e) {
	if (!i.startsWith("--")) throw new Error("The --theme(…) function can only be used with CSS variables from your theme.");
	let n = !1;
	i.endsWith(" inline") && (n = !0, i = i.slice(0, -7)), r.kind === "at-rule" && (n = !0);
	let s = t.resolveThemeValue(i, n);
	if (!s) {
		if (e.length > 0) return e.join(", ");
		throw new Error(`Could not resolve value for theme function: \`theme(${i})\`. Consider checking if the variable name is correct or provide a fallback value to silence this error.`);
	}
	if (e.length === 0) return s;
	let a = e.join(", ");
	if (a === "initial") return s;
	if (s === "initial") return a;
	if (s.startsWith("var(") || s.startsWith("theme(") || s.startsWith("--theme(")) {
		let p = B(s);
		return xn(p, a), Z(p);
	}
	return s;
}
function kn(t, r, i, ...e) {
	i = bn(i);
	let n = t.resolveThemeValue(i);
	if (!n && e.length > 0) return e.join(", ");
	if (!n) throw new Error(`Could not resolve value for theme function: \`theme(${i})\`. Consider checking if the path is correct or provide a fallback value to silence this error.`);
	return n;
}
var Ur = new RegExp(Object.keys(jt).map((t) => `${t}\\(`).join("|"));
function De(t, r) {
	let i = 0;
	return I(t, (e) => {
		if (e.kind === "declaration" && e.value && Ur.test(e.value)) {
			i |= 8, e.value = Lr(e.value, e, r);
			return;
		}
		e.kind === "at-rule" && (e.name === "@media" || e.name === "@custom-media" || e.name === "@container" || e.name === "@supports") && Ur.test(e.params) && (i |= 8, e.params = Lr(e.params, e, r));
	}), i;
}
function Lr(t, r, i) {
	let e = B(t);
	return I(e, (n) => {
		if (n.kind === "function" && n.value in jt) {
			let s = d(Z(n.nodes).trim(), ",").map((p) => p.trim()), a = jt[n.value](i, r, ...s);
			return E.Replace(B(a));
		}
	}), Z(e);
}
function bn(t) {
	if (t[0] !== "'" && t[0] !== "\"") return t;
	let r = "", i = t[0];
	for (let e = 1; e < t.length - 1; e++) {
		let n = t[e], s = t[e + 1];
		n === "\\" && (s === i || s === "\\") ? (r += s, e++) : r += n;
	}
	return r;
}
function xn(t, r) {
	I(t, (i) => {
		if (i.kind === "function" && !(i.value !== "var" && i.value !== "theme" && i.value !== "--theme")) if (i.nodes.length === 1) i.nodes.push({
			kind: "word",
			value: `, ${r}`
		});
		else {
			let e = i.nodes[i.nodes.length - 1];
			e.kind === "word" && e.value === "initial" && (e.value = r);
		}
	});
}
function pt(t, r) {
	let i = t.length, e = r.length, n = i < e ? i : e;
	for (let s = 0; s < n; s++) {
		let a = t.charCodeAt(s), p = r.charCodeAt(s);
		if (a >= 48 && a <= 57 && p >= 48 && p <= 57) {
			let u = s, f = s + 1, m = s, d = s + 1;
			for (a = t.charCodeAt(f); a >= 48 && a <= 57;) a = t.charCodeAt(++f);
			for (p = r.charCodeAt(d); p >= 48 && p <= 57;) p = r.charCodeAt(++d);
			let c = t.slice(u, f), w = r.slice(m, d), h = Number(c) - Number(w);
			if (h) return h;
			if (c < w) return -1;
			if (c > w) return 1;
			continue;
		}
		if (a !== p) return a - p;
	}
	return t.length - r.length;
}
function jr(t) {
	if (t[0] !== "[" || t[t.length - 1] !== "]") return null;
	let r = 1, i = r, e = t.length - 1;
	for (; Ue(t.charCodeAt(r));) r++;
	for (i = r; r < e; r++) {
		let m = t.charCodeAt(r);
		if (m === 92) {
			r++;
			continue;
		}
		if (!(m >= 65 && m <= 90) && !(m >= 97 && m <= 122) && !(m >= 48 && m <= 57) && !(m === 45 || m === 95)) break;
	}
	if (i === r) return null;
	let n = t.slice(i, r);
	for (; Ue(t.charCodeAt(r));) r++;
	if (r === e) return {
		attribute: n,
		operator: null,
		quote: null,
		value: null,
		sensitivity: null
	};
	let s = null, a = t.charCodeAt(r);
	if (a === 61) s = "=", r++;
	else if ((a === 126 || a === 124 || a === 94 || a === 36 || a === 42) && t.charCodeAt(r + 1) === 61) s = t[r] + "=", r += 2;
	else return null;
	for (; Ue(t.charCodeAt(r));) r++;
	if (r === e) return null;
	let p = "", u = null;
	if (a = t.charCodeAt(r), a === 39 || a === 34) {
		u = t[r], r++, i = r;
		for (let m = r; m < e; m++) {
			let d = t.charCodeAt(m);
			d === a ? r = m + 1 : d === 92 && m++;
		}
		p = t.slice(i, r - 1);
	} else {
		for (i = r; r < e && !Ue(t.charCodeAt(r));) r++;
		p = t.slice(i, r);
	}
	for (; Ue(t.charCodeAt(r));) r++;
	if (r === e) return {
		attribute: n,
		operator: s,
		quote: u,
		value: p,
		sensitivity: null
	};
	let f = null;
	switch (t.charCodeAt(r)) {
		case 105:
		case 73:
			f = "i", r++;
			break;
		case 115:
		case 83:
			f = "s", r++;
			break;
		default: return null;
	}
	for (; Ue(t.charCodeAt(r));) r++;
	return r !== e ? null : {
		attribute: n,
		operator: s,
		quote: u,
		value: p,
		sensitivity: f
	};
}
function Ue(t) {
	switch (t) {
		case 32:
		case 9:
		case 10:
		case 13: return !0;
		default: return !1;
	}
}
function Le(t, r = null) {
	return Array.isArray(t) && t.length === 2 && typeof t[1] == "object" && true ? r ? t[1][r] ?? null : t[0] : Array.isArray(t) && r === null ? t.join(", ") : typeof t == "string" && r === null ? t : null;
}
function zr(t, { theme: r }, i) {
	for (let e of i) {
		let n = je([e]);
		n && t.theme.clearNamespace(`--${n}`, 4);
	}
	for (let [e, n] of Cn(r)) {
		if (typeof n != "string" && typeof n != "number") continue;
		if (typeof n == "string" && (n = n.replace(/<alpha-value>/g, "1")), e[0] === "opacity" && (typeof n == "number" || typeof n == "string")) {
			let a = typeof n == "string" ? parseFloat(n) : n;
			a >= 0 && a <= 1 && (n = a * 100 + "%");
		}
		let s = je(e);
		s && t.theme.add(`--${s}`, "" + n, 7);
	}
	if (Object.hasOwn(r, "fontFamily")) {
		let e = 5;
		{
			let n = Le(r.fontFamily.sans);
			n && t.theme.hasDefault("--font-sans") && (t.theme.add("--default-font-family", n, e), t.theme.add("--default-font-feature-settings", Le(r.fontFamily.sans, "fontFeatureSettings") ?? "normal", e), t.theme.add("--default-font-variation-settings", Le(r.fontFamily.sans, "fontVariationSettings") ?? "normal", e));
		}
		{
			let n = Le(r.fontFamily.mono);
			n && t.theme.hasDefault("--font-mono") && (t.theme.add("--default-mono-font-family", n, e), t.theme.add("--default-mono-font-feature-settings", Le(r.fontFamily.mono, "fontFeatureSettings") ?? "normal", e), t.theme.add("--default-mono-font-variation-settings", Le(r.fontFamily.mono, "fontVariationSettings") ?? "normal", e));
		}
	}
	return r;
}
function Cn(t) {
	let r = [];
	return Mr(t, [], (i, e) => {
		if (Vn(i)) return r.push([e, i]), 1;
		if (Nn(i)) {
			r.push([e, i[0]]);
			for (let n of Reflect.ownKeys(i[1])) r.push([[...e, `-${n}`], i[1][n]]);
			return 1;
		}
		if (Array.isArray(i) && i.every((n) => typeof n == "string")) return e[0] === "fontSize" ? (r.push([e, i[0]]), i.length >= 2 && r.push([[...e, "-line-height"], i[1]])) : r.push([e, i.join(", ")]), 1;
	}), r;
}
var $n = {
	borderWidth: "border-width",
	outlineWidth: "outline-width",
	ringColor: "ring-color",
	ringWidth: "ring-width",
	transitionDuration: "transition-duration",
	transitionTimingFunction: "transition-timing-function"
}, Sn = {
	animation: "animate",
	aspectRatio: "aspect",
	borderRadius: "radius",
	boxShadow: "shadow",
	colors: "color",
	containers: "container",
	fontFamily: "font",
	fontSize: "text",
	letterSpacing: "tracking",
	lineHeight: "leading",
	maxWidth: "container",
	screens: "breakpoint",
	transitionTimingFunction: "ease"
}, Tn = /^[a-zA-Z0-9-_%/\.]+$/;
function je(t) {
	let r = $n[t[0]];
	if (r && t[1] === "DEFAULT") return `default-${r}`;
	if (t[0] === "container") return null;
	for (let e of t) if (!Tn.test(e)) return null;
	let i = Sn[t[0]];
	return i && (t = t.slice(), t[0] = i), t.map((e, n, s) => e === "1" && n !== s.length - 1 ? "" : e).map((e, n) => (e = e.replaceAll(".", "_"), (n === 0 || e.startsWith("-") || e === "lineHeight") && (e = e.replace(/([a-z])([A-Z])/g, (a, p, u) => `${p}-${u.toLowerCase()}`)), e)).filter((e, n) => e !== "DEFAULT" || n !== t.length - 1).join("-");
}
function Vn(t) {
	return typeof t == "number" || typeof t == "string";
}
function Nn(t) {
	if (!Array.isArray(t) || t.length !== 2 || typeof t[0] != "string" && typeof t[0] != "number" || t[1] === void 0 || t[1] === null || typeof t[1] != "object") return !1;
	for (let r of Reflect.ownKeys(t[1])) if (typeof r != "string" || typeof t[1][r] != "string" && typeof t[1][r] != "number") return !1;
	return !0;
}
function Mr(t, r = [], i) {
	for (let e of Reflect.ownKeys(t)) {
		let n = t[e];
		if (n == null) continue;
		let s = [...r, e], a = i(n, s) ?? 0;
		if (a !== 1) {
			if (a === 2) return 2;
			if (!(!Array.isArray(n) && typeof n != "object") && Mr(n, s, i) === 2) return 2;
		}
	}
}
var En = /^(?<value>[-+]?(?:\d*\.)?\d+)(?<unit>[a-z]+|%)?$/i, Ne = new K((t) => {
	var _r$groups, _r$groups2;
	let r = En.exec(t);
	if (!r) return null;
	let i = (_r$groups = r.groups) === null || _r$groups === void 0 ? void 0 : _r$groups.value;
	if (i === void 0) return null;
	let e = Number(i);
	if (Number.isNaN(e)) return null;
	let n = (_r$groups2 = r.groups) === null || _r$groups2 === void 0 ? void 0 : _r$groups2.unit;
	return n === void 0 ? [e, null] : [e, n];
});
function dt(t, r = null) {
	let i = !1, e = B(t);
	return I(e, { exit(n) {
		if (n.kind === "word" && n.value !== "0") {
			let s = Rn(n.value, r);
			return s === null || s === n.value ? void 0 : (i = !0, E.ReplaceSkip(ne(s)));
		} else if (n.kind === "function" && (n.value === "calc" || n.value === "")) {
			if (n.nodes.length !== 5) return;
			let s = Ne.get(n.nodes[0].value), a = n.nodes[2].value, p = Ne.get(n.nodes[4].value);
			if (a === "*" && ((s === null || s === void 0 ? void 0 : s[0]) === 0 && (s === null || s === void 0 ? void 0 : s[1]) === null || (p === null || p === void 0 ? void 0 : p[0]) === 0 && (p === null || p === void 0 ? void 0 : p[1]) === null)) return i = !0, E.ReplaceSkip(ne("0"));
			if (s === null || p === null) return;
			switch (a) {
				case "*":
					if (s[1] === p[1] || s[1] === null && p[1] !== null || s[1] !== null && p[1] === null) return i = !0, E.ReplaceSkip(ne(`${s[0] * p[0]}${s[1] ?? ""}`));
					break;
				case "+":
					if (s[1] === p[1]) return i = !0, E.ReplaceSkip(ne(`${s[0] + p[0]}${s[1] ?? ""}`));
					break;
				case "-":
					if (s[1] === p[1]) return i = !0, E.ReplaceSkip(ne(`${s[0] - p[0]}${s[1] ?? ""}`));
					break;
				case "/":
					if (p[0] !== 0 && (s[1] === null && p[1] === null || s[1] !== null && p[1] === null)) return i = !0, E.ReplaceSkip(ne(`${s[0] / p[0]}${s[1] ?? ""}`));
					break;
			}
		}
	} }), i ? Z(e) : t;
}
function Rn(t, r = null) {
	let i = Ne.get(t);
	if (i === null) return null;
	let [e, n] = i;
	if (n === null) return `${e}`;
	if (e === 0 && y(t)) return "0";
	switch (n.toLowerCase()) {
		case "in": return `${e * 96}px`;
		case "cm": return `${e * 96 / 2.54}px`;
		case "mm": return `${e * 96 / 2.54 / 10}px`;
		case "q": return `${e * 96 / 2.54 / 10 / 4}px`;
		case "pc": return `${e * 96 / 6}px`;
		case "pt": return `${e * 96 / 72}px`;
		case "rem": return r !== null ? `${e * r}px` : null;
		case "grad": return `${e * .9}deg`;
		case "rad": return `${e * 180 / Math.PI}deg`;
		case "turn": return `${e * 360}deg`;
		case "ms": return `${e / 1e3}s`;
		case "khz": return `${e * 1e3}hz`;
		default: return `${e}${n}`;
	}
}
function Fr(t, r = "top", i = "right", e = "bottom", n = "left") {
	return Gr(`${t}-${r}`, `${t}-${i}`, `${t}-${e}`, `${t}-${n}`);
}
function Gr(t = "top", r = "right", i = "bottom", e = "left") {
	return {
		1: [
			[t, 0],
			[r, 0],
			[i, 0],
			[e, 0]
		],
		2: [
			[t, 0],
			[r, 1],
			[i, 0],
			[e, 1]
		],
		3: [
			[t, 0],
			[r, 1],
			[i, 2],
			[e, 1]
		],
		4: [
			[t, 0],
			[r, 1],
			[i, 2],
			[e, 3]
		]
	};
}
function Ee(t, r) {
	return {
		1: [[t, 0], [r, 0]],
		2: [[t, 0], [r, 1]]
	};
}
var Wr = {
	inset: Gr(),
	margin: Fr("margin"),
	padding: Fr("padding"),
	gap: Ee("row-gap", "column-gap")
}, Br = {
	"inset-block": Ee("top", "bottom"),
	"inset-inline": Ee("left", "right"),
	"margin-block": Ee("margin-top", "margin-bottom"),
	"margin-inline": Ee("margin-left", "margin-right"),
	"padding-block": Ee("padding-top", "padding-bottom"),
	"padding-inline": Ee("padding-left", "padding-right")
}, Yr = {
	"border-block": ["border-bottom", "border-top"],
	"border-block-color": ["border-bottom-color", "border-top-color"],
	"border-block-style": ["border-bottom-style", "border-top-style"],
	"border-block-width": ["border-bottom-width", "border-top-width"],
	"border-inline": ["border-left", "border-right"],
	"border-inline-color": ["border-left-color", "border-right-color"],
	"border-inline-style": ["border-left-style", "border-right-style"],
	"border-inline-width": ["border-left-width", "border-right-width"]
};
function qr(t, r) {
	if (r & 2) {
		var _Yr$t$property;
		if (t.property in Br) {
			var _Br$t$property$i$leng;
			let i = d(t.value, " ");
			return (_Br$t$property$i$leng = Br[t.property][i.length]) === null || _Br$t$property$i$leng === void 0 ? void 0 : _Br$t$property$i$leng.map(([e, n]) => o(e, i[n], t.important));
		}
		if (t.property in Yr) return (_Yr$t$property = Yr[t.property]) === null || _Yr$t$property === void 0 ? void 0 : _Yr$t$property.map((i) => o(i, t.value, t.important));
	}
	if (t.property in Wr) {
		var _Wr$t$property$i$leng;
		let i = d(t.value, " ");
		return (_Wr$t$property$i$leng = Wr[t.property][i.length]) === null || _Wr$t$property$i$leng === void 0 ? void 0 : _Wr$t$property$i$leng.map(([e, n]) => o(e, i[n], t.important));
	}
	return null;
}
function On(t) {
	return {
		kind: "combinator",
		value: t
	};
}
function Pn(t, r) {
	return {
		kind: "function",
		value: t,
		nodes: r
	};
}
function xe(t) {
	return {
		kind: "selector",
		value: t
	};
}
function In(t) {
	return {
		kind: "separator",
		value: t
	};
}
function _n(t) {
	return {
		kind: "value",
		value: t
	};
}
function pe(t) {
	let r = "";
	for (let i of t) switch (i.kind) {
		case "combinator":
		case "selector":
		case "separator":
		case "value":
			r += i.value;
			break;
		case "function": r += i.value + "(" + pe(i.nodes) + ")";
	}
	return r;
}
var Zr = 92, Dn = 93, Hr = 41, Kn = 58, Jr = 44, Un = 34, Ln = 46, Qr = 62, Xr = 10, jn = 35, ei = 91, ti = 40, ri = 43, zn = 39, ii = 32, ni = 9, ai = 126, Mn = 38, Fn = 42;
function Re(t) {
	t = t.replaceAll(`\r
`, `
`);
	let r = [], i = [], e = null, n = "", s;
	for (let a = 0; a < t.length; a++) {
		let p = t.charCodeAt(a);
		switch (p) {
			case Jr:
			case Qr:
			case Xr:
			case ii:
			case ri:
			case ni:
			case ai: {
				if (n.length > 0) {
					let c = xe(n);
					e ? e.nodes.push(c) : r.push(c), n = "";
				}
				let u = a, f = a + 1;
				for (; f < t.length && (s = t.charCodeAt(f), !(s !== Jr && s !== Qr && s !== Xr && s !== ii && s !== ri && s !== ni && s !== ai)); f++);
				a = f - 1;
				let m = t.slice(u, f), d = m.trim() === "," ? In(m) : On(m);
				e ? e.nodes.push(d) : r.push(d);
				break;
			}
			case ti: {
				let u = Pn(n, []);
				if (n = "", u.value !== ":not" && u.value !== ":where" && u.value !== ":has" && u.value !== ":is") {
					let f = a + 1, m = 0;
					for (let c = a + 1; c < t.length; c++) {
						if (s = t.charCodeAt(c), s === ti) {
							m++;
							continue;
						}
						if (s === Hr) {
							if (m === 0) {
								a = c;
								break;
							}
							m--;
						}
					}
					let d = a;
					u.nodes.push(_n(t.slice(f, d))), n = "", a = d, e ? e.nodes.push(u) : r.push(u);
					break;
				}
				e ? e.nodes.push(u) : r.push(u), i.push(u), e = u;
				break;
			}
			case Hr: {
				let u = i.pop();
				if (n.length > 0) {
					let f = xe(n);
					u.nodes.push(f), n = "";
				}
				i.length > 0 ? e = i[i.length - 1] : e = null;
				break;
			}
			case Ln:
			case Kn:
			case jn:
				if (n.length > 0) {
					let u = xe(n);
					e ? e.nodes.push(u) : r.push(u);
				}
				n = t[a];
				break;
			case ei: {
				if (n.length > 0) {
					let m = xe(n);
					e ? e.nodes.push(m) : r.push(m);
				}
				n = "";
				let u = a, f = 0;
				for (let m = a + 1; m < t.length; m++) {
					if (s = t.charCodeAt(m), s === ei) {
						f++;
						continue;
					}
					if (s === Dn) {
						if (f === 0) {
							a = m;
							break;
						}
						f--;
					}
				}
				n += t.slice(u, a + 1);
				break;
			}
			case zn:
			case Un: {
				let u = a;
				for (let f = a + 1; f < t.length; f++) if (s = t.charCodeAt(f), s === Zr) f += 1;
				else if (s === p) {
					a = f;
					break;
				}
				n += t.slice(u, a + 1);
				break;
			}
			case Mn:
			case Fn:
				if (n.length > 0) {
					let u = xe(n);
					e ? e.nodes.push(u) : r.push(u), n = "";
				}
				e ? e.nodes.push(xe(t[a])) : r.push(xe(t[a]));
				break;
			case Zr:
				n += t[a] + t[a + 1], a += 1;
				break;
			default: n += t[a];
		}
	}
	return n.length > 0 && r.push(xe(n)), r;
}
function ue(t, r) {
	for (let i in t) delete t[i];
	return Object.assign(t, r);
}
function Oe(t) {
	let r = [];
	for (let i of d(t, ".")) {
		if (!i.includes("[")) {
			r.push(i);
			continue;
		}
		let e = 0;
		for (;;) {
			let n = i.indexOf("[", e), s = i.indexOf("]", n);
			if (n === -1 || s === -1) break;
			n > e && r.push(i.slice(e, n)), r.push(i.slice(n + 1, s)), e = s + 1;
		}
		e <= i.length - 1 && r.push(i.slice(e));
	}
	return r;
}
function zt(t, r) {
	var _i$storage, _i$storage2, _i$storage3, _i$storage4, _i$storage5, _i$storage6, _i$storage7, _i$storage8, _i$storage9, _i$storage10, _i$storage11, _i$storage12, _i$storage13;
	let i = t;
	return (_i$storage = i.storage)[ui] ?? (_i$storage[ui] = Wn()), (_i$storage2 = i.storage)[fi] ?? (_i$storage2[fi] = Yn(i)), (_i$storage3 = i.storage)[ci] ?? (_i$storage3[ci] = Zn()), (_i$storage4 = i.storage)[pi] ?? (_i$storage4[pi] = Jn()), (_i$storage5 = i.storage)[di] ?? (_i$storage5[di] = Xn()), (_i$storage6 = i.storage)[Ft] ?? (_i$storage6[Ft] = na(i)), (_i$storage7 = i.storage)[ht] ?? (_i$storage7[ht] = la(i, r)), (_i$storage8 = i.storage)[de] ?? (_i$storage8[de] = ya(i)), (_i$storage9 = i.storage)[Wt] ?? (_i$storage9[Wt] = ba()), (_i$storage10 = i.storage)[vt] ?? (_i$storage10[vt] = xa(i)), (_i$storage11 = i.storage)[Bt] ?? (_i$storage11[Bt] = Aa(i)), (_i$storage12 = i.storage)[yt] ?? (_i$storage12[yt] = Ca(i)), (_i$storage13 = i.storage)[hi] ?? (_i$storage13[hi] = $a(i)), i;
}
var ui = Symbol();
function Wn() {
	return new K((t) => new K((r) => ({
		rem: t,
		features: r
	})));
}
function Bn(t, r) {
	let i = 0;
	return !(r === null || r === void 0) && r.collapse && (i |= 1), !(r === null || r === void 0) && r.logicalToPhysical && (i |= 2), zt(t, r).storage[ui].get((r === null || r === void 0 ? void 0 : r.rem) ?? null).get(i);
}
var fi = Symbol();
function Yn(t) {
	return new K((r) => new K((i) => ({
		features: i,
		designSystem: t,
		signatureOptions: r
	})));
}
function Gn(t, r, i) {
	let e = 0;
	return !(i === null || i === void 0) && i.collapse && (e |= 1), zt(t).storage[fi].get(r).get(e);
}
function Mt(t, r, i) {
	let n = Gn(t, Bn(t, i), i), s = zt(t), a = /* @__PURE__ */ new Set(), p = s.storage[ci].get(n);
	for (let u of r) a.add(p.get(u));
	return a.size <= 1 || !(n.features & 1) ? Array.from(a) : qn(n, Array.from(a));
}
function qn(t, r) {
	if (r.length <= 1) return r;
	let i = t.designSystem, e = new K((p) => new K((u) => /* @__PURE__ */ new Set())), n = t.designSystem.theme.prefix ? `${t.designSystem.theme.prefix}:` : "";
	for (let p of r) {
		let u = d(p, ":"), f = u.pop(), m = f.endsWith("!");
		m && (f = f.slice(0, -1));
		let d$3 = u.length > 0 ? `${u.join(":")}:` : "", c = m ? "!" : "";
		e.get(d$3).get(c).add(`${n}${f}`);
	}
	let s = /* @__PURE__ */ new Set();
	for (let [p, u] of e.entries()) for (let [f, m] of u.entries()) for (let d of a(Array.from(m))) n && d.startsWith(n) && (d = d.slice(n.length)), s.add(`${p}${d}${f}`);
	return Array.from(s);
	function a(p) {
		let u = t.signatureOptions, f = i.storage[vt].get(u), m = i.storage[Wt].get(u), d = p.map(($) => f.get($));
		if (d.some(($) => $.has("line-height"))) {
			let $ = i.theme.keysInNamespaces(["--text"]);
			if ($.length > 0) {
				let A = /* @__PURE__ */ new Set(), k = /* @__PURE__ */ new Set();
				for (let N of d) for (let O of N.get("line-height")) {
					var _i$storage$ht;
					if (k.has(O)) continue;
					k.add(O);
					let L = ((_i$storage$ht = i.storage[ht]) === null || _i$storage$ht === void 0 ? void 0 : _i$storage$ht.get(O)) ?? null;
					if (L !== null) if (ge(L)) {
						A.add(L);
						for (let _ of $) f.get(`text-${_}/${L}`);
					} else {
						A.add(O);
						for (let _ of $) f.get(`text-${_}/[${O}]`);
					}
				}
				let U = /* @__PURE__ */ new Set();
				for (let N of d) for (let O of N.get("font-size")) if (!U.has(O)) {
					U.add(O);
					for (let L of A) ge(L) ? f.get(`text-[${O}]/${L}`) : f.get(`text-[${O}]/[${L}]`);
				}
			}
		}
		let c = d.map(($) => {
			let A = null;
			for (let k of $.keys()) {
				let U = /* @__PURE__ */ new Set();
				for (let N of m.get(k).values()) for (let O of N) U.add(O);
				if (A === null ? A = U : A = si(A, U), A.size === 0) return A;
			}
			return A;
		}), w = new K(($) => new Set([$]));
		for (let $ = 0; $ < c.length; $++) {
			let A = c[$];
			for (let k = $ + 1; k < c.length; k++) {
				let U = c[k];
				for (let N of A) if (U.has(N)) {
					w.get($).add(k), w.get(k).add($);
					break;
				}
			}
		}
		if (w.size === 0) return p;
		let h = new K(($) => $.split(",").map(Number));
		for (let $ of w.values()) {
			let A = Array.from($).sort((k, U) => k - U);
			h.get(A.join(","));
		}
		let y = new Set(p), x = /* @__PURE__ */ new Set();
		for (let $ of h.values()) for (let A of Ta($)) {
			if (A.some((N) => x.has(p[N]))) continue;
			let k = A.flatMap((N) => c[N]).reduce(si), U = i.storage[de].get(u).get(A.map((N) => p[N]).sort((N, O) => N.localeCompare(O)).join(" "));
			for (let N of k) if (i.storage[de].get(u).get(N) === U) {
				for (let L of A) x.add(p[L]);
				y.add(N);
				break;
			}
		}
		for (let $ of x) y.delete($);
		return Array.from(y);
	}
}
var ci = Symbol();
function Zn() {
	return new K((t) => {
		let r = t.designSystem, i = r.theme.prefix ? `${r.theme.prefix}:` : "", e = r.storage[pi].get(t), n = r.storage[di].get(t);
		return new K((s, a) => {
			for (let p of r.parseCandidate(s)) {
				let u = p.variants.slice().reverse().flatMap((d) => e.get(d)), f = p.important;
				if (f || u.length > 0) {
					let c = a.get(r.printCandidate({
						...p,
						variants: [],
						important: !1
					}));
					return r.theme.prefix !== null && u.length > 0 && (c = c.slice(i.length)), u.length > 0 && (c = `${u.map((w) => r.printVariant(w)).join(":")}:${c}`), f && (c += "!"), r.theme.prefix !== null && u.length > 0 && (c = `${i}${c}`), c;
				}
				let m = n.get(s);
				if (m !== s) return m;
			}
			return s;
		});
	});
}
var Hn = [
	ia,
	ha,
	va,
	da
], pi = Symbol();
function Jn() {
	return new K((t) => new K((r) => {
		let i = [r];
		for (let e of Hn) for (let n of i.splice(0)) {
			let s = e(_e(n), t);
			if (Array.isArray(s)) {
				i.push(...s);
				continue;
			} else i.push(s);
		}
		return i;
	}));
}
var Qn = [
	ta,
	ra,
	sa,
	fa,
	pa,
	ma,
	ga,
	wa
], di = Symbol();
function Xn() {
	return new K((t) => {
		let r = t.designSystem;
		return new K((i) => {
			for (let e of r.parseCandidate(i)) {
				let n = Tr(e);
				for (let a of Qn) n = a(n, t);
				let s = r.printCandidate(n);
				if (i !== s) return s;
			}
			return i;
		});
	});
}
var ea = [
	"t",
	"tr",
	"r",
	"br",
	"b",
	"bl",
	"l",
	"tl"
];
function ta(t) {
	if (t.kind === "static" && t.root.startsWith("bg-gradient-to-")) {
		let r = t.root.slice(15);
		return ea.includes(r) && (t.root = `bg-linear-to-${r}`), t;
	}
	return t;
}
function ra(t, r) {
	var _t$value;
	let i = r.designSystem.storage[Ft];
	if (t.kind === "arbitrary") {
		let [e, n] = i(t.value, t.modifier === null ? 1 : 0);
		e !== t.value && (t.value = e, n !== null && (t.modifier = n));
	} else if (t.kind === "functional" && ((_t$value = t.value) === null || _t$value === void 0 ? void 0 : _t$value.kind) === "arbitrary") {
		let [e, n] = i(t.value.value, t.modifier === null ? 1 : 0);
		e !== t.value.value && (t.value.value = e, n !== null && (t.modifier = n));
	}
	return t;
}
function ia(t, r) {
	var _n$value;
	let i = r.designSystem.storage[Ft], e = wt(t);
	for (let [n] of e) if (n.kind === "arbitrary") {
		let [s] = i(n.selector, 2);
		s !== n.selector && (n.selector = s);
	} else if (n.kind === "functional" && ((_n$value = n.value) === null || _n$value === void 0 ? void 0 : _n$value.kind) === "arbitrary") {
		let [s] = i(n.value.value, 2);
		s !== n.value.value && (n.value.value = s);
	}
	return t;
}
var Ft = Symbol();
function na(t) {
	return r(t);
	function r(i) {
		function e(p, u = 0) {
			let f = B(p);
			if (u & 2) return [mt(f, a), null];
			let m = 0, d$4 = 0;
			if (I(f, (h) => {
				h.kind === "function" && h.value === "theme" && (m += 1, I(h.nodes, (y) => y.kind === "separator" && y.value.includes(",") ? E.Stop : y.kind === "word" && y.value === "/" ? (d$4 += 1, E.Stop) : E.Skip));
			}), m === 0) return [p, null];
			if (d$4 === 0) return [mt(f, s), null];
			if (d$4 > 1) return [mt(f, a), null];
			let c = null;
			return [mt(f, (h, y) => {
				let x = d(h, "/").map(($) => $.trim());
				if (x.length > 2) return null;
				if (f.length === 1 && x.length === 2 && u & 1) {
					let [$, A] = x;
					if (/^\d+%$/.test(A)) c = {
						kind: "named",
						value: A.slice(0, -1)
					};
					else if (/^0?\.\d+$/.test(A)) {
						let k = Number(A) * 100;
						c = {
							kind: Number.isInteger(k) ? "named" : "arbitrary",
							value: k.toString()
						};
					} else c = {
						kind: "arbitrary",
						value: A
					};
					h = $;
				}
				return s(h, y) || a(h, y);
			}), c];
		}
		function n(p, u = !0) {
			let f = `--${je(Oe(p))}`;
			return i.theme.get([f]) ? u && i.theme.prefix ? `--${i.theme.prefix}-${f.slice(2)}` : f : null;
		}
		function s(p, u) {
			let f = n(p);
			if (f) return u ? `var(${f}, ${u})` : `var(${f})`;
			let m = Oe(p);
			if (m[0] === "spacing" && i.theme.get(["--spacing"])) {
				let d = m[1];
				return ge(d) ? `--spacing(${d})` : null;
			}
			return null;
		}
		function a(p, u) {
			let f = d(p, "/").map((c) => c.trim());
			p = f.shift();
			let m = n(p, !1);
			if (!m) return null;
			let d$5 = f.length > 0 ? `/${f.join("/")}` : "";
			return u ? `--theme(${m}${d$5}, ${u})` : `--theme(${m}${d$5})`;
		}
		return e;
	}
}
function mt(t, r) {
	return I(t, (i, e) => {
		if (i.kind === "function" && i.value === "theme") {
			if (i.nodes.length < 1) return;
			i.nodes[0].kind === "separator" && i.nodes[0].value.trim() === "" && i.nodes.shift();
			let n = i.nodes[0];
			if (n.kind !== "word") return;
			let s = n.value, a = 1;
			for (let f = a; f < i.nodes.length && !i.nodes[f].value.includes(","); f++) s += Z([i.nodes[f]]), a = f + 1;
			s = aa(s);
			let p = i.nodes.slice(a + 1), u = p.length > 0 ? r(s, Z(p)) : r(s);
			if (u === null) return;
			if (e.parent) {
				let f = e.parent.nodes.indexOf(i) - 1;
				for (; f !== -1;) {
					let m = e.parent.nodes[f];
					if (m.kind === "separator" && m.value.trim() === "") {
						f -= 1;
						continue;
					}
					/^[-+*/]$/.test(m.value.trim()) && (u = `(${u})`);
					break;
				}
			}
			return E.Replace(B(u));
		}
	}), Z(t);
}
function aa(t) {
	if (t[0] !== "'" && t[0] !== "\"") return t;
	let r = "", i = t[0];
	for (let e = 1; e < t.length - 1; e++) {
		let n = t[e], s = t[e + 1];
		n === "\\" && (s === i || s === "\\") ? (r += s, e++) : r += n;
	}
	return r;
}
function* wt(t) {
	function* r(i, e = null) {
		yield [i, e], i.kind === "compound" && (yield* r(i.variant, i));
	}
	yield* r(t, null);
}
function we(t, r) {
	return t.parseCandidate(t.theme.prefix && !r.startsWith(`${t.theme.prefix}:`) ? `${t.theme.prefix}:${r}` : r);
}
function oa(t, r) {
	let i = t.printCandidate(r);
	return t.theme.prefix && i.startsWith(`${t.theme.prefix}:`) ? i.slice(t.theme.prefix.length + 1) : i;
}
var ht = Symbol();
function la(t, r) {
	let i = t.resolveThemeValue("--spacing");
	if (i === void 0) return null;
	i = dt(i, (r === null || r === void 0 ? void 0 : r.rem) ?? null);
	let e = Ne.get(i);
	if (!e) return null;
	let [n, s] = e;
	return new K((a) => {
		if (n === 0) return null;
		let p = Ne.get(dt(a, (r === null || r === void 0 ? void 0 : r.rem) ?? null));
		if (!p) return null;
		let [u, f] = p;
		return f !== s ? null : u / n;
	});
}
function sa(t, r) {
	var _t$value2;
	if (t.kind !== "arbitrary" && !(t.kind === "functional" && ((_t$value2 = t.value) === null || _t$value2 === void 0 ? void 0 : _t$value2.kind) === "arbitrary")) return t;
	let i = r.designSystem, e = i.storage[Bt].get(r.signatureOptions), n = i.storage[de].get(r.signatureOptions), s = i.printCandidate(t), a = n.get(s);
	if (typeof a != "string") return t;
	for (let u of p(a, t)) {
		let f = i.printCandidate(u);
		if (n.get(f) === a && ua(i, t, u)) return u;
	}
	return t;
	function* p(u, f) {
		let m = e.get(u);
		if (!(m.length > 1)) {
			if (m.length === 0 && f.modifier) {
				let d = {
					...f,
					modifier: null
				}, c = n.get(i.printCandidate(d));
				if (typeof c == "string") for (let w of p(c, d)) yield Object.assign({}, w, { modifier: f.modifier });
			}
			if (m.length === 1) for (let d of we(i, m[0])) yield d;
			else if (m.length === 0) {
				var _f$value, _f$value2, _i$storage$ht3;
				let d = f.kind === "arbitrary" ? f.value : ((_f$value = f.value) === null || _f$value === void 0 ? void 0 : _f$value.value) ?? null;
				if (d === null) return;
				if (r.signatureOptions.rem !== null && f.kind === "functional" && ((_f$value2 = f.value) === null || _f$value2 === void 0 ? void 0 : _f$value2.kind) === "arbitrary") {
					var _i$storage$ht2;
					let h = ((_i$storage$ht2 = i.storage[ht]) === null || _i$storage$ht2 === void 0 ? void 0 : _i$storage$ht2.get(d)) ?? null;
					h !== null && ge(h) && (yield Object.assign({}, f, { value: {
						kind: "named",
						value: h,
						fraction: null
					} }));
				}
				let c = ((_i$storage$ht3 = i.storage[ht]) === null || _i$storage$ht3 === void 0 ? void 0 : _i$storage$ht3.get(d)) ?? null, w = "";
				c !== null && c < 0 && (w = "-", c = Math.abs(c));
				for (let h of Array.from(i.utilities.keys("functional")).sort((y, x) => +(y[0] === "-") - +(x[0] === "-"))) {
					w && (h = `${w}${h}`);
					for (let y of we(i, `${h}-${d}`)) yield y;
					if (f.modifier) for (let y of we(i, `${h}-${d}${f.modifier}`)) yield y;
					if (c !== null) {
						for (let y of we(i, `${h}-${c}`)) yield y;
						if (f.modifier) for (let y of we(i, `${h}-${c}${He(f.modifier)}`)) yield y;
					}
					for (let y of we(i, `${h}-[${d}]`)) yield y;
					if (f.modifier) for (let y of we(i, `${h}-[${d}]${He(f.modifier)}`)) yield y;
				}
			}
		}
	}
}
function ua(t, r, i) {
	var _r$value;
	let e = null;
	if (r.kind === "functional" && ((_r$value = r.value) === null || _r$value === void 0 ? void 0 : _r$value.kind) === "arbitrary" && r.value.value.includes("var(--") ? e = r.value.value : r.kind === "arbitrary" && r.value.includes("var(--") && (e = r.value), e === null) return !0;
	let n = t.candidatesToCss([t.printCandidate(i)]).join(`
`), s = !0;
	return I(B(e), (a) => {
		if (a.kind === "function" && a.value === "var") {
			let p = a.nodes[0].value;
			if (!new RegExp(`var\\(${p}[,)]\\s*`, "g").test(n) || n.includes(`${p}:`)) return s = !1, E.Stop;
		}
	}), s;
}
function fa(t, r) {
	var _t$value3;
	if (t.kind !== "functional" || ((_t$value3 = t.value) === null || _t$value3 === void 0 ? void 0 : _t$value3.kind) !== "named") return t;
	let i = r.designSystem, e = i.storage[Bt].get(r.signatureOptions), n = i.storage[de].get(r.signatureOptions), s = i.printCandidate(t), a = n.get(s);
	if (typeof a != "string") return t;
	for (let u of p(a, t)) {
		let f = i.printCandidate(u);
		if (n.get(f) === a) return u;
	}
	return t;
	function* p(u, f) {
		let m = e.get(u);
		if (!(m.length > 1)) {
			if (m.length === 0 && f.modifier) {
				let d = {
					...f,
					modifier: null
				}, c = n.get(i.printCandidate(d));
				if (typeof c == "string") for (let w of p(c, d)) yield Object.assign({}, w, { modifier: f.modifier });
			}
			if (m.length === 1) for (let d of we(i, m[0])) yield d;
		}
	}
}
var ca = new Map([["order-none", "order-0"], ["break-words", "wrap-break-word"]]);
function pa(t, r) {
	let i = r.designSystem, e = i.storage[de].get(r.signatureOptions), n = oa(i, t), s = ca.get(n) ?? null;
	if (s === null) return t;
	let a = e.get(n);
	if (typeof a != "string") return t;
	let p = e.get(s);
	if (typeof p != "string" || a !== p) return t;
	let [u] = we(i, s);
	return u;
}
function da(t, r) {
	let i = r.designSystem, e = i.storage[yt], n = i.storage[hi], s = wt(t);
	for (let [a] of s) {
		if (a.kind === "compound") continue;
		let p = i.printVariant(a), u = e.get(p);
		if (typeof u != "string") continue;
		let f = n.get(u);
		if (f.length !== 1) continue;
		let m = f[0], d = i.parseVariant(m);
		d !== null && ue(a, d);
	}
	return t;
}
function ma(t, r) {
	var _t$value4;
	let i = r.designSystem, e = i.storage[de].get(r.signatureOptions);
	if (t.kind === "functional" && ((_t$value4 = t.value) === null || _t$value4 === void 0 ? void 0 : _t$value4.kind) === "arbitrary" && t.value.dataType !== null) {
		let n = i.printCandidate({
			...t,
			value: {
				...t.value,
				dataType: null
			}
		});
		e.get(i.printCandidate(t)) === e.get(n) && (t.value.dataType = null);
	}
	return t;
}
function ga(t, r) {
	var _t$value5;
	if (t.kind !== "functional" || ((_t$value5 = t.value) === null || _t$value5 === void 0 ? void 0 : _t$value5.kind) !== "arbitrary") return t;
	let i = r.designSystem, e = i.storage[de].get(r.signatureOptions), n = e.get(i.printCandidate(t));
	if (n === null) return t;
	for (let s of mi(t)) if (e.get(i.printCandidate({
		...t,
		value: s
	})) === n) return t.value = s, t;
	return t;
}
function ha(t) {
	var _i$value, _i$value2, _i$value3;
	let r = wt(t);
	for (let [i] of r) if (i.kind === "functional" && i.root === "data" && ((_i$value = i.value) === null || _i$value === void 0 ? void 0 : _i$value.kind) === "arbitrary" && !i.value.value.includes("=")) i.value = {
		kind: "named",
		value: i.value.value
	};
	else if (i.kind === "functional" && i.root === "aria" && ((_i$value2 = i.value) === null || _i$value2 === void 0 ? void 0 : _i$value2.kind) === "arbitrary" && (i.value.value.endsWith("=true") || i.value.value.endsWith("=\"true\"") || i.value.value.endsWith("='true'"))) {
		let [e, n] = d(i.value.value, "=");
		if (e[e.length - 1] === "~" || e[e.length - 1] === "|" || e[e.length - 1] === "^" || e[e.length - 1] === "$" || e[e.length - 1] === "*") continue;
		i.value = {
			kind: "named",
			value: i.value.value.slice(0, i.value.value.indexOf("="))
		};
	} else i.kind === "functional" && i.root === "supports" && ((_i$value3 = i.value) === null || _i$value3 === void 0 ? void 0 : _i$value3.kind) === "arbitrary" && /^[a-z-][a-z0-9-]*$/i.test(i.value.value) && (i.value = {
		kind: "named",
		value: i.value.value
	});
	return t;
}
function* mi(t, r = (() => {
	var _t$value6;
	return (_t$value6 = t.value) === null || _t$value6 === void 0 ? void 0 : _t$value6.value;
})() ?? "", i = /* @__PURE__ */ new Set()) {
	if (i.has(r)) return;
	if (i.add(r), yield {
		kind: "named",
		value: r,
		fraction: null
	}, r.endsWith("%") && ge(r.slice(0, -1)) && (yield {
		kind: "named",
		value: r.slice(0, -1),
		fraction: null
	}), r.includes("/")) {
		let [s, a] = r.split("/");
		u(s) && u(a) && (yield {
			kind: "named",
			value: s,
			fraction: `${s}/${a}`
		});
	}
	let e = /* @__PURE__ */ new Set();
	for (let s of r.matchAll(/(\d+\/\d+)|(\d+\.?\d+)/g)) e.add(s[0].trim());
	let n = Array.from(e).sort((s, a) => s.length - a.length);
	for (let s of n) yield* mi(t, s, i);
}
function li(t) {
	return !t.some((r) => r.kind === "separator" && r.value.trim() === ",");
}
function gt(t) {
	let r = t.value.trim();
	return t.kind === "selector" && r[0] === "[" && r[r.length - 1] === "]";
}
function va(t, r) {
	let i = [t], e = r.designSystem, n = e.storage[yt], s = wt(t);
	for (let [a, p] of s) if (a.kind === "compound" && (a.root === "has" || a.root === "not" || a.root === "in") && a.modifier !== null && "modifier" in a.variant && (a.variant.modifier = a.modifier, a.modifier = null), a.kind === "arbitrary") {
		if (a.relative) continue;
		let u$3 = Re(a.selector.trim());
		if (!li(u$3)) continue;
		if (p === null && u$3.length === 3 && u$3[0].kind === "selector" && u$3[0].value === "&" && u$3[1].kind === "combinator" && u$3[1].value.trim() === ">" && u$3[2].kind === "selector" && u$3[2].value === "*") {
			ue(a, e.parseVariant("*"));
			continue;
		}
		if (p === null && u$3.length === 3 && u$3[0].kind === "selector" && u$3[0].value === "&" && u$3[1].kind === "combinator" && u$3[1].value.trim() === "" && u$3[2].kind === "selector" && u$3[2].value === "*") {
			ue(a, e.parseVariant("**"));
			continue;
		}
		if (p === null && u$3.length === 3 && u$3[1].kind === "combinator" && u$3[1].value.trim() === "" && u$3[2].kind === "selector" && u$3[2].value === "&") {
			u$3.pop(), u$3.pop(), ue(a, e.parseVariant(`in-[${pe(u$3)}]`));
			continue;
		}
		if (p === null && u$3[0].kind === "selector" && (u$3[0].value === "@media" || u$3[0].value === "@supports")) {
			let c = n.get(e.printVariant(a)), w = B(pe(u$3)), h = !1;
			if (I(w, (y) => {
				if (y.kind === "word" && y.value === "not") return h = !0, E.Replace([]);
			}), w = B(Z(w)), I(w, (y) => {
				y.kind === "separator" && y.value !== " " && y.value.trim() === "" && (y.value = " ");
			}), h) {
				let y = e.parseVariant(`not-[${Z(w)}]`);
				if (y === null) continue;
				if (c === n.get(e.printVariant(y))) {
					ue(a, y);
					continue;
				}
			}
		}
		let f = null;
		p === null && u$3.length === 3 && u$3[0].kind === "selector" && u$3[0].value.trim() === "&" && u$3[1].kind === "combinator" && u$3[1].value.trim() === ">" && u$3[2].kind === "selector" && (gt(u$3[2]) || u$3[2].value[0] === ":") && (u$3 = [u$3[2]], f = e.parseVariant("*")), p === null && u$3.length === 3 && u$3[0].kind === "selector" && u$3[0].value.trim() === "&" && u$3[1].kind === "combinator" && u$3[1].value.trim() === "" && u$3[2].kind === "selector" && (gt(u$3[2]) || u$3[2].value[0] === ":") && (u$3 = [u$3[2]], f = e.parseVariant("**"));
		let m = u$3.filter((c) => !(c.kind === "selector" && c.value.trim() === "&"));
		if (m.length !== 1) continue;
		let d = m[0];
		if (d.kind === "function" && d.value === ":is") {
			if (!li(d.nodes) || d.nodes.length !== 1 || !gt(d.nodes[0])) continue;
			d = d.nodes[0];
		}
		if (d.kind === "function" && d.value[0] === ":" || d.kind === "selector" && d.value[0] === ":") {
			let c = d, w = !1;
			if (c.kind === "function" && c.value === ":not") {
				if (w = !0, c.nodes.length !== 1 || c.nodes[0].kind !== "selector" && c.nodes[0].kind !== "function" || c.nodes[0].value[0] !== ":") continue;
				c = c.nodes[0];
			}
			let h = ((x) => {
				if (x === ":nth-child" && c.kind === "function" && c.nodes.length === 1 && c.nodes[0].kind === "value" && c.nodes[0].value === "odd") return w ? (w = !1, "even") : "odd";
				if (x === ":nth-child" && c.kind === "function" && c.nodes.length === 1 && c.nodes[0].kind === "value" && c.nodes[0].value === "even") return w ? (w = !1, "odd") : "even";
				for (let [$, A] of [
					[":nth-child", "nth"],
					[":nth-last-child", "nth-last"],
					[":nth-of-type", "nth-of-type"],
					[":nth-last-of-type", "nth-of-last-type"]
				]) if (x === $ && c.kind === "function" && c.nodes.length === 1) return c.nodes.length === 1 && c.nodes[0].kind === "value" && u(c.nodes[0].value) ? `${A}-${c.nodes[0].value}` : `${A}-[${pe(c.nodes)}]`;
				if (w) {
					if (n.get(e.printVariant(a)) === n.get(`not-[${x}]`)) return `[&${x}]`;
				}
				return null;
			})(c.value);
			if (h === null) {
				if (f) return ue(a, {
					kind: "arbitrary",
					selector: d.value,
					relative: !1
				}), [f, a];
				continue;
			}
			w && (h = `not-${h}`);
			let y = e.parseVariant(h);
			if (y === null) continue;
			ue(a, y);
		} else if (gt(d)) {
			let c = jr(d.value);
			if (c === null) continue;
			if (c.attribute.startsWith("data-")) {
				let w = c.attribute.slice(5);
				ue(a, {
					kind: "functional",
					root: "data",
					modifier: null,
					value: c.value === null ? {
						kind: "named",
						value: w
					} : {
						kind: "arbitrary",
						value: `${w}${c.operator}${c.quote ?? ""}${c.value}${c.quote ?? ""}${c.sensitivity ? ` ${c.sensitivity}` : ""}`
					}
				});
			} else if (c.attribute.startsWith("aria-")) {
				let w = c.attribute.slice(5);
				ue(a, {
					kind: "functional",
					root: "aria",
					modifier: null,
					value: c.value === null ? {
						kind: "arbitrary",
						value: w
					} : c.operator === "=" && c.value === "true" && c.sensitivity === null ? {
						kind: "named",
						value: w
					} : {
						kind: "arbitrary",
						value: `${c.attribute}${c.operator}${c.quote ?? ""}${c.value}${c.quote ?? ""}${c.sensitivity ? ` ${c.sensitivity}` : ""}`
					}
				});
			} else ue(a, {
				kind: "arbitrary",
				selector: d.value,
				relative: !1
			});
		}
		if (f) return [f, a];
	}
	return i;
}
function wa(t, r) {
	if (t.kind !== "functional" && t.kind !== "arbitrary" || t.modifier === null) return t;
	let i = r.designSystem, e = i.storage[de].get(r.signatureOptions), n = e.get(i.printCandidate(t)), s = t.modifier;
	if (n === e.get(i.printCandidate({
		...t,
		modifier: null
	}))) return t.modifier = null, t;
	{
		let a = {
			kind: "named",
			value: s.value.endsWith("%") ? s.value.includes(".") ? `${Number(s.value.slice(0, -1))}` : s.value.slice(0, -1) : s.value,
			fraction: null
		};
		if (n === e.get(i.printCandidate({
			...t,
			modifier: a
		}))) return t.modifier = a, t;
	}
	{
		let a = {
			kind: "named",
			value: `${parseFloat(s.value) * 100}`,
			fraction: null
		};
		if (n === e.get(i.printCandidate({
			...t,
			modifier: a
		}))) return t.modifier = a, t;
	}
	return t;
}
var de = Symbol();
function ya(t) {
	return new K((r) => new K((i) => {
		try {
			i = t.theme.prefix && !i.startsWith(t.theme.prefix) ? `${t.theme.prefix}:${i}` : i;
			let e = [G(".x", [F("@apply", i)])];
			return Sa(t, () => {
				for (let s of t.parseCandidate(i)) t.compileAstNodes(s, 1);
				Ae(e, t);
			}), gi(t, e, r), re(e);
		} catch {
			return Symbol();
		}
	}));
}
function gi(t, r, i) {
	let { rem: e } = i;
	return I(r, {
		enter(n, s) {
			if (n.kind === "declaration") {
				var _s$parent;
				if (n.value === void 0 || n.property === "--tw-sort") return E.Replace([]);
				if (n.property.startsWith("--tw-") && (((_s$parent = s.parent) === null || _s$parent === void 0 ? void 0 : _s$parent.nodes) ?? []).some((a) => a.kind === "declaration" && n.value === a.value && n.important === a.important && !a.property.startsWith("--tw-"))) return E.Replace([]);
				if (i.features & 1) {
					let a = qr(n, i.features);
					if (a) return E.Replace(a);
				}
				n.value.includes("var(") && (n.value = ka(n.value, t)), n.value = dt(n.value, e), n.value = be(n.value);
			} else {
				if (n.kind === "context" || n.kind === "at-root") return E.Replace(n.nodes);
				if (n.kind === "comment") return E.Replace([]);
				if (n.kind === "at-rule" && n.name === "@property") return E.Replace([]);
			}
		},
		exit(n) {
			if (n.kind === "rule" || n.kind === "at-rule") {
				if (n.nodes.length > 1) {
					let s = /* @__PURE__ */ new Set();
					for (let a = n.nodes.length - 1; a >= 0; a--) {
						let p = n.nodes[a];
						p.kind === "declaration" && p.value !== void 0 && (s.has(p.property) && n.nodes.splice(a, 1), s.add(p.property));
					}
				}
				n.nodes.sort((s, a) => s.kind !== "declaration" || a.kind !== "declaration" ? 0 : s.property.localeCompare(a.property));
			}
		}
	}), r;
}
function ka(t, r) {
	let i = !1, e = B(t), n = /* @__PURE__ */ new Set();
	return I(e, (s) => {
		if (s.kind !== "function" || s.value !== "var" || s.nodes.length !== 1 && s.nodes.length < 3) return;
		let a = s.nodes[0].value;
		r.theme.prefix && a.startsWith(`--${r.theme.prefix}-`) && (a = a.slice(`--${r.theme.prefix}-`.length));
		let p = r.resolveThemeValue(a);
		if (!n.has(a) && (n.add(a), p !== void 0 && (s.nodes.length === 1 && (i = !0, s.nodes.push(...B(`,${p}`))), s.nodes.length >= 3))) {
			if (Z(s.nodes) === `${s.nodes[0].value},${p}`) return i = !0, E.Replace(B(p));
		}
	}), i ? Z(e) : t;
}
var Wt = Symbol();
function ba() {
	return new K((t) => new K((r) => new K((i) => /* @__PURE__ */ new Set())));
}
var vt = Symbol();
function xa(t) {
	return new K((r) => new K((i) => {
		let e = new K((s) => /* @__PURE__ */ new Set());
		t.theme.prefix && !i.startsWith(t.theme.prefix) && (i = `${t.theme.prefix}:${i}`);
		let n = t.parseCandidate(i);
		return n.length === 0 || I(gi(t, t.compileAstNodes(n[0]).map((s) => ee(s.node)), r), (s) => {
			s.kind === "declaration" && (e.get(s.property).add(s.value), t.storage[Wt].get(r).get(s.property).get(s.value).add(i));
		}), e;
	}));
}
var Bt = Symbol();
function Aa(t) {
	return new K((r) => {
		let i = t.storage[de].get(r), e = new K(() => []);
		for (let [n, s] of t.getClassList()) {
			let a = i.get(n);
			if (typeof a == "string") {
				if (n[0] === "-" && n.endsWith("-0")) {
					let p = i.get(n.slice(1));
					if (typeof p == "string" && a === p) continue;
				}
				e.get(a).push(n), t.storage[vt].get(r).get(n);
				for (let p of s.modifiers) {
					if (ge(p)) continue;
					let u = `${n}/${p}`, f = i.get(u);
					typeof f == "string" && (e.get(f).push(u), t.storage[vt].get(r).get(u));
				}
			}
		}
		return e;
	});
}
var yt = Symbol();
function Ca(t) {
	return new K((r) => {
		try {
			r = t.theme.prefix && !r.startsWith(t.theme.prefix) ? `${t.theme.prefix}:${r}` : r;
			let i = [G(".x", [F("@apply", `${r}:flex`)])];
			return Ae(i, t), I(i, (n) => {
				if (n.kind === "at-rule" && n.params.includes(" ")) n.params = n.params.replaceAll(" ", "");
				else if (n.kind === "rule") {
					let s = Re(n.selector), a = !1;
					I(s, (p) => {
						var _p$nodes$, _p$nodes$2;
						if (p.kind === "separator" && p.value !== " ") p.value = p.value.trim(), a = !0;
						else if (p.kind === "function" && p.value === ":is") {
							if (p.nodes.length === 1) return a = !0, E.Replace(p.nodes);
							if (p.nodes.length === 2 && p.nodes[0].kind === "selector" && p.nodes[0].value === "*" && p.nodes[1].kind === "selector" && p.nodes[1].value[0] === ":") return a = !0, E.Replace(p.nodes[1]);
						} else p.kind === "function" && p.value[0] === ":" && ((_p$nodes$ = p.nodes[0]) === null || _p$nodes$ === void 0 ? void 0 : _p$nodes$.kind) === "selector" && ((_p$nodes$2 = p.nodes[0]) === null || _p$nodes$2 === void 0 ? void 0 : _p$nodes$2.value[0]) === ":" && (a = !0, p.nodes.unshift({
							kind: "selector",
							value: "*"
						}));
					}), a && (n.selector = pe(s));
				}
			}), re(i);
		} catch {
			return Symbol();
		}
	});
}
var hi = Symbol();
function $a(t) {
	let r = t.storage[yt], i = new K(() => []);
	for (let [e, n] of t.variants.entries()) if (n.kind === "static") {
		let s = r.get(e);
		if (typeof s != "string") continue;
		i.get(s).push(e);
	}
	return i;
}
function Sa(t, r) {
	let i = t.theme.values.get, e = /* @__PURE__ */ new Set();
	t.theme.values.get = (n) => {
		let s = i.call(t.theme.values, n);
		return s === void 0 || s.options & 1 && (e.add(s), s.options &= -2), s;
	};
	try {
		return r();
	} finally {
		t.theme.values.get = i;
		for (let n of e) n.options |= 1;
	}
}
function* Ta(t) {
	let r = t.length, i = 1n << BigInt(r);
	for (let e = r; e >= 2; e--) {
		let n = (1n << BigInt(e)) - 1n;
		for (; n < i;) {
			let s = [];
			for (let u = 0; u < r; u++) n >> BigInt(u) & 1n && s.push(t[u]);
			yield s;
			let a = n & -n, p = n + a;
			n = ((p ^ n) >> 2n) / a | p;
		}
	}
}
function si(t, r) {
	if (typeof t.intersection == "function") return t.intersection(r);
	if (t.size === 0 || r.size === 0) return /* @__PURE__ */ new Set();
	let i = new Set(t);
	for (let e of r) i.has(e) || i.delete(e);
	return i;
}
var Na = /^\d+\/\d+$/;
function vi(t) {
	let r = new K((n) => ({
		name: n,
		utility: n,
		fraction: !1,
		modifiers: []
	}));
	for (let n of t.utilities.keys("static")) {
		if (t.utilities.getCompletions(n).length === 0) continue;
		let a = r.get(n);
		a.fraction = !1, a.modifiers = [];
	}
	for (let n of t.utilities.keys("functional")) {
		let s = t.utilities.getCompletions(n);
		for (let a of s) for (let p of a.values) {
			let u = p !== null && Na.test(p), f = p === null ? n : `${n}-${p}`, m = r.get(f);
			if (m.utility = n, m.fraction || (m.fraction = u), m.modifiers.push(...a.modifiers), a.supportsNegative) {
				let d = r.get(`-${f}`);
				d.utility = `-${n}`, d.fraction || (d.fraction = u), d.modifiers.push(...a.modifiers);
			}
			m.modifiers = Array.from(new Set(m.modifiers));
		}
	}
	if (r.size === 0) return [];
	let i = Array.from(r.values());
	return i.sort((n, s) => pt(n.name, s.name)), Ea(i);
}
function Ea(t) {
	let r = [], i = null, e = /* @__PURE__ */ new Map(), n = new K(() => []);
	for (let a of t) {
		let { utility: p, fraction: u } = a;
		i || (i = {
			utility: p,
			items: []
		}, e.set(p, i)), p !== i.utility && (r.push(i), i = {
			utility: p,
			items: []
		}, e.set(p, i)), u ? n.get(p).push(a) : i.items.push(a);
	}
	i && r[r.length - 1] !== i && r.push(i);
	for (let [a, p] of n) {
		let u = e.get(a);
		u && u.items.push(...p);
	}
	let s = [];
	for (let a of r) for (let p of a.items) s.push([p.name, { modifiers: p.modifiers }]);
	return s;
}
function wi(t) {
	let r = [];
	for (let [e, n] of t.variants.entries()) {
		let p = function({ value: u, modifier: f } = {}) {
			let m = e;
			u && (m += s ? `-${u}` : u), f && (m += `/${f}`);
			let d = t.parseVariant(m);
			if (!d) return [];
			let c = G(".__placeholder__", []);
			if (ze(c, d, t.variants) === null) return [];
			let w = [];
			return I(c.nodes, { exit(h, y) {
				if (h.kind !== "rule" && h.kind !== "at-rule" || h.nodes.length > 0) return;
				let x = y.path();
				x.push(h), x.sort((k, U) => {
					let N = k.kind === "at-rule", O = U.kind === "at-rule";
					return N && !O ? -1 : !N && O ? 1 : 0;
				});
				let $ = x.flatMap((k) => k.kind === "rule" ? k.selector === "&" ? [] : [k.selector] : k.kind === "at-rule" ? [`${k.name} ${k.params}`] : []), A = "";
				for (let k = $.length - 1; k >= 0; k--) A = A === "" ? $[k] : `${$[k]} { ${A} }`;
				w.push(A);
			} }), w;
		};
		if (n.kind === "arbitrary") continue;
		let s = e !== "@", a = t.variants.getCompletions(e);
		switch (n.kind) {
			case "static":
				r.push({
					name: e,
					values: a,
					isArbitrary: !1,
					hasDash: s,
					selectors: p
				});
				break;
			case "functional":
				r.push({
					name: e,
					values: a,
					isArbitrary: !0,
					hasDash: s,
					selectors: p
				});
				break;
			case "compound":
				r.push({
					name: e,
					values: a,
					isArbitrary: !0,
					hasDash: s,
					selectors: p
				});
				break;
		}
	}
	return r;
}
function yi(t, r) {
	let { astNodes: i, nodeSorting: e } = Ce(Array.from(r), t), n = new Map(r.map((a) => [a, null])), s = 0n;
	for (let a of i) {
		var _e$get;
		let p = (_e$get = e.get(a)) === null || _e$get === void 0 ? void 0 : _e$get.candidate;
		p && n.set(p, n.get(p) ?? s++);
	}
	return r.map((a) => [a, n.get(a) ?? null]);
}
var kt = /^@?[a-z0-9][a-zA-Z0-9_-]*(?<![_-])$/;
var Yt = class {
	compareFns = /* @__PURE__ */ new Map();
	variants = /* @__PURE__ */ new Map();
	completions = /* @__PURE__ */ new Map();
	groupOrder = null;
	lastOrder = 0;
	static(r, i, { compounds: e, order: n } = {}) {
		this.set(r, {
			kind: "static",
			applyFn: i,
			compoundsWith: 0,
			compounds: e ?? 2,
			order: n
		});
	}
	fromAst(r, i, e) {
		let n = [], s = !1;
		I(i, (a) => {
			a.kind === "rule" ? n.push(a.selector) : a.kind === "at-rule" && a.name === "@variant" ? s = !0 : a.kind === "at-rule" && a.name !== "@slot" && n.push(`${a.name} ${a.params}`);
		}), this.static(r, (a) => {
			let p = i.map(ee);
			s && Qe(p, e), Gt(p, a.nodes), a.nodes = p;
		}, { compounds: Pe(n) });
	}
	functional(r, i, { compounds: e, order: n } = {}) {
		this.set(r, {
			kind: "functional",
			applyFn: i,
			compoundsWith: 0,
			compounds: e ?? 2,
			order: n
		});
	}
	compound(r, i, e, { compounds: n, order: s } = {}) {
		this.set(r, {
			kind: "compound",
			applyFn: e,
			compoundsWith: i,
			compounds: n ?? 2,
			order: s
		});
	}
	group(r, i) {
		this.groupOrder = this.nextOrder(), i && this.compareFns.set(this.groupOrder, i), r(), this.groupOrder = null;
	}
	has(r) {
		return this.variants.has(r);
	}
	get(r) {
		return this.variants.get(r);
	}
	kind(r) {
		var _this$variants$get;
		return (_this$variants$get = this.variants.get(r)) === null || _this$variants$get === void 0 ? void 0 : _this$variants$get.kind;
	}
	compoundsWith(r, i) {
		let e = this.variants.get(r), n = typeof i == "string" ? this.variants.get(i) : i.kind === "arbitrary" ? { compounds: Pe([i.selector]) } : this.variants.get(i.root);
		return !(!e || !n || e.kind !== "compound" || n.compounds === 0 || e.compoundsWith === 0 || (e.compoundsWith & n.compounds) === 0);
	}
	suggest(r, i) {
		this.completions.set(r, i);
	}
	getCompletions(r) {
		var _this$completions$get3;
		return ((_this$completions$get3 = this.completions.get(r)) === null || _this$completions$get3 === void 0 ? void 0 : _this$completions$get3()) ?? [];
	}
	compare(r, i) {
		if (r === i) return 0;
		if (r === null) return -1;
		if (i === null) return 1;
		if (r.kind === "arbitrary" && i.kind === "arbitrary") return r.selector < i.selector ? -1 : 1;
		if (r.kind === "arbitrary") return 1;
		if (i.kind === "arbitrary") return -1;
		let e = this.variants.get(r.root).order, s = e - this.variants.get(i.root).order;
		if (s !== 0) return s;
		if (r.kind === "compound" && i.kind === "compound") {
			let f = this.compare(r.variant, i.variant);
			return f !== 0 ? f : r.modifier && i.modifier ? r.modifier.value < i.modifier.value ? -1 : 1 : r.modifier ? 1 : i.modifier ? -1 : 0;
		}
		let a = this.compareFns.get(e);
		if (a !== void 0) return a(r, i);
		if (r.root !== i.root) return r.root < i.root ? -1 : 1;
		let p = r.value, u = i.value;
		return p === null ? -1 : u === null || p.kind === "arbitrary" && u.kind !== "arbitrary" ? 1 : p.kind !== "arbitrary" && u.kind === "arbitrary" || p.value < u.value ? -1 : 1;
	}
	keys() {
		return this.variants.keys();
	}
	entries() {
		return this.variants.entries();
	}
	set(r, { kind: i, applyFn: e, compounds: n, compoundsWith: s, order: a }) {
		let p = this.variants.get(r);
		p ? Object.assign(p, {
			kind: i,
			applyFn: e,
			compounds: n
		}) : (a === void 0 && (this.lastOrder = this.nextOrder(), a = this.lastOrder), this.variants.set(r, {
			kind: i,
			applyFn: e,
			order: a,
			compoundsWith: s,
			compounds: n
		}));
	}
	nextOrder() {
		return this.groupOrder ?? this.lastOrder + 1;
	}
};
function Pe(t) {
	let r = 0;
	for (let i of t) {
		if (i[0] === "@") {
			if (!i.startsWith("@media") && !i.startsWith("@supports") && !i.startsWith("@container")) return 0;
			r |= 1;
			continue;
		}
		if (i.includes("::")) return 0;
		r |= 2;
	}
	return r;
}
function bi(t) {
	let r = new Yt();
	function i(f, m, { compounds: d } = {}) {
		d = d ?? Pe(m), r.static(f, (c) => {
			c.nodes = m.map((w) => J(w, c.nodes));
		}, { compounds: d });
	}
	i("*", [":is(& > *)"], { compounds: 0 }), i("**", [":is(& *)"], { compounds: 0 });
	function e(f, m) {
		return m.map((d$6) => {
			d$6 = d$6.trim();
			let c = d(d$6, " ");
			return c[0] === "not" ? c.slice(1).join(" ") : f === "@container" ? c[0][0] === "(" ? `not ${d$6}` : c[1] === "not" ? `${c[0]} ${c.slice(2).join(" ")}` : `${c[0]} not ${c.slice(1).join(" ")}` : `not ${d$6}`;
		});
	}
	let n = [
		"@media",
		"@supports",
		"@container"
	];
	function s(f) {
		for (let m of n) {
			if (m !== f.name) continue;
			let d$7 = d(f.params, ",");
			return d$7.length > 1 ? null : (d$7 = e(f.name, d$7), F(f.name, d$7.join(", ")));
		}
		return null;
	}
	function a(f) {
		return f.includes("::") ? null : `&:not(${d(f, ",").map((d) => (d = d.replaceAll("&", "*"), d)).join(", ")})`;
	}
	r.compound("not", 3, (f, m) => {
		if (m.variant.kind === "arbitrary" && m.variant.relative || m.modifier) return null;
		let d = !1;
		if (I([f], (c, w) => {
			if (c.kind !== "rule" && c.kind !== "at-rule") return E.Continue;
			if (c.nodes.length > 0) return E.Continue;
			let h = [], y = [], x = w.path();
			x.push(c);
			for (let A of x) A.kind === "at-rule" ? h.push(A) : A.kind === "rule" && y.push(A);
			if (h.length > 1) return E.Stop;
			if (y.length > 1) return E.Stop;
			let $ = [];
			for (let A of y) {
				let k = a(A.selector);
				if (!k) return d = !1, E.Stop;
				$.push(G(k, []));
			}
			for (let A of h) {
				let k = s(A);
				if (!k) return d = !1, E.Stop;
				$.push(k);
			}
			return Object.assign(f, G("&", $)), d = !0, E.Skip;
		}), f.kind === "rule" && f.selector === "&" && f.nodes.length === 1 && Object.assign(f, f.nodes[0]), !d) return null;
	}), r.suggest("not", () => Array.from(r.keys()).filter((f) => r.compoundsWith("not", f))), r.compound("group", 2, (f, m) => {
		if (m.variant.kind === "arbitrary" && m.variant.relative) return null;
		let d$8 = m.modifier ? `:where(.${t.prefix ? `${t.prefix}\\:` : ""}group\\/${m.modifier.value})` : `:where(.${t.prefix ? `${t.prefix}\\:` : ""}group)`, c = !1;
		if (I([f], (w, h) => {
			if (w.kind !== "rule") return E.Continue;
			for (let x of h.path()) if (x.kind === "rule") return c = !1, E.Stop;
			let y = w.selector.replaceAll("&", d$8);
			d(y, ",").length > 1 && (y = `:is(${y})`), w.selector = `&:is(${y} *)`, c = !0;
		}), !c) return null;
	}), r.suggest("group", () => Array.from(r.keys()).filter((f) => r.compoundsWith("group", f))), r.compound("peer", 2, (f, m) => {
		if (m.variant.kind === "arbitrary" && m.variant.relative) return null;
		let d$9 = m.modifier ? `:where(.${t.prefix ? `${t.prefix}\\:` : ""}peer\\/${m.modifier.value})` : `:where(.${t.prefix ? `${t.prefix}\\:` : ""}peer)`, c = !1;
		if (I([f], (w, h) => {
			if (w.kind !== "rule") return E.Continue;
			for (let x of h.path()) if (x.kind === "rule") return c = !1, E.Stop;
			let y = w.selector.replaceAll("&", d$9);
			d(y, ",").length > 1 && (y = `:is(${y})`), w.selector = `&:is(${y} ~ *)`, c = !0;
		}), !c) return null;
	}), r.suggest("peer", () => Array.from(r.keys()).filter((f) => r.compoundsWith("peer", f))), i("first-letter", ["&::first-letter"]), i("first-line", ["&::first-line"]), i("marker", [
		"& *::marker",
		"&::marker",
		"& *::-webkit-details-marker",
		"&::-webkit-details-marker"
	]), i("selection", ["& *::selection", "&::selection"]), i("file", ["&::file-selector-button"]), i("placeholder", ["&::placeholder"]), i("backdrop", ["&::backdrop"]), i("details-content", ["&::details-content"]);
	{
		let f = function() {
			return W([F("@property", "--tw-content", [
				o("syntax", "\"*\""),
				o("initial-value", "\"\""),
				o("inherits", "false")
			])]);
		};
		r.static("before", (m) => {
			m.nodes = [G("&::before", [
				f(),
				o("content", "var(--tw-content)"),
				...m.nodes
			])];
		}, { compounds: 0 }), r.static("after", (m) => {
			m.nodes = [G("&::after", [
				f(),
				o("content", "var(--tw-content)"),
				...m.nodes
			])];
		}, { compounds: 0 });
	}
	i("first", ["&:first-child"]), i("last", ["&:last-child"]), i("only", ["&:only-child"]), i("odd", ["&:nth-child(odd)"]), i("even", ["&:nth-child(even)"]), i("first-of-type", ["&:first-of-type"]), i("last-of-type", ["&:last-of-type"]), i("only-of-type", ["&:only-of-type"]), i("visited", ["&:visited"]), i("target", ["&:target"]), i("open", ["&:is([open], :popover-open, :open)"]), i("default", ["&:default"]), i("checked", ["&:checked"]), i("indeterminate", ["&:indeterminate"]), i("placeholder-shown", ["&:placeholder-shown"]), i("autofill", ["&:autofill"]), i("optional", ["&:optional"]), i("required", ["&:required"]), i("valid", ["&:valid"]), i("invalid", ["&:invalid"]), i("user-valid", ["&:user-valid"]), i("user-invalid", ["&:user-invalid"]), i("in-range", ["&:in-range"]), i("out-of-range", ["&:out-of-range"]), i("read-only", ["&:read-only"]), i("empty", ["&:empty"]), i("focus-within", ["&:focus-within"]), r.static("hover", (f) => {
		f.nodes = [G("&:hover", [F("@media", "(hover: hover)", f.nodes)])];
	}), i("focus", ["&:focus"]), i("focus-visible", ["&:focus-visible"]), i("active", ["&:active"]), i("enabled", ["&:enabled"]), i("disabled", ["&:disabled"]), i("inert", ["&:is([inert], [inert] *)"]), r.compound("in", 2, (f, m) => {
		if (m.modifier) return null;
		let d = !1;
		if (I([f], (c, w) => {
			if (c.kind !== "rule") return E.Continue;
			for (let h of w.path()) if (h.kind === "rule") return d = !1, E.Stop;
			c.selector = `:where(${c.selector.replaceAll("&", "*")}) &`, d = !0;
		}), !d) return null;
	}), r.suggest("in", () => Array.from(r.keys()).filter((f) => r.compoundsWith("in", f))), r.compound("has", 2, (f, m) => {
		if (m.modifier) return null;
		let d = !1;
		if (I([f], (c, w) => {
			if (c.kind !== "rule") return E.Continue;
			for (let h of w.path()) if (h.kind === "rule") return d = !1, E.Stop;
			c.selector = `&:has(${c.selector.replaceAll("&", "*")})`, d = !0;
		}), !d) return null;
	}), r.suggest("has", () => Array.from(r.keys()).filter((f) => r.compoundsWith("has", f))), r.functional("aria", (f, m) => {
		if (!m.value || m.modifier) return null;
		m.value.kind === "arbitrary" ? f.nodes = [G(`&[aria-${ki(m.value.value)}]`, f.nodes)] : f.nodes = [G(`&[aria-${m.value.value}="true"]`, f.nodes)];
	}), r.suggest("aria", () => [
		"busy",
		"checked",
		"disabled",
		"expanded",
		"hidden",
		"pressed",
		"readonly",
		"required",
		"selected"
	]), r.functional("data", (f, m) => {
		if (!m.value || m.modifier) return null;
		f.nodes = [G(`&[data-${ki(m.value.value)}]`, f.nodes)];
	}), r.functional("nth", (f, m) => {
		if (!m.value || m.modifier || m.value.kind === "named" && !u(m.value.value)) return null;
		f.nodes = [G(`&:nth-child(${m.value.value})`, f.nodes)];
	}), r.functional("nth-last", (f, m) => {
		if (!m.value || m.modifier || m.value.kind === "named" && !u(m.value.value)) return null;
		f.nodes = [G(`&:nth-last-child(${m.value.value})`, f.nodes)];
	}), r.functional("nth-of-type", (f, m) => {
		if (!m.value || m.modifier || m.value.kind === "named" && !u(m.value.value)) return null;
		f.nodes = [G(`&:nth-of-type(${m.value.value})`, f.nodes)];
	}), r.functional("nth-last-of-type", (f, m) => {
		if (!m.value || m.modifier || m.value.kind === "named" && !u(m.value.value)) return null;
		f.nodes = [G(`&:nth-last-of-type(${m.value.value})`, f.nodes)];
	}), r.functional("supports", (f, m) => {
		if (!m.value || m.modifier) return null;
		let d = m.value.value;
		if (d === null) return null;
		if (/^[\w-]*\s*\(/.test(d)) {
			f.nodes = [F("@supports", d.replace(/\b(and|or|not)\b/g, " $1 "), f.nodes)];
			return;
		}
		d.includes(":") || (d = `${d}: var(--tw)`), (d[0] !== "(" || d[d.length - 1] !== ")") && (d = `(${d})`), f.nodes = [F("@supports", d, f.nodes)];
	}, { compounds: 1 }), i("motion-safe", ["@media (prefers-reduced-motion: no-preference)"]), i("motion-reduce", ["@media (prefers-reduced-motion: reduce)"]), i("contrast-more", ["@media (prefers-contrast: more)"]), i("contrast-less", ["@media (prefers-contrast: less)"]);
	{
		let f = function(m, d, c, w) {
			if (m === d) return 0;
			let h = w.get(m);
			if (h === null) return c === "asc" ? -1 : 1;
			let y = w.get(d);
			return y === null ? c === "asc" ? 1 : -1 : Ve(h, y, c);
		};
		{
			let m = t.namespace("--breakpoint"), d = new K((c) => {
				switch (c.kind) {
					case "static": return t.resolveValue(c.root, ["--breakpoint"]) ?? null;
					case "functional": {
						if (!c.value || c.modifier) return null;
						let w = null;
						return c.value.kind === "arbitrary" ? w = c.value.value : c.value.kind === "named" && (w = t.resolveValue(c.value.value, ["--breakpoint"])), !w || w.includes("var(") ? null : w;
					}
					case "arbitrary":
					case "compound": return null;
				}
			});
			r.group(() => {
				r.functional("max", (c, w) => {
					if (w.modifier) return null;
					let h = d.get(w);
					if (h === null) return null;
					c.nodes = [F("@media", `(width < ${h})`, c.nodes)];
				}, { compounds: 1 });
			}, (c, w) => f(c, w, "desc", d)), r.suggest("max", () => Array.from(m.keys()).filter((c) => c !== null)), r.group(() => {
				for (let [c, w] of t.namespace("--breakpoint")) c !== null && r.static(c, (h) => {
					h.nodes = [F("@media", `(width >= ${w})`, h.nodes)];
				}, { compounds: 1 });
				r.functional("min", (c, w) => {
					if (w.modifier) return null;
					let h = d.get(w);
					if (h === null) return null;
					c.nodes = [F("@media", `(width >= ${h})`, c.nodes)];
				}, { compounds: 1 });
			}, (c, w) => f(c, w, "asc", d)), r.suggest("min", () => Array.from(m.keys()).filter((c) => c !== null));
		}
		{
			let m = t.namespace("--container"), d = new K((c) => {
				switch (c.kind) {
					case "functional": {
						if (c.value === null) return null;
						let w = null;
						return c.value.kind === "arbitrary" ? w = c.value.value : c.value.kind === "named" && (w = t.resolveValue(c.value.value, ["--container"])), !w || w.includes("var(") ? null : w;
					}
					case "static":
					case "arbitrary":
					case "compound": return null;
				}
			});
			r.group(() => {
				r.functional("@max", (c, w) => {
					let h = d.get(w);
					if (h === null) return null;
					c.nodes = [F("@container", w.modifier ? `${w.modifier.value} (width < ${h})` : `(width < ${h})`, c.nodes)];
				}, { compounds: 1 });
			}, (c, w) => f(c, w, "desc", d)), r.suggest("@max", () => Array.from(m.keys()).filter((c) => c !== null)), r.group(() => {
				r.functional("@", (c, w) => {
					let h = d.get(w);
					if (h === null) return null;
					c.nodes = [F("@container", w.modifier ? `${w.modifier.value} (width >= ${h})` : `(width >= ${h})`, c.nodes)];
				}, { compounds: 1 }), r.functional("@min", (c, w) => {
					let h = d.get(w);
					if (h === null) return null;
					c.nodes = [F("@container", w.modifier ? `${w.modifier.value} (width >= ${h})` : `(width >= ${h})`, c.nodes)];
				}, { compounds: 1 });
			}, (c, w) => f(c, w, "asc", d)), r.suggest("@min", () => Array.from(m.keys()).filter((c) => c !== null)), r.suggest("@", () => Array.from(m.keys()).filter((c) => c !== null));
		}
	}
	return i("portrait", ["@media (orientation: portrait)"]), i("landscape", ["@media (orientation: landscape)"]), i("ltr", ["&:where(:dir(ltr), [dir=\"ltr\"], [dir=\"ltr\"] *)"]), i("rtl", ["&:where(:dir(rtl), [dir=\"rtl\"], [dir=\"rtl\"] *)"]), i("dark", ["@media (prefers-color-scheme: dark)"]), i("starting", ["@starting-style"]), i("print", ["@media print"]), i("forced-colors", ["@media (forced-colors: active)"]), i("inverted-colors", ["@media (inverted-colors: inverted)"]), i("pointer-none", ["@media (pointer: none)"]), i("pointer-coarse", ["@media (pointer: coarse)"]), i("pointer-fine", ["@media (pointer: fine)"]), i("any-pointer-none", ["@media (any-pointer: none)"]), i("any-pointer-coarse", ["@media (any-pointer: coarse)"]), i("any-pointer-fine", ["@media (any-pointer: fine)"]), i("noscript", ["@media (scripting: none)"]), r;
}
function ki(t) {
	if (t.includes("=")) {
		let [r, ...i] = d(t, "="), e = i.join("=").trim();
		if (e[0] === "'" || e[0] === "\"") return t;
		if (e.length > 1) {
			let n = e[e.length - 1];
			if (e[e.length - 2] === " " && (n === "i" || n === "I" || n === "s" || n === "S")) return `${r}="${e.slice(0, -2)}" ${n}`;
		}
		return `${r}="${e}"`;
	}
	return t;
}
function Gt(t, r) {
	I(t, (i) => {
		if (i.kind === "at-rule" && i.name === "@slot") return E.Replace(r);
		if (i.kind === "at-rule" && (i.name === "@keyframes" || i.name === "@property")) return Object.assign(i, W([F(i.name, i.params, i.nodes)])), E.Skip;
	});
}
function Qe(t, r) {
	let i = 0;
	return I(t, (e) => {
		if (e.kind !== "at-rule" || e.name !== "@variant") return;
		let n = G("&", e.nodes), s = e.params, a = r.parseVariant(s);
		if (a === null) throw new Error(`Cannot use \`@variant\` with unknown variant: ${s}`);
		if (ze(n, a, r.variants) === null) throw new Error(`Cannot use \`@variant\` with variant: ${s}`);
		return i |= 32, E.Replace(n);
	}), i;
}
function xi(t, r) {
	let i = Dr(t), e = bi(t), n = new K((d) => Nr(d, m)), s = new K((d) => Array.from(Vr(d, m))), a = new K((d) => new K((c) => {
		let w = Ai(c, m, d);
		try {
			De(w.map(({ node: h }) => h), m), Qe(w.map(({ node: h }) => h), m);
		} catch {
			return [];
		}
		return w;
	})), p = new K((d) => {
		for (let c of st(d)) t.markUsedVariable(c);
	});
	function u(d) {
		let c = [];
		for (let w of d) {
			let h = !0, { astNodes: y } = Ce([w], m, { onInvalidCandidate() {
				h = !1;
			} });
			r && I(y, (x) => (x.src ?? (x.src = r), E.Continue)), y = Te(y, m, 0), c.push(h ? y : []);
		}
		return c;
	}
	function f(d) {
		return u(d).map((c) => c.length > 0 ? re(c) : null);
	}
	let m = {
		theme: t,
		utilities: i,
		variants: e,
		invalidCandidates: /* @__PURE__ */ new Set(),
		important: !1,
		candidatesToCss: f,
		candidatesToAst: u,
		getClassOrder(d) {
			return yi(this, d);
		},
		getClassList() {
			return vi(this);
		},
		getVariants() {
			return wi(this);
		},
		parseCandidate(d) {
			return s.get(d);
		},
		parseVariant(d) {
			return n.get(d);
		},
		compileAstNodes(d, c = 1) {
			return a.get(c).get(d);
		},
		printCandidate(d) {
			return Rr(m, d);
		},
		printVariant(d) {
			return ut(d);
		},
		getVariantOrder() {
			let d = Array.from(n.values());
			d.sort((y, x) => this.variants.compare(y, x));
			let c = /* @__PURE__ */ new Map(), w, h = 0;
			for (let y of d) y !== null && (w !== void 0 && this.variants.compare(w, y) !== 0 && h++, c.set(y, h), w = y);
			return c;
		},
		resolveThemeValue(d, c = !0) {
			let w = d.lastIndexOf("/"), h = null;
			w !== -1 && (h = d.slice(w + 1).trim(), d = d.slice(0, w).trim());
			let y = t.resolve(null, [d], c ? 1 : 0) ?? void 0;
			return h && y ? Q(y, h) : y;
		},
		trackUsedVariables(d) {
			p.get(d);
		},
		canonicalizeCandidates(d, c) {
			return Mt(this, d, c);
		},
		storage: {}
	};
	return m;
}
var qt = [
	"container-type",
	"pointer-events",
	"visibility",
	"position",
	"inset",
	"inset-inline",
	"inset-block",
	"inset-inline-start",
	"inset-inline-end",
	"top",
	"right",
	"bottom",
	"left",
	"isolation",
	"z-index",
	"order",
	"grid-column",
	"grid-column-start",
	"grid-column-end",
	"grid-row",
	"grid-row-start",
	"grid-row-end",
	"float",
	"clear",
	"--tw-container-component",
	"margin",
	"margin-inline",
	"margin-block",
	"margin-inline-start",
	"margin-inline-end",
	"margin-top",
	"margin-right",
	"margin-bottom",
	"margin-left",
	"box-sizing",
	"display",
	"field-sizing",
	"aspect-ratio",
	"height",
	"max-height",
	"min-height",
	"width",
	"max-width",
	"min-width",
	"flex",
	"flex-shrink",
	"flex-grow",
	"flex-basis",
	"table-layout",
	"caption-side",
	"border-collapse",
	"border-spacing",
	"transform-origin",
	"translate",
	"--tw-translate-x",
	"--tw-translate-y",
	"--tw-translate-z",
	"scale",
	"--tw-scale-x",
	"--tw-scale-y",
	"--tw-scale-z",
	"rotate",
	"--tw-rotate-x",
	"--tw-rotate-y",
	"--tw-rotate-z",
	"--tw-skew-x",
	"--tw-skew-y",
	"transform",
	"animation",
	"cursor",
	"touch-action",
	"--tw-pan-x",
	"--tw-pan-y",
	"--tw-pinch-zoom",
	"resize",
	"scroll-snap-type",
	"--tw-scroll-snap-strictness",
	"scroll-snap-align",
	"scroll-snap-stop",
	"scroll-margin",
	"scroll-margin-inline",
	"scroll-margin-block",
	"scroll-margin-inline-start",
	"scroll-margin-inline-end",
	"scroll-margin-top",
	"scroll-margin-right",
	"scroll-margin-bottom",
	"scroll-margin-left",
	"scroll-padding",
	"scroll-padding-inline",
	"scroll-padding-block",
	"scroll-padding-inline-start",
	"scroll-padding-inline-end",
	"scroll-padding-top",
	"scroll-padding-right",
	"scroll-padding-bottom",
	"scroll-padding-left",
	"list-style-position",
	"list-style-type",
	"list-style-image",
	"appearance",
	"columns",
	"break-before",
	"break-inside",
	"break-after",
	"grid-auto-columns",
	"grid-auto-flow",
	"grid-auto-rows",
	"grid-template-columns",
	"grid-template-rows",
	"flex-direction",
	"flex-wrap",
	"place-content",
	"place-items",
	"align-content",
	"align-items",
	"justify-content",
	"justify-items",
	"gap",
	"column-gap",
	"row-gap",
	"--tw-space-x-reverse",
	"--tw-space-y-reverse",
	"divide-x-width",
	"divide-y-width",
	"--tw-divide-y-reverse",
	"divide-style",
	"divide-color",
	"place-self",
	"align-self",
	"justify-self",
	"overflow",
	"overflow-x",
	"overflow-y",
	"overscroll-behavior",
	"overscroll-behavior-x",
	"overscroll-behavior-y",
	"scroll-behavior",
	"border-radius",
	"border-start-radius",
	"border-end-radius",
	"border-top-radius",
	"border-right-radius",
	"border-bottom-radius",
	"border-left-radius",
	"border-start-start-radius",
	"border-start-end-radius",
	"border-end-end-radius",
	"border-end-start-radius",
	"border-top-left-radius",
	"border-top-right-radius",
	"border-bottom-right-radius",
	"border-bottom-left-radius",
	"border-width",
	"border-inline-width",
	"border-block-width",
	"border-inline-start-width",
	"border-inline-end-width",
	"border-top-width",
	"border-right-width",
	"border-bottom-width",
	"border-left-width",
	"border-style",
	"border-inline-style",
	"border-block-style",
	"border-inline-start-style",
	"border-inline-end-style",
	"border-top-style",
	"border-right-style",
	"border-bottom-style",
	"border-left-style",
	"border-color",
	"border-inline-color",
	"border-block-color",
	"border-inline-start-color",
	"border-inline-end-color",
	"border-top-color",
	"border-right-color",
	"border-bottom-color",
	"border-left-color",
	"background-color",
	"background-image",
	"--tw-gradient-position",
	"--tw-gradient-stops",
	"--tw-gradient-via-stops",
	"--tw-gradient-from",
	"--tw-gradient-from-position",
	"--tw-gradient-via",
	"--tw-gradient-via-position",
	"--tw-gradient-to",
	"--tw-gradient-to-position",
	"mask-image",
	"--tw-mask-top",
	"--tw-mask-top-from-color",
	"--tw-mask-top-from-position",
	"--tw-mask-top-to-color",
	"--tw-mask-top-to-position",
	"--tw-mask-right",
	"--tw-mask-right-from-color",
	"--tw-mask-right-from-position",
	"--tw-mask-right-to-color",
	"--tw-mask-right-to-position",
	"--tw-mask-bottom",
	"--tw-mask-bottom-from-color",
	"--tw-mask-bottom-from-position",
	"--tw-mask-bottom-to-color",
	"--tw-mask-bottom-to-position",
	"--tw-mask-left",
	"--tw-mask-left-from-color",
	"--tw-mask-left-from-position",
	"--tw-mask-left-to-color",
	"--tw-mask-left-to-position",
	"--tw-mask-linear",
	"--tw-mask-linear-position",
	"--tw-mask-linear-from-color",
	"--tw-mask-linear-from-position",
	"--tw-mask-linear-to-color",
	"--tw-mask-linear-to-position",
	"--tw-mask-radial",
	"--tw-mask-radial-shape",
	"--tw-mask-radial-size",
	"--tw-mask-radial-position",
	"--tw-mask-radial-from-color",
	"--tw-mask-radial-from-position",
	"--tw-mask-radial-to-color",
	"--tw-mask-radial-to-position",
	"--tw-mask-conic",
	"--tw-mask-conic-position",
	"--tw-mask-conic-from-color",
	"--tw-mask-conic-from-position",
	"--tw-mask-conic-to-color",
	"--tw-mask-conic-to-position",
	"box-decoration-break",
	"background-size",
	"background-attachment",
	"background-clip",
	"background-position",
	"background-repeat",
	"background-origin",
	"mask-composite",
	"mask-mode",
	"mask-type",
	"mask-size",
	"mask-clip",
	"mask-position",
	"mask-repeat",
	"mask-origin",
	"fill",
	"stroke",
	"stroke-width",
	"object-fit",
	"object-position",
	"padding",
	"padding-inline",
	"padding-block",
	"padding-inline-start",
	"padding-inline-end",
	"padding-top",
	"padding-right",
	"padding-bottom",
	"padding-left",
	"text-align",
	"text-indent",
	"vertical-align",
	"font-family",
	"font-size",
	"line-height",
	"font-weight",
	"letter-spacing",
	"text-wrap",
	"overflow-wrap",
	"word-break",
	"text-overflow",
	"hyphens",
	"white-space",
	"color",
	"text-transform",
	"font-style",
	"font-stretch",
	"font-variant-numeric",
	"text-decoration-line",
	"text-decoration-color",
	"text-decoration-style",
	"text-decoration-thickness",
	"text-underline-offset",
	"-webkit-font-smoothing",
	"placeholder-color",
	"caret-color",
	"accent-color",
	"color-scheme",
	"opacity",
	"background-blend-mode",
	"mix-blend-mode",
	"box-shadow",
	"--tw-shadow",
	"--tw-shadow-color",
	"--tw-ring-shadow",
	"--tw-ring-color",
	"--tw-inset-shadow",
	"--tw-inset-shadow-color",
	"--tw-inset-ring-shadow",
	"--tw-inset-ring-color",
	"--tw-ring-offset-width",
	"--tw-ring-offset-color",
	"outline",
	"outline-width",
	"outline-offset",
	"outline-color",
	"--tw-blur",
	"--tw-brightness",
	"--tw-contrast",
	"--tw-drop-shadow",
	"--tw-grayscale",
	"--tw-hue-rotate",
	"--tw-invert",
	"--tw-saturate",
	"--tw-sepia",
	"filter",
	"--tw-backdrop-blur",
	"--tw-backdrop-brightness",
	"--tw-backdrop-contrast",
	"--tw-backdrop-grayscale",
	"--tw-backdrop-hue-rotate",
	"--tw-backdrop-invert",
	"--tw-backdrop-opacity",
	"--tw-backdrop-saturate",
	"--tw-backdrop-sepia",
	"backdrop-filter",
	"transition-property",
	"transition-behavior",
	"transition-delay",
	"transition-duration",
	"transition-timing-function",
	"will-change",
	"contain",
	"content",
	"forced-color-adjust"
];
function Ce(t, r, { onInvalidCandidate: i, respectImportant: e } = {}) {
	let n = /* @__PURE__ */ new Map(), s = [], a = /* @__PURE__ */ new Map();
	for (let f of t) {
		if (r.invalidCandidates.has(f)) {
			i === null || i === void 0 || i(f);
			continue;
		}
		let m = r.parseCandidate(f);
		if (m.length === 0) {
			i === null || i === void 0 || i(f);
			continue;
		}
		a.set(f, m);
	}
	let p = 0;
	(e ?? !0) && (p |= 1);
	let u = r.getVariantOrder();
	for (let [f, m] of a) {
		let d = !1;
		for (let c of m) {
			let w = r.compileAstNodes(c, p);
			if (w.length !== 0) {
				d = !0;
				for (let { node: h, propertySort: y } of w) {
					let x = 0n;
					for (let $ of c.variants) x |= 1n << BigInt(u.get($));
					n.set(h, {
						properties: y,
						variants: x,
						candidate: f
					}), s.push(h);
				}
			}
		}
		d || i === null || i === void 0 || i(f);
	}
	return s.sort((f, m) => {
		let d = n.get(f), c = n.get(m);
		if (d.variants - c.variants !== 0n) return Number(d.variants - c.variants);
		let w = 0;
		for (; w < d.properties.order.length && w < c.properties.order.length && d.properties.order[w] === c.properties.order[w];) w += 1;
		return (d.properties.order[w] ?? Infinity) - (c.properties.order[w] ?? Infinity) || c.properties.count - d.properties.count || pt(d.candidate, c.candidate);
	}), {
		astNodes: s,
		nodeSorting: n
	};
}
function Ai(t, r, i) {
	let e = Ra(t, r);
	if (e.length === 0) return [];
	let n = r.important && !!(i & 1), s = [], a = `.${ye(t.raw)}`;
	for (let p of e) {
		let u = Oa(p);
		(t.important || n) && $i(p);
		let f = {
			kind: "rule",
			selector: a,
			nodes: p
		};
		for (let m of t.variants) if (ze(f, m, r.variants) === null) return [];
		s.push({
			node: f,
			propertySort: u
		});
	}
	return s;
}
function ze(t, r, i, e = 0) {
	if (r.kind === "arbitrary") {
		if (r.relative && e === 0) return null;
		t.nodes = [J(r.selector, t.nodes)];
		return;
	}
	let { applyFn: n } = i.get(r.root);
	if (r.kind === "compound") {
		let a = F("@slot");
		if (ze(a, r.variant, i, e + 1) === null || r.root === "not" && a.nodes.length > 1) return null;
		for (let u of a.nodes) if (u.kind !== "rule" && u.kind !== "at-rule" || n(u, r) === null) return null;
		I(a.nodes, (u) => {
			if ((u.kind === "rule" || u.kind === "at-rule") && u.nodes.length <= 0) return u.nodes = t.nodes, E.Skip;
		}), t.nodes = a.nodes;
		return;
	}
	if (n(t, r) === null) return null;
}
function Ci(t) {
	var _t$options;
	let r = ((_t$options = t.options) === null || _t$options === void 0 ? void 0 : _t$options.types) ?? [];
	return r.length > 1 && r.includes("any");
}
function Ra(t, r) {
	if (t.kind === "arbitrary") {
		let a = t.value;
		return t.modifier && (a = X(a, t.modifier, r.theme)), a === null ? [] : [[o(t.property, a)]];
	}
	let i = r.utilities.get(t.root) ?? [], e = [], n = i.filter((a) => !Ci(a));
	for (let a of n) {
		if (a.kind !== t.kind) continue;
		let p = a.compileFn(t);
		if (p !== void 0) {
			if (p === null) return e;
			e.push(p);
		}
	}
	if (e.length > 0) return e;
	let s = i.filter((a) => Ci(a));
	for (let a of s) {
		if (a.kind !== t.kind) continue;
		let p = a.compileFn(t);
		if (p !== void 0) {
			if (p === null) return e;
			e.push(p);
		}
	}
	return e;
}
function $i(t) {
	for (let r of t) r.kind !== "at-root" && (r.kind === "declaration" ? r.important = !0 : (r.kind === "rule" || r.kind === "at-rule") && $i(r.nodes));
}
function Oa(t) {
	let r = /* @__PURE__ */ new Set(), i = 0, e = t.slice(), n = !1;
	for (; e.length > 0;) {
		let s = e.shift();
		if (s.kind === "declaration") {
			if (s.value === void 0 || (i++, n)) continue;
			if (s.property === "--tw-sort") {
				let p = qt.indexOf(s.value ?? "");
				if (p !== -1) {
					r.add(p), n = !0;
					continue;
				}
			}
			let a = qt.indexOf(s.property);
			a !== -1 && r.add(a);
		} else if (s.kind === "rule" || s.kind === "at-rule") for (let a of s.nodes) e.push(a);
	}
	return {
		order: Array.from(r).sort((s, a) => s - a),
		count: i
	};
}
function Ae(t, r) {
	let i = 0, e = J("&", t), n = /* @__PURE__ */ new Set(), s = new K(() => /* @__PURE__ */ new Set()), a = new K(() => /* @__PURE__ */ new Set());
	I([e], (d, c) => {
		if (d.kind === "at-rule") {
			if (d.name === "@keyframes") return I(d.nodes, (w) => {
				if (w.kind === "at-rule" && w.name === "@apply") throw new Error("You cannot use `@apply` inside `@keyframes`.");
			}), E.Skip;
			if (d.name === "@utility") {
				let w = d.params.replace(/-\*$/, "");
				a.get(w).add(d), I(d.nodes, (h) => {
					if (!(h.kind !== "at-rule" || h.name !== "@apply")) {
						n.add(d);
						for (let y of Si(h, r)) s.get(d).add(y);
					}
				});
				return;
			}
			if (d.name === "@apply") {
				if (c.parent === null) return;
				i |= 1, n.add(c.parent);
				for (let w of Si(d, r)) for (let h of c.path()) n.has(h) && s.get(h).add(w);
			}
		}
	});
	let p = /* @__PURE__ */ new Set(), u = [], f = /* @__PURE__ */ new Set();
	function m(d, c = []) {
		if (!p.has(d)) {
			if (f.has(d)) {
				let w = c[(c.indexOf(d) + 1) % c.length];
				throw d.kind === "at-rule" && d.name === "@utility" && w.kind === "at-rule" && w.name === "@utility" && I(d.nodes, (h) => {
					if (h.kind !== "at-rule" || h.name !== "@apply") return;
					let y = h.params.split(/\s+/g);
					for (let x of y) for (let $ of r.parseCandidate(x)) switch ($.kind) {
						case "arbitrary": break;
						case "static":
						case "functional":
							if (w.params.replace(/-\*$/, "") === $.root) throw new Error(`You cannot \`@apply\` the \`${x}\` utility here because it creates a circular dependency.`);
							break;
						default:
					}
				}), /* @__PURE__ */ new Error(`Circular dependency detected:

${re([d])}
Relies on:

${re([w])}`);
			}
			f.add(d);
			for (let w of s.get(d)) for (let h of a.get(w)) c.push(d), m(h, c), c.pop();
			p.add(d), f.delete(d), u.push(d);
		}
	}
	for (let d of n) m(d);
	for (let d$10 of u) "nodes" in d$10 && I(d$10.nodes, (c) => {
		if (c.kind !== "at-rule" || c.name !== "@apply") return;
		let w = c.params.split(/(\s+)/g), h = {}, y = 0;
		for (let [x, $] of w.entries()) x % 2 === 0 && (h[$] = y), y += $.length;
		{
			let $ = Ce(Object.keys(h), r, {
				respectImportant: !1,
				onInvalidCandidate: (N) => {
					if (r.theme.prefix && !N.startsWith(r.theme.prefix)) throw new Error(`Cannot apply unprefixed utility class \`${N}\`. Did you mean \`${r.theme.prefix}:${N}\`?`);
					if (r.invalidCandidates.has(N)) throw new Error(`Cannot apply utility class \`${N}\` because it has been explicitly disabled: https://tailwindcss.com/docs/detecting-classes-in-source-files#explicitly-excluding-classes`);
					let O = d(N, ":");
					if (O.length > 1) {
						let L = O.pop();
						if (r.candidatesToCss([L])[0]) {
							let _ = r.candidatesToCss(O.map((Y) => `${Y}:[--tw-variant-check:1]`)), z = O.filter((Y, q) => _[q] === null);
							if (z.length > 0) {
								if (z.length === 1) throw new Error(`Cannot apply utility class \`${N}\` because the ${z.map((Y) => `\`${Y}\``)} variant does not exist.`);
								{
									let Y = new Intl.ListFormat("en", {
										style: "long",
										type: "conjunction"
									});
									throw new Error(`Cannot apply utility class \`${N}\` because the ${Y.format(z.map((q) => `\`${q}\``))} variants do not exist.`);
								}
							}
						}
					}
					throw r.theme.size === 0 ? /* @__PURE__ */ new Error(`Cannot apply unknown utility class \`${N}\`. Are you using CSS modules or similar and missing \`@reference\`? https://tailwindcss.com/docs/functions-and-directives#reference-directive`) : /* @__PURE__ */ new Error(`Cannot apply unknown utility class \`${N}\``);
				}
			}), A = c.src, k = $.astNodes.map((N) => {
				var _$$nodeSorting$get;
				let O = (_$$nodeSorting$get = $.nodeSorting.get(N)) === null || _$$nodeSorting$get === void 0 ? void 0 : _$$nodeSorting$get.candidate, L = O ? h[O] : void 0;
				if (N = ee(N), !A || !O || L === void 0) return I([N], (z) => {
					z.src = A;
				}), N;
				let _ = [
					A[0],
					A[1],
					A[2]
				];
				return _[1] += 7 + L, _[2] = _[1] + O.length, I([N], (z) => {
					z.src = _;
				}), N;
			}), U = [];
			for (let N of k) if (N.kind === "rule") for (let O of N.nodes) U.push(O);
			else U.push(N);
			return E.Replace(U);
		}
	});
	return i;
}
function* Si(t, r) {
	for (let i of t.params.split(/\s+/g)) for (let e of r.parseCandidate(i)) switch (e.kind) {
		case "arbitrary": break;
		case "static":
		case "functional":
			yield e.root;
			break;
		default:
	}
}
async function Zt(t, r, i, e = 0, n = !1) {
	let s = 0, a = [];
	return I(t, (p) => {
		if (p.kind === "at-rule" && (p.name === "@import" || p.name === "@reference")) {
			let u = Pa(B(p.params));
			if (u === null) return;
			p.name === "@reference" && (u.media = "reference"), s |= 2;
			let { uri: f, layer: m, media: d, supports: c } = u;
			if (f.startsWith("data:") || f.startsWith("http://") || f.startsWith("https://")) return;
			let w = ce({}, []);
			return a.push((async () => {
				if (e > 100) throw new Error(`Exceeded maximum recursion depth while resolving \`${f}\` in \`${r}\`)`);
				let h = await i(f, r), y = $e(h.content, { from: n ? h.path : void 0 });
				await Zt(y, h.base, i, e + 1, n), w.nodes = Ia(p, [ce({ base: h.base }, y)], m, d, c);
			})()), E.ReplaceSkip(w);
		}
	}), a.length > 0 && await Promise.all(a), s;
}
function Pa(t) {
	let r, i = null, e = null, n = null;
	for (let s = 0; s < t.length; s++) {
		let a = t[s];
		if (a.kind !== "separator") {
			if (a.kind === "word" && !r) {
				if (!a.value || a.value[0] !== "\"" && a.value[0] !== "'") return null;
				r = a.value.slice(1, -1);
				continue;
			}
			if (a.kind === "function" && a.value.toLowerCase() === "url" || !r) return null;
			if ((a.kind === "word" || a.kind === "function") && a.value.toLowerCase() === "layer") {
				if (i) return null;
				if (n) throw new Error("`layer(…)` in an `@import` should come before any other functions or conditions");
				"nodes" in a ? i = Z(a.nodes) : i = "";
				continue;
			}
			if (a.kind === "function" && a.value.toLowerCase() === "supports") {
				if (n) return null;
				n = Z(a.nodes);
				continue;
			}
			e = Z(t.slice(s));
			break;
		}
	}
	return r ? {
		uri: r,
		layer: i,
		media: e,
		supports: n
	} : null;
}
function Ia(t, r, i, e, n) {
	let s = r;
	if (i !== null) {
		let a = F("@layer", i, s);
		a.src = t.src, s = [a];
	}
	if (e !== null) {
		let a = F("@media", e, s);
		a.src = t.src, s = [a];
	}
	if (n !== null) {
		let a = F("@supports", n[0] === "(" ? n : `(${n})`, s);
		a.src = t.src, s = [a];
	}
	return s;
}
function Me(t) {
	if (Object.prototype.toString.call(t) !== "[object Object]") return !1;
	let r = Object.getPrototypeOf(t);
	return r === null || Object.getPrototypeOf(r) === null;
}
function Xe(t, r, i, e = []) {
	for (let n of r) if (n != null) for (let s of Reflect.ownKeys(n)) {
		e.push(s);
		let a = i(t[s], n[s], e);
		a !== void 0 ? t[s] = a : !Me(t[s]) || !Me(n[s]) ? t[s] = n[s] : t[s] = Xe({}, [t[s], n[s]], i, e), e.pop();
	}
	return t;
}
function bt(t, r, i) {
	return function(n, s) {
		let a = n.lastIndexOf("/"), p = null;
		a !== -1 && (p = n.slice(a + 1).trim(), n = n.slice(0, a).trim());
		let u = (() => {
			let f = Oe(n), [m, d] = _a(t.theme, f), c = i(Ti(r() ?? {}, f) ?? null);
			if (typeof c == "string" && (c = c.replace("<alpha-value>", "1")), typeof m != "object") return typeof d != "object" && d & 4 ? c ?? m : m;
			if (c !== null && typeof c == "object" && !Array.isArray(c)) {
				var _c$__CSS_VALUES__;
				let w = Xe({}, [c], (h, y) => y);
				if (m === null && Object.hasOwn(c, "__CSS_VALUES__")) {
					let h = {};
					for (let y in c.__CSS_VALUES__) h[y] = c[y], delete w[y];
					m = h;
				}
				for (let h in m) h !== "__CSS_VALUES__" && ((c === null || c === void 0 || (_c$__CSS_VALUES__ = c.__CSS_VALUES__) === null || _c$__CSS_VALUES__ === void 0 ? void 0 : _c$__CSS_VALUES__[h]) & 4 && Ti(w, h.split("-")) !== void 0 || (w[Se(h)] = m[h]));
				return w;
			}
			if (Array.isArray(m) && Array.isArray(d) && Array.isArray(c)) {
				let w = m[0], h = m[1];
				d[0] & 4 && (w = c[0] ?? w);
				for (let y of Object.keys(h)) d[1][y] & 4 && (h[y] = c[1][y] ?? h[y]);
				return [w, h];
			}
			return m ?? c;
		})();
		return p && typeof u == "string" && (u = Q(u, p)), u ?? s;
	};
}
function _a(t, r) {
	if (r.length === 1 && r[0].startsWith("--")) return [t.get([r[0]]), t.getOptions(r[0])];
	let i = je(r), e = /* @__PURE__ */ new Map(), n = new K(() => /* @__PURE__ */ new Map()), s = t.namespace(`--${i}`);
	if (s.size === 0) return [null, 0];
	let a = /* @__PURE__ */ new Map();
	for (let [m, d] of s) {
		if (!m || !m.includes("--")) {
			e.set(m, d), a.set(m, t.getOptions(m ? `--${i}-${m}` : `--${i}`));
			continue;
		}
		let c = m.indexOf("--"), w = m.slice(0, c), h = m.slice(c + 2);
		h = h.replace(/-([a-z])/g, (y, x) => x.toUpperCase()), n.get(w === "" ? null : w).set(h, [d, t.getOptions(`--${i}${m}`)]);
	}
	let p = t.getOptions(`--${i}`);
	for (let [m, d] of n) {
		let c = e.get(m);
		if (typeof c != "string") continue;
		let w = {}, h = {};
		for (let [y, [x, $]] of d) w[y] = x, h[y] = $;
		e.set(m, [c, w]), a.set(m, [p, h]);
	}
	let u = {}, f = {};
	for (let [m, d] of e) Vi(u, [m ?? "DEFAULT"], d);
	for (let [m, d] of a) Vi(f, [m ?? "DEFAULT"], d);
	return r[r.length - 1] === "DEFAULT" ? [(u === null || u === void 0 ? void 0 : u.DEFAULT) ?? null, f.DEFAULT ?? 0] : "DEFAULT" in u && Object.keys(u).length === 1 ? [u.DEFAULT, f.DEFAULT ?? 0] : (u.__CSS_VALUES__ = f, [u, f]);
}
function Ti(t, r) {
	for (let i = 0; i < r.length; ++i) {
		let e = r[i];
		if ((t === null || t === void 0 ? void 0 : t[e]) === void 0) {
			if (r[i + 1] === void 0) return;
			r[i + 1] = `${e}-${r[i + 1]}`;
			continue;
		}
		if (typeof t == "string") return;
		t = t[e];
	}
	return t;
}
function Vi(t, r, i) {
	for (let e of r.slice(0, -1)) t[e] === void 0 && (t[e] = {}), t = t[e];
	t[r[r.length - 1]] = i;
}
var Ni = /^[a-z@][a-zA-Z0-9/%._-]*$/;
function Ht({ designSystem: t, ast: r, resolvedConfig: i, featuresRef: e, referenceMode: n, src: s }) {
	let a = {
		addBase(p) {
			if (n) return;
			let u = me(p);
			e.current |= De(u, t);
			let f = F("@layer", "base", u);
			I([f], (m) => {
				m.src = s;
			}), r.push(f);
		},
		addVariant(p, u) {
			if (!kt.test(p)) throw new Error(`\`addVariant('${p}')\` defines an invalid variant name. Variants should only contain alphanumeric, dashes, or underscore characters and start with a lowercase letter or number.`);
			if (typeof u == "string") {
				if (u.includes(":merge(")) return;
			} else if (Array.isArray(u)) {
				if (u.some((m) => m.includes(":merge("))) return;
			} else if (typeof u == "object") {
				let m = function(d, c) {
					return Object.entries(d).some(([w, h]) => w.includes(c) || typeof h == "object" && m(h, c));
				};
				if (m(u, ":merge(")) return;
			}
			typeof u == "string" || Array.isArray(u) ? t.variants.static(p, (m) => {
				m.nodes = Ei(u, m.nodes);
			}, { compounds: Pe(typeof u == "string" ? [u] : u) }) : typeof u == "object" && t.variants.fromAst(p, me(u), t);
		},
		matchVariant(p, u, f) {
			function m(c, w, h) {
				return Ei(u(c, { modifier: (w === null || w === void 0 ? void 0 : w.value) ?? null }), h);
			}
			try {
				let c = u("a", { modifier: null });
				if (typeof c == "string" && c.includes(":merge(")) return;
				if (Array.isArray(c) && c.some((w) => w.includes(":merge("))) return;
			} catch {}
			let d = Object.keys((f === null || f === void 0 ? void 0 : f.values) ?? {});
			t.variants.group(() => {
				t.variants.functional(p, (c, w) => {
					if (!w.value) {
						if ((f === null || f === void 0 ? void 0 : f.values) && "DEFAULT" in f.values) {
							c.nodes = m(f.values.DEFAULT, w.modifier, c.nodes);
							return;
						}
						return null;
					}
					if (w.value.kind === "arbitrary") c.nodes = m(w.value.value, w.modifier, c.nodes);
					else if (w.value.kind === "named" && (f === null || f === void 0 ? void 0 : f.values)) {
						let h = f.values[w.value.value];
						if (typeof h != "string") return null;
						c.nodes = m(h, w.modifier, c.nodes);
					} else return null;
				});
			}, (c, w) => {
				var _f$values, _f$values2, _c$modifier, _w$modifier2;
				if (c.kind !== "functional" || w.kind !== "functional") return 0;
				let h = c.value ? c.value.value : "DEFAULT", y = w.value ? w.value.value : "DEFAULT", x = (f === null || f === void 0 || (_f$values = f.values) === null || _f$values === void 0 ? void 0 : _f$values[h]) ?? h, $ = (f === null || f === void 0 || (_f$values2 = f.values) === null || _f$values2 === void 0 ? void 0 : _f$values2[y]) ?? y;
				if (f && typeof f.sort == "function") return f.sort({
					value: x,
					modifier: ((_c$modifier = c.modifier) === null || _c$modifier === void 0 ? void 0 : _c$modifier.value) ?? null
				}, {
					value: $,
					modifier: ((_w$modifier2 = w.modifier) === null || _w$modifier2 === void 0 ? void 0 : _w$modifier2.value) ?? null
				});
				let A = d.indexOf(h), k = d.indexOf(y);
				return A = A === -1 ? d.length : A, k = k === -1 ? d.length : k, A !== k ? A - k : x < $ ? -1 : 1;
			}), t.variants.suggest(p, () => Object.keys((f === null || f === void 0 ? void 0 : f.values) ?? {}).filter((c) => c !== "DEFAULT"));
		},
		addUtilities(p) {
			p = Array.isArray(p) ? p : [p];
			let u = p.flatMap((m) => Object.entries(m));
			u = u.flatMap(([m, d$11]) => d(m, ",").map((c) => [c.trim(), d$11]));
			let f = new K(() => []);
			for (let [m, d] of u) {
				if (m.startsWith("@keyframes ")) {
					if (!n) {
						let h = J(m, me(d));
						I([h], (y) => {
							y.src = s;
						}), r.push(h);
					}
					continue;
				}
				let c = Re(m), w = !1;
				if (I(c, (h) => {
					if (h.kind === "selector" && h.value[0] === "." && Ni.test(h.value.slice(1))) {
						let y = h.value;
						h.value = "&";
						let x = pe(c), $ = y.slice(1), A = x === "&" ? me(d) : [J(x, me(d))];
						f.get($).push(...A), w = !0, h.value = y;
						return;
					}
					if (h.kind === "function" && h.value === ":not") return E.Skip;
				}), !w) throw new Error(`\`addUtilities({ '${m}' : \u2026 })\` defines an invalid utility selector. Utilities must be a single class name and start with a lowercase letter, eg. \`.scrollbar-none\`.`);
			}
			for (let [m, d] of f) t.theme.prefix && I(d, (c) => {
				if (c.kind === "rule") {
					let w = Re(c.selector);
					I(w, (h) => {
						h.kind === "selector" && h.value[0] === "." && (h.value = `.${t.theme.prefix}\\:${h.value.slice(1)}`);
					}), c.selector = pe(w);
				}
			}), t.utilities.static(m, (c) => {
				let w = d.map(ee);
				return Ri(w, m, c.raw), e.current |= Ae(w, t), w;
			});
		},
		matchUtilities(p, u) {
			let f = (u === null || u === void 0 ? void 0 : u.type) ? Array.isArray(u === null || u === void 0 ? void 0 : u.type) ? u.type : [u.type] : ["any"];
			for (let [d, c] of Object.entries(p)) {
				let w = function({ negative: h }) {
					return (y) => {
						var _y$value, _y$value2;
						if (((_y$value = y.value) === null || _y$value === void 0 ? void 0 : _y$value.kind) === "arbitrary" && f.length > 0 && !f.includes("any") && (y.value.dataType && !f.includes(y.value.dataType) || !y.value.dataType && !me$1(y.value.value, f))) return;
						let x = f.includes("color"), $ = null, A = !1;
						{
							let N = (u === null || u === void 0 ? void 0 : u.values) ?? {};
							x && (N = Object.assign({
								inherit: "inherit",
								transparent: "transparent",
								current: "currentcolor"
							}, N)), y.value ? y.value.kind === "arbitrary" ? $ = y.value.value : y.value.fraction && N[y.value.fraction] ? ($ = N[y.value.fraction], A = !0) : N[y.value.value] ? $ = N[y.value.value] : N.__BARE_VALUE__ && ($ = N.__BARE_VALUE__(y.value) ?? null, A = (y.value.fraction !== null && ($ === null || $ === void 0 ? void 0 : $.includes("/"))) ?? !1) : $ = N.DEFAULT ?? null;
						}
						if ($ === null) return;
						let k;
						{
							let N = (u === null || u === void 0 ? void 0 : u.modifiers) ?? null;
							y.modifier ? N === "any" || y.modifier.kind === "arbitrary" ? k = y.modifier.value : (N === null || N === void 0 ? void 0 : N[y.modifier.value]) ? k = N[y.modifier.value] : x && !Number.isNaN(Number(y.modifier.value)) ? k = `${y.modifier.value}%` : k = null : k = null;
						}
						if (y.modifier && k === null && !A) return ((_y$value2 = y.value) === null || _y$value2 === void 0 ? void 0 : _y$value2.kind) === "arbitrary" ? null : void 0;
						x && k !== null && ($ = Q($, k)), h && ($ = `calc(${$} * -1)`);
						let U = me(c($, { modifier: k }));
						return Ri(U, d, y.raw), e.current |= Ae(U, t), U;
					};
				};
				if (!Ni.test(d)) throw new Error(`\`matchUtilities({ '${d}' : \u2026 })\` defines an invalid utility name. Utilities should be alphanumeric and start with a lowercase letter, eg. \`scrollbar\`.`);
				!(u === null || u === void 0) && u.supportsNegativeValues && t.utilities.functional(`-${d}`, w({ negative: !0 }), { types: f }), t.utilities.functional(d, w({ negative: !1 }), { types: f }), t.utilities.suggest(d, () => {
					let h = (u === null || u === void 0 ? void 0 : u.values) ?? {}, y = new Set(Object.keys(h));
					y.delete("__BARE_VALUE__"), y.delete("__CSS_VALUES__"), y.has("DEFAULT") && (y.delete("DEFAULT"), y.add(null));
					let x = (u === null || u === void 0 ? void 0 : u.modifiers) ?? {}, $ = x === "any" ? [] : Object.keys(x);
					return [{
						supportsNegative: (u === null || u === void 0 ? void 0 : u.supportsNegativeValues) ?? !1,
						values: Array.from(y),
						modifiers: $
					}];
				});
			}
		},
		addComponents(p, u) {
			this.addUtilities(p, u);
		},
		matchComponents(p, u) {
			this.matchUtilities(p, u);
		},
		theme: bt(t, () => i.theme ?? {}, (p) => p),
		prefix(p) {
			return p;
		},
		config(p, u) {
			let f = i;
			if (!p) return f;
			let m = Oe(p);
			for (let d = 0; d < m.length; ++d) {
				let c = m[d];
				if (f[c] === void 0) return u;
				f = f[c];
			}
			return f ?? u;
		}
	};
	return a.addComponents = a.addComponents.bind(a), a.matchComponents = a.matchComponents.bind(a), a;
}
function me(t) {
	let r = [];
	t = Array.isArray(t) ? t : [t];
	let i = t.flatMap((e) => Object.entries(e));
	for (let [e, n] of i) if (n != null && n !== !1) if (typeof n != "object") {
		if (!e.startsWith("--")) {
			if (n === "@slot") {
				r.push(J(e, [F("@slot")]));
				continue;
			}
			e = e.replace(/([A-Z])/g, "-$1").toLowerCase();
		}
		r.push(o(e, String(n)));
	} else if (Array.isArray(n)) for (let s of n) typeof s == "string" ? r.push(o(e, s)) : r.push(J(e, me(s)));
	else r.push(J(e, me(n)));
	return r;
}
function Ei(t, r) {
	return (typeof t == "string" ? [t] : t).flatMap((e) => {
		if (e.trim().endsWith("}")) {
			let s = $e(e.replace("}", "{@slot}}"));
			return Gt(s, r), s;
		} else return J(e, r);
	});
}
function Ri(t, r, i) {
	I(t, (e) => {
		if (e.kind === "rule") {
			let n = Re(e.selector);
			I(n, (s) => {
				s.kind === "selector" && s.value === `.${r}` && (s.value = `.${ye(i)}`);
			}), e.selector = pe(n);
		}
	});
}
function Oi(t, r) {
	for (let i of Da(r)) t.theme.addKeyframes(i);
}
function Da(t) {
	let r = [];
	if ("keyframes" in t.theme) for (let [i, e] of Object.entries(t.theme.keyframes)) r.push(F("@keyframes", i, me(e)));
	return r;
}
function Pi(t) {
	return { theme: {
		...be$1,
		colors: ({ theme: r }) => r("color", {}),
		extend: {
			fontSize: ({ theme: r }) => ({ ...r("text", {}) }),
			boxShadow: ({ theme: r }) => ({ ...r("shadow", {}) }),
			animation: ({ theme: r }) => ({ ...r("animate", {}) }),
			aspectRatio: ({ theme: r }) => ({ ...r("aspect", {}) }),
			borderRadius: ({ theme: r }) => ({ ...r("radius", {}) }),
			screens: ({ theme: r }) => ({ ...r("breakpoint", {}) }),
			letterSpacing: ({ theme: r }) => ({ ...r("tracking", {}) }),
			lineHeight: ({ theme: r }) => ({ ...r("leading", {}) }),
			transitionDuration: { DEFAULT: t.get(["--default-transition-duration"]) ?? null },
			transitionTimingFunction: { DEFAULT: t.get(["--default-transition-timing-function"]) ?? null },
			maxWidth: ({ theme: r }) => ({ ...r("container", {}) })
		}
	} };
}
var Ka = {
	blocklist: [],
	future: {},
	experimental: {},
	prefix: "",
	important: !1,
	darkMode: null,
	theme: {},
	plugins: [],
	content: { files: [] }
};
function Qt(t, r) {
	let i = {
		design: t,
		configs: [],
		plugins: [],
		content: { files: [] },
		theme: {},
		extend: {},
		result: structuredClone(Ka)
	};
	for (let n of r) Jt(i, n);
	for (let n of i.configs) "darkMode" in n && n.darkMode !== void 0 && (i.result.darkMode = n.darkMode ?? null), "prefix" in n && n.prefix !== void 0 && (i.result.prefix = n.prefix ?? ""), "blocklist" in n && n.blocklist !== void 0 && (i.result.blocklist = n.blocklist ?? []), "important" in n && n.important !== void 0 && (i.result.important = n.important ?? !1);
	let e = La(i);
	return {
		resolvedConfig: {
			...i.result,
			content: i.content,
			theme: i.theme,
			plugins: i.plugins
		},
		replacedThemeKeys: e
	};
}
function Ua(t, r) {
	if (Array.isArray(t) && Me(t[0])) return t.concat(r);
	if (Array.isArray(r) && Me(r[0]) && Me(t)) return [t, ...r];
	if (Array.isArray(r)) return r;
}
function Jt(t, { config: r, base: i, path: e, reference: n, src: s }) {
	let a = [];
	for (let f of r.plugins ?? []) "__isOptionsFunction" in f ? a.push({
		...f(),
		reference: n,
		src: s
	}) : "handler" in f ? a.push({
		...f,
		reference: n,
		src: s
	}) : a.push({
		handler: f,
		reference: n,
		src: s
	});
	if (Array.isArray(r.presets) && r.presets.length === 0) throw new Error("Error in the config file/plugin/preset. An empty preset (`preset: []`) is not currently supported.");
	for (let f of r.presets ?? []) Jt(t, {
		path: e,
		base: i,
		config: f,
		reference: n,
		src: s
	});
	for (let f of a) t.plugins.push(f), f.config && Jt(t, {
		path: e,
		base: i,
		config: f.config,
		reference: !!f.reference,
		src: f.src ?? s
	});
	let p = r.content ?? [], u = Array.isArray(p) ? p : p.files;
	for (let f of u) t.content.files.push(typeof f == "object" ? f : {
		base: i,
		pattern: f
	});
	t.configs.push(r);
}
function La(t) {
	let r = /* @__PURE__ */ new Set(), i = bt(t.design, () => t.theme, n), e = Object.assign(i, {
		theme: i,
		colors: l$1
	});
	function n(s) {
		return typeof s == "function" ? s(e) ?? null : s ?? null;
	}
	for (let s of t.configs) {
		var _t$extend;
		let a = s.theme ?? {}, p = a.extend ?? {};
		for (let u in a) u !== "extend" && r.add(u);
		Object.assign(t.theme, a);
		for (let u in p) (_t$extend = t.extend)[u] ?? (_t$extend[u] = []), t.extend[u].push(p[u]);
	}
	delete t.theme.extend;
	for (let s in t.extend) {
		let a = [t.theme[s], ...t.extend[s]];
		t.theme[s] = () => {
			return Xe({}, a.map(n), Ua);
		};
	}
	for (let s in t.theme) t.theme[s] = n(t.theme[s]);
	if (t.theme.screens && typeof t.theme.screens == "object") for (let s of Object.keys(t.theme.screens)) {
		let a = t.theme.screens[s];
		a && typeof a == "object" && ("raw" in a || "max" in a || "min" in a && (t.theme.screens[s] = a.min));
	}
	return r;
}
function Ii(t, r) {
	let i = t.theme.container || {};
	if (typeof i != "object" || i === null) return;
	let e = ja(i, r);
	e.length !== 0 && r.utilities.static("container", () => e.map(ee));
}
function ja({ center: t, padding: r, screens: i }, e) {
	let n = [], s = null;
	if (t && n.push(o("margin-inline", "auto")), (typeof r == "string" || typeof r == "object" && r !== null && "DEFAULT" in r) && n.push(o("padding-inline", typeof r == "string" ? r : r.DEFAULT)), typeof i == "object" && i !== null) {
		s = /* @__PURE__ */ new Map();
		let a = Array.from(e.theme.namespace("--breakpoint").entries());
		if (a.sort((p, u) => Ve(p[1], u[1], "asc")), a.length > 0) {
			let [p] = a[0];
			n.push(F("@media", `(width >= --theme(--breakpoint-${p}))`, [o("max-width", "none")]));
		}
		for (let [p, u] of Object.entries(i)) {
			if (typeof u == "object") if ("min" in u) u = u.min;
			else continue;
			s.set(p, F("@media", `(width >= ${u})`, [o("max-width", u)]));
		}
	}
	if (typeof r == "object" && r !== null) {
		let a = Object.entries(r).filter(([p]) => p !== "DEFAULT").map(([p, u]) => [
			p,
			e.theme.resolveValue(p, ["--breakpoint"]),
			u
		]).filter(Boolean);
		a.sort((p, u) => Ve(p[1], u[1], "asc"));
		for (let [p, , u] of a) if (s && s.has(p)) s.get(p).nodes.push(o("padding-inline", u));
		else {
			if (s) continue;
			n.push(F("@media", `(width >= theme(--breakpoint-${p}))`, [o("padding-inline", u)]));
		}
	}
	if (s) for (let [, a] of s) n.push(a);
	return n;
}
function _i({ addVariant: t, config: r }) {
	let i = r("darkMode", null), [e, n = ".dark"] = Array.isArray(i) ? i : [i];
	if (e === "variant") {
		let s;
		if (Array.isArray(n) || typeof n == "function" ? s = n : typeof n == "string" && (s = [n]), Array.isArray(s)) for (let a of s) a === ".dark" ? (e = !1, console.warn("When using `variant` for `darkMode`, you must provide a selector.\nExample: `darkMode: [\"variant\", \".your-selector &\"]`")) : a.includes("&") || (e = !1, console.warn("When using `variant` for `darkMode`, your selector must contain `&`.\nExample `darkMode: [\"variant\", \".your-selector &\"]`"));
		n = s;
	}
	e === null || (e === "selector" ? t("dark", `&:where(${n}, ${n} *)`) : e === "media" ? t("dark", "@media (prefers-color-scheme: dark)") : e === "variant" ? t("dark", n) : e === "class" && t("dark", `&:is(${n} *)`));
}
function Di(t) {
	for (let [r, i] of [
		["t", "top"],
		["tr", "top right"],
		["r", "right"],
		["br", "bottom right"],
		["b", "bottom"],
		["bl", "bottom left"],
		["l", "left"],
		["tl", "top left"]
	]) t.utilities.suggest(`bg-gradient-to-${r}`, () => []), t.utilities.static(`bg-gradient-to-${r}`, () => [o("--tw-gradient-position", `to ${i} in oklab`), o("background-image", "linear-gradient(var(--tw-gradient-stops))")]);
	t.utilities.suggest("bg-left-top", () => []), t.utilities.static("bg-left-top", () => [o("background-position", "left top")]), t.utilities.suggest("bg-right-top", () => []), t.utilities.static("bg-right-top", () => [o("background-position", "right top")]), t.utilities.suggest("bg-left-bottom", () => []), t.utilities.static("bg-left-bottom", () => [o("background-position", "left bottom")]), t.utilities.suggest("bg-right-bottom", () => []), t.utilities.static("bg-right-bottom", () => [o("background-position", "right bottom")]), t.utilities.suggest("object-left-top", () => []), t.utilities.static("object-left-top", () => [o("object-position", "left top")]), t.utilities.suggest("object-right-top", () => []), t.utilities.static("object-right-top", () => [o("object-position", "right top")]), t.utilities.suggest("object-left-bottom", () => []), t.utilities.static("object-left-bottom", () => [o("object-position", "left bottom")]), t.utilities.suggest("object-right-bottom", () => []), t.utilities.static("object-right-bottom", () => [o("object-position", "right bottom")]), t.utilities.suggest("max-w-screen", () => []), t.utilities.functional("max-w-screen", (r) => {
		if (!r.value || r.value.kind === "arbitrary") return;
		let i = t.theme.resolve(r.value.value, ["--breakpoint"]);
		if (i) return [o("max-width", i)];
	}), t.utilities.suggest("overflow-ellipsis", () => []), t.utilities.static("overflow-ellipsis", () => [o("text-overflow", "ellipsis")]), t.utilities.suggest("decoration-slice", () => []), t.utilities.static("decoration-slice", () => [o("-webkit-box-decoration-break", "slice"), o("box-decoration-break", "slice")]), t.utilities.suggest("decoration-clone", () => []), t.utilities.static("decoration-clone", () => [o("-webkit-box-decoration-break", "clone"), o("box-decoration-break", "clone")]), t.utilities.suggest("flex-shrink", () => []), t.utilities.functional("flex-shrink", (r) => {
		if (!r.modifier) {
			if (!r.value) return [o("flex-shrink", "1")];
			if (r.value.kind === "arbitrary") return [o("flex-shrink", r.value.value)];
			if (u(r.value.value)) return [o("flex-shrink", r.value.value)];
		}
	}), t.utilities.suggest("flex-grow", () => []), t.utilities.functional("flex-grow", (r) => {
		if (!r.modifier) {
			if (!r.value) return [o("flex-grow", "1")];
			if (r.value.kind === "arbitrary") return [o("flex-grow", r.value.value)];
			if (u(r.value.value)) return [o("flex-grow", r.value.value)];
		}
	}), t.utilities.suggest("order-none", () => []), t.utilities.static("order-none", () => [o("order", "0")]), t.utilities.suggest("break-words", () => []), t.utilities.static("break-words", () => [o("overflow-wrap", "break-word")]);
}
function Ki(t, r) {
	var _r$variants$get;
	let i = t.theme.screens || {}, e = ((_r$variants$get = r.variants.get("min")) === null || _r$variants$get === void 0 ? void 0 : _r$variants$get.order) ?? 0, n = [];
	for (let [a, p] of Object.entries(i)) {
		let c = function(w) {
			r.variants.static(a, (h) => {
				h.nodes = [F("@media", d, h.nodes)];
			}, { order: w });
		};
		let u = r.variants.get(a), f = r.theme.resolveValue(a, ["--breakpoint"]);
		if (u && f && !r.theme.hasDefault(`--breakpoint-${a}`)) continue;
		let m = !0;
		typeof p == "string" && (m = !1);
		let d = za(p);
		m ? n.push(c) : c(e);
	}
	if (n.length !== 0) {
		for (let [, a] of r.variants.variants) a.order > e && (a.order += n.length);
		r.variants.compareFns = new Map(Array.from(r.variants.compareFns).map(([a, p]) => (a > e && (a += n.length), [a, p])));
		for (let [a, p] of n.entries()) p(e + a + 1);
	}
}
function za(t) {
	return (Array.isArray(t) ? t : [t]).map((i) => typeof i == "string" ? { min: i } : i && typeof i == "object" ? i : null).map((i) => {
		if (i === null) return null;
		if ("raw" in i) return i.raw;
		let e = "";
		return i.max !== void 0 && (e += `${i.max} >= `), e += "width", i.min !== void 0 && (e += ` >= ${i.min}`), `(${e})`;
	}).filter(Boolean).join(", ");
}
function Ui(t, r) {
	let i = t.theme.aria || {}, e = t.theme.supports || {}, n = t.theme.data || {};
	if (Object.keys(i).length > 0) {
		let s = r.variants.get("aria"), a = s === null || s === void 0 ? void 0 : s.applyFn, p = s === null || s === void 0 ? void 0 : s.compounds;
		r.variants.functional("aria", (u, f) => {
			let m = f.value;
			return m && m.kind === "named" && m.value in i ? a === null || a === void 0 ? void 0 : a(u, {
				...f,
				value: {
					kind: "arbitrary",
					value: i[m.value]
				}
			}) : a === null || a === void 0 ? void 0 : a(u, f);
		}, { compounds: p });
	}
	if (Object.keys(e).length > 0) {
		let s = r.variants.get("supports"), a = s === null || s === void 0 ? void 0 : s.applyFn, p = s === null || s === void 0 ? void 0 : s.compounds;
		r.variants.functional("supports", (u, f) => {
			let m = f.value;
			return m && m.kind === "named" && m.value in e ? a === null || a === void 0 ? void 0 : a(u, {
				...f,
				value: {
					kind: "arbitrary",
					value: e[m.value]
				}
			}) : a === null || a === void 0 ? void 0 : a(u, f);
		}, { compounds: p });
	}
	if (Object.keys(n).length > 0) {
		let s = r.variants.get("data"), a = s === null || s === void 0 ? void 0 : s.applyFn, p = s === null || s === void 0 ? void 0 : s.compounds;
		r.variants.functional("data", (u, f) => {
			let m = f.value;
			return m && m.kind === "named" && m.value in n ? a === null || a === void 0 ? void 0 : a(u, {
				...f,
				value: {
					kind: "arbitrary",
					value: n[m.value]
				}
			}) : a === null || a === void 0 ? void 0 : a(u, f);
		}, { compounds: p });
	}
}
var Ma = /^[a-z]+$/;
async function ji({ designSystem: t, base: r, ast: i, loadModule: e, sources: n }) {
	let s = 0, a = [], p = [];
	I(i, (d$12, c) => {
		if (d$12.kind !== "at-rule") return;
		let w = qe(c);
		if (d$12.name === "@plugin") {
			if (w.parent !== null) throw new Error("`@plugin` cannot be nested.");
			let h = d$12.params.slice(1, -1);
			if (h.length === 0) throw new Error("`@plugin` must have a path.");
			let y = {};
			for (let x of d$12.nodes ?? []) {
				if (x.kind !== "declaration") throw new Error(`Unexpected \`@plugin\` option:

${re([x])}

\`@plugin\` options must be a flat list of declarations.`);
				if (x.value === void 0) continue;
				let $ = x.value, A = d($, ",").map((k) => {
					if (k = k.trim(), k === "null") return null;
					if (k === "true") return !0;
					if (k === "false") return !1;
					if (Number.isNaN(Number(k))) {
						if (k[0] === "\"" && k[k.length - 1] === "\"" || k[0] === "'" && k[k.length - 1] === "'") return k.slice(1, -1);
						if (k[0] === "{" && k[k.length - 1] === "}") throw new Error(`Unexpected \`@plugin\` option: Value of declaration \`${re([x]).trim()}\` is not supported.

Using an object as a plugin option is currently only supported in JavaScript configuration files.`);
					} else return Number(k);
					return k;
				});
				y[x.property] = A.length === 1 ? A[0] : A;
			}
			return a.push([{
				id: h,
				base: w.context.base,
				reference: !!w.context.reference,
				src: d$12.src
			}, Object.keys(y).length > 0 ? y : null]), s |= 4, E.Replace([]);
		}
		if (d$12.name === "@config") {
			if (d$12.nodes.length > 0) throw new Error("`@config` cannot have a body.");
			if (w.parent !== null) throw new Error("`@config` cannot be nested.");
			return p.push({
				id: d$12.params.slice(1, -1),
				base: w.context.base,
				reference: !!w.context.reference,
				src: d$12.src
			}), s |= 4, E.Replace([]);
		}
	}), Di(t);
	let u = t.resolveThemeValue;
	if (t.resolveThemeValue = function(c, w) {
		return c.startsWith("--") ? u(c, w) : (s |= Li({
			designSystem: t,
			base: r,
			ast: i,
			sources: n,
			configs: [],
			pluginDetails: []
		}), t.resolveThemeValue(c, w));
	}, !a.length && !p.length) return 0;
	let [f, m] = await Promise.all([Promise.all(p.map(async ({ id: d, base: c, reference: w, src: h }) => {
		let y = await e(d, c, "config");
		return {
			path: d,
			base: y.base,
			config: y.module,
			reference: w,
			src: h
		};
	})), Promise.all(a.map(async ([{ id: d, base: c, reference: w, src: h }, y]) => {
		let x = await e(d, c, "plugin");
		return {
			path: d,
			base: x.base,
			plugin: x.module,
			options: y,
			reference: w,
			src: h
		};
	}))]);
	return s |= Li({
		designSystem: t,
		base: r,
		ast: i,
		sources: n,
		configs: f,
		pluginDetails: m
	}), s;
}
function Li({ designSystem: t, base: r, ast: i, sources: e, configs: n, pluginDetails: s }) {
	let a = 0, u = [...s.map((y) => {
		if (!y.options) return {
			config: { plugins: [y.plugin] },
			base: y.base,
			reference: y.reference,
			src: y.src
		};
		if ("__isOptionsFunction" in y.plugin) return {
			config: { plugins: [y.plugin(y.options)] },
			base: y.base,
			reference: y.reference,
			src: y.src
		};
		throw new Error(`The plugin "${y.path}" does not accept options`);
	}), ...n], { resolvedConfig: f } = Qt(t, [
		{
			config: Pi(t.theme),
			base: r,
			reference: !0,
			src: void 0
		},
		...u,
		{
			config: { plugins: [_i] },
			base: r,
			reference: !0,
			src: void 0
		}
	]), { resolvedConfig: m, replacedThemeKeys: d } = Qt(t, u), c = {
		designSystem: t,
		ast: i,
		resolvedConfig: f,
		featuresRef: { set current(y) {
			a |= y;
		} }
	}, w = Ht({
		...c,
		referenceMode: !1,
		src: void 0
	}), h = t.resolveThemeValue;
	t.resolveThemeValue = function(x, $) {
		if (x[0] === "-" && x[1] === "-") return h(x, $);
		let A = w.theme(x, void 0);
		if (Array.isArray(A) && A.length === 2) return A[0];
		if (Array.isArray(A)) return A.join(", ");
		if (typeof A == "object" && A !== null && "DEFAULT" in A) return A.DEFAULT;
		if (typeof A == "string") return A;
	};
	for (let { handler: y, reference: x, src: $ } of f.plugins) y(Ht({
		...c,
		referenceMode: x ?? !1,
		src: $
	}));
	if (zr(t, m, d), Oi(t, m), Ui(m, t), Ki(m, t), Ii(m, t), !t.theme.prefix && f.prefix) {
		if (f.prefix.endsWith("-") && (f.prefix = f.prefix.slice(0, -1), console.warn(`The prefix "${f.prefix}" is invalid. Prefixes must be lowercase ASCII letters (a-z) only and is written as a variant before all utilities. We have fixed up the prefix for you. Remove the trailing \`-\` to silence this warning.`)), !Ma.test(f.prefix)) throw new Error(`The prefix "${f.prefix}" is invalid. Prefixes must be lowercase ASCII letters (a-z) only.`);
		t.theme.prefix = f.prefix;
	}
	if (!t.important && f.important === !0 && (t.important = !0), typeof f.important == "string") {
		let y = f.important;
		I(i, (x, $) => {
			var _A$parent;
			if (x.kind !== "at-rule" || x.name !== "@tailwind" || x.params !== "utilities") return;
			let A = qe($);
			return ((_A$parent = A.parent) === null || _A$parent === void 0 ? void 0 : _A$parent.kind) === "rule" && A.parent.selector === y ? E.Stop : E.ReplaceStop(G(y, [x]));
		});
	}
	for (let y of f.blocklist) t.invalidCandidates.add(y);
	for (let y of f.content.files) {
		if ("raw" in y) throw new Error(`Error in the config file/plugin/preset. The \`content\` key contains a \`raw\` entry:

${JSON.stringify(y, null, 2)}

This feature is not currently supported.`);
		let x = !1;
		y.pattern[0] == "!" && (x = !0, y.pattern = y.pattern.slice(1)), e.push({
			...y,
			negated: x
		});
	}
	return a;
}
function zi({ ast: t }) {
	let r = new K((n) => tt(n.code)), i = new K((n) => ({
		url: n.file,
		content: n.code,
		ignore: !1
	})), e = {
		file: null,
		sources: [],
		mappings: []
	};
	I(t, (n) => {
		if (!n.src || !n.dst) return;
		let s = i.get(n.src[0]);
		if (!s.content) return;
		let a = r.get(n.src[0]), p = r.get(n.dst[0]), u = s.content.slice(n.src[1], n.src[2]), f = 0;
		for (let c of u.split(`
`)) {
			if (c.trim() !== "") {
				let w = a.find(n.src[1] + f), h = p.find(n.dst[1]);
				e.mappings.push({
					name: null,
					originalPosition: {
						source: s,
						...w
					},
					generatedPosition: h
				});
			}
			f += c.length, f += 1;
		}
		let m = a.find(n.src[2]), d = p.find(n.dst[2]);
		e.mappings.push({
			name: null,
			originalPosition: {
				source: s,
				...m
			},
			generatedPosition: d
		});
	});
	for (let n of r.keys()) e.sources.push(i.get(n));
	return e.mappings.sort((n, s) => {
		var _n$originalPosition, _s$originalPosition, _n$originalPosition2, _s$originalPosition2;
		return n.generatedPosition.line - s.generatedPosition.line || n.generatedPosition.column - s.generatedPosition.column || (((_n$originalPosition = n.originalPosition) === null || _n$originalPosition === void 0 ? void 0 : _n$originalPosition.line) ?? 0) - (((_s$originalPosition = s.originalPosition) === null || _s$originalPosition === void 0 ? void 0 : _s$originalPosition.line) ?? 0) || (((_n$originalPosition2 = n.originalPosition) === null || _n$originalPosition2 === void 0 ? void 0 : _n$originalPosition2.column) ?? 0) - (((_s$originalPosition2 = s.originalPosition) === null || _s$originalPosition2 === void 0 ? void 0 : _s$originalPosition2.column) ?? 0);
	}), e;
}
var Mi = /^(-?\d+)\.\.(-?\d+)(?:\.\.(-?\d+))?$/;
function xt(t) {
	let r = t.indexOf("{");
	if (r === -1) return [t];
	let i = [], e = t.slice(0, r), n = t.slice(r), s = 0, a = n.lastIndexOf("}");
	for (let d = 0; d < n.length; d++) {
		let c = n[d];
		if (c === "{") s++;
		else if (c === "}" && (s--, s === 0)) {
			a = d;
			break;
		}
	}
	if (a === -1) throw new Error(`The pattern \`${t}\` is not balanced.`);
	let p = n.slice(1, a), u = n.slice(a + 1), f;
	Fa(p) ? f = Wa(p) : f = d(p, ","), f = f.flatMap((d) => xt(d));
	let m = xt(u);
	for (let d of m) for (let c of f) i.push(e + c + d);
	return i;
}
function Fa(t) {
	return Mi.test(t);
}
function Wa(t) {
	let r = t.match(Mi);
	if (!r) return [t];
	let [, i, e, n] = r, s = n ? parseInt(n, 10) : void 0, a = [];
	if (/^-?\d+$/.test(i) && /^-?\d+$/.test(e)) {
		let p = parseInt(i, 10), u = parseInt(e, 10);
		if (s === void 0 && (s = p <= u ? 1 : -1), s === 0) throw new Error("Step cannot be zero in sequence expansion.");
		let f = p < u;
		f && s < 0 && (s = -s), !f && s > 0 && (s = -s);
		for (let m = p; f ? m <= u : m >= u; m += s) a.push(m.toString());
	}
	return a;
}
function Fi(t, r) {
	let i = /* @__PURE__ */ new Set(), e = /* @__PURE__ */ new Set(), n = [];
	function s(a, p = []) {
		if (t.has(a) && !i.has(a)) {
			var _r$onCircularDependen;
			e.has(a) && ((_r$onCircularDependen = r.onCircularDependency) === null || _r$onCircularDependen === void 0 || _r$onCircularDependen.call(r, p, a)), e.add(a);
			for (let u of t.get(a) ?? []) p.push(a), s(u, p), p.pop();
			i.add(a), e.delete(a), n.push(a);
		}
	}
	for (let a of t.keys()) s(a);
	return n;
}
var Ba = /^[a-z]+$/, Rt = ((n) => (n[n.None = 0] = "None", n[n.AtProperty = 1] = "AtProperty", n[n.ColorMix = 2] = "ColorMix", n[n.All = 3] = "All", n))(Rt || {});
function Ya() {
	throw new Error("No `loadModule` function provided to `compile`");
}
function Ga() {
	throw new Error("No `loadStylesheet` function provided to `compile`");
}
function qa(t) {
	let r = 0, i = null;
	for (let e of d(t, " ")) e === "reference" ? r |= 2 : e === "inline" ? r |= 1 : e === "default" ? r |= 4 : e === "static" ? r |= 8 : e.startsWith("prefix(") && e.endsWith(")") && (i = e.slice(7, -1));
	return [r, i];
}
var Ke = ((u) => (u[u.None = 0] = "None", u[u.AtApply = 1] = "AtApply", u[u.AtImport = 2] = "AtImport", u[u.JsPluginCompat = 4] = "JsPluginCompat", u[u.ThemeFunction = 8] = "ThemeFunction", u[u.Utilities = 16] = "Utilities", u[u.Variants = 32] = "Variants", u[u.AtTheme = 64] = "AtTheme", u))(Ke || {});
async function Wi(t, { base: r = "", from: i, loadModule: e = Ya, loadStylesheet: n = Ga } = {}) {
	var _u$get;
	let s = 0;
	t = [ce({ base: r }, t)], s |= await Zt(t, r, n, 0, i !== void 0);
	let a = null, p = new lt(), u = /* @__PURE__ */ new Map(), f = /* @__PURE__ */ new Map(), m = [], d$13 = null, c = null, w = [], h = [], y = [], x = [], $ = null;
	I(t, (k, U) => {
		if (k.kind !== "at-rule") return;
		let N = qe(U);
		if (k.name === "@tailwind" && (k.params === "utilities" || k.params.startsWith("utilities"))) {
			if (c !== null) return E.Replace([]);
			if (N.context.reference) return E.Replace([]);
			let O = d(k.params, " ");
			for (let L of O) if (L.startsWith("source(")) {
				let _ = L.slice(7, -1);
				if (_ === "none") {
					$ = _;
					continue;
				}
				if (_[0] === "\"" && _[_.length - 1] !== "\"" || _[0] === "'" && _[_.length - 1] !== "'" || _[0] !== "'" && _[0] !== "\"") throw new Error("`source(…)` paths must be quoted.");
				$ = {
					base: N.context.sourceBase ?? N.context.base,
					pattern: _.slice(1, -1)
				};
			}
			c = k, s |= 16;
		}
		if (k.name === "@utility") {
			if (N.parent !== null) throw new Error("`@utility` cannot be nested.");
			if (k.nodes.length === 0) throw new Error(`\`@utility ${k.params}\` is empty. Utilities should include at least one property.`);
			let O = Kr(k);
			if (O === null) {
				if (!k.params.endsWith("-*")) {
					if (k.params.endsWith("*")) throw new Error(`\`@utility ${k.params}\` defines an invalid utility name. A functional utility must end in \`-*\`.`);
					if (k.params.includes("*")) throw new Error(`\`@utility ${k.params}\` defines an invalid utility name. The dynamic portion marked by \`-*\` must appear once at the end.`);
				}
				throw new Error(`\`@utility ${k.params}\` defines an invalid utility name. Utilities should be alphanumeric and start with a lowercase letter.`);
			}
			m.push(O);
		}
		if (k.name === "@source") {
			if (k.nodes.length > 0) throw new Error("`@source` cannot have a body.");
			if (N.parent !== null) throw new Error("`@source` cannot be nested.");
			let O = !1, L = !1, _ = k.params;
			if (_[0] === "n" && _.startsWith("not ") && (O = !0, _ = _.slice(4)), _[0] === "i" && _.startsWith("inline(") && (L = !0, _ = _.slice(7, -1)), _[0] === "\"" && _[_.length - 1] !== "\"" || _[0] === "'" && _[_.length - 1] !== "'" || _[0] !== "'" && _[0] !== "\"") throw new Error("`@source` paths must be quoted.");
			let z = _.slice(1, -1);
			if (L) {
				let Y = O ? x : y, q = d(z, " ");
				for (let ae of q) for (let oe of xt(ae)) Y.push(oe);
			} else h.push({
				base: N.context.base,
				pattern: z,
				negated: O
			});
			return E.ReplaceSkip([]);
		}
		if (k.name === "@variant" && (N.parent === null ? k.nodes.length === 0 ? k.name = "@custom-variant" : (I(k.nodes, (O) => {
			if (O.kind === "at-rule" && O.name === "@slot") return k.name = "@custom-variant", E.Stop;
		}), k.name === "@variant" && w.push(k)) : w.push(k)), k.name === "@custom-variant") {
			if (N.parent !== null) throw new Error("`@custom-variant` cannot be nested.");
			let [O, L] = d(k.params, " ");
			if (!kt.test(O)) throw new Error(`\`@custom-variant ${O}\` defines an invalid variant name. Variants should only contain alphanumeric, dashes, or underscore characters and start with a lowercase letter or number.`);
			if (k.nodes.length > 0 && L) throw new Error(`\`@custom-variant ${O}\` cannot have both a selector and a body.`);
			if (k.nodes.length === 0) {
				if (!L) throw new Error(`\`@custom-variant ${O}\` has no selector or body.`);
				let _ = d(L.slice(1, -1), ",");
				if (_.length === 0 || _.some((q) => q.trim() === "")) throw new Error(`\`@custom-variant ${O} (${_.join(",")})\` selector is invalid.`);
				let z = [], Y = [];
				for (let q of _) q = q.trim(), q[0] === "@" ? z.push(q) : Y.push(q);
				u.set(O, (q) => {
					q.variants.static(O, (ae) => {
						let oe = [];
						Y.length > 0 && oe.push(G(Y.join(", "), ae.nodes));
						for (let l of z) oe.push(J(l, ae.nodes));
						ae.nodes = oe;
					}, { compounds: Pe([...Y, ...z]) });
				}), f.set(O, /* @__PURE__ */ new Set());
			} else {
				let _ = /* @__PURE__ */ new Set();
				I(k.nodes, (z) => {
					z.kind === "at-rule" && z.name === "@variant" && _.add(z.params);
				}), u.set(O, (z) => {
					z.variants.fromAst(O, k.nodes, z);
				}), f.set(O, _);
			}
			return E.ReplaceSkip([]);
		}
		if (k.name === "@media") {
			let O = d(k.params, " "), L = [];
			for (let _ of O) if (_.startsWith("source(")) {
				let z = _.slice(7, -1);
				I(k.nodes, (Y) => {
					if (Y.kind === "at-rule" && Y.name === "@tailwind" && Y.params === "utilities") return Y.params += ` source(${z})`, E.ReplaceStop([ce({ sourceBase: N.context.base }, [Y])]);
				});
			} else if (_.startsWith("theme(")) {
				let z = _.slice(6, -1), Y = z.includes("reference");
				I(k.nodes, (q) => {
					if (q.kind !== "context") {
						if (q.kind !== "at-rule") {
							if (Y) throw new Error("Files imported with `@import \"…\" theme(reference)` must only contain `@theme` blocks.\nUse `@reference \"…\";` instead.");
							return E.Continue;
						}
						if (q.name === "@theme") return q.params += " " + z, E.Skip;
					}
				});
			} else if (_.startsWith("prefix(")) {
				let z = _.slice(7, -1);
				I(k.nodes, (Y) => {
					if (Y.kind === "at-rule" && Y.name === "@theme") return Y.params += ` prefix(${z})`, E.Skip;
				});
			} else _ === "important" ? a = !0 : _ === "reference" ? k.nodes = [ce({ reference: !0 }, k.nodes)] : L.push(_);
			if (L.length > 0) k.params = L.join(" ");
			else if (O.length > 0) return E.Replace(k.nodes);
			return E.Continue;
		}
		if (k.name === "@theme") {
			let [O, L] = qa(k.params);
			if (s |= 64, N.context.reference && (O |= 2), L) {
				if (!Ba.test(L)) throw new Error(`The prefix "${L}" is invalid. Prefixes must be lowercase ASCII letters (a-z) only.`);
				p.prefix = L;
			}
			return I(k.nodes, (_) => {
				if (_.kind === "at-rule" && _.name === "@keyframes") return p.addKeyframes(_), E.Skip;
				if (_.kind === "comment") return;
				if (_.kind === "declaration" && _.property.startsWith("--")) {
					p.add(Se(_.property), _.value ?? "", O, _.src);
					return;
				}
				let z = re([F(k.name, k.params, [_])]).split(`
`).map((Y, q, ae) => `${q === 0 || q >= ae.length - 2 ? " " : ">"} ${Y}`).join(`
`);
				throw new Error(`\`@theme\` blocks must only contain custom properties or \`@keyframes\`.

${z}`);
			}), d$13 ? E.ReplaceSkip([]) : (d$13 = G(":root, :host", []), d$13.src = k.src, E.ReplaceSkip(d$13));
		}
	});
	let A = xi(p, c === null || c === void 0 ? void 0 : c.src);
	if (a && (A.important = a), x.length > 0) for (let k of x) A.invalidCandidates.add(k);
	s |= await ji({
		designSystem: A,
		base: r,
		ast: t,
		loadModule: e,
		sources: h
	});
	for (let k of u.keys()) A.variants.static(k, () => {});
	for (let k of Fi(f, { onCircularDependency(U, N) {
		let O = re(U.map((L, _) => F("@custom-variant", L, [F("@variant", U[_ + 1] ?? N, [])]))).replaceAll(";", " { … }").replace(`@custom-variant ${N} {`, `@custom-variant ${N} { /* \u2190 */`);
		throw new Error(`Circular dependency detected in custom variants:

${O}`);
	} })) (_u$get = u.get(k)) === null || _u$get === void 0 || _u$get(A);
	for (let k of m) k(A);
	if (d$13) {
		let k = [];
		for (let [N, O] of A.theme.entries()) {
			if (O.options & 2) continue;
			let L = o(ye(N), O.value);
			L.src = O.src, k.push(L);
		}
		let U = A.theme.getKeyframes();
		for (let N of U) t.push(ce({ theme: !0 }, [W([N])]));
		d$13.nodes = [ce({ theme: !0 }, k)];
	}
	if (s |= Qe(t, A), s |= De(t, A), s |= Ae(t, A), c) {
		let k = c;
		k.kind = "context", k.context = {};
	}
	return I(t, (k) => {
		if (k.kind === "at-rule") return k.name === "@utility" ? E.Replace([]) : E.Skip;
	}), {
		designSystem: A,
		ast: t,
		sources: h,
		root: $,
		utilitiesNode: c,
		features: s,
		inlineCandidates: y
	};
}
async function Za(t, r = {}) {
	let { designSystem: i, ast: e, sources: n, root: s, utilitiesNode: a, features: p, inlineCandidates: u } = await Wi(t, r);
	e.unshift(ot(`! tailwindcss v${ir} | MIT License | https://tailwindcss.com `));
	function f(h) {
		i.invalidCandidates.add(h);
	}
	let m = /* @__PURE__ */ new Set(), d = null, c = 0, w = !1;
	for (let h of u) i.invalidCandidates.has(h) || (m.add(h), w = !0);
	return {
		sources: n,
		root: s,
		features: p,
		build(h) {
			if (p === 0) return t;
			if (!a) return d ?? (d = Te(e, i, r.polyfills)), d;
			let y = w, x = !1;
			w = !1;
			let $ = m.size;
			for (let k of h) if (!i.invalidCandidates.has(k)) if (k[0] === "-" && k[1] === "-") {
				let U = i.theme.markUsedVariable(k);
				y || (y = U), x || (x = U);
			} else m.add(k), y || (y = m.size !== $);
			if (!y) return d ?? (d = Te(e, i, r.polyfills)), d;
			let A = Ce(m, i, { onInvalidCandidate: f }).astNodes;
			return r.from && I(A, (k) => {
				k.src ?? (k.src = a.src);
			}), !x && c === A.length ? (d ?? (d = Te(e, i, r.polyfills)), d) : (c = A.length, a.nodes = A, d = Te(e, i, r.polyfills), d);
		}
	};
}
async function rf(t, r = {}) {
	let i = $e(t, { from: r.from }), e = await Za(i, r), n = i, s = t;
	return {
		...e,
		build(a) {
			let p = e.build(a);
			return p === n || (s = re(p, !!r.from), n = p), s;
		},
		buildSourceMap() {
			return zi({ ast: n });
		}
	};
}
async function nf(t, r = {}) {
	return (await Wi($e(t, { from: r.from }), r)).designSystem;
}
function Ha() {
	throw new Error("It looks like you're trying to use `tailwindcss` directly as a PostCSS plugin. The PostCSS plugin has moved to a separate package, so to continue using Tailwind CSS with PostCSS you'll need to install `@tailwindcss/postcss` and update your PostCSS configuration.");
}
var lib_exports = /* @__PURE__ */ __exportAll({
	Features: () => Ke,
	Polyfills: () => Rt,
	__unstable__loadDesignSystem: () => nf,
	compile: () => rf,
	compileAst: () => Za,
	default: () => Ha
});
var tailwindcss_default = "@layer theme, base, components, utilities;\n\n@layer theme {\n  @theme default {\n    --font-sans:\n      ui-sans-serif, system-ui, sans-serif, \"Apple Color Emoji\",\n      \"Segoe UI Emoji\", \"Segoe UI Symbol\", \"Noto Color Emoji\";\n    --font-serif: ui-serif, Georgia, Cambria, \"Times New Roman\", Times, serif;\n    --font-mono:\n      ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, \"Liberation Mono\",\n      \"Courier New\", monospace;\n\n    --color-red-50: oklch(97.1% 0.013 17.38);\n    --color-red-100: oklch(93.6% 0.032 17.717);\n    --color-red-200: oklch(88.5% 0.062 18.334);\n    --color-red-300: oklch(80.8% 0.114 19.571);\n    --color-red-400: oklch(70.4% 0.191 22.216);\n    --color-red-500: oklch(63.7% 0.237 25.331);\n    --color-red-600: oklch(57.7% 0.245 27.325);\n    --color-red-700: oklch(50.5% 0.213 27.518);\n    --color-red-800: oklch(44.4% 0.177 26.899);\n    --color-red-900: oklch(39.6% 0.141 25.723);\n    --color-red-950: oklch(25.8% 0.092 26.042);\n\n    --color-orange-50: oklch(98% 0.016 73.684);\n    --color-orange-100: oklch(95.4% 0.038 75.164);\n    --color-orange-200: oklch(90.1% 0.076 70.697);\n    --color-orange-300: oklch(83.7% 0.128 66.29);\n    --color-orange-400: oklch(75% 0.183 55.934);\n    --color-orange-500: oklch(70.5% 0.213 47.604);\n    --color-orange-600: oklch(64.6% 0.222 41.116);\n    --color-orange-700: oklch(55.3% 0.195 38.402);\n    --color-orange-800: oklch(47% 0.157 37.304);\n    --color-orange-900: oklch(40.8% 0.123 38.172);\n    --color-orange-950: oklch(26.6% 0.079 36.259);\n\n    --color-amber-50: oklch(98.7% 0.022 95.277);\n    --color-amber-100: oklch(96.2% 0.059 95.617);\n    --color-amber-200: oklch(92.4% 0.12 95.746);\n    --color-amber-300: oklch(87.9% 0.169 91.605);\n    --color-amber-400: oklch(82.8% 0.189 84.429);\n    --color-amber-500: oklch(76.9% 0.188 70.08);\n    --color-amber-600: oklch(66.6% 0.179 58.318);\n    --color-amber-700: oklch(55.5% 0.163 48.998);\n    --color-amber-800: oklch(47.3% 0.137 46.201);\n    --color-amber-900: oklch(41.4% 0.112 45.904);\n    --color-amber-950: oklch(27.9% 0.077 45.635);\n\n    --color-yellow-50: oklch(98.7% 0.026 102.212);\n    --color-yellow-100: oklch(97.3% 0.071 103.193);\n    --color-yellow-200: oklch(94.5% 0.129 101.54);\n    --color-yellow-300: oklch(90.5% 0.182 98.111);\n    --color-yellow-400: oklch(85.2% 0.199 91.936);\n    --color-yellow-500: oklch(79.5% 0.184 86.047);\n    --color-yellow-600: oklch(68.1% 0.162 75.834);\n    --color-yellow-700: oklch(55.4% 0.135 66.442);\n    --color-yellow-800: oklch(47.6% 0.114 61.907);\n    --color-yellow-900: oklch(42.1% 0.095 57.708);\n    --color-yellow-950: oklch(28.6% 0.066 53.813);\n\n    --color-lime-50: oklch(98.6% 0.031 120.757);\n    --color-lime-100: oklch(96.7% 0.067 122.328);\n    --color-lime-200: oklch(93.8% 0.127 124.321);\n    --color-lime-300: oklch(89.7% 0.196 126.665);\n    --color-lime-400: oklch(84.1% 0.238 128.85);\n    --color-lime-500: oklch(76.8% 0.233 130.85);\n    --color-lime-600: oklch(64.8% 0.2 131.684);\n    --color-lime-700: oklch(53.2% 0.157 131.589);\n    --color-lime-800: oklch(45.3% 0.124 130.933);\n    --color-lime-900: oklch(40.5% 0.101 131.063);\n    --color-lime-950: oklch(27.4% 0.072 132.109);\n\n    --color-green-50: oklch(98.2% 0.018 155.826);\n    --color-green-100: oklch(96.2% 0.044 156.743);\n    --color-green-200: oklch(92.5% 0.084 155.995);\n    --color-green-300: oklch(87.1% 0.15 154.449);\n    --color-green-400: oklch(79.2% 0.209 151.711);\n    --color-green-500: oklch(72.3% 0.219 149.579);\n    --color-green-600: oklch(62.7% 0.194 149.214);\n    --color-green-700: oklch(52.7% 0.154 150.069);\n    --color-green-800: oklch(44.8% 0.119 151.328);\n    --color-green-900: oklch(39.3% 0.095 152.535);\n    --color-green-950: oklch(26.6% 0.065 152.934);\n\n    --color-emerald-50: oklch(97.9% 0.021 166.113);\n    --color-emerald-100: oklch(95% 0.052 163.051);\n    --color-emerald-200: oklch(90.5% 0.093 164.15);\n    --color-emerald-300: oklch(84.5% 0.143 164.978);\n    --color-emerald-400: oklch(76.5% 0.177 163.223);\n    --color-emerald-500: oklch(69.6% 0.17 162.48);\n    --color-emerald-600: oklch(59.6% 0.145 163.225);\n    --color-emerald-700: oklch(50.8% 0.118 165.612);\n    --color-emerald-800: oklch(43.2% 0.095 166.913);\n    --color-emerald-900: oklch(37.8% 0.077 168.94);\n    --color-emerald-950: oklch(26.2% 0.051 172.552);\n\n    --color-teal-50: oklch(98.4% 0.014 180.72);\n    --color-teal-100: oklch(95.3% 0.051 180.801);\n    --color-teal-200: oklch(91% 0.096 180.426);\n    --color-teal-300: oklch(85.5% 0.138 181.071);\n    --color-teal-400: oklch(77.7% 0.152 181.912);\n    --color-teal-500: oklch(70.4% 0.14 182.503);\n    --color-teal-600: oklch(60% 0.118 184.704);\n    --color-teal-700: oklch(51.1% 0.096 186.391);\n    --color-teal-800: oklch(43.7% 0.078 188.216);\n    --color-teal-900: oklch(38.6% 0.063 188.416);\n    --color-teal-950: oklch(27.7% 0.046 192.524);\n\n    --color-cyan-50: oklch(98.4% 0.019 200.873);\n    --color-cyan-100: oklch(95.6% 0.045 203.388);\n    --color-cyan-200: oklch(91.7% 0.08 205.041);\n    --color-cyan-300: oklch(86.5% 0.127 207.078);\n    --color-cyan-400: oklch(78.9% 0.154 211.53);\n    --color-cyan-500: oklch(71.5% 0.143 215.221);\n    --color-cyan-600: oklch(60.9% 0.126 221.723);\n    --color-cyan-700: oklch(52% 0.105 223.128);\n    --color-cyan-800: oklch(45% 0.085 224.283);\n    --color-cyan-900: oklch(39.8% 0.07 227.392);\n    --color-cyan-950: oklch(30.2% 0.056 229.695);\n\n    --color-sky-50: oklch(97.7% 0.013 236.62);\n    --color-sky-100: oklch(95.1% 0.026 236.824);\n    --color-sky-200: oklch(90.1% 0.058 230.902);\n    --color-sky-300: oklch(82.8% 0.111 230.318);\n    --color-sky-400: oklch(74.6% 0.16 232.661);\n    --color-sky-500: oklch(68.5% 0.169 237.323);\n    --color-sky-600: oklch(58.8% 0.158 241.966);\n    --color-sky-700: oklch(50% 0.134 242.749);\n    --color-sky-800: oklch(44.3% 0.11 240.79);\n    --color-sky-900: oklch(39.1% 0.09 240.876);\n    --color-sky-950: oklch(29.3% 0.066 243.157);\n\n    --color-blue-50: oklch(97% 0.014 254.604);\n    --color-blue-100: oklch(93.2% 0.032 255.585);\n    --color-blue-200: oklch(88.2% 0.059 254.128);\n    --color-blue-300: oklch(80.9% 0.105 251.813);\n    --color-blue-400: oklch(70.7% 0.165 254.624);\n    --color-blue-500: oklch(62.3% 0.214 259.815);\n    --color-blue-600: oklch(54.6% 0.245 262.881);\n    --color-blue-700: oklch(48.8% 0.243 264.376);\n    --color-blue-800: oklch(42.4% 0.199 265.638);\n    --color-blue-900: oklch(37.9% 0.146 265.522);\n    --color-blue-950: oklch(28.2% 0.091 267.935);\n\n    --color-indigo-50: oklch(96.2% 0.018 272.314);\n    --color-indigo-100: oklch(93% 0.034 272.788);\n    --color-indigo-200: oklch(87% 0.065 274.039);\n    --color-indigo-300: oklch(78.5% 0.115 274.713);\n    --color-indigo-400: oklch(67.3% 0.182 276.935);\n    --color-indigo-500: oklch(58.5% 0.233 277.117);\n    --color-indigo-600: oklch(51.1% 0.262 276.966);\n    --color-indigo-700: oklch(45.7% 0.24 277.023);\n    --color-indigo-800: oklch(39.8% 0.195 277.366);\n    --color-indigo-900: oklch(35.9% 0.144 278.697);\n    --color-indigo-950: oklch(25.7% 0.09 281.288);\n\n    --color-violet-50: oklch(96.9% 0.016 293.756);\n    --color-violet-100: oklch(94.3% 0.029 294.588);\n    --color-violet-200: oklch(89.4% 0.057 293.283);\n    --color-violet-300: oklch(81.1% 0.111 293.571);\n    --color-violet-400: oklch(70.2% 0.183 293.541);\n    --color-violet-500: oklch(60.6% 0.25 292.717);\n    --color-violet-600: oklch(54.1% 0.281 293.009);\n    --color-violet-700: oklch(49.1% 0.27 292.581);\n    --color-violet-800: oklch(43.2% 0.232 292.759);\n    --color-violet-900: oklch(38% 0.189 293.745);\n    --color-violet-950: oklch(28.3% 0.141 291.089);\n\n    --color-purple-50: oklch(97.7% 0.014 308.299);\n    --color-purple-100: oklch(94.6% 0.033 307.174);\n    --color-purple-200: oklch(90.2% 0.063 306.703);\n    --color-purple-300: oklch(82.7% 0.119 306.383);\n    --color-purple-400: oklch(71.4% 0.203 305.504);\n    --color-purple-500: oklch(62.7% 0.265 303.9);\n    --color-purple-600: oklch(55.8% 0.288 302.321);\n    --color-purple-700: oklch(49.6% 0.265 301.924);\n    --color-purple-800: oklch(43.8% 0.218 303.724);\n    --color-purple-900: oklch(38.1% 0.176 304.987);\n    --color-purple-950: oklch(29.1% 0.149 302.717);\n\n    --color-fuchsia-50: oklch(97.7% 0.017 320.058);\n    --color-fuchsia-100: oklch(95.2% 0.037 318.852);\n    --color-fuchsia-200: oklch(90.3% 0.076 319.62);\n    --color-fuchsia-300: oklch(83.3% 0.145 321.434);\n    --color-fuchsia-400: oklch(74% 0.238 322.16);\n    --color-fuchsia-500: oklch(66.7% 0.295 322.15);\n    --color-fuchsia-600: oklch(59.1% 0.293 322.896);\n    --color-fuchsia-700: oklch(51.8% 0.253 323.949);\n    --color-fuchsia-800: oklch(45.2% 0.211 324.591);\n    --color-fuchsia-900: oklch(40.1% 0.17 325.612);\n    --color-fuchsia-950: oklch(29.3% 0.136 325.661);\n\n    --color-pink-50: oklch(97.1% 0.014 343.198);\n    --color-pink-100: oklch(94.8% 0.028 342.258);\n    --color-pink-200: oklch(89.9% 0.061 343.231);\n    --color-pink-300: oklch(82.3% 0.12 346.018);\n    --color-pink-400: oklch(71.8% 0.202 349.761);\n    --color-pink-500: oklch(65.6% 0.241 354.308);\n    --color-pink-600: oklch(59.2% 0.249 0.584);\n    --color-pink-700: oklch(52.5% 0.223 3.958);\n    --color-pink-800: oklch(45.9% 0.187 3.815);\n    --color-pink-900: oklch(40.8% 0.153 2.432);\n    --color-pink-950: oklch(28.4% 0.109 3.907);\n\n    --color-rose-50: oklch(96.9% 0.015 12.422);\n    --color-rose-100: oklch(94.1% 0.03 12.58);\n    --color-rose-200: oklch(89.2% 0.058 10.001);\n    --color-rose-300: oklch(81% 0.117 11.638);\n    --color-rose-400: oklch(71.2% 0.194 13.428);\n    --color-rose-500: oklch(64.5% 0.246 16.439);\n    --color-rose-600: oklch(58.6% 0.253 17.585);\n    --color-rose-700: oklch(51.4% 0.222 16.935);\n    --color-rose-800: oklch(45.5% 0.188 13.697);\n    --color-rose-900: oklch(41% 0.159 10.272);\n    --color-rose-950: oklch(27.1% 0.105 12.094);\n\n    --color-slate-50: oklch(98.4% 0.003 247.858);\n    --color-slate-100: oklch(96.8% 0.007 247.896);\n    --color-slate-200: oklch(92.9% 0.013 255.508);\n    --color-slate-300: oklch(86.9% 0.022 252.894);\n    --color-slate-400: oklch(70.4% 0.04 256.788);\n    --color-slate-500: oklch(55.4% 0.046 257.417);\n    --color-slate-600: oklch(44.6% 0.043 257.281);\n    --color-slate-700: oklch(37.2% 0.044 257.287);\n    --color-slate-800: oklch(27.9% 0.041 260.031);\n    --color-slate-900: oklch(20.8% 0.042 265.755);\n    --color-slate-950: oklch(12.9% 0.042 264.695);\n\n    --color-gray-50: oklch(98.5% 0.002 247.839);\n    --color-gray-100: oklch(96.7% 0.003 264.542);\n    --color-gray-200: oklch(92.8% 0.006 264.531);\n    --color-gray-300: oklch(87.2% 0.01 258.338);\n    --color-gray-400: oklch(70.7% 0.022 261.325);\n    --color-gray-500: oklch(55.1% 0.027 264.364);\n    --color-gray-600: oklch(44.6% 0.03 256.802);\n    --color-gray-700: oklch(37.3% 0.034 259.733);\n    --color-gray-800: oklch(27.8% 0.033 256.848);\n    --color-gray-900: oklch(21% 0.034 264.665);\n    --color-gray-950: oklch(13% 0.028 261.692);\n\n    --color-zinc-50: oklch(98.5% 0 0);\n    --color-zinc-100: oklch(96.7% 0.001 286.375);\n    --color-zinc-200: oklch(92% 0.004 286.32);\n    --color-zinc-300: oklch(87.1% 0.006 286.286);\n    --color-zinc-400: oklch(70.5% 0.015 286.067);\n    --color-zinc-500: oklch(55.2% 0.016 285.938);\n    --color-zinc-600: oklch(44.2% 0.017 285.786);\n    --color-zinc-700: oklch(37% 0.013 285.805);\n    --color-zinc-800: oklch(27.4% 0.006 286.033);\n    --color-zinc-900: oklch(21% 0.006 285.885);\n    --color-zinc-950: oklch(14.1% 0.005 285.823);\n\n    --color-neutral-50: oklch(98.5% 0 0);\n    --color-neutral-100: oklch(97% 0 0);\n    --color-neutral-200: oklch(92.2% 0 0);\n    --color-neutral-300: oklch(87% 0 0);\n    --color-neutral-400: oklch(70.8% 0 0);\n    --color-neutral-500: oklch(55.6% 0 0);\n    --color-neutral-600: oklch(43.9% 0 0);\n    --color-neutral-700: oklch(37.1% 0 0);\n    --color-neutral-800: oklch(26.9% 0 0);\n    --color-neutral-900: oklch(20.5% 0 0);\n    --color-neutral-950: oklch(14.5% 0 0);\n\n    --color-stone-50: oklch(98.5% 0.001 106.423);\n    --color-stone-100: oklch(97% 0.001 106.424);\n    --color-stone-200: oklch(92.3% 0.003 48.717);\n    --color-stone-300: oklch(86.9% 0.005 56.366);\n    --color-stone-400: oklch(70.9% 0.01 56.259);\n    --color-stone-500: oklch(55.3% 0.013 58.071);\n    --color-stone-600: oklch(44.4% 0.011 73.639);\n    --color-stone-700: oklch(37.4% 0.01 67.558);\n    --color-stone-800: oklch(26.8% 0.007 34.298);\n    --color-stone-900: oklch(21.6% 0.006 56.043);\n    --color-stone-950: oklch(14.7% 0.004 49.25);\n\n    --color-black: #000;\n    --color-white: #fff;\n\n    --spacing: 0.25rem;\n\n    --breakpoint-sm: 40rem;\n    --breakpoint-md: 48rem;\n    --breakpoint-lg: 64rem;\n    --breakpoint-xl: 80rem;\n    --breakpoint-2xl: 96rem;\n\n    --container-3xs: 16rem;\n    --container-2xs: 18rem;\n    --container-xs: 20rem;\n    --container-sm: 24rem;\n    --container-md: 28rem;\n    --container-lg: 32rem;\n    --container-xl: 36rem;\n    --container-2xl: 42rem;\n    --container-3xl: 48rem;\n    --container-4xl: 56rem;\n    --container-5xl: 64rem;\n    --container-6xl: 72rem;\n    --container-7xl: 80rem;\n\n    --text-xs: 0.75rem;\n    --text-xs--line-height: calc(1 / 0.75);\n    --text-sm: 0.875rem;\n    --text-sm--line-height: calc(1.25 / 0.875);\n    --text-base: 1rem;\n    --text-base--line-height: calc(1.5 / 1);\n    --text-lg: 1.125rem;\n    --text-lg--line-height: calc(1.75 / 1.125);\n    --text-xl: 1.25rem;\n    --text-xl--line-height: calc(1.75 / 1.25);\n    --text-2xl: 1.5rem;\n    --text-2xl--line-height: calc(2 / 1.5);\n    --text-3xl: 1.875rem;\n    --text-3xl--line-height: calc(2.25 / 1.875);\n    --text-4xl: 2.25rem;\n    --text-4xl--line-height: calc(2.5 / 2.25);\n    --text-5xl: 3rem;\n    --text-5xl--line-height: 1;\n    --text-6xl: 3.75rem;\n    --text-6xl--line-height: 1;\n    --text-7xl: 4.5rem;\n    --text-7xl--line-height: 1;\n    --text-8xl: 6rem;\n    --text-8xl--line-height: 1;\n    --text-9xl: 8rem;\n    --text-9xl--line-height: 1;\n\n    --font-weight-thin: 100;\n    --font-weight-extralight: 200;\n    --font-weight-light: 300;\n    --font-weight-normal: 400;\n    --font-weight-medium: 500;\n    --font-weight-semibold: 600;\n    --font-weight-bold: 700;\n    --font-weight-extrabold: 800;\n    --font-weight-black: 900;\n\n    --tracking-tighter: -0.05em;\n    --tracking-tight: -0.025em;\n    --tracking-normal: 0em;\n    --tracking-wide: 0.025em;\n    --tracking-wider: 0.05em;\n    --tracking-widest: 0.1em;\n\n    --leading-tight: 1.25;\n    --leading-snug: 1.375;\n    --leading-normal: 1.5;\n    --leading-relaxed: 1.625;\n    --leading-loose: 2;\n\n    --radius-xs: 0.125rem;\n    --radius-sm: 0.25rem;\n    --radius-md: 0.375rem;\n    --radius-lg: 0.5rem;\n    --radius-xl: 0.75rem;\n    --radius-2xl: 1rem;\n    --radius-3xl: 1.5rem;\n    --radius-4xl: 2rem;\n\n    --shadow-2xs: 0 1px rgb(0 0 0 / 0.05);\n    --shadow-xs: 0 1px 2px 0 rgb(0 0 0 / 0.05);\n    --shadow-sm: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);\n    --shadow-md:\n      0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);\n    --shadow-lg:\n      0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);\n    --shadow-xl:\n      0 20px 25px -5px rgb(0 0 0 / 0.1), 0 8px 10px -6px rgb(0 0 0 / 0.1);\n    --shadow-2xl: 0 25px 50px -12px rgb(0 0 0 / 0.25);\n\n    --inset-shadow-2xs: inset 0 1px rgb(0 0 0 / 0.05);\n    --inset-shadow-xs: inset 0 1px 1px rgb(0 0 0 / 0.05);\n    --inset-shadow-sm: inset 0 2px 4px rgb(0 0 0 / 0.05);\n\n    --drop-shadow-xs: 0 1px 1px rgb(0 0 0 / 0.05);\n    --drop-shadow-sm: 0 1px 2px rgb(0 0 0 / 0.15);\n    --drop-shadow-md: 0 3px 3px rgb(0 0 0 / 0.12);\n    --drop-shadow-lg: 0 4px 4px rgb(0 0 0 / 0.15);\n    --drop-shadow-xl: 0 9px 7px rgb(0 0 0 / 0.1);\n    --drop-shadow-2xl: 0 25px 25px rgb(0 0 0 / 0.15);\n\n    --text-shadow-2xs: 0px 1px 0px rgb(0 0 0 / 0.15);\n    --text-shadow-xs: 0px 1px 1px rgb(0 0 0 / 0.2);\n    --text-shadow-sm:\n      0px 1px 0px rgb(0 0 0 / 0.075), 0px 1px 1px rgb(0 0 0 / 0.075),\n      0px 2px 2px rgb(0 0 0 / 0.075);\n    --text-shadow-md:\n      0px 1px 1px rgb(0 0 0 / 0.1), 0px 1px 2px rgb(0 0 0 / 0.1),\n      0px 2px 4px rgb(0 0 0 / 0.1);\n    --text-shadow-lg:\n      0px 1px 2px rgb(0 0 0 / 0.1), 0px 3px 2px rgb(0 0 0 / 0.1),\n      0px 4px 8px rgb(0 0 0 / 0.1);\n\n    --ease-in: cubic-bezier(0.4, 0, 1, 1);\n    --ease-out: cubic-bezier(0, 0, 0.2, 1);\n    --ease-in-out: cubic-bezier(0.4, 0, 0.2, 1);\n\n    --animate-spin: spin 1s linear infinite;\n    --animate-ping: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n    --animate-pulse: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n    --animate-bounce: bounce 1s infinite;\n\n    @keyframes spin {\n      to {\n        transform: rotate(360deg);\n      }\n    }\n\n    @keyframes ping {\n      75%,\n      100% {\n        transform: scale(2);\n        opacity: 0;\n      }\n    }\n\n    @keyframes pulse {\n      50% {\n        opacity: 0.5;\n      }\n    }\n\n    @keyframes bounce {\n      0%,\n      100% {\n        transform: translateY(-25%);\n        animation-timing-function: cubic-bezier(0.8, 0, 1, 1);\n      }\n\n      50% {\n        transform: none;\n        animation-timing-function: cubic-bezier(0, 0, 0.2, 1);\n      }\n    }\n\n    --blur-xs: 4px;\n    --blur-sm: 8px;\n    --blur-md: 12px;\n    --blur-lg: 16px;\n    --blur-xl: 24px;\n    --blur-2xl: 40px;\n    --blur-3xl: 64px;\n\n    --perspective-dramatic: 100px;\n    --perspective-near: 300px;\n    --perspective-normal: 500px;\n    --perspective-midrange: 800px;\n    --perspective-distant: 1200px;\n\n    --aspect-video: 16 / 9;\n\n    --default-transition-duration: 150ms;\n    --default-transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);\n    --default-font-family: --theme(--font-sans, initial);\n    --default-font-feature-settings: --theme(\n      --font-sans--font-feature-settings,\n      initial\n    );\n    --default-font-variation-settings: --theme(\n      --font-sans--font-variation-settings,\n      initial\n    );\n    --default-mono-font-family: --theme(--font-mono, initial);\n    --default-mono-font-feature-settings: --theme(\n      --font-mono--font-feature-settings,\n      initial\n    );\n    --default-mono-font-variation-settings: --theme(\n      --font-mono--font-variation-settings,\n      initial\n    );\n  }\n\n  /* Deprecated */\n  @theme default inline reference {\n    --blur: 8px;\n    --shadow: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);\n    --shadow-inner: inset 0 2px 4px 0 rgb(0 0 0 / 0.05);\n    --drop-shadow: 0 1px 2px rgb(0 0 0 / 0.1), 0 1px 1px rgb(0 0 0 / 0.06);\n    --radius: 0.25rem;\n    --max-width-prose: 65ch;\n  }\n}\n\n@layer base {\n  /*\n  1. Prevent padding and border from affecting element width. (https://github.com/mozdevs/cssremedy/issues/4)\n  2. Remove default margins and padding\n  3. Reset all borders.\n*/\n\n  *,\n  ::after,\n  ::before,\n  ::backdrop,\n  ::file-selector-button {\n    box-sizing: border-box; /* 1 */\n    margin: 0; /* 2 */\n    padding: 0; /* 2 */\n    border: 0 solid; /* 3 */\n  }\n\n  /*\n  1. Use a consistent sensible line-height in all browsers.\n  2. Prevent adjustments of font size after orientation changes in iOS.\n  3. Use a more readable tab size.\n  4. Use the user's configured `sans` font-family by default.\n  5. Use the user's configured `sans` font-feature-settings by default.\n  6. Use the user's configured `sans` font-variation-settings by default.\n  7. Disable tap highlights on iOS.\n*/\n\n  html,\n  :host {\n    line-height: 1.5; /* 1 */\n    -webkit-text-size-adjust: 100%; /* 2 */\n    tab-size: 4; /* 3 */\n    font-family: --theme(\n      --default-font-family,\n      ui-sans-serif,\n      system-ui,\n      sans-serif,\n      \"Apple Color Emoji\",\n      \"Segoe UI Emoji\",\n      \"Segoe UI Symbol\",\n      \"Noto Color Emoji\"\n    ); /* 4 */\n    font-feature-settings: --theme(\n      --default-font-feature-settings,\n      normal\n    ); /* 5 */\n    font-variation-settings: --theme(\n      --default-font-variation-settings,\n      normal\n    ); /* 6 */\n    -webkit-tap-highlight-color: transparent; /* 7 */\n  }\n\n  /*\n  1. Add the correct height in Firefox.\n  2. Correct the inheritance of border color in Firefox. (https://bugzilla.mozilla.org/show_bug.cgi?id=190655)\n  3. Reset the default border style to a 1px solid border.\n*/\n\n  hr {\n    height: 0; /* 1 */\n    color: inherit; /* 2 */\n    border-top-width: 1px; /* 3 */\n  }\n\n  /*\n  Add the correct text decoration in Chrome, Edge, and Safari.\n*/\n\n  abbr:where([title]) {\n    -webkit-text-decoration: underline dotted;\n    text-decoration: underline dotted;\n  }\n\n  /*\n  Remove the default font size and weight for headings.\n*/\n\n  h1,\n  h2,\n  h3,\n  h4,\n  h5,\n  h6 {\n    font-size: inherit;\n    font-weight: inherit;\n  }\n\n  /*\n  Reset links to optimize for opt-in styling instead of opt-out.\n*/\n\n  a {\n    color: inherit;\n    -webkit-text-decoration: inherit;\n    text-decoration: inherit;\n  }\n\n  /*\n  Add the correct font weight in Edge and Safari.\n*/\n\n  b,\n  strong {\n    font-weight: bolder;\n  }\n\n  /*\n  1. Use the user's configured `mono` font-family by default.\n  2. Use the user's configured `mono` font-feature-settings by default.\n  3. Use the user's configured `mono` font-variation-settings by default.\n  4. Correct the odd `em` font sizing in all browsers.\n*/\n\n  code,\n  kbd,\n  samp,\n  pre {\n    font-family: --theme(\n      --default-mono-font-family,\n      ui-monospace,\n      SFMono-Regular,\n      Menlo,\n      Monaco,\n      Consolas,\n      \"Liberation Mono\",\n      \"Courier New\",\n      monospace\n    ); /* 1 */\n    font-feature-settings: --theme(\n      --default-mono-font-feature-settings,\n      normal\n    ); /* 2 */\n    font-variation-settings: --theme(\n      --default-mono-font-variation-settings,\n      normal\n    ); /* 3 */\n    font-size: 1em; /* 4 */\n  }\n\n  /*\n  Add the correct font size in all browsers.\n*/\n\n  small {\n    font-size: 80%;\n  }\n\n  /*\n  Prevent `sub` and `sup` elements from affecting the line height in all browsers.\n*/\n\n  sub,\n  sup {\n    font-size: 75%;\n    line-height: 0;\n    position: relative;\n    vertical-align: baseline;\n  }\n\n  sub {\n    bottom: -0.25em;\n  }\n\n  sup {\n    top: -0.5em;\n  }\n\n  /*\n  1. Remove text indentation from table contents in Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=999088, https://bugs.webkit.org/show_bug.cgi?id=201297)\n  2. Correct table border color inheritance in all Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=935729, https://bugs.webkit.org/show_bug.cgi?id=195016)\n  3. Remove gaps between table borders by default.\n*/\n\n  table {\n    text-indent: 0; /* 1 */\n    border-color: inherit; /* 2 */\n    border-collapse: collapse; /* 3 */\n  }\n\n  /*\n  Use the modern Firefox focus style for all focusable elements.\n*/\n\n  :-moz-focusring {\n    outline: auto;\n  }\n\n  /*\n  Add the correct vertical alignment in Chrome and Firefox.\n*/\n\n  progress {\n    vertical-align: baseline;\n  }\n\n  /*\n  Add the correct display in Chrome and Safari.\n*/\n\n  summary {\n    display: list-item;\n  }\n\n  /*\n  Make lists unstyled by default.\n*/\n\n  ol,\n  ul,\n  menu {\n    list-style: none;\n  }\n\n  /*\n  1. Make replaced elements `display: block` by default. (https://github.com/mozdevs/cssremedy/issues/14)\n  2. Add `vertical-align: middle` to align replaced elements more sensibly by default. (https://github.com/jensimmons/cssremedy/issues/14#issuecomment-634934210)\n      This can trigger a poorly considered lint error in some tools but is included by design.\n*/\n\n  img,\n  svg,\n  video,\n  canvas,\n  audio,\n  iframe,\n  embed,\n  object {\n    display: block; /* 1 */\n    vertical-align: middle; /* 2 */\n  }\n\n  /*\n  Constrain images and videos to the parent width and preserve their intrinsic aspect ratio. (https://github.com/mozdevs/cssremedy/issues/14)\n*/\n\n  img,\n  video {\n    max-width: 100%;\n    height: auto;\n  }\n\n  /*\n  1. Inherit font styles in all browsers.\n  2. Remove border radius in all browsers.\n  3. Remove background color in all browsers.\n  4. Ensure consistent opacity for disabled states in all browsers.\n*/\n\n  button,\n  input,\n  select,\n  optgroup,\n  textarea,\n  ::file-selector-button {\n    font: inherit; /* 1 */\n    font-feature-settings: inherit; /* 1 */\n    font-variation-settings: inherit; /* 1 */\n    letter-spacing: inherit; /* 1 */\n    color: inherit; /* 1 */\n    border-radius: 0; /* 2 */\n    background-color: transparent; /* 3 */\n    opacity: 1; /* 4 */\n  }\n\n  /*\n  Restore default font weight.\n*/\n\n  :where(select:is([multiple], [size])) optgroup {\n    font-weight: bolder;\n  }\n\n  /*\n  Restore indentation.\n*/\n\n  :where(select:is([multiple], [size])) optgroup option {\n    padding-inline-start: 20px;\n  }\n\n  /*\n  Restore space after button.\n*/\n\n  ::file-selector-button {\n    margin-inline-end: 4px;\n  }\n\n  /*\n  Reset the default placeholder opacity in Firefox. (https://github.com/tailwindlabs/tailwindcss/issues/3300)\n*/\n\n  ::placeholder {\n    opacity: 1;\n  }\n\n  /*\n  Set the default placeholder color to a semi-transparent version of the current text color in browsers that do not\n  crash when using `color-mix(…)` with `currentcolor`. (https://github.com/tailwindlabs/tailwindcss/issues/17194)\n*/\n\n  @supports (not (-webkit-appearance: -apple-pay-button)) /* Not Safari */ or\n    (contain-intrinsic-size: 1px) /* Safari 17+ */ {\n    ::placeholder {\n      color: color-mix(in oklab, currentcolor 50%, transparent);\n    }\n  }\n\n  /*\n  Prevent resizing textareas horizontally by default.\n*/\n\n  textarea {\n    resize: vertical;\n  }\n\n  /*\n  Remove the inner padding in Chrome and Safari on macOS.\n*/\n\n  ::-webkit-search-decoration {\n    -webkit-appearance: none;\n  }\n\n  /*\n  1. Ensure date/time inputs have the same height when empty in iOS Safari.\n  2. Ensure text alignment can be changed on date/time inputs in iOS Safari.\n*/\n\n  ::-webkit-date-and-time-value {\n    min-height: 1lh; /* 1 */\n    text-align: inherit; /* 2 */\n  }\n\n  /*\n  Prevent height from changing on date/time inputs in macOS Safari when the input is set to `display: block`.\n*/\n\n  ::-webkit-datetime-edit {\n    display: inline-flex;\n  }\n\n  /*\n  Remove excess padding from pseudo-elements in date/time inputs to ensure consistent height across browsers.\n*/\n\n  ::-webkit-datetime-edit-fields-wrapper {\n    padding: 0;\n  }\n\n  ::-webkit-datetime-edit,\n  ::-webkit-datetime-edit-year-field,\n  ::-webkit-datetime-edit-month-field,\n  ::-webkit-datetime-edit-day-field,\n  ::-webkit-datetime-edit-hour-field,\n  ::-webkit-datetime-edit-minute-field,\n  ::-webkit-datetime-edit-second-field,\n  ::-webkit-datetime-edit-millisecond-field,\n  ::-webkit-datetime-edit-meridiem-field {\n    padding-block: 0;\n  }\n\n  /*\n  Center dropdown marker shown on inputs with paired `<datalist>`s in Chrome. (https://github.com/tailwindlabs/tailwindcss/issues/18499)\n*/\n\n  ::-webkit-calendar-picker-indicator {\n    line-height: 1;\n  }\n\n  /*\n  Remove the additional `:invalid` styles in Firefox. (https://github.com/mozilla/gecko-dev/blob/2f9eacd9d3d995c937b4251a5557d95d494c9be1/layout/style/res/forms.css#L728-L737)\n*/\n\n  :-moz-ui-invalid {\n    box-shadow: none;\n  }\n\n  /*\n  Correct the inability to style the border radius in iOS Safari.\n*/\n\n  button,\n  input:where([type=\"button\"], [type=\"reset\"], [type=\"submit\"]),\n  ::file-selector-button {\n    appearance: button;\n  }\n\n  /*\n  Correct the cursor style of increment and decrement buttons in Safari.\n*/\n\n  ::-webkit-inner-spin-button,\n  ::-webkit-outer-spin-button {\n    height: auto;\n  }\n\n  /*\n  Make elements with the HTML hidden attribute stay hidden by default.\n*/\n\n  [hidden]:where(:not([hidden=\"until-found\"])) {\n    display: none !important;\n  }\n}\n\n@layer utilities {\n  @tailwind utilities;\n}\n";
var preflight_default = "/*\n  1. Prevent padding and border from affecting element width. (https://github.com/mozdevs/cssremedy/issues/4)\n  2. Remove default margins and padding\n  3. Reset all borders.\n*/\n\n*,\n::after,\n::before,\n::backdrop,\n::file-selector-button {\n  box-sizing: border-box; /* 1 */\n  margin: 0; /* 2 */\n  padding: 0; /* 2 */\n  border: 0 solid; /* 3 */\n}\n\n/*\n  1. Use a consistent sensible line-height in all browsers.\n  2. Prevent adjustments of font size after orientation changes in iOS.\n  3. Use a more readable tab size.\n  4. Use the user's configured `sans` font-family by default.\n  5. Use the user's configured `sans` font-feature-settings by default.\n  6. Use the user's configured `sans` font-variation-settings by default.\n  7. Disable tap highlights on iOS.\n*/\n\nhtml,\n:host {\n  line-height: 1.5; /* 1 */\n  -webkit-text-size-adjust: 100%; /* 2 */\n  tab-size: 4; /* 3 */\n  font-family: --theme(\n    --default-font-family,\n    ui-sans-serif,\n    system-ui,\n    sans-serif,\n    'Apple Color Emoji',\n    'Segoe UI Emoji',\n    'Segoe UI Symbol',\n    'Noto Color Emoji'\n  ); /* 4 */\n  font-feature-settings: --theme(--default-font-feature-settings, normal); /* 5 */\n  font-variation-settings: --theme(--default-font-variation-settings, normal); /* 6 */\n  -webkit-tap-highlight-color: transparent; /* 7 */\n}\n\n/*\n  1. Add the correct height in Firefox.\n  2. Correct the inheritance of border color in Firefox. (https://bugzilla.mozilla.org/show_bug.cgi?id=190655)\n  3. Reset the default border style to a 1px solid border.\n*/\n\nhr {\n  height: 0; /* 1 */\n  color: inherit; /* 2 */\n  border-top-width: 1px; /* 3 */\n}\n\n/*\n  Add the correct text decoration in Chrome, Edge, and Safari.\n*/\n\nabbr:where([title]) {\n  -webkit-text-decoration: underline dotted;\n  text-decoration: underline dotted;\n}\n\n/*\n  Remove the default font size and weight for headings.\n*/\n\nh1,\nh2,\nh3,\nh4,\nh5,\nh6 {\n  font-size: inherit;\n  font-weight: inherit;\n}\n\n/*\n  Reset links to optimize for opt-in styling instead of opt-out.\n*/\n\na {\n  color: inherit;\n  -webkit-text-decoration: inherit;\n  text-decoration: inherit;\n}\n\n/*\n  Add the correct font weight in Edge and Safari.\n*/\n\nb,\nstrong {\n  font-weight: bolder;\n}\n\n/*\n  1. Use the user's configured `mono` font-family by default.\n  2. Use the user's configured `mono` font-feature-settings by default.\n  3. Use the user's configured `mono` font-variation-settings by default.\n  4. Correct the odd `em` font sizing in all browsers.\n*/\n\ncode,\nkbd,\nsamp,\npre {\n  font-family: --theme(\n    --default-mono-font-family,\n    ui-monospace,\n    SFMono-Regular,\n    Menlo,\n    Monaco,\n    Consolas,\n    'Liberation Mono',\n    'Courier New',\n    monospace\n  ); /* 1 */\n  font-feature-settings: --theme(--default-mono-font-feature-settings, normal); /* 2 */\n  font-variation-settings: --theme(--default-mono-font-variation-settings, normal); /* 3 */\n  font-size: 1em; /* 4 */\n}\n\n/*\n  Add the correct font size in all browsers.\n*/\n\nsmall {\n  font-size: 80%;\n}\n\n/*\n  Prevent `sub` and `sup` elements from affecting the line height in all browsers.\n*/\n\nsub,\nsup {\n  font-size: 75%;\n  line-height: 0;\n  position: relative;\n  vertical-align: baseline;\n}\n\nsub {\n  bottom: -0.25em;\n}\n\nsup {\n  top: -0.5em;\n}\n\n/*\n  1. Remove text indentation from table contents in Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=999088, https://bugs.webkit.org/show_bug.cgi?id=201297)\n  2. Correct table border color inheritance in all Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=935729, https://bugs.webkit.org/show_bug.cgi?id=195016)\n  3. Remove gaps between table borders by default.\n*/\n\ntable {\n  text-indent: 0; /* 1 */\n  border-color: inherit; /* 2 */\n  border-collapse: collapse; /* 3 */\n}\n\n/*\n  Use the modern Firefox focus style for all focusable elements.\n*/\n\n:-moz-focusring {\n  outline: auto;\n}\n\n/*\n  Add the correct vertical alignment in Chrome and Firefox.\n*/\n\nprogress {\n  vertical-align: baseline;\n}\n\n/*\n  Add the correct display in Chrome and Safari.\n*/\n\nsummary {\n  display: list-item;\n}\n\n/*\n  Make lists unstyled by default.\n*/\n\nol,\nul,\nmenu {\n  list-style: none;\n}\n\n/*\n  1. Make replaced elements `display: block` by default. (https://github.com/mozdevs/cssremedy/issues/14)\n  2. Add `vertical-align: middle` to align replaced elements more sensibly by default. (https://github.com/jensimmons/cssremedy/issues/14#issuecomment-634934210)\n      This can trigger a poorly considered lint error in some tools but is included by design.\n*/\n\nimg,\nsvg,\nvideo,\ncanvas,\naudio,\niframe,\nembed,\nobject {\n  display: block; /* 1 */\n  vertical-align: middle; /* 2 */\n}\n\n/*\n  Constrain images and videos to the parent width and preserve their intrinsic aspect ratio. (https://github.com/mozdevs/cssremedy/issues/14)\n*/\n\nimg,\nvideo {\n  max-width: 100%;\n  height: auto;\n}\n\n/*\n  1. Inherit font styles in all browsers.\n  2. Remove border radius in all browsers.\n  3. Remove background color in all browsers.\n  4. Ensure consistent opacity for disabled states in all browsers.\n*/\n\nbutton,\ninput,\nselect,\noptgroup,\ntextarea,\n::file-selector-button {\n  font: inherit; /* 1 */\n  font-feature-settings: inherit; /* 1 */\n  font-variation-settings: inherit; /* 1 */\n  letter-spacing: inherit; /* 1 */\n  color: inherit; /* 1 */\n  border-radius: 0; /* 2 */\n  background-color: transparent; /* 3 */\n  opacity: 1; /* 4 */\n}\n\n/*\n  Restore default font weight.\n*/\n\n:where(select:is([multiple], [size])) optgroup {\n  font-weight: bolder;\n}\n\n/*\n  Restore indentation.\n*/\n\n:where(select:is([multiple], [size])) optgroup option {\n  padding-inline-start: 20px;\n}\n\n/*\n  Restore space after button.\n*/\n\n::file-selector-button {\n  margin-inline-end: 4px;\n}\n\n/*\n  Reset the default placeholder opacity in Firefox. (https://github.com/tailwindlabs/tailwindcss/issues/3300)\n*/\n\n::placeholder {\n  opacity: 1;\n}\n\n/*\n  Set the default placeholder color to a semi-transparent version of the current text color in browsers that do not\n  crash when using `color-mix(…)` with `currentcolor`. (https://github.com/tailwindlabs/tailwindcss/issues/17194)\n*/\n\n@supports (not (-webkit-appearance: -apple-pay-button)) /* Not Safari */ or\n  (contain-intrinsic-size: 1px) /* Safari 17+ */ {\n  ::placeholder {\n    color: color-mix(in oklab, currentcolor 50%, transparent);\n  }\n}\n\n/*\n  Prevent resizing textareas horizontally by default.\n*/\n\ntextarea {\n  resize: vertical;\n}\n\n/*\n  Remove the inner padding in Chrome and Safari on macOS.\n*/\n\n::-webkit-search-decoration {\n  -webkit-appearance: none;\n}\n\n/*\n  1. Ensure date/time inputs have the same height when empty in iOS Safari.\n  2. Ensure text alignment can be changed on date/time inputs in iOS Safari.\n*/\n\n::-webkit-date-and-time-value {\n  min-height: 1lh; /* 1 */\n  text-align: inherit; /* 2 */\n}\n\n/*\n  Prevent height from changing on date/time inputs in macOS Safari when the input is set to `display: block`.\n*/\n\n::-webkit-datetime-edit {\n  display: inline-flex;\n}\n\n/*\n  Remove excess padding from pseudo-elements in date/time inputs to ensure consistent height across browsers.\n*/\n\n::-webkit-datetime-edit-fields-wrapper {\n  padding: 0;\n}\n\n::-webkit-datetime-edit,\n::-webkit-datetime-edit-year-field,\n::-webkit-datetime-edit-month-field,\n::-webkit-datetime-edit-day-field,\n::-webkit-datetime-edit-hour-field,\n::-webkit-datetime-edit-minute-field,\n::-webkit-datetime-edit-second-field,\n::-webkit-datetime-edit-millisecond-field,\n::-webkit-datetime-edit-meridiem-field {\n  padding-block: 0;\n}\n\n/*\n  Center dropdown marker shown on inputs with paired `<datalist>`s in Chrome. (https://github.com/tailwindlabs/tailwindcss/issues/18499)\n*/\n\n::-webkit-calendar-picker-indicator {\n  line-height: 1;\n}\n\n/*\n  Remove the additional `:invalid` styles in Firefox. (https://github.com/mozilla/gecko-dev/blob/2f9eacd9d3d995c937b4251a5557d95d494c9be1/layout/style/res/forms.css#L728-L737)\n*/\n\n:-moz-ui-invalid {\n  box-shadow: none;\n}\n\n/*\n  Correct the inability to style the border radius in iOS Safari.\n*/\n\nbutton,\ninput:where([type='button'], [type='reset'], [type='submit']),\n::file-selector-button {\n  appearance: button;\n}\n\n/*\n  Correct the cursor style of increment and decrement buttons in Safari.\n*/\n\n::-webkit-inner-spin-button,\n::-webkit-outer-spin-button {\n  height: auto;\n}\n\n/*\n  Make elements with the HTML hidden attribute stay hidden by default.\n*/\n\n[hidden]:where(:not([hidden='until-found'])) {\n  display: none !important;\n}\n";
var theme_default = "@theme default {\n  --font-sans:\n    ui-sans-serif, system-ui, sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol',\n    'Noto Color Emoji';\n  --font-serif: ui-serif, Georgia, Cambria, 'Times New Roman', Times, serif;\n  --font-mono:\n    ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, 'Liberation Mono', 'Courier New',\n    monospace;\n\n  --color-red-50: oklch(97.1% 0.013 17.38);\n  --color-red-100: oklch(93.6% 0.032 17.717);\n  --color-red-200: oklch(88.5% 0.062 18.334);\n  --color-red-300: oklch(80.8% 0.114 19.571);\n  --color-red-400: oklch(70.4% 0.191 22.216);\n  --color-red-500: oklch(63.7% 0.237 25.331);\n  --color-red-600: oklch(57.7% 0.245 27.325);\n  --color-red-700: oklch(50.5% 0.213 27.518);\n  --color-red-800: oklch(44.4% 0.177 26.899);\n  --color-red-900: oklch(39.6% 0.141 25.723);\n  --color-red-950: oklch(25.8% 0.092 26.042);\n\n  --color-orange-50: oklch(98% 0.016 73.684);\n  --color-orange-100: oklch(95.4% 0.038 75.164);\n  --color-orange-200: oklch(90.1% 0.076 70.697);\n  --color-orange-300: oklch(83.7% 0.128 66.29);\n  --color-orange-400: oklch(75% 0.183 55.934);\n  --color-orange-500: oklch(70.5% 0.213 47.604);\n  --color-orange-600: oklch(64.6% 0.222 41.116);\n  --color-orange-700: oklch(55.3% 0.195 38.402);\n  --color-orange-800: oklch(47% 0.157 37.304);\n  --color-orange-900: oklch(40.8% 0.123 38.172);\n  --color-orange-950: oklch(26.6% 0.079 36.259);\n\n  --color-amber-50: oklch(98.7% 0.022 95.277);\n  --color-amber-100: oklch(96.2% 0.059 95.617);\n  --color-amber-200: oklch(92.4% 0.12 95.746);\n  --color-amber-300: oklch(87.9% 0.169 91.605);\n  --color-amber-400: oklch(82.8% 0.189 84.429);\n  --color-amber-500: oklch(76.9% 0.188 70.08);\n  --color-amber-600: oklch(66.6% 0.179 58.318);\n  --color-amber-700: oklch(55.5% 0.163 48.998);\n  --color-amber-800: oklch(47.3% 0.137 46.201);\n  --color-amber-900: oklch(41.4% 0.112 45.904);\n  --color-amber-950: oklch(27.9% 0.077 45.635);\n\n  --color-yellow-50: oklch(98.7% 0.026 102.212);\n  --color-yellow-100: oklch(97.3% 0.071 103.193);\n  --color-yellow-200: oklch(94.5% 0.129 101.54);\n  --color-yellow-300: oklch(90.5% 0.182 98.111);\n  --color-yellow-400: oklch(85.2% 0.199 91.936);\n  --color-yellow-500: oklch(79.5% 0.184 86.047);\n  --color-yellow-600: oklch(68.1% 0.162 75.834);\n  --color-yellow-700: oklch(55.4% 0.135 66.442);\n  --color-yellow-800: oklch(47.6% 0.114 61.907);\n  --color-yellow-900: oklch(42.1% 0.095 57.708);\n  --color-yellow-950: oklch(28.6% 0.066 53.813);\n\n  --color-lime-50: oklch(98.6% 0.031 120.757);\n  --color-lime-100: oklch(96.7% 0.067 122.328);\n  --color-lime-200: oklch(93.8% 0.127 124.321);\n  --color-lime-300: oklch(89.7% 0.196 126.665);\n  --color-lime-400: oklch(84.1% 0.238 128.85);\n  --color-lime-500: oklch(76.8% 0.233 130.85);\n  --color-lime-600: oklch(64.8% 0.2 131.684);\n  --color-lime-700: oklch(53.2% 0.157 131.589);\n  --color-lime-800: oklch(45.3% 0.124 130.933);\n  --color-lime-900: oklch(40.5% 0.101 131.063);\n  --color-lime-950: oklch(27.4% 0.072 132.109);\n\n  --color-green-50: oklch(98.2% 0.018 155.826);\n  --color-green-100: oklch(96.2% 0.044 156.743);\n  --color-green-200: oklch(92.5% 0.084 155.995);\n  --color-green-300: oklch(87.1% 0.15 154.449);\n  --color-green-400: oklch(79.2% 0.209 151.711);\n  --color-green-500: oklch(72.3% 0.219 149.579);\n  --color-green-600: oklch(62.7% 0.194 149.214);\n  --color-green-700: oklch(52.7% 0.154 150.069);\n  --color-green-800: oklch(44.8% 0.119 151.328);\n  --color-green-900: oklch(39.3% 0.095 152.535);\n  --color-green-950: oklch(26.6% 0.065 152.934);\n\n  --color-emerald-50: oklch(97.9% 0.021 166.113);\n  --color-emerald-100: oklch(95% 0.052 163.051);\n  --color-emerald-200: oklch(90.5% 0.093 164.15);\n  --color-emerald-300: oklch(84.5% 0.143 164.978);\n  --color-emerald-400: oklch(76.5% 0.177 163.223);\n  --color-emerald-500: oklch(69.6% 0.17 162.48);\n  --color-emerald-600: oklch(59.6% 0.145 163.225);\n  --color-emerald-700: oklch(50.8% 0.118 165.612);\n  --color-emerald-800: oklch(43.2% 0.095 166.913);\n  --color-emerald-900: oklch(37.8% 0.077 168.94);\n  --color-emerald-950: oklch(26.2% 0.051 172.552);\n\n  --color-teal-50: oklch(98.4% 0.014 180.72);\n  --color-teal-100: oklch(95.3% 0.051 180.801);\n  --color-teal-200: oklch(91% 0.096 180.426);\n  --color-teal-300: oklch(85.5% 0.138 181.071);\n  --color-teal-400: oklch(77.7% 0.152 181.912);\n  --color-teal-500: oklch(70.4% 0.14 182.503);\n  --color-teal-600: oklch(60% 0.118 184.704);\n  --color-teal-700: oklch(51.1% 0.096 186.391);\n  --color-teal-800: oklch(43.7% 0.078 188.216);\n  --color-teal-900: oklch(38.6% 0.063 188.416);\n  --color-teal-950: oklch(27.7% 0.046 192.524);\n\n  --color-cyan-50: oklch(98.4% 0.019 200.873);\n  --color-cyan-100: oklch(95.6% 0.045 203.388);\n  --color-cyan-200: oklch(91.7% 0.08 205.041);\n  --color-cyan-300: oklch(86.5% 0.127 207.078);\n  --color-cyan-400: oklch(78.9% 0.154 211.53);\n  --color-cyan-500: oklch(71.5% 0.143 215.221);\n  --color-cyan-600: oklch(60.9% 0.126 221.723);\n  --color-cyan-700: oklch(52% 0.105 223.128);\n  --color-cyan-800: oklch(45% 0.085 224.283);\n  --color-cyan-900: oklch(39.8% 0.07 227.392);\n  --color-cyan-950: oklch(30.2% 0.056 229.695);\n\n  --color-sky-50: oklch(97.7% 0.013 236.62);\n  --color-sky-100: oklch(95.1% 0.026 236.824);\n  --color-sky-200: oklch(90.1% 0.058 230.902);\n  --color-sky-300: oklch(82.8% 0.111 230.318);\n  --color-sky-400: oklch(74.6% 0.16 232.661);\n  --color-sky-500: oklch(68.5% 0.169 237.323);\n  --color-sky-600: oklch(58.8% 0.158 241.966);\n  --color-sky-700: oklch(50% 0.134 242.749);\n  --color-sky-800: oklch(44.3% 0.11 240.79);\n  --color-sky-900: oklch(39.1% 0.09 240.876);\n  --color-sky-950: oklch(29.3% 0.066 243.157);\n\n  --color-blue-50: oklch(97% 0.014 254.604);\n  --color-blue-100: oklch(93.2% 0.032 255.585);\n  --color-blue-200: oklch(88.2% 0.059 254.128);\n  --color-blue-300: oklch(80.9% 0.105 251.813);\n  --color-blue-400: oklch(70.7% 0.165 254.624);\n  --color-blue-500: oklch(62.3% 0.214 259.815);\n  --color-blue-600: oklch(54.6% 0.245 262.881);\n  --color-blue-700: oklch(48.8% 0.243 264.376);\n  --color-blue-800: oklch(42.4% 0.199 265.638);\n  --color-blue-900: oklch(37.9% 0.146 265.522);\n  --color-blue-950: oklch(28.2% 0.091 267.935);\n\n  --color-indigo-50: oklch(96.2% 0.018 272.314);\n  --color-indigo-100: oklch(93% 0.034 272.788);\n  --color-indigo-200: oklch(87% 0.065 274.039);\n  --color-indigo-300: oklch(78.5% 0.115 274.713);\n  --color-indigo-400: oklch(67.3% 0.182 276.935);\n  --color-indigo-500: oklch(58.5% 0.233 277.117);\n  --color-indigo-600: oklch(51.1% 0.262 276.966);\n  --color-indigo-700: oklch(45.7% 0.24 277.023);\n  --color-indigo-800: oklch(39.8% 0.195 277.366);\n  --color-indigo-900: oklch(35.9% 0.144 278.697);\n  --color-indigo-950: oklch(25.7% 0.09 281.288);\n\n  --color-violet-50: oklch(96.9% 0.016 293.756);\n  --color-violet-100: oklch(94.3% 0.029 294.588);\n  --color-violet-200: oklch(89.4% 0.057 293.283);\n  --color-violet-300: oklch(81.1% 0.111 293.571);\n  --color-violet-400: oklch(70.2% 0.183 293.541);\n  --color-violet-500: oklch(60.6% 0.25 292.717);\n  --color-violet-600: oklch(54.1% 0.281 293.009);\n  --color-violet-700: oklch(49.1% 0.27 292.581);\n  --color-violet-800: oklch(43.2% 0.232 292.759);\n  --color-violet-900: oklch(38% 0.189 293.745);\n  --color-violet-950: oklch(28.3% 0.141 291.089);\n\n  --color-purple-50: oklch(97.7% 0.014 308.299);\n  --color-purple-100: oklch(94.6% 0.033 307.174);\n  --color-purple-200: oklch(90.2% 0.063 306.703);\n  --color-purple-300: oklch(82.7% 0.119 306.383);\n  --color-purple-400: oklch(71.4% 0.203 305.504);\n  --color-purple-500: oklch(62.7% 0.265 303.9);\n  --color-purple-600: oklch(55.8% 0.288 302.321);\n  --color-purple-700: oklch(49.6% 0.265 301.924);\n  --color-purple-800: oklch(43.8% 0.218 303.724);\n  --color-purple-900: oklch(38.1% 0.176 304.987);\n  --color-purple-950: oklch(29.1% 0.149 302.717);\n\n  --color-fuchsia-50: oklch(97.7% 0.017 320.058);\n  --color-fuchsia-100: oklch(95.2% 0.037 318.852);\n  --color-fuchsia-200: oklch(90.3% 0.076 319.62);\n  --color-fuchsia-300: oklch(83.3% 0.145 321.434);\n  --color-fuchsia-400: oklch(74% 0.238 322.16);\n  --color-fuchsia-500: oklch(66.7% 0.295 322.15);\n  --color-fuchsia-600: oklch(59.1% 0.293 322.896);\n  --color-fuchsia-700: oklch(51.8% 0.253 323.949);\n  --color-fuchsia-800: oklch(45.2% 0.211 324.591);\n  --color-fuchsia-900: oklch(40.1% 0.17 325.612);\n  --color-fuchsia-950: oklch(29.3% 0.136 325.661);\n\n  --color-pink-50: oklch(97.1% 0.014 343.198);\n  --color-pink-100: oklch(94.8% 0.028 342.258);\n  --color-pink-200: oklch(89.9% 0.061 343.231);\n  --color-pink-300: oklch(82.3% 0.12 346.018);\n  --color-pink-400: oklch(71.8% 0.202 349.761);\n  --color-pink-500: oklch(65.6% 0.241 354.308);\n  --color-pink-600: oklch(59.2% 0.249 0.584);\n  --color-pink-700: oklch(52.5% 0.223 3.958);\n  --color-pink-800: oklch(45.9% 0.187 3.815);\n  --color-pink-900: oklch(40.8% 0.153 2.432);\n  --color-pink-950: oklch(28.4% 0.109 3.907);\n\n  --color-rose-50: oklch(96.9% 0.015 12.422);\n  --color-rose-100: oklch(94.1% 0.03 12.58);\n  --color-rose-200: oklch(89.2% 0.058 10.001);\n  --color-rose-300: oklch(81% 0.117 11.638);\n  --color-rose-400: oklch(71.2% 0.194 13.428);\n  --color-rose-500: oklch(64.5% 0.246 16.439);\n  --color-rose-600: oklch(58.6% 0.253 17.585);\n  --color-rose-700: oklch(51.4% 0.222 16.935);\n  --color-rose-800: oklch(45.5% 0.188 13.697);\n  --color-rose-900: oklch(41% 0.159 10.272);\n  --color-rose-950: oklch(27.1% 0.105 12.094);\n\n  --color-slate-50: oklch(98.4% 0.003 247.858);\n  --color-slate-100: oklch(96.8% 0.007 247.896);\n  --color-slate-200: oklch(92.9% 0.013 255.508);\n  --color-slate-300: oklch(86.9% 0.022 252.894);\n  --color-slate-400: oklch(70.4% 0.04 256.788);\n  --color-slate-500: oklch(55.4% 0.046 257.417);\n  --color-slate-600: oklch(44.6% 0.043 257.281);\n  --color-slate-700: oklch(37.2% 0.044 257.287);\n  --color-slate-800: oklch(27.9% 0.041 260.031);\n  --color-slate-900: oklch(20.8% 0.042 265.755);\n  --color-slate-950: oklch(12.9% 0.042 264.695);\n\n  --color-gray-50: oklch(98.5% 0.002 247.839);\n  --color-gray-100: oklch(96.7% 0.003 264.542);\n  --color-gray-200: oklch(92.8% 0.006 264.531);\n  --color-gray-300: oklch(87.2% 0.01 258.338);\n  --color-gray-400: oklch(70.7% 0.022 261.325);\n  --color-gray-500: oklch(55.1% 0.027 264.364);\n  --color-gray-600: oklch(44.6% 0.03 256.802);\n  --color-gray-700: oklch(37.3% 0.034 259.733);\n  --color-gray-800: oklch(27.8% 0.033 256.848);\n  --color-gray-900: oklch(21% 0.034 264.665);\n  --color-gray-950: oklch(13% 0.028 261.692);\n\n  --color-zinc-50: oklch(98.5% 0 0);\n  --color-zinc-100: oklch(96.7% 0.001 286.375);\n  --color-zinc-200: oklch(92% 0.004 286.32);\n  --color-zinc-300: oklch(87.1% 0.006 286.286);\n  --color-zinc-400: oklch(70.5% 0.015 286.067);\n  --color-zinc-500: oklch(55.2% 0.016 285.938);\n  --color-zinc-600: oklch(44.2% 0.017 285.786);\n  --color-zinc-700: oklch(37% 0.013 285.805);\n  --color-zinc-800: oklch(27.4% 0.006 286.033);\n  --color-zinc-900: oklch(21% 0.006 285.885);\n  --color-zinc-950: oklch(14.1% 0.005 285.823);\n\n  --color-neutral-50: oklch(98.5% 0 0);\n  --color-neutral-100: oklch(97% 0 0);\n  --color-neutral-200: oklch(92.2% 0 0);\n  --color-neutral-300: oklch(87% 0 0);\n  --color-neutral-400: oklch(70.8% 0 0);\n  --color-neutral-500: oklch(55.6% 0 0);\n  --color-neutral-600: oklch(43.9% 0 0);\n  --color-neutral-700: oklch(37.1% 0 0);\n  --color-neutral-800: oklch(26.9% 0 0);\n  --color-neutral-900: oklch(20.5% 0 0);\n  --color-neutral-950: oklch(14.5% 0 0);\n\n  --color-stone-50: oklch(98.5% 0.001 106.423);\n  --color-stone-100: oklch(97% 0.001 106.424);\n  --color-stone-200: oklch(92.3% 0.003 48.717);\n  --color-stone-300: oklch(86.9% 0.005 56.366);\n  --color-stone-400: oklch(70.9% 0.01 56.259);\n  --color-stone-500: oklch(55.3% 0.013 58.071);\n  --color-stone-600: oklch(44.4% 0.011 73.639);\n  --color-stone-700: oklch(37.4% 0.01 67.558);\n  --color-stone-800: oklch(26.8% 0.007 34.298);\n  --color-stone-900: oklch(21.6% 0.006 56.043);\n  --color-stone-950: oklch(14.7% 0.004 49.25);\n\n  --color-black: #000;\n  --color-white: #fff;\n\n  --spacing: 0.25rem;\n\n  --breakpoint-sm: 40rem;\n  --breakpoint-md: 48rem;\n  --breakpoint-lg: 64rem;\n  --breakpoint-xl: 80rem;\n  --breakpoint-2xl: 96rem;\n\n  --container-3xs: 16rem;\n  --container-2xs: 18rem;\n  --container-xs: 20rem;\n  --container-sm: 24rem;\n  --container-md: 28rem;\n  --container-lg: 32rem;\n  --container-xl: 36rem;\n  --container-2xl: 42rem;\n  --container-3xl: 48rem;\n  --container-4xl: 56rem;\n  --container-5xl: 64rem;\n  --container-6xl: 72rem;\n  --container-7xl: 80rem;\n\n  --text-xs: 0.75rem;\n  --text-xs--line-height: calc(1 / 0.75);\n  --text-sm: 0.875rem;\n  --text-sm--line-height: calc(1.25 / 0.875);\n  --text-base: 1rem;\n  --text-base--line-height: calc(1.5 / 1);\n  --text-lg: 1.125rem;\n  --text-lg--line-height: calc(1.75 / 1.125);\n  --text-xl: 1.25rem;\n  --text-xl--line-height: calc(1.75 / 1.25);\n  --text-2xl: 1.5rem;\n  --text-2xl--line-height: calc(2 / 1.5);\n  --text-3xl: 1.875rem;\n  --text-3xl--line-height: calc(2.25 / 1.875);\n  --text-4xl: 2.25rem;\n  --text-4xl--line-height: calc(2.5 / 2.25);\n  --text-5xl: 3rem;\n  --text-5xl--line-height: 1;\n  --text-6xl: 3.75rem;\n  --text-6xl--line-height: 1;\n  --text-7xl: 4.5rem;\n  --text-7xl--line-height: 1;\n  --text-8xl: 6rem;\n  --text-8xl--line-height: 1;\n  --text-9xl: 8rem;\n  --text-9xl--line-height: 1;\n\n  --font-weight-thin: 100;\n  --font-weight-extralight: 200;\n  --font-weight-light: 300;\n  --font-weight-normal: 400;\n  --font-weight-medium: 500;\n  --font-weight-semibold: 600;\n  --font-weight-bold: 700;\n  --font-weight-extrabold: 800;\n  --font-weight-black: 900;\n\n  --tracking-tighter: -0.05em;\n  --tracking-tight: -0.025em;\n  --tracking-normal: 0em;\n  --tracking-wide: 0.025em;\n  --tracking-wider: 0.05em;\n  --tracking-widest: 0.1em;\n\n  --leading-tight: 1.25;\n  --leading-snug: 1.375;\n  --leading-normal: 1.5;\n  --leading-relaxed: 1.625;\n  --leading-loose: 2;\n\n  --radius-xs: 0.125rem;\n  --radius-sm: 0.25rem;\n  --radius-md: 0.375rem;\n  --radius-lg: 0.5rem;\n  --radius-xl: 0.75rem;\n  --radius-2xl: 1rem;\n  --radius-3xl: 1.5rem;\n  --radius-4xl: 2rem;\n\n  --shadow-2xs: 0 1px rgb(0 0 0 / 0.05);\n  --shadow-xs: 0 1px 2px 0 rgb(0 0 0 / 0.05);\n  --shadow-sm: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);\n  --shadow-md: 0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);\n  --shadow-lg: 0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);\n  --shadow-xl: 0 20px 25px -5px rgb(0 0 0 / 0.1), 0 8px 10px -6px rgb(0 0 0 / 0.1);\n  --shadow-2xl: 0 25px 50px -12px rgb(0 0 0 / 0.25);\n\n  --inset-shadow-2xs: inset 0 1px rgb(0 0 0 / 0.05);\n  --inset-shadow-xs: inset 0 1px 1px rgb(0 0 0 / 0.05);\n  --inset-shadow-sm: inset 0 2px 4px rgb(0 0 0 / 0.05);\n\n  --drop-shadow-xs: 0 1px 1px rgb(0 0 0 / 0.05);\n  --drop-shadow-sm: 0 1px 2px rgb(0 0 0 / 0.15);\n  --drop-shadow-md: 0 3px 3px rgb(0 0 0 / 0.12);\n  --drop-shadow-lg: 0 4px 4px rgb(0 0 0 / 0.15);\n  --drop-shadow-xl: 0 9px 7px rgb(0 0 0 / 0.1);\n  --drop-shadow-2xl: 0 25px 25px rgb(0 0 0 / 0.15);\n\n  --text-shadow-2xs: 0px 1px 0px rgb(0 0 0 / 0.15);\n  --text-shadow-xs: 0px 1px 1px rgb(0 0 0 / 0.2);\n  --text-shadow-sm:\n    0px 1px 0px rgb(0 0 0 / 0.075), 0px 1px 1px rgb(0 0 0 / 0.075), 0px 2px 2px rgb(0 0 0 / 0.075);\n  --text-shadow-md:\n    0px 1px 1px rgb(0 0 0 / 0.1), 0px 1px 2px rgb(0 0 0 / 0.1), 0px 2px 4px rgb(0 0 0 / 0.1);\n  --text-shadow-lg:\n    0px 1px 2px rgb(0 0 0 / 0.1), 0px 3px 2px rgb(0 0 0 / 0.1), 0px 4px 8px rgb(0 0 0 / 0.1);\n\n  --ease-in: cubic-bezier(0.4, 0, 1, 1);\n  --ease-out: cubic-bezier(0, 0, 0.2, 1);\n  --ease-in-out: cubic-bezier(0.4, 0, 0.2, 1);\n\n  --animate-spin: spin 1s linear infinite;\n  --animate-ping: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n  --animate-pulse: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n  --animate-bounce: bounce 1s infinite;\n\n  @keyframes spin {\n    to {\n      transform: rotate(360deg);\n    }\n  }\n\n  @keyframes ping {\n    75%,\n    100% {\n      transform: scale(2);\n      opacity: 0;\n    }\n  }\n\n  @keyframes pulse {\n    50% {\n      opacity: 0.5;\n    }\n  }\n\n  @keyframes bounce {\n    0%,\n    100% {\n      transform: translateY(-25%);\n      animation-timing-function: cubic-bezier(0.8, 0, 1, 1);\n    }\n\n    50% {\n      transform: none;\n      animation-timing-function: cubic-bezier(0, 0, 0.2, 1);\n    }\n  }\n\n  --blur-xs: 4px;\n  --blur-sm: 8px;\n  --blur-md: 12px;\n  --blur-lg: 16px;\n  --blur-xl: 24px;\n  --blur-2xl: 40px;\n  --blur-3xl: 64px;\n\n  --perspective-dramatic: 100px;\n  --perspective-near: 300px;\n  --perspective-normal: 500px;\n  --perspective-midrange: 800px;\n  --perspective-distant: 1200px;\n\n  --aspect-video: 16 / 9;\n\n  --default-transition-duration: 150ms;\n  --default-transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);\n  --default-font-family: --theme(--font-sans, initial);\n  --default-font-feature-settings: --theme(--font-sans--font-feature-settings, initial);\n  --default-font-variation-settings: --theme(--font-sans--font-variation-settings, initial);\n  --default-mono-font-family: --theme(--font-mono, initial);\n  --default-mono-font-feature-settings: --theme(--font-mono--font-feature-settings, initial);\n  --default-mono-font-variation-settings: --theme(--font-mono--font-variation-settings, initial);\n}\n\n/* Deprecated */\n@theme default inline reference {\n  --blur: 8px;\n  --shadow: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);\n  --shadow-inner: inset 0 2px 4px 0 rgb(0 0 0 / 0.05);\n  --drop-shadow: 0 1px 2px rgb(0 0 0 / 0.1), 0 1px 1px rgb(0 0 0 / 0.06);\n  --radius: 0.25rem;\n  --max-width-prose: 65ch;\n}\n";
var utilities_default = "@tailwind utilities;\n";
const assets = {
	tailwindcss: tailwindcss_default,
	"tailwindcss/index": tailwindcss_default,
	"tailwindcss/index.css": tailwindcss_default,
	"tailwindcss/preflight": preflight_default,
	"tailwindcss/preflight.css": preflight_default,
	"tailwindcss/theme": theme_default,
	"tailwindcss/theme.css": theme_default,
	"tailwindcss/utilities": utilities_default,
	"tailwindcss/utilities.css": utilities_default
};
async function loadV4(mod, stylesheet) {
	let isFallback = false;
	if (!mod || !mod.__unstable__loadDesignSystem) {
		mod = lib_exports;
		isFallback = true;
	}
	let jiti = createJiti(import.meta.url, {
		moduleCache: false,
		fsCache: false
	});
	let css;
	let importBasePath;
	if (stylesheet) {
		css = await fs.readFile(stylesheet, "utf-8");
		importBasePath = path.dirname(stylesheet);
	} else {
		importBasePath = process.cwd();
		stylesheet = path.join(importBasePath, "fake.css");
		css = assets["tailwindcss/theme.css"];
	}
	let design = await mod.__unstable__loadDesignSystem(css, {
		base: importBasePath,
		loadModule: createLoader({
			legacy: false,
			jiti,
			filepath: stylesheet,
			onError: (id, err, resourceType) => {
				console.error(`Unable to load ${resourceType}: ${id}`, err);
				if (resourceType === "config") return {};
				else if (resourceType === "plugin") return () => {};
			}
		}),
		loadStylesheet: async (id, base) => {
			try {
				let resolved = resolveCssFrom(base, id);
				return {
					base: path.dirname(resolved),
					content: await fs.readFile(resolved, "utf-8")
				};
			} catch (err) {
				if (isFallback && id in assets) return {
					base,
					content: assets[id]
				};
				throw err;
			}
		},
		loadPlugin: createLoader({
			legacy: true,
			jiti,
			filepath: stylesheet,
			onError(id, err) {
				console.error(`Unable to load plugin: ${id}`, err);
				return () => {};
			}
		}),
		loadConfig: createLoader({
			legacy: true,
			jiti,
			filepath: stylesheet,
			onError(id, err) {
				console.error(`Unable to load config: ${id}`, err);
				return {};
			}
		})
	});
	return { getClassOrder: (classList) => {
		return design.getClassOrder(classList);
	} };
}
function createLoader({ legacy, jiti, filepath, onError }) {
	let cacheKey = `${+Date.now()}`;
	async function loadFile(id, base, resourceType) {
		try {
			let url = pathToFileURL(resolveJsFrom(base, id));
			url.searchParams.append("t", cacheKey);
			return await jiti.import(url.href, { default: true });
		} catch (err) {
			return onError(id, err, resourceType);
		}
	}
	if (legacy) {
		let baseDir = path.dirname(filepath);
		return (id) => loadFile(id, baseDir, "module");
	}
	return async (id, base, resourceType) => {
		return {
			base,
			module: await loadFile(id, base, resourceType)
		};
	};
}
//#endregion
export { loadV4 };
