//#region ../../node_modules/.pnpm/prettier@3.8.2/node_modules/prettier/plugins/typescript.mjs
var ty = Object.defineProperty;
var hd = (e, t) => {
	for (var a in t) ty(e, a, {
		get: t[a],
		enumerable: !0
	});
};
var I0 = {};
hd(I0, { parsers: () => ld });
var ld = {};
hd(ld, { typescript: () => Y4 });
var ny = () => () => {}, Na = ny;
var Ia = (e, t) => (a, _, ...f) => a | 1 && _ == null ? void 0 : (t.call(_) ?? _[e]).apply(_, f);
var ry = String.prototype.replaceAll ?? function(e, t) {
	return e.global ? this.replace(e, t) : this.split(e).join(t);
}, Wr = Ia("replaceAll", function() {
	if (typeof this == "string") return ry;
});
var gm = "5.9";
var vt = [], ay = /* @__PURE__ */ new Map();
function e_(e) {
	return e !== void 0 ? e.length : 0;
}
function jn(e, t) {
	if (e !== void 0) for (let a = 0; a < e.length; a++) {
		let _ = t(e[a], a);
		if (_) return _;
	}
}
function sy(e, t) {
	if (e !== void 0) for (let a = 0; a < e.length; a++) {
		let _ = t(e[a], a);
		if (_ !== void 0) return _;
	}
}
function yd(e, t, a) {
	let _ = [];
	q.assertEqual(e.length, t.length);
	for (let f = 0; f < e.length; f++) _.push(a(e[f], t[f], f));
	return _;
}
function Gp(e, t) {
	if (e !== void 0) {
		for (let a = 0; a < e.length; a++) if (!t(e[a], a)) return !1;
	}
	return !0;
}
function bm(e, t, a) {
	if (e !== void 0) for (let _ = a ?? 0; _ < e.length; _++) {
		let f = e[_];
		if (t(f, _)) return f;
	}
}
function gp(e, t, a) {
	if (e === void 0) return -1;
	for (let _ = a ?? 0; _ < e.length; _++) if (t(e[_], _)) return _;
	return -1;
}
function _y(e, t, a = Xp) {
	if (e !== void 0) {
		for (let _ = 0; _ < e.length; _++) if (a(e[_], t)) return !0;
	}
	return !1;
}
function Hr(e, t) {
	if (e !== void 0) {
		let a = e.length, _ = 0;
		for (; _ < a && t(e[_]);) _++;
		if (_ < a) {
			let f = e.slice(0, _);
			for (_++; _ < a;) {
				let h = e[_];
				t(h) && f.push(h), _++;
			}
			return f;
		}
	}
	return e;
}
function Pp(e, t) {
	let a;
	if (e !== void 0) {
		a = [];
		for (let _ = 0; _ < e.length; _++) a.push(t(e[_], _));
	}
	return a;
}
function vm(e) {
	let t = [];
	for (let a = 0; a < e.length; a++) {
		let _ = e[a];
		_ && ($r(_) ? En(t, _) : t.push(_));
	}
	return t;
}
function Tm(e, t) {
	let a;
	if (e !== void 0) for (let _ = 0; _ < e.length; _++) {
		let f = t(e[_], _);
		f && ($r(f) ? a = En(a, f) : a = wn(a, f));
	}
	return a ?? vt;
}
function oy(e, t) {
	let a;
	if (e !== void 0) for (let _ = 0; _ < e.length; _++) {
		let f = e[_], h = t(f, _);
		(a || f !== h || $r(h)) && (a || (a = e.slice(0, _)), $r(h) ? En(a, h) : a.push(h));
	}
	return a ?? e;
}
function cy(e, t) {
	let a = [];
	if (e !== void 0) for (let _ = 0; _ < e.length; _++) {
		let f = t(e[_], _);
		f !== void 0 && a.push(f);
	}
	return a;
}
function Zt(e, t) {
	if (e !== void 0) if (t !== void 0) {
		for (let a = 0; a < e.length; a++) if (t(e[a])) return !0;
	} else return e.length > 0;
	return !1;
}
function Yp(e, t) {
	return t === void 0 || t.length === 0 ? e : e === void 0 || e.length === 0 ? t : [...e, ...t];
}
function ly(e, t, a = Xp) {
	if (e === void 0 || t === void 0) return e === t;
	if (e.length !== t.length) return !1;
	for (let _ = 0; _ < e.length; _++) if (!a(e[_], t[_], _)) return !1;
	return !0;
}
function wn(e, t) {
	return t === void 0 ? e : e === void 0 ? [t] : (e.push(t), e);
}
function Np(e, t) {
	return t < 0 ? e.length + t : t;
}
function En(e, t, a, _) {
	if (t === void 0 || t.length === 0) return e;
	if (e === void 0) return t.slice(a, _);
	a = a === void 0 ? 0 : Np(t, a), _ = _ === void 0 ? t.length : Np(t, _);
	for (let f = a; f < _ && f < t.length; f++) t[f] !== void 0 && e.push(t[f]);
	return e;
}
function uy(e, t, a) {
	return _y(e, t, a) ? !1 : (e.push(t), !0);
}
function py(e, t, a) {
	return e !== void 0 ? (uy(e, t, a), e) : [t];
}
function fy(e, t) {
	return e.length === 0 ? vt : e.slice().sort(t);
}
Array.prototype.at;
function Hp(e) {
	return e === void 0 || e.length === 0 ? void 0 : e[0];
}
function Ba(e) {
	return e === void 0 || e.length === 0 ? void 0 : e[e.length - 1];
}
function dy(e) {
	return q.assert(e.length !== 0), e[e.length - 1];
}
function my(e) {
	return e !== void 0 && e.length === 1 ? e[0] : void 0;
}
function hy(e, t, a, _, f) {
	return yy(e, a(t), a, _, f);
}
function yy(e, t, a, _, f) {
	if (!Zt(e)) return -1;
	let h = f ?? 0, T = e.length - 1;
	for (; h <= T;) {
		let k = h + (T - h >> 1);
		switch (_(a(e[k], k), t)) {
			case -1:
				h = k + 1;
				break;
			case 0: return k;
			case 1:
				T = k - 1;
				break;
		}
	}
	return ~h;
}
function gy(e, t, a, _, f) {
	if (e && e.length > 0) {
		let h = e.length;
		if (h > 0) {
			let T = _ === void 0 || _ < 0 ? 0 : _, k = f === void 0 || T + f > h - 1 ? h - 1 : T + f, c;
			for (arguments.length <= 2 ? (c = e[T], T++) : c = a; T <= k;) c = t(c, e[T], T), T++;
			return c;
		}
	}
	return a;
}
var xm = Object.prototype.hasOwnProperty;
function Dr(e, t) {
	return xm.call(e, t);
}
function by(e) {
	let t = [];
	for (let a in e) xm.call(e, a) && t.push(a);
	return t;
}
function vy() {
	let e = /* @__PURE__ */ new Map();
	return e.add = Ty, e.remove = xy, e;
}
function Ty(e, t) {
	let a = this.get(e);
	return a !== void 0 ? a.push(t) : this.set(e, a = [t]), a;
}
function xy(e, t) {
	let a = this.get(e);
	a !== void 0 && (Ny(a, t), a.length || this.delete(e));
}
function $r(e) {
	return Array.isArray(e);
}
function bp(e) {
	return $r(e) ? e : [e];
}
function Sy(e, t) {
	return e !== void 0 && t(e) ? e : void 0;
}
function Er(e, t) {
	return e !== void 0 && t(e) ? e : q.fail(`Invalid cast. The supplied value ${e} did not pass the test '${q.getFunctionName(t)}'.`);
}
function Va(e) {}
function wy() {
	return !0;
}
function bt(e) {
	return e;
}
function gd(e) {
	let t;
	return () => (e && (t = e(), e = void 0), t);
}
function Kn(e) {
	let t = /* @__PURE__ */ new Map();
	return (a) => {
		let _ = `${typeof a}:${a}`, f = t.get(_);
		return f === void 0 && !t.has(_) && (f = e(a), t.set(_, f)), f;
	};
}
function Xp(e, t) {
	return e === t;
}
function $p(e, t) {
	return e === t || e !== void 0 && t !== void 0 && e.toUpperCase() === t.toUpperCase();
}
function ky(e, t) {
	return Xp(e, t);
}
function Ey(e, t) {
	return e === t ? 0 : e === void 0 ? -1 : t === void 0 ? 1 : e < t ? -1 : 1;
}
function Sm(e, t) {
	return Ey(e, t);
}
function Ay(e, t, a) {
	for (let _ = 0; _ < e.length; _++) t = Math.max(t, a(e[_]));
	return t;
}
function t_(e, t, a) {
	let _ = Math.max(2, Math.floor(e.length * .34)), f = Math.floor(e.length * .4) + 1, h;
	for (let T of t) {
		let k = a(T);
		if (k !== void 0 && Math.abs(k.length - e.length) <= _) {
			if (k === e || k.length < 3 && k.toLowerCase() !== e.toLowerCase()) continue;
			let c = Cy(e, k, f - .1);
			if (c === void 0) continue;
			q.assert(c < f), f = c, h = T;
		}
	}
	return h;
}
function Cy(e, t, a) {
	let _ = new Array(t.length + 1), f = new Array(t.length + 1), h = a + .01;
	for (let k = 0; k <= t.length; k++) _[k] = k;
	for (let k = 1; k <= e.length; k++) {
		let c = e.charCodeAt(k - 1), W = Math.ceil(k > a ? k - a : 1), y = Math.floor(t.length > a + k ? a + k : t.length);
		f[0] = k;
		let G = k;
		for (let D = 1; D < W; D++) f[D] = h;
		for (let D = W; D <= y; D++) {
			let R = e[k - 1].toLowerCase() === t[D - 1].toLowerCase() ? _[D - 1] + .1 : _[D - 1] + 2, ue = c === t.charCodeAt(D - 1) ? _[D - 1] : Math.min(_[D] + 1, f[D - 1] + 1, R);
			f[D] = ue, G = Math.min(G, ue);
		}
		for (let D = y + 1; D <= t.length; D++) f[D] = h;
		if (G > a) return;
		let E = _;
		_ = f, f = E;
	}
	let T = _[t.length];
	return T > a ? void 0 : T;
}
function Dy(e, t, a) {
	let _ = e.length - t.length;
	return _ >= 0 && (a ? $p(e.slice(_), t) : e.indexOf(t, _) === _);
}
function Py(e, t) {
	e[t] = e[e.length - 1], e.pop();
}
function Ny(e, t) {
	return Iy(e, (a) => a === t);
}
function Iy(e, t) {
	for (let a = 0; a < e.length; a++) if (t(e[a])) return Py(e, a), !0;
	return !1;
}
function ml(e, t, a) {
	return a ? $p(e.slice(0, t.length), t) : e.lastIndexOf(t, 0) === 0;
}
function Ip(e) {
	return e === void 0 ? void 0 : [e];
}
var q;
((e) => {
	let t = 0;
	e.currentLogLevel = 2, e.isDebugging = !1;
	function a(L) {
		return e.currentLogLevel <= L;
	}
	e.shouldLog = a;
	function _(L, se) {
		e.loggingHost && a(L) && e.loggingHost.log(L, se);
	}
	function f(L) {
		_(3, L);
	}
	e.log = f, ((L) => {
		function se(Qe) {
			_(1, Qe);
		}
		L.error = se;
		function fe(Qe) {
			_(2, Qe);
		}
		L.warn = fe;
		function Te(Qe) {
			_(3, Qe);
		}
		L.log = Te;
		function He(Qe) {
			_(4, Qe);
		}
		L.trace = He;
	})(f = e.log || (e.log = {}));
	let h = {};
	function T() {
		return t;
	}
	e.getAssertionLevel = T;
	function k(L) {
		let se = t;
		if (t = L, L > se) for (let fe of by(h)) {
			let Te = h[fe];
			Te !== void 0 && e[fe] !== Te.assertion && L >= Te.level && (e[fe] = Te, h[fe] = void 0);
		}
	}
	e.setAssertionLevel = k;
	function c(L) {
		return t >= L;
	}
	e.shouldAssert = c;
	function W(L, se) {
		return c(L) ? !0 : (h[se] = {
			level: L,
			assertion: e[se]
		}, e[se] = Va, !1);
	}
	function y(L, se) {
		debugger;
		let fe = /* @__PURE__ */ new Error(L ? `Debug Failure. ${L}` : "Debug Failure.");
		throw Error.captureStackTrace && Error.captureStackTrace(fe, se || y), fe;
	}
	e.fail = y;
	function G(L, se, fe) {
		return y(`${se || "Unexpected node."}\r
Node ${Ot(L.kind)} was unexpected.`, fe || G);
	}
	e.failBadSyntaxKind = G;
	function E(L, se, fe, Te) {
		L || (se = se ? `False expression: ${se}` : "False expression.", fe && (se += `\r
Verbose Debug Information: ` + (typeof fe == "string" ? fe : fe())), y(se, Te || E));
	}
	e.assert = E;
	function D(L, se, fe, Te, He) {
		if (L !== se) y(`Expected ${L} === ${se}. ${fe ? Te ? `${fe} ${Te}` : fe : ""}`, He || D);
	}
	e.assertEqual = D;
	function R(L, se, fe, Te) {
		L >= se && y(`Expected ${L} < ${se}. ${fe || ""}`, Te || R);
	}
	e.assertLessThan = R;
	function ue(L, se, fe) {
		L > se && y(`Expected ${L} <= ${se}`, fe || ue);
	}
	e.assertLessThanOrEqual = ue;
	function be(L, se, fe) {
		L < se && y(`Expected ${L} >= ${se}`, fe || be);
	}
	e.assertGreaterThanOrEqual = be;
	function he(L, se, fe) {
		L ?? y(se, fe || he);
	}
	e.assertIsDefined = he;
	function de(L, se, fe) {
		return he(L, se, fe || de), L;
	}
	e.checkDefined = de;
	function O(L, se, fe) {
		for (let Te of L) he(Te, se, fe || O);
	}
	e.assertEachIsDefined = O;
	function ae(L, se, fe) {
		return O(L, se, fe || ae), L;
	}
	e.checkEachDefined = ae;
	function Oe(L, se = "Illegal value:", fe) {
		return y(`${se} ${typeof L == "object" && Dr(L, "kind") && Dr(L, "pos") ? "SyntaxKind: " + Ot(L.kind) : JSON.stringify(L)}`, fe || Oe);
	}
	e.assertNever = Oe;
	function V(L, se, fe, Te) {
		W(1, "assertEachNode") && E(se === void 0 || Gp(L, se), fe || "Unexpected node.", () => `Node array did not pass test '${hn(se)}'.`, Te || V);
	}
	e.assertEachNode = V;
	function oe(L, se, fe, Te) {
		W(1, "assertNode") && E(L !== void 0 && (se === void 0 || se(L)), fe || "Unexpected node.", () => `Node ${Ot(L?.kind)} did not pass test '${hn(se)}'.`, Te || oe);
	}
	e.assertNode = oe;
	function Y(L, se, fe, Te) {
		W(1, "assertNotNode") && E(L === void 0 || se === void 0 || !se(L), fe || "Unexpected node.", () => `Node ${Ot(L.kind)} should not have passed test '${hn(se)}'.`, Te || Y);
	}
	e.assertNotNode = Y;
	function ft(L, se, fe, Te) {
		W(1, "assertOptionalNode") && E(se === void 0 || L === void 0 || se(L), fe || "Unexpected node.", () => `Node ${Ot(L?.kind)} did not pass test '${hn(se)}'.`, Te || ft);
	}
	e.assertOptionalNode = ft;
	function nr(L, se, fe, Te) {
		W(1, "assertOptionalToken") && E(se === void 0 || L === void 0 || L.kind === se, fe || "Unexpected node.", () => `Node ${Ot(L?.kind)} was not a '${Ot(se)}' token.`, Te || nr);
	}
	e.assertOptionalToken = nr;
	function mn(L, se, fe) {
		W(1, "assertMissingNode") && E(L === void 0, se || "Unexpected node.", () => `Node ${Ot(L.kind)} was unexpected'.`, fe || mn);
	}
	e.assertMissingNode = mn;
	function rr(L) {}
	e.type = rr;
	function hn(L) {
		if (typeof L != "function") return "";
		if (Dr(L, "name")) return L.name;
		{
			let se = Function.prototype.toString.call(L), fe = /^function\s+([\w$]+)\s*\(/.exec(se);
			return fe ? fe[1] : "";
		}
	}
	e.getFunctionName = hn;
	function Dn(L) {
		return `{ name: ${l_(L.escapedName)}; flags: ${ot(L.flags)}; declarations: ${Pp(L.declarations, (se) => Ot(se.kind))} }`;
	}
	e.formatSymbol = Dn;
	function We(L = 0, se, fe) {
		let Te = Ir(se);
		if (L === 0) return Te.length > 0 && Te[0][0] === 0 ? Te[0][1] : "0";
		if (fe) {
			let He = [], Qe = L;
			for (let [st, Ct] of Te) {
				if (st > L) break;
				st !== 0 && st & L && (He.push(Ct), Qe &= ~st);
			}
			if (Qe === 0) return He.join("|");
		} else for (let [He, Qe] of Te) if (He === L) return Qe;
		return L.toString();
	}
	e.formatEnum = We;
	let ir = /* @__PURE__ */ new Map();
	function Ir(L) {
		let se = ir.get(L);
		if (se) return se;
		let fe = [];
		for (let He in L) {
			let Qe = L[He];
			typeof Qe == "number" && fe.push([Qe, He]);
		}
		let Te = fy(fe, (He, Qe) => Sm(He[0], Qe[0]));
		return ir.set(L, Te), Te;
	}
	function Ot(L) {
		return We(L, Ae, !1);
	}
	e.formatSyntaxKind = Ot;
	function Bn(L) {
		return We(L, Cm, !1);
	}
	e.formatSnippetKind = Bn;
	function Pn(L) {
		return We(L, Pr, !1);
	}
	e.formatScriptKind = Pn;
	function Mt(L) {
		return We(L, sn, !0);
	}
	e.formatNodeFlags = Mt;
	function ht(L) {
		return We(L, km, !0);
	}
	e.formatNodeCheckFlags = ht;
	function $e(L) {
		return We(L, Qp, !0);
	}
	e.formatModifierFlags = $e;
	function qn(L) {
		return We(L, Am, !0);
	}
	e.formatTransformFlags = qn;
	function $t(L) {
		return We(L, Dm, !0);
	}
	e.formatEmitFlags = $t;
	function ot(L) {
		return We(L, Kp, !0);
	}
	e.formatSymbolFlags = ot;
	function at(L) {
		return We(L, en, !0);
	}
	e.formatTypeFlags = at;
	function Bt(L) {
		return We(L, Em, !0);
	}
	e.formatSignatureFlags = Bt;
	function Lt(L) {
		return We(L, Zp, !0);
	}
	e.formatObjectFlags = Lt;
	function ct(L) {
		return We(L, Op, !0);
	}
	e.formatFlowFlags = ct;
	function ar(L) {
		return We(L, wm, !0);
	}
	e.formatRelationComparisonResult = ar;
	function dt(L) {
		return We(L, CheckMode, !0);
	}
	e.formatCheckMode = dt;
	function yn(L) {
		return We(L, SignatureCheckMode, !0);
	}
	e.formatSignatureCheckMode = yn;
	function yt(L) {
		return We(L, TypeFacts, !0);
	}
	e.formatTypeFacts = yt;
	let _n = !1, tt;
	function qt(L) {
		"__debugFlowFlags" in L || Object.defineProperties(L, {
			__tsDebuggerDisplay: { value() {
				let se = this.flags & 2 ? "FlowStart" : this.flags & 4 ? "FlowBranchLabel" : this.flags & 8 ? "FlowLoopLabel" : this.flags & 16 ? "FlowAssignment" : this.flags & 32 ? "FlowTrueCondition" : this.flags & 64 ? "FlowFalseCondition" : this.flags & 128 ? "FlowSwitchClause" : this.flags & 256 ? "FlowArrayMutation" : this.flags & 512 ? "FlowCall" : this.flags & 1024 ? "FlowReduceLabel" : this.flags & 1 ? "FlowUnreachable" : "UnknownFlow", fe = this.flags & -2048;
				return `${se}${fe ? ` (${ct(fe)})` : ""}`;
			} },
			__debugFlowFlags: { get() {
				return We(this.flags, Op, !0);
			} },
			__debugToString: { value() {
				return yr(this);
			} }
		});
	}
	function tn(L) {
		return _n && (typeof Object.setPrototypeOf == "function" ? (tt || (tt = Object.create(Object.prototype), qt(tt)), Object.setPrototypeOf(L, tt)) : qt(L)), L;
	}
	e.attachFlowNodeDebugInfo = tn;
	let sr;
	function mr(L) {
		"__tsDebuggerDisplay" in L || Object.defineProperties(L, { __tsDebuggerDisplay: { value(se) {
			return se = String(se).replace(/(?:,[\s\w]+:[^,]+)+\]$/, "]"), `NodeArray ${se}`;
		} } });
	}
	function hr(L) {
		_n && (typeof Object.setPrototypeOf == "function" ? (sr || (sr = Object.create(Array.prototype), mr(sr)), Object.setPrototypeOf(L, sr)) : mr(L));
	}
	e.attachNodeArrayDebugInfo = hr;
	function Fn() {
		if (_n) return;
		let L = /* @__PURE__ */ new WeakMap(), se = /* @__PURE__ */ new WeakMap();
		Object.defineProperties(Et.getSymbolConstructor().prototype, {
			__tsDebuggerDisplay: { value() {
				let Te = this.flags & 33554432 ? "TransientSymbol" : "Symbol", He = this.flags & -33554433;
				return `${Te} '${Jp(this)}'${He ? ` (${ot(He)})` : ""}`;
			} },
			__debugFlags: { get() {
				return ot(this.flags);
			} }
		}), Object.defineProperties(Et.getTypeConstructor().prototype, {
			__tsDebuggerDisplay: { value() {
				let Te = this.flags & 67359327 ? `IntrinsicType ${this.intrinsicName}${this.debugIntrinsicName ? ` (${this.debugIntrinsicName})` : ""}` : this.flags & 98304 ? "NullableType" : this.flags & 384 ? `LiteralType ${JSON.stringify(this.value)}` : this.flags & 2048 ? `LiteralType ${this.value.negative ? "-" : ""}${this.value.base10Value}n` : this.flags & 8192 ? "UniqueESSymbolType" : this.flags & 32 ? "EnumType" : this.flags & 1048576 ? "UnionType" : this.flags & 2097152 ? "IntersectionType" : this.flags & 4194304 ? "IndexType" : this.flags & 8388608 ? "IndexedAccessType" : this.flags & 16777216 ? "ConditionalType" : this.flags & 33554432 ? "SubstitutionType" : this.flags & 262144 ? "TypeParameter" : this.flags & 524288 ? this.objectFlags & 3 ? "InterfaceType" : this.objectFlags & 4 ? "TypeReference" : this.objectFlags & 8 ? "TupleType" : this.objectFlags & 16 ? "AnonymousType" : this.objectFlags & 32 ? "MappedType" : this.objectFlags & 1024 ? "ReverseMappedType" : this.objectFlags & 256 ? "EvolvingArrayType" : "ObjectType" : "Type", He = this.flags & 524288 ? this.objectFlags & -1344 : 0;
				return `${Te}${this.symbol ? ` '${Jp(this.symbol)}'` : ""}${He ? ` (${Lt(He)})` : ""}`;
			} },
			__debugFlags: { get() {
				return at(this.flags);
			} },
			__debugObjectFlags: { get() {
				return this.flags & 524288 ? Lt(this.objectFlags) : "";
			} },
			__debugTypeToString: { value() {
				let Te = L.get(this);
				return Te === void 0 && (Te = this.checker.typeToString(this), L.set(this, Te)), Te;
			} }
		}), Object.defineProperties(Et.getSignatureConstructor().prototype, {
			__debugFlags: { get() {
				return Bt(this.flags);
			} },
			__debugSignatureToString: { value() {
				var Te;
				return (Te = this.checker) == null ? void 0 : Te.signatureToString(this);
			} }
		});
		let fe = [
			Et.getNodeConstructor(),
			Et.getIdentifierConstructor(),
			Et.getTokenConstructor(),
			Et.getSourceFileConstructor()
		];
		for (let Te of fe) Dr(Te.prototype, "__debugKind") || Object.defineProperties(Te.prototype, {
			__tsDebuggerDisplay: { value() {
				return `${Ua(this) ? "GeneratedIdentifier" : Ke(this) ? `Identifier '${An(this)}'` : gi(this) ? `PrivateIdentifier '${An(this)}'` : vi(this) ? `StringLiteral ${JSON.stringify(this.text.length < 10 ? this.text : this.text.slice(10) + "...")}` : aa(this) ? `NumericLiteral ${this.text}` : k1(this) ? `BigIntLiteral ${this.text}n` : Ef(this) ? "TypeParameterDeclaration" : m_(this) ? "ParameterDeclaration" : Af(this) ? "ConstructorDeclaration" : Tl(this) ? "GetAccessorDeclaration" : y_(this) ? "SetAccessorDeclaration" : P1(this) ? "CallSignatureDeclaration" : N1(this) ? "ConstructSignatureDeclaration" : Cf(this) ? "IndexSignatureDeclaration" : I1(this) ? "TypePredicateNode" : Df(this) ? "TypeReferenceNode" : Pf(this) ? "FunctionTypeNode" : Nf(this) ? "ConstructorTypeNode" : qb(this) ? "TypeQueryNode" : O1(this) ? "TypeLiteralNode" : Fb(this) ? "ArrayTypeNode" : zb(this) ? "TupleTypeNode" : Vb(this) ? "OptionalTypeNode" : Wb(this) ? "RestTypeNode" : L1(this) ? "UnionTypeNode" : J1(this) ? "IntersectionTypeNode" : Gb(this) ? "ConditionalTypeNode" : Yb(this) ? "InferTypeNode" : j1(this) ? "ParenthesizedTypeNode" : Hb(this) ? "ThisTypeNode" : R1(this) ? "TypeOperatorNode" : Xb(this) ? "IndexedAccessTypeNode" : U1(this) ? "MappedTypeNode" : $b(this) ? "LiteralTypeNode" : M1(this) ? "NamedTupleMember" : Qb(this) ? "ImportTypeNode" : Ot(this.kind)}${this.flags ? ` (${Mt(this.flags)})` : ""}`;
			} },
			__debugKind: { get() {
				return Ot(this.kind);
			} },
			__debugNodeFlags: { get() {
				return Mt(this.flags);
			} },
			__debugModifierFlags: { get() {
				return $e(H2(this));
			} },
			__debugTransformFlags: { get() {
				return qn(this.transformFlags);
			} },
			__debugIsParseTreeNode: { get() {
				return gl(this);
			} },
			__debugEmitFlags: { get() {
				return $t(za(this));
			} },
			__debugGetText: { value(He) {
				if (Ja(this)) return "";
				let Qe = se.get(this);
				if (Qe === void 0) {
					let st = mg(this), Ct = st && hi(st);
					Qe = Ct ? Od(Ct, st, He) : "", se.set(this, Qe);
				}
				return Qe;
			} }
		});
		_n = !0;
	}
	e.enableDebugInfo = Fn;
	function zn(L) {
		let se = L & 7, fe = se === 0 ? "in out" : se === 3 ? "[bivariant]" : se === 2 ? "in" : se === 1 ? "out" : se === 4 ? "[independent]" : "";
		return L & 8 ? fe += " (unmeasurable)" : L & 16 && (fe += " (unreliable)"), fe;
	}
	e.formatVariance = zn;
	class Or {
		__debugToString() {
			var se;
			switch (this.kind) {
				case 3: return ((se = this.debugInfo) == null ? void 0 : se.call(this)) || "(function mapper)";
				case 0: return `${this.source.__debugTypeToString()} -> ${this.target.__debugTypeToString()}`;
				case 1: return yd(this.sources, this.targets || Pp(this.sources, () => "any"), (fe, Te) => `${fe.__debugTypeToString()} -> ${typeof Te == "string" ? Te : Te.__debugTypeToString()}`).join(", ");
				case 2: return yd(this.sources, this.targets, (fe, Te) => `${fe.__debugTypeToString()} -> ${Te().__debugTypeToString()}`).join(", ");
				case 5:
				case 4: return `m1: ${this.mapper1.__debugToString().split(`
`).join(`
    `)}
m2: ${this.mapper2.__debugToString().split(`
`).join(`
    `)}`;
				default: return Oe(this);
			}
		}
	}
	e.DebugTypeMapper = Or;
	function Vn(L) {
		return e.isDebugging ? Object.setPrototypeOf(L, Or.prototype) : L;
	}
	e.attachDebugPrototypeIfDebug = Vn;
	function Ce(L) {
		return console.log(yr(L));
	}
	e.printControlFlowGraph = Ce;
	function yr(L) {
		let se = -1;
		function fe(u) {
			return u.id || (u.id = se, se--), u.id;
		}
		let Te;
		((u) => {
			u.lr = "─", u.ud = "│", u.dr = "╭", u.dl = "╮", u.ul = "╯", u.ur = "╰", u.udr = "├", u.udl = "┤", u.dlr = "┬", u.ulr = "┴", u.udlr = "╫";
		})(Te || (Te = {}));
		let He;
		((u) => {
			u[u.None = 0] = "None", u[u.Up = 1] = "Up", u[u.Down = 2] = "Down", u[u.Left = 4] = "Left", u[u.Right = 8] = "Right", u[u.UpDown = 3] = "UpDown", u[u.LeftRight = 12] = "LeftRight", u[u.UpLeft = 5] = "UpLeft", u[u.UpRight = 9] = "UpRight", u[u.DownLeft = 6] = "DownLeft", u[u.DownRight = 10] = "DownRight", u[u.UpDownLeft = 7] = "UpDownLeft", u[u.UpDownRight = 11] = "UpDownRight", u[u.UpLeftRight = 13] = "UpLeftRight", u[u.DownLeftRight = 14] = "DownLeftRight", u[u.UpDownLeftRight = 15] = "UpDownLeftRight", u[u.NoChildren = 16] = "NoChildren";
		})(He || (He = {}));
		let Qe = 2032, st = 882, Ct = Object.create(null), Tt = [], lt = [], Mr = Se(L, /* @__PURE__ */ new Set());
		for (let u of Tt) u.text = rt(u.flowNode, u.circular), me(u);
		let Nn = Ze(Ve(Mr));
		return Ye(Mr, 0), on();
		function Wn(u) {
			return !!(u.flags & 128);
		}
		function wi(u) {
			return !!(u.flags & 12) && !!u.antecedent;
		}
		function U(u) {
			return !!(u.flags & Qe);
		}
		function K(u) {
			return !!(u.flags & st);
		}
		function Z(u) {
			let Ie = [];
			for (let Me of u.edges) Me.source === u && Ie.push(Me.target);
			return Ie;
		}
		function xe(u) {
			let Ie = [];
			for (let Me of u.edges) Me.target === u && Ie.push(Me.source);
			return Ie;
		}
		function Se(u, Ie) {
			let Me = fe(u), B = Ct[Me];
			if (B && Ie.has(u)) return B.circular = !0, B = {
				id: -1,
				flowNode: u,
				edges: [],
				text: "",
				lane: -1,
				endLane: -1,
				level: -1,
				circular: "circularity"
			}, Tt.push(B), B;
			if (Ie.add(u), !B) if (Ct[Me] = B = {
				id: Me,
				flowNode: u,
				edges: [],
				text: "",
				lane: -1,
				endLane: -1,
				level: -1,
				circular: !1
			}, Tt.push(B), wi(u)) for (let Be of u.antecedent) we(B, Be, Ie);
			else U(u) && we(B, u.antecedent, Ie);
			return Ie.delete(u), B;
		}
		function we(u, Ie, Me) {
			let B = Se(Ie, Me), Be = {
				source: u,
				target: B
			};
			lt.push(Be), u.edges.push(Be), B.edges.push(Be);
		}
		function me(u) {
			if (u.level !== -1) return u.level;
			let Ie = 0;
			for (let Me of xe(u)) Ie = Math.max(Ie, me(Me) + 1);
			return u.level = Ie;
		}
		function Ve(u) {
			let Ie = 0;
			for (let Me of Z(u)) Ie = Math.max(Ie, Ve(Me));
			return Ie + 1;
		}
		function Ze(u) {
			let Ie = M(Array(u), 0);
			for (let Me of Tt) Ie[Me.level] = Math.max(Ie[Me.level], Me.text.length);
			return Ie;
		}
		function Ye(u, Ie) {
			if (u.lane === -1) {
				u.lane = Ie, u.endLane = Ie;
				let Me = Z(u);
				for (let B = 0; B < Me.length; B++) {
					B > 0 && Ie++;
					let Be = Me[B];
					Ye(Be, Ie), Be.endLane > u.endLane && (Ie = Be.endLane);
				}
				u.endLane = Ie;
			}
		}
		function Ee(u) {
			if (u & 2) return "Start";
			if (u & 4) return "Branch";
			if (u & 8) return "Loop";
			if (u & 16) return "Assignment";
			if (u & 32) return "True";
			if (u & 64) return "False";
			if (u & 128) return "SwitchClause";
			if (u & 256) return "ArrayMutation";
			if (u & 512) return "Call";
			if (u & 1024) return "ReduceLabel";
			if (u & 1) return "Unreachable";
			throw new Error();
		}
		function gn(u) {
			return Od(hi(u), u, !1);
		}
		function rt(u, Ie) {
			let Me = Ee(u.flags);
			if (Ie && (Me = `${Me}#${fe(u)}`), Wn(u)) {
				let B = [], { switchStatement: Be, clauseStart: nn, clauseEnd: ze } = u.node;
				for (let Xe = nn; Xe < ze; Xe++) {
					let Dt = Be.caseBlock.clauses[Xe];
					r6(Dt) ? B.push("default") : B.push(gn(Dt.expression));
				}
				Me += ` (${B.join(", ")})`;
			} else K(u) && u.node && (Me += ` (${gn(u.node)})`);
			return Ie === "circularity" ? `Circular(${Me})` : Me;
		}
		function on() {
			let u = Nn.length, Ie = Ay(Tt, 0, (ze) => ze.lane) + 1, Me = M(Array(Ie), ""), B = Nn.map(() => Array(Ie)), Be = Nn.map(() => M(Array(Ie), 0));
			for (let ze of Tt) {
				B[ze.level][ze.lane] = ze;
				let Xe = Z(ze);
				for (let wt = 0; wt < Xe.length; wt++) {
					let Pt = Xe[wt], Ft = 8;
					Pt.lane === ze.lane && (Ft |= 4), wt > 0 && (Ft |= 1), wt < Xe.length - 1 && (Ft |= 2), Be[ze.level][Pt.lane] |= Ft;
				}
				Xe.length === 0 && (Be[ze.level][ze.lane] |= 16);
				let Dt = xe(ze);
				for (let wt = 0; wt < Dt.length; wt++) {
					let Pt = Dt[wt], Ft = 4;
					wt > 0 && (Ft |= 1), wt < Dt.length - 1 && (Ft |= 2), Be[ze.level - 1][Pt.lane] |= Ft;
				}
			}
			for (let ze = 0; ze < u; ze++) for (let Xe = 0; Xe < Ie; Xe++) {
				let Dt = ze > 0 ? Be[ze - 1][Xe] : 0, wt = Xe > 0 ? Be[ze][Xe - 1] : 0, Pt = Be[ze][Xe];
				Pt || (Dt & 8 && (Pt |= 12), wt & 2 && (Pt |= 3), Be[ze][Xe] = Pt);
			}
			for (let ze = 0; ze < u; ze++) for (let Xe = 0; Xe < Me.length; Xe++) {
				let Dt = Be[ze][Xe], wt = Dt & 4 ? "─" : " ", Pt = B[ze][Xe];
				Pt ? (nn(Xe, Pt.text), ze < u - 1 && (nn(Xe, " "), nn(Xe, Ue(wt, Nn[ze] - Pt.text.length)))) : ze < u - 1 && nn(Xe, Ue(wt, Nn[ze] + 1)), nn(Xe, Zr(Dt)), nn(Xe, Dt & 8 && ze < u - 1 && !B[ze + 1][Xe] ? "─" : " ");
			}
			return `
${Me.join(`
`)}
`;
			function nn(ze, Xe) {
				Me[ze] += Xe;
			}
		}
		function Zr(u) {
			switch (u) {
				case 3: return "│";
				case 12: return "─";
				case 5: return "╯";
				case 9: return "╰";
				case 6: return "╮";
				case 10: return "╭";
				case 7: return "┤";
				case 11: return "├";
				case 13: return "┴";
				case 14: return "┬";
				case 15: return "╫";
			}
			return " ";
		}
		function M(u, Ie) {
			if (u.fill) u.fill(Ie);
			else for (let Me = 0; Me < u.length; Me++) u[Me] = Ie;
			return u;
		}
		function Ue(u, Ie) {
			if (u.repeat) return Ie > 0 ? u.repeat(Ie) : "";
			let Me = "";
			for (; Me.length < Ie;) Me += u;
			return Me;
		}
	}
	e.formatControlFlowGraph = yr;
})(q || (q = {}));
Date.now;
var bd = () => {}, Oy = () => {}, ll, Ae = ((e) => (e[e.Unknown = 0] = "Unknown", e[e.EndOfFileToken = 1] = "EndOfFileToken", e[e.SingleLineCommentTrivia = 2] = "SingleLineCommentTrivia", e[e.MultiLineCommentTrivia = 3] = "MultiLineCommentTrivia", e[e.NewLineTrivia = 4] = "NewLineTrivia", e[e.WhitespaceTrivia = 5] = "WhitespaceTrivia", e[e.ShebangTrivia = 6] = "ShebangTrivia", e[e.ConflictMarkerTrivia = 7] = "ConflictMarkerTrivia", e[e.NonTextFileMarkerTrivia = 8] = "NonTextFileMarkerTrivia", e[e.NumericLiteral = 9] = "NumericLiteral", e[e.BigIntLiteral = 10] = "BigIntLiteral", e[e.StringLiteral = 11] = "StringLiteral", e[e.JsxText = 12] = "JsxText", e[e.JsxTextAllWhiteSpaces = 13] = "JsxTextAllWhiteSpaces", e[e.RegularExpressionLiteral = 14] = "RegularExpressionLiteral", e[e.NoSubstitutionTemplateLiteral = 15] = "NoSubstitutionTemplateLiteral", e[e.TemplateHead = 16] = "TemplateHead", e[e.TemplateMiddle = 17] = "TemplateMiddle", e[e.TemplateTail = 18] = "TemplateTail", e[e.OpenBraceToken = 19] = "OpenBraceToken", e[e.CloseBraceToken = 20] = "CloseBraceToken", e[e.OpenParenToken = 21] = "OpenParenToken", e[e.CloseParenToken = 22] = "CloseParenToken", e[e.OpenBracketToken = 23] = "OpenBracketToken", e[e.CloseBracketToken = 24] = "CloseBracketToken", e[e.DotToken = 25] = "DotToken", e[e.DotDotDotToken = 26] = "DotDotDotToken", e[e.SemicolonToken = 27] = "SemicolonToken", e[e.CommaToken = 28] = "CommaToken", e[e.QuestionDotToken = 29] = "QuestionDotToken", e[e.LessThanToken = 30] = "LessThanToken", e[e.LessThanSlashToken = 31] = "LessThanSlashToken", e[e.GreaterThanToken = 32] = "GreaterThanToken", e[e.LessThanEqualsToken = 33] = "LessThanEqualsToken", e[e.GreaterThanEqualsToken = 34] = "GreaterThanEqualsToken", e[e.EqualsEqualsToken = 35] = "EqualsEqualsToken", e[e.ExclamationEqualsToken = 36] = "ExclamationEqualsToken", e[e.EqualsEqualsEqualsToken = 37] = "EqualsEqualsEqualsToken", e[e.ExclamationEqualsEqualsToken = 38] = "ExclamationEqualsEqualsToken", e[e.EqualsGreaterThanToken = 39] = "EqualsGreaterThanToken", e[e.PlusToken = 40] = "PlusToken", e[e.MinusToken = 41] = "MinusToken", e[e.AsteriskToken = 42] = "AsteriskToken", e[e.AsteriskAsteriskToken = 43] = "AsteriskAsteriskToken", e[e.SlashToken = 44] = "SlashToken", e[e.PercentToken = 45] = "PercentToken", e[e.PlusPlusToken = 46] = "PlusPlusToken", e[e.MinusMinusToken = 47] = "MinusMinusToken", e[e.LessThanLessThanToken = 48] = "LessThanLessThanToken", e[e.GreaterThanGreaterThanToken = 49] = "GreaterThanGreaterThanToken", e[e.GreaterThanGreaterThanGreaterThanToken = 50] = "GreaterThanGreaterThanGreaterThanToken", e[e.AmpersandToken = 51] = "AmpersandToken", e[e.BarToken = 52] = "BarToken", e[e.CaretToken = 53] = "CaretToken", e[e.ExclamationToken = 54] = "ExclamationToken", e[e.TildeToken = 55] = "TildeToken", e[e.AmpersandAmpersandToken = 56] = "AmpersandAmpersandToken", e[e.BarBarToken = 57] = "BarBarToken", e[e.QuestionToken = 58] = "QuestionToken", e[e.ColonToken = 59] = "ColonToken", e[e.AtToken = 60] = "AtToken", e[e.QuestionQuestionToken = 61] = "QuestionQuestionToken", e[e.BacktickToken = 62] = "BacktickToken", e[e.HashToken = 63] = "HashToken", e[e.EqualsToken = 64] = "EqualsToken", e[e.PlusEqualsToken = 65] = "PlusEqualsToken", e[e.MinusEqualsToken = 66] = "MinusEqualsToken", e[e.AsteriskEqualsToken = 67] = "AsteriskEqualsToken", e[e.AsteriskAsteriskEqualsToken = 68] = "AsteriskAsteriskEqualsToken", e[e.SlashEqualsToken = 69] = "SlashEqualsToken", e[e.PercentEqualsToken = 70] = "PercentEqualsToken", e[e.LessThanLessThanEqualsToken = 71] = "LessThanLessThanEqualsToken", e[e.GreaterThanGreaterThanEqualsToken = 72] = "GreaterThanGreaterThanEqualsToken", e[e.GreaterThanGreaterThanGreaterThanEqualsToken = 73] = "GreaterThanGreaterThanGreaterThanEqualsToken", e[e.AmpersandEqualsToken = 74] = "AmpersandEqualsToken", e[e.BarEqualsToken = 75] = "BarEqualsToken", e[e.BarBarEqualsToken = 76] = "BarBarEqualsToken", e[e.AmpersandAmpersandEqualsToken = 77] = "AmpersandAmpersandEqualsToken", e[e.QuestionQuestionEqualsToken = 78] = "QuestionQuestionEqualsToken", e[e.CaretEqualsToken = 79] = "CaretEqualsToken", e[e.Identifier = 80] = "Identifier", e[e.PrivateIdentifier = 81] = "PrivateIdentifier", e[e.JSDocCommentTextToken = 82] = "JSDocCommentTextToken", e[e.BreakKeyword = 83] = "BreakKeyword", e[e.CaseKeyword = 84] = "CaseKeyword", e[e.CatchKeyword = 85] = "CatchKeyword", e[e.ClassKeyword = 86] = "ClassKeyword", e[e.ConstKeyword = 87] = "ConstKeyword", e[e.ContinueKeyword = 88] = "ContinueKeyword", e[e.DebuggerKeyword = 89] = "DebuggerKeyword", e[e.DefaultKeyword = 90] = "DefaultKeyword", e[e.DeleteKeyword = 91] = "DeleteKeyword", e[e.DoKeyword = 92] = "DoKeyword", e[e.ElseKeyword = 93] = "ElseKeyword", e[e.EnumKeyword = 94] = "EnumKeyword", e[e.ExportKeyword = 95] = "ExportKeyword", e[e.ExtendsKeyword = 96] = "ExtendsKeyword", e[e.FalseKeyword = 97] = "FalseKeyword", e[e.FinallyKeyword = 98] = "FinallyKeyword", e[e.ForKeyword = 99] = "ForKeyword", e[e.FunctionKeyword = 100] = "FunctionKeyword", e[e.IfKeyword = 101] = "IfKeyword", e[e.ImportKeyword = 102] = "ImportKeyword", e[e.InKeyword = 103] = "InKeyword", e[e.InstanceOfKeyword = 104] = "InstanceOfKeyword", e[e.NewKeyword = 105] = "NewKeyword", e[e.NullKeyword = 106] = "NullKeyword", e[e.ReturnKeyword = 107] = "ReturnKeyword", e[e.SuperKeyword = 108] = "SuperKeyword", e[e.SwitchKeyword = 109] = "SwitchKeyword", e[e.ThisKeyword = 110] = "ThisKeyword", e[e.ThrowKeyword = 111] = "ThrowKeyword", e[e.TrueKeyword = 112] = "TrueKeyword", e[e.TryKeyword = 113] = "TryKeyword", e[e.TypeOfKeyword = 114] = "TypeOfKeyword", e[e.VarKeyword = 115] = "VarKeyword", e[e.VoidKeyword = 116] = "VoidKeyword", e[e.WhileKeyword = 117] = "WhileKeyword", e[e.WithKeyword = 118] = "WithKeyword", e[e.ImplementsKeyword = 119] = "ImplementsKeyword", e[e.InterfaceKeyword = 120] = "InterfaceKeyword", e[e.LetKeyword = 121] = "LetKeyword", e[e.PackageKeyword = 122] = "PackageKeyword", e[e.PrivateKeyword = 123] = "PrivateKeyword", e[e.ProtectedKeyword = 124] = "ProtectedKeyword", e[e.PublicKeyword = 125] = "PublicKeyword", e[e.StaticKeyword = 126] = "StaticKeyword", e[e.YieldKeyword = 127] = "YieldKeyword", e[e.AbstractKeyword = 128] = "AbstractKeyword", e[e.AccessorKeyword = 129] = "AccessorKeyword", e[e.AsKeyword = 130] = "AsKeyword", e[e.AssertsKeyword = 131] = "AssertsKeyword", e[e.AssertKeyword = 132] = "AssertKeyword", e[e.AnyKeyword = 133] = "AnyKeyword", e[e.AsyncKeyword = 134] = "AsyncKeyword", e[e.AwaitKeyword = 135] = "AwaitKeyword", e[e.BooleanKeyword = 136] = "BooleanKeyword", e[e.ConstructorKeyword = 137] = "ConstructorKeyword", e[e.DeclareKeyword = 138] = "DeclareKeyword", e[e.GetKeyword = 139] = "GetKeyword", e[e.InferKeyword = 140] = "InferKeyword", e[e.IntrinsicKeyword = 141] = "IntrinsicKeyword", e[e.IsKeyword = 142] = "IsKeyword", e[e.KeyOfKeyword = 143] = "KeyOfKeyword", e[e.ModuleKeyword = 144] = "ModuleKeyword", e[e.NamespaceKeyword = 145] = "NamespaceKeyword", e[e.NeverKeyword = 146] = "NeverKeyword", e[e.OutKeyword = 147] = "OutKeyword", e[e.ReadonlyKeyword = 148] = "ReadonlyKeyword", e[e.RequireKeyword = 149] = "RequireKeyword", e[e.NumberKeyword = 150] = "NumberKeyword", e[e.ObjectKeyword = 151] = "ObjectKeyword", e[e.SatisfiesKeyword = 152] = "SatisfiesKeyword", e[e.SetKeyword = 153] = "SetKeyword", e[e.StringKeyword = 154] = "StringKeyword", e[e.SymbolKeyword = 155] = "SymbolKeyword", e[e.TypeKeyword = 156] = "TypeKeyword", e[e.UndefinedKeyword = 157] = "UndefinedKeyword", e[e.UniqueKeyword = 158] = "UniqueKeyword", e[e.UnknownKeyword = 159] = "UnknownKeyword", e[e.UsingKeyword = 160] = "UsingKeyword", e[e.FromKeyword = 161] = "FromKeyword", e[e.GlobalKeyword = 162] = "GlobalKeyword", e[e.BigIntKeyword = 163] = "BigIntKeyword", e[e.OverrideKeyword = 164] = "OverrideKeyword", e[e.OfKeyword = 165] = "OfKeyword", e[e.DeferKeyword = 166] = "DeferKeyword", e[e.QualifiedName = 167] = "QualifiedName", e[e.ComputedPropertyName = 168] = "ComputedPropertyName", e[e.TypeParameter = 169] = "TypeParameter", e[e.Parameter = 170] = "Parameter", e[e.Decorator = 171] = "Decorator", e[e.PropertySignature = 172] = "PropertySignature", e[e.PropertyDeclaration = 173] = "PropertyDeclaration", e[e.MethodSignature = 174] = "MethodSignature", e[e.MethodDeclaration = 175] = "MethodDeclaration", e[e.ClassStaticBlockDeclaration = 176] = "ClassStaticBlockDeclaration", e[e.Constructor = 177] = "Constructor", e[e.GetAccessor = 178] = "GetAccessor", e[e.SetAccessor = 179] = "SetAccessor", e[e.CallSignature = 180] = "CallSignature", e[e.ConstructSignature = 181] = "ConstructSignature", e[e.IndexSignature = 182] = "IndexSignature", e[e.TypePredicate = 183] = "TypePredicate", e[e.TypeReference = 184] = "TypeReference", e[e.FunctionType = 185] = "FunctionType", e[e.ConstructorType = 186] = "ConstructorType", e[e.TypeQuery = 187] = "TypeQuery", e[e.TypeLiteral = 188] = "TypeLiteral", e[e.ArrayType = 189] = "ArrayType", e[e.TupleType = 190] = "TupleType", e[e.OptionalType = 191] = "OptionalType", e[e.RestType = 192] = "RestType", e[e.UnionType = 193] = "UnionType", e[e.IntersectionType = 194] = "IntersectionType", e[e.ConditionalType = 195] = "ConditionalType", e[e.InferType = 196] = "InferType", e[e.ParenthesizedType = 197] = "ParenthesizedType", e[e.ThisType = 198] = "ThisType", e[e.TypeOperator = 199] = "TypeOperator", e[e.IndexedAccessType = 200] = "IndexedAccessType", e[e.MappedType = 201] = "MappedType", e[e.LiteralType = 202] = "LiteralType", e[e.NamedTupleMember = 203] = "NamedTupleMember", e[e.TemplateLiteralType = 204] = "TemplateLiteralType", e[e.TemplateLiteralTypeSpan = 205] = "TemplateLiteralTypeSpan", e[e.ImportType = 206] = "ImportType", e[e.ObjectBindingPattern = 207] = "ObjectBindingPattern", e[e.ArrayBindingPattern = 208] = "ArrayBindingPattern", e[e.BindingElement = 209] = "BindingElement", e[e.ArrayLiteralExpression = 210] = "ArrayLiteralExpression", e[e.ObjectLiteralExpression = 211] = "ObjectLiteralExpression", e[e.PropertyAccessExpression = 212] = "PropertyAccessExpression", e[e.ElementAccessExpression = 213] = "ElementAccessExpression", e[e.CallExpression = 214] = "CallExpression", e[e.NewExpression = 215] = "NewExpression", e[e.TaggedTemplateExpression = 216] = "TaggedTemplateExpression", e[e.TypeAssertionExpression = 217] = "TypeAssertionExpression", e[e.ParenthesizedExpression = 218] = "ParenthesizedExpression", e[e.FunctionExpression = 219] = "FunctionExpression", e[e.ArrowFunction = 220] = "ArrowFunction", e[e.DeleteExpression = 221] = "DeleteExpression", e[e.TypeOfExpression = 222] = "TypeOfExpression", e[e.VoidExpression = 223] = "VoidExpression", e[e.AwaitExpression = 224] = "AwaitExpression", e[e.PrefixUnaryExpression = 225] = "PrefixUnaryExpression", e[e.PostfixUnaryExpression = 226] = "PostfixUnaryExpression", e[e.BinaryExpression = 227] = "BinaryExpression", e[e.ConditionalExpression = 228] = "ConditionalExpression", e[e.TemplateExpression = 229] = "TemplateExpression", e[e.YieldExpression = 230] = "YieldExpression", e[e.SpreadElement = 231] = "SpreadElement", e[e.ClassExpression = 232] = "ClassExpression", e[e.OmittedExpression = 233] = "OmittedExpression", e[e.ExpressionWithTypeArguments = 234] = "ExpressionWithTypeArguments", e[e.AsExpression = 235] = "AsExpression", e[e.NonNullExpression = 236] = "NonNullExpression", e[e.MetaProperty = 237] = "MetaProperty", e[e.SyntheticExpression = 238] = "SyntheticExpression", e[e.SatisfiesExpression = 239] = "SatisfiesExpression", e[e.TemplateSpan = 240] = "TemplateSpan", e[e.SemicolonClassElement = 241] = "SemicolonClassElement", e[e.Block = 242] = "Block", e[e.EmptyStatement = 243] = "EmptyStatement", e[e.VariableStatement = 244] = "VariableStatement", e[e.ExpressionStatement = 245] = "ExpressionStatement", e[e.IfStatement = 246] = "IfStatement", e[e.DoStatement = 247] = "DoStatement", e[e.WhileStatement = 248] = "WhileStatement", e[e.ForStatement = 249] = "ForStatement", e[e.ForInStatement = 250] = "ForInStatement", e[e.ForOfStatement = 251] = "ForOfStatement", e[e.ContinueStatement = 252] = "ContinueStatement", e[e.BreakStatement = 253] = "BreakStatement", e[e.ReturnStatement = 254] = "ReturnStatement", e[e.WithStatement = 255] = "WithStatement", e[e.SwitchStatement = 256] = "SwitchStatement", e[e.LabeledStatement = 257] = "LabeledStatement", e[e.ThrowStatement = 258] = "ThrowStatement", e[e.TryStatement = 259] = "TryStatement", e[e.DebuggerStatement = 260] = "DebuggerStatement", e[e.VariableDeclaration = 261] = "VariableDeclaration", e[e.VariableDeclarationList = 262] = "VariableDeclarationList", e[e.FunctionDeclaration = 263] = "FunctionDeclaration", e[e.ClassDeclaration = 264] = "ClassDeclaration", e[e.InterfaceDeclaration = 265] = "InterfaceDeclaration", e[e.TypeAliasDeclaration = 266] = "TypeAliasDeclaration", e[e.EnumDeclaration = 267] = "EnumDeclaration", e[e.ModuleDeclaration = 268] = "ModuleDeclaration", e[e.ModuleBlock = 269] = "ModuleBlock", e[e.CaseBlock = 270] = "CaseBlock", e[e.NamespaceExportDeclaration = 271] = "NamespaceExportDeclaration", e[e.ImportEqualsDeclaration = 272] = "ImportEqualsDeclaration", e[e.ImportDeclaration = 273] = "ImportDeclaration", e[e.ImportClause = 274] = "ImportClause", e[e.NamespaceImport = 275] = "NamespaceImport", e[e.NamedImports = 276] = "NamedImports", e[e.ImportSpecifier = 277] = "ImportSpecifier", e[e.ExportAssignment = 278] = "ExportAssignment", e[e.ExportDeclaration = 279] = "ExportDeclaration", e[e.NamedExports = 280] = "NamedExports", e[e.NamespaceExport = 281] = "NamespaceExport", e[e.ExportSpecifier = 282] = "ExportSpecifier", e[e.MissingDeclaration = 283] = "MissingDeclaration", e[e.ExternalModuleReference = 284] = "ExternalModuleReference", e[e.JsxElement = 285] = "JsxElement", e[e.JsxSelfClosingElement = 286] = "JsxSelfClosingElement", e[e.JsxOpeningElement = 287] = "JsxOpeningElement", e[e.JsxClosingElement = 288] = "JsxClosingElement", e[e.JsxFragment = 289] = "JsxFragment", e[e.JsxOpeningFragment = 290] = "JsxOpeningFragment", e[e.JsxClosingFragment = 291] = "JsxClosingFragment", e[e.JsxAttribute = 292] = "JsxAttribute", e[e.JsxAttributes = 293] = "JsxAttributes", e[e.JsxSpreadAttribute = 294] = "JsxSpreadAttribute", e[e.JsxExpression = 295] = "JsxExpression", e[e.JsxNamespacedName = 296] = "JsxNamespacedName", e[e.CaseClause = 297] = "CaseClause", e[e.DefaultClause = 298] = "DefaultClause", e[e.HeritageClause = 299] = "HeritageClause", e[e.CatchClause = 300] = "CatchClause", e[e.ImportAttributes = 301] = "ImportAttributes", e[e.ImportAttribute = 302] = "ImportAttribute", e[e.AssertClause = 301] = "AssertClause", e[e.AssertEntry = 302] = "AssertEntry", e[e.ImportTypeAssertionContainer = 303] = "ImportTypeAssertionContainer", e[e.PropertyAssignment = 304] = "PropertyAssignment", e[e.ShorthandPropertyAssignment = 305] = "ShorthandPropertyAssignment", e[e.SpreadAssignment = 306] = "SpreadAssignment", e[e.EnumMember = 307] = "EnumMember", e[e.SourceFile = 308] = "SourceFile", e[e.Bundle = 309] = "Bundle", e[e.JSDocTypeExpression = 310] = "JSDocTypeExpression", e[e.JSDocNameReference = 311] = "JSDocNameReference", e[e.JSDocMemberName = 312] = "JSDocMemberName", e[e.JSDocAllType = 313] = "JSDocAllType", e[e.JSDocUnknownType = 314] = "JSDocUnknownType", e[e.JSDocNullableType = 315] = "JSDocNullableType", e[e.JSDocNonNullableType = 316] = "JSDocNonNullableType", e[e.JSDocOptionalType = 317] = "JSDocOptionalType", e[e.JSDocFunctionType = 318] = "JSDocFunctionType", e[e.JSDocVariadicType = 319] = "JSDocVariadicType", e[e.JSDocNamepathType = 320] = "JSDocNamepathType", e[e.JSDoc = 321] = "JSDoc", e[e.JSDocComment = 321] = "JSDocComment", e[e.JSDocText = 322] = "JSDocText", e[e.JSDocTypeLiteral = 323] = "JSDocTypeLiteral", e[e.JSDocSignature = 324] = "JSDocSignature", e[e.JSDocLink = 325] = "JSDocLink", e[e.JSDocLinkCode = 326] = "JSDocLinkCode", e[e.JSDocLinkPlain = 327] = "JSDocLinkPlain", e[e.JSDocTag = 328] = "JSDocTag", e[e.JSDocAugmentsTag = 329] = "JSDocAugmentsTag", e[e.JSDocImplementsTag = 330] = "JSDocImplementsTag", e[e.JSDocAuthorTag = 331] = "JSDocAuthorTag", e[e.JSDocDeprecatedTag = 332] = "JSDocDeprecatedTag", e[e.JSDocClassTag = 333] = "JSDocClassTag", e[e.JSDocPublicTag = 334] = "JSDocPublicTag", e[e.JSDocPrivateTag = 335] = "JSDocPrivateTag", e[e.JSDocProtectedTag = 336] = "JSDocProtectedTag", e[e.JSDocReadonlyTag = 337] = "JSDocReadonlyTag", e[e.JSDocOverrideTag = 338] = "JSDocOverrideTag", e[e.JSDocCallbackTag = 339] = "JSDocCallbackTag", e[e.JSDocOverloadTag = 340] = "JSDocOverloadTag", e[e.JSDocEnumTag = 341] = "JSDocEnumTag", e[e.JSDocParameterTag = 342] = "JSDocParameterTag", e[e.JSDocReturnTag = 343] = "JSDocReturnTag", e[e.JSDocThisTag = 344] = "JSDocThisTag", e[e.JSDocTypeTag = 345] = "JSDocTypeTag", e[e.JSDocTemplateTag = 346] = "JSDocTemplateTag", e[e.JSDocTypedefTag = 347] = "JSDocTypedefTag", e[e.JSDocSeeTag = 348] = "JSDocSeeTag", e[e.JSDocPropertyTag = 349] = "JSDocPropertyTag", e[e.JSDocThrowsTag = 350] = "JSDocThrowsTag", e[e.JSDocSatisfiesTag = 351] = "JSDocSatisfiesTag", e[e.JSDocImportTag = 352] = "JSDocImportTag", e[e.SyntaxList = 353] = "SyntaxList", e[e.NotEmittedStatement = 354] = "NotEmittedStatement", e[e.NotEmittedTypeElement = 355] = "NotEmittedTypeElement", e[e.PartiallyEmittedExpression = 356] = "PartiallyEmittedExpression", e[e.CommaListExpression = 357] = "CommaListExpression", e[e.SyntheticReferenceExpression = 358] = "SyntheticReferenceExpression", e[e.Count = 359] = "Count", e[e.FirstAssignment = 64] = "FirstAssignment", e[e.LastAssignment = 79] = "LastAssignment", e[e.FirstCompoundAssignment = 65] = "FirstCompoundAssignment", e[e.LastCompoundAssignment = 79] = "LastCompoundAssignment", e[e.FirstReservedWord = 83] = "FirstReservedWord", e[e.LastReservedWord = 118] = "LastReservedWord", e[e.FirstKeyword = 83] = "FirstKeyword", e[e.LastKeyword = 166] = "LastKeyword", e[e.FirstFutureReservedWord = 119] = "FirstFutureReservedWord", e[e.LastFutureReservedWord = 127] = "LastFutureReservedWord", e[e.FirstTypeNode = 183] = "FirstTypeNode", e[e.LastTypeNode = 206] = "LastTypeNode", e[e.FirstPunctuation = 19] = "FirstPunctuation", e[e.LastPunctuation = 79] = "LastPunctuation", e[e.FirstToken = 0] = "FirstToken", e[e.LastToken = 166] = "LastToken", e[e.FirstTriviaToken = 2] = "FirstTriviaToken", e[e.LastTriviaToken = 7] = "LastTriviaToken", e[e.FirstLiteralToken = 9] = "FirstLiteralToken", e[e.LastLiteralToken = 15] = "LastLiteralToken", e[e.FirstTemplateToken = 15] = "FirstTemplateToken", e[e.LastTemplateToken = 18] = "LastTemplateToken", e[e.FirstBinaryOperator = 30] = "FirstBinaryOperator", e[e.LastBinaryOperator = 79] = "LastBinaryOperator", e[e.FirstStatement = 244] = "FirstStatement", e[e.LastStatement = 260] = "LastStatement", e[e.FirstNode = 167] = "FirstNode", e[e.FirstJSDocNode = 310] = "FirstJSDocNode", e[e.LastJSDocNode = 352] = "LastJSDocNode", e[e.FirstJSDocTagNode = 328] = "FirstJSDocTagNode", e[e.LastJSDocTagNode = 352] = "LastJSDocTagNode", e[e.FirstContextualKeyword = 128] = "FirstContextualKeyword", e[e.LastContextualKeyword = 166] = "LastContextualKeyword", e))(Ae || {}), sn = ((e) => (e[e.None = 0] = "None", e[e.Let = 1] = "Let", e[e.Const = 2] = "Const", e[e.Using = 4] = "Using", e[e.AwaitUsing = 6] = "AwaitUsing", e[e.NestedNamespace = 8] = "NestedNamespace", e[e.Synthesized = 16] = "Synthesized", e[e.Namespace = 32] = "Namespace", e[e.OptionalChain = 64] = "OptionalChain", e[e.ExportContext = 128] = "ExportContext", e[e.ContainsThis = 256] = "ContainsThis", e[e.HasImplicitReturn = 512] = "HasImplicitReturn", e[e.HasExplicitReturn = 1024] = "HasExplicitReturn", e[e.GlobalAugmentation = 2048] = "GlobalAugmentation", e[e.HasAsyncFunctions = 4096] = "HasAsyncFunctions", e[e.DisallowInContext = 8192] = "DisallowInContext", e[e.YieldContext = 16384] = "YieldContext", e[e.DecoratorContext = 32768] = "DecoratorContext", e[e.AwaitContext = 65536] = "AwaitContext", e[e.DisallowConditionalTypesContext = 131072] = "DisallowConditionalTypesContext", e[e.ThisNodeHasError = 262144] = "ThisNodeHasError", e[e.JavaScriptFile = 524288] = "JavaScriptFile", e[e.ThisNodeOrAnySubNodesHasError = 1048576] = "ThisNodeOrAnySubNodesHasError", e[e.HasAggregatedChildData = 2097152] = "HasAggregatedChildData", e[e.PossiblyContainsDynamicImport = 4194304] = "PossiblyContainsDynamicImport", e[e.PossiblyContainsImportMeta = 8388608] = "PossiblyContainsImportMeta", e[e.JSDoc = 16777216] = "JSDoc", e[e.Ambient = 33554432] = "Ambient", e[e.InWithStatement = 67108864] = "InWithStatement", e[e.JsonFile = 134217728] = "JsonFile", e[e.TypeCached = 268435456] = "TypeCached", e[e.Deprecated = 536870912] = "Deprecated", e[e.BlockScoped = 7] = "BlockScoped", e[e.Constant = 6] = "Constant", e[e.ReachabilityCheckFlags = 1536] = "ReachabilityCheckFlags", e[e.ReachabilityAndEmitFlags = 5632] = "ReachabilityAndEmitFlags", e[e.ContextFlags = 101441536] = "ContextFlags", e[e.TypeExcludesFlags = 81920] = "TypeExcludesFlags", e[e.PermanentlySetIncrementalFlags = 12582912] = "PermanentlySetIncrementalFlags", e[e.IdentifierHasExtendedUnicodeEscape = 256] = "IdentifierHasExtendedUnicodeEscape", e[e.IdentifierIsInJSDocNamespace = 4096] = "IdentifierIsInJSDocNamespace", e))(sn || {}), Qp = ((e) => (e[e.None = 0] = "None", e[e.Public = 1] = "Public", e[e.Private = 2] = "Private", e[e.Protected = 4] = "Protected", e[e.Readonly = 8] = "Readonly", e[e.Override = 16] = "Override", e[e.Export = 32] = "Export", e[e.Abstract = 64] = "Abstract", e[e.Ambient = 128] = "Ambient", e[e.Static = 256] = "Static", e[e.Accessor = 512] = "Accessor", e[e.Async = 1024] = "Async", e[e.Default = 2048] = "Default", e[e.Const = 4096] = "Const", e[e.In = 8192] = "In", e[e.Out = 16384] = "Out", e[e.Decorator = 32768] = "Decorator", e[e.Deprecated = 65536] = "Deprecated", e[e.JSDocPublic = 8388608] = "JSDocPublic", e[e.JSDocPrivate = 16777216] = "JSDocPrivate", e[e.JSDocProtected = 33554432] = "JSDocProtected", e[e.JSDocReadonly = 67108864] = "JSDocReadonly", e[e.JSDocOverride = 134217728] = "JSDocOverride", e[e.SyntacticOrJSDocModifiers = 31] = "SyntacticOrJSDocModifiers", e[e.SyntacticOnlyModifiers = 65504] = "SyntacticOnlyModifiers", e[e.SyntacticModifiers = 65535] = "SyntacticModifiers", e[e.JSDocCacheOnlyModifiers = 260046848] = "JSDocCacheOnlyModifiers", e[e.JSDocOnlyModifiers = 65536] = "JSDocOnlyModifiers", e[e.NonCacheOnlyModifiers = 131071] = "NonCacheOnlyModifiers", e[e.HasComputedJSDocModifiers = 268435456] = "HasComputedJSDocModifiers", e[e.HasComputedFlags = 536870912] = "HasComputedFlags", e[e.AccessibilityModifier = 7] = "AccessibilityModifier", e[e.ParameterPropertyModifier = 31] = "ParameterPropertyModifier", e[e.NonPublicAccessibilityModifier = 6] = "NonPublicAccessibilityModifier", e[e.TypeScriptModifier = 28895] = "TypeScriptModifier", e[e.ExportDefault = 2080] = "ExportDefault", e[e.All = 131071] = "All", e[e.Modifier = 98303] = "Modifier", e))(Qp || {});
var wm = ((e) => (e[e.None = 0] = "None", e[e.Succeeded = 1] = "Succeeded", e[e.Failed = 2] = "Failed", e[e.ReportsUnmeasurable = 8] = "ReportsUnmeasurable", e[e.ReportsUnreliable = 16] = "ReportsUnreliable", e[e.ReportsMask = 24] = "ReportsMask", e[e.ComplexityOverflow = 32] = "ComplexityOverflow", e[e.StackDepthOverflow = 64] = "StackDepthOverflow", e[e.Overflow = 96] = "Overflow", e))(wm || {});
var Op = ((e) => (e[e.Unreachable = 1] = "Unreachable", e[e.Start = 2] = "Start", e[e.BranchLabel = 4] = "BranchLabel", e[e.LoopLabel = 8] = "LoopLabel", e[e.Assignment = 16] = "Assignment", e[e.TrueCondition = 32] = "TrueCondition", e[e.FalseCondition = 64] = "FalseCondition", e[e.SwitchClause = 128] = "SwitchClause", e[e.ArrayMutation = 256] = "ArrayMutation", e[e.Call = 512] = "Call", e[e.ReduceLabel = 1024] = "ReduceLabel", e[e.Referenced = 2048] = "Referenced", e[e.Shared = 4096] = "Shared", e[e.Label = 12] = "Label", e[e.Condition = 96] = "Condition", e))(Op || {});
var Kp = ((e) => (e[e.None = 0] = "None", e[e.FunctionScopedVariable = 1] = "FunctionScopedVariable", e[e.BlockScopedVariable = 2] = "BlockScopedVariable", e[e.Property = 4] = "Property", e[e.EnumMember = 8] = "EnumMember", e[e.Function = 16] = "Function", e[e.Class = 32] = "Class", e[e.Interface = 64] = "Interface", e[e.ConstEnum = 128] = "ConstEnum", e[e.RegularEnum = 256] = "RegularEnum", e[e.ValueModule = 512] = "ValueModule", e[e.NamespaceModule = 1024] = "NamespaceModule", e[e.TypeLiteral = 2048] = "TypeLiteral", e[e.ObjectLiteral = 4096] = "ObjectLiteral", e[e.Method = 8192] = "Method", e[e.Constructor = 16384] = "Constructor", e[e.GetAccessor = 32768] = "GetAccessor", e[e.SetAccessor = 65536] = "SetAccessor", e[e.Signature = 131072] = "Signature", e[e.TypeParameter = 262144] = "TypeParameter", e[e.TypeAlias = 524288] = "TypeAlias", e[e.ExportValue = 1048576] = "ExportValue", e[e.Alias = 2097152] = "Alias", e[e.Prototype = 4194304] = "Prototype", e[e.ExportStar = 8388608] = "ExportStar", e[e.Optional = 16777216] = "Optional", e[e.Transient = 33554432] = "Transient", e[e.Assignment = 67108864] = "Assignment", e[e.ModuleExports = 134217728] = "ModuleExports", e[e.All = -1] = "All", e[e.Enum = 384] = "Enum", e[e.Variable = 3] = "Variable", e[e.Value = 111551] = "Value", e[e.Type = 788968] = "Type", e[e.Namespace = 1920] = "Namespace", e[e.Module = 1536] = "Module", e[e.Accessor = 98304] = "Accessor", e[e.FunctionScopedVariableExcludes = 111550] = "FunctionScopedVariableExcludes", e[e.BlockScopedVariableExcludes = 111551] = "BlockScopedVariableExcludes", e[e.ParameterExcludes = 111551] = "ParameterExcludes", e[e.PropertyExcludes = 0] = "PropertyExcludes", e[e.EnumMemberExcludes = 900095] = "EnumMemberExcludes", e[e.FunctionExcludes = 110991] = "FunctionExcludes", e[e.ClassExcludes = 899503] = "ClassExcludes", e[e.InterfaceExcludes = 788872] = "InterfaceExcludes", e[e.RegularEnumExcludes = 899327] = "RegularEnumExcludes", e[e.ConstEnumExcludes = 899967] = "ConstEnumExcludes", e[e.ValueModuleExcludes = 110735] = "ValueModuleExcludes", e[e.NamespaceModuleExcludes = 0] = "NamespaceModuleExcludes", e[e.MethodExcludes = 103359] = "MethodExcludes", e[e.GetAccessorExcludes = 46015] = "GetAccessorExcludes", e[e.SetAccessorExcludes = 78783] = "SetAccessorExcludes", e[e.AccessorExcludes = 13247] = "AccessorExcludes", e[e.TypeParameterExcludes = 526824] = "TypeParameterExcludes", e[e.TypeAliasExcludes = 788968] = "TypeAliasExcludes", e[e.AliasExcludes = 2097152] = "AliasExcludes", e[e.ModuleMember = 2623475] = "ModuleMember", e[e.ExportHasLocal = 944] = "ExportHasLocal", e[e.BlockScoped = 418] = "BlockScoped", e[e.PropertyOrAccessor = 98308] = "PropertyOrAccessor", e[e.ClassMember = 106500] = "ClassMember", e[e.ExportSupportsDefaultModifier = 112] = "ExportSupportsDefaultModifier", e[e.ExportDoesNotSupportDefaultModifier = -113] = "ExportDoesNotSupportDefaultModifier", e[e.Classifiable = 2885600] = "Classifiable", e[e.LateBindingContainer = 6256] = "LateBindingContainer", e))(Kp || {});
var km = ((e) => (e[e.None = 0] = "None", e[e.TypeChecked = 1] = "TypeChecked", e[e.LexicalThis = 2] = "LexicalThis", e[e.CaptureThis = 4] = "CaptureThis", e[e.CaptureNewTarget = 8] = "CaptureNewTarget", e[e.SuperInstance = 16] = "SuperInstance", e[e.SuperStatic = 32] = "SuperStatic", e[e.ContextChecked = 64] = "ContextChecked", e[e.MethodWithSuperPropertyAccessInAsync = 128] = "MethodWithSuperPropertyAccessInAsync", e[e.MethodWithSuperPropertyAssignmentInAsync = 256] = "MethodWithSuperPropertyAssignmentInAsync", e[e.CaptureArguments = 512] = "CaptureArguments", e[e.EnumValuesComputed = 1024] = "EnumValuesComputed", e[e.LexicalModuleMergesWithClass = 2048] = "LexicalModuleMergesWithClass", e[e.LoopWithCapturedBlockScopedBinding = 4096] = "LoopWithCapturedBlockScopedBinding", e[e.ContainsCapturedBlockScopeBinding = 8192] = "ContainsCapturedBlockScopeBinding", e[e.CapturedBlockScopedBinding = 16384] = "CapturedBlockScopedBinding", e[e.BlockScopedBindingInLoop = 32768] = "BlockScopedBindingInLoop", e[e.NeedsLoopOutParameter = 65536] = "NeedsLoopOutParameter", e[e.AssignmentsMarked = 131072] = "AssignmentsMarked", e[e.ContainsConstructorReference = 262144] = "ContainsConstructorReference", e[e.ConstructorReference = 536870912] = "ConstructorReference", e[e.ContainsClassWithPrivateIdentifiers = 1048576] = "ContainsClassWithPrivateIdentifiers", e[e.ContainsSuperPropertyInStaticInitializer = 2097152] = "ContainsSuperPropertyInStaticInitializer", e[e.InCheckIdentifier = 4194304] = "InCheckIdentifier", e[e.PartiallyTypeChecked = 8388608] = "PartiallyTypeChecked", e[e.LazyFlags = 539358128] = "LazyFlags", e))(km || {}), en = ((e) => (e[e.Any = 1] = "Any", e[e.Unknown = 2] = "Unknown", e[e.String = 4] = "String", e[e.Number = 8] = "Number", e[e.Boolean = 16] = "Boolean", e[e.Enum = 32] = "Enum", e[e.BigInt = 64] = "BigInt", e[e.StringLiteral = 128] = "StringLiteral", e[e.NumberLiteral = 256] = "NumberLiteral", e[e.BooleanLiteral = 512] = "BooleanLiteral", e[e.EnumLiteral = 1024] = "EnumLiteral", e[e.BigIntLiteral = 2048] = "BigIntLiteral", e[e.ESSymbol = 4096] = "ESSymbol", e[e.UniqueESSymbol = 8192] = "UniqueESSymbol", e[e.Void = 16384] = "Void", e[e.Undefined = 32768] = "Undefined", e[e.Null = 65536] = "Null", e[e.Never = 131072] = "Never", e[e.TypeParameter = 262144] = "TypeParameter", e[e.Object = 524288] = "Object", e[e.Union = 1048576] = "Union", e[e.Intersection = 2097152] = "Intersection", e[e.Index = 4194304] = "Index", e[e.IndexedAccess = 8388608] = "IndexedAccess", e[e.Conditional = 16777216] = "Conditional", e[e.Substitution = 33554432] = "Substitution", e[e.NonPrimitive = 67108864] = "NonPrimitive", e[e.TemplateLiteral = 134217728] = "TemplateLiteral", e[e.StringMapping = 268435456] = "StringMapping", e[e.Reserved1 = 536870912] = "Reserved1", e[e.Reserved2 = 1073741824] = "Reserved2", e[e.AnyOrUnknown = 3] = "AnyOrUnknown", e[e.Nullable = 98304] = "Nullable", e[e.Literal = 2944] = "Literal", e[e.Unit = 109472] = "Unit", e[e.Freshable = 2976] = "Freshable", e[e.StringOrNumberLiteral = 384] = "StringOrNumberLiteral", e[e.StringOrNumberLiteralOrUnique = 8576] = "StringOrNumberLiteralOrUnique", e[e.DefinitelyFalsy = 117632] = "DefinitelyFalsy", e[e.PossiblyFalsy = 117724] = "PossiblyFalsy", e[e.Intrinsic = 67359327] = "Intrinsic", e[e.StringLike = 402653316] = "StringLike", e[e.NumberLike = 296] = "NumberLike", e[e.BigIntLike = 2112] = "BigIntLike", e[e.BooleanLike = 528] = "BooleanLike", e[e.EnumLike = 1056] = "EnumLike", e[e.ESSymbolLike = 12288] = "ESSymbolLike", e[e.VoidLike = 49152] = "VoidLike", e[e.Primitive = 402784252] = "Primitive", e[e.DefinitelyNonNullable = 470302716] = "DefinitelyNonNullable", e[e.DisjointDomains = 469892092] = "DisjointDomains", e[e.UnionOrIntersection = 3145728] = "UnionOrIntersection", e[e.StructuredType = 3670016] = "StructuredType", e[e.TypeVariable = 8650752] = "TypeVariable", e[e.InstantiableNonPrimitive = 58982400] = "InstantiableNonPrimitive", e[e.InstantiablePrimitive = 406847488] = "InstantiablePrimitive", e[e.Instantiable = 465829888] = "Instantiable", e[e.StructuredOrInstantiable = 469499904] = "StructuredOrInstantiable", e[e.ObjectFlagsType = 3899393] = "ObjectFlagsType", e[e.Simplifiable = 25165824] = "Simplifiable", e[e.Singleton = 67358815] = "Singleton", e[e.Narrowable = 536624127] = "Narrowable", e[e.IncludesMask = 473694207] = "IncludesMask", e[e.IncludesMissingType = 262144] = "IncludesMissingType", e[e.IncludesNonWideningType = 4194304] = "IncludesNonWideningType", e[e.IncludesWildcard = 8388608] = "IncludesWildcard", e[e.IncludesEmptyObject = 16777216] = "IncludesEmptyObject", e[e.IncludesInstantiable = 33554432] = "IncludesInstantiable", e[e.IncludesConstrainedTypeVariable = 536870912] = "IncludesConstrainedTypeVariable", e[e.IncludesError = 1073741824] = "IncludesError", e[e.NotPrimitiveUnion = 36323331] = "NotPrimitiveUnion", e))(en || {}), Zp = ((e) => (e[e.None = 0] = "None", e[e.Class = 1] = "Class", e[e.Interface = 2] = "Interface", e[e.Reference = 4] = "Reference", e[e.Tuple = 8] = "Tuple", e[e.Anonymous = 16] = "Anonymous", e[e.Mapped = 32] = "Mapped", e[e.Instantiated = 64] = "Instantiated", e[e.ObjectLiteral = 128] = "ObjectLiteral", e[e.EvolvingArray = 256] = "EvolvingArray", e[e.ObjectLiteralPatternWithComputedProperties = 512] = "ObjectLiteralPatternWithComputedProperties", e[e.ReverseMapped = 1024] = "ReverseMapped", e[e.JsxAttributes = 2048] = "JsxAttributes", e[e.JSLiteral = 4096] = "JSLiteral", e[e.FreshLiteral = 8192] = "FreshLiteral", e[e.ArrayLiteral = 16384] = "ArrayLiteral", e[e.PrimitiveUnion = 32768] = "PrimitiveUnion", e[e.ContainsWideningType = 65536] = "ContainsWideningType", e[e.ContainsObjectOrArrayLiteral = 131072] = "ContainsObjectOrArrayLiteral", e[e.NonInferrableType = 262144] = "NonInferrableType", e[e.CouldContainTypeVariablesComputed = 524288] = "CouldContainTypeVariablesComputed", e[e.CouldContainTypeVariables = 1048576] = "CouldContainTypeVariables", e[e.SingleSignatureType = 134217728] = "SingleSignatureType", e[e.ClassOrInterface = 3] = "ClassOrInterface", e[e.RequiresWidening = 196608] = "RequiresWidening", e[e.PropagatingFlags = 458752] = "PropagatingFlags", e[e.InstantiatedMapped = 96] = "InstantiatedMapped", e[e.ObjectTypeKindMask = 1343] = "ObjectTypeKindMask", e[e.ContainsSpread = 2097152] = "ContainsSpread", e[e.ObjectRestType = 4194304] = "ObjectRestType", e[e.InstantiationExpressionType = 8388608] = "InstantiationExpressionType", e[e.IsClassInstanceClone = 16777216] = "IsClassInstanceClone", e[e.IdenticalBaseTypeCalculated = 33554432] = "IdenticalBaseTypeCalculated", e[e.IdenticalBaseTypeExists = 67108864] = "IdenticalBaseTypeExists", e[e.IsGenericTypeComputed = 2097152] = "IsGenericTypeComputed", e[e.IsGenericObjectType = 4194304] = "IsGenericObjectType", e[e.IsGenericIndexType = 8388608] = "IsGenericIndexType", e[e.IsGenericType = 12582912] = "IsGenericType", e[e.ContainsIntersections = 16777216] = "ContainsIntersections", e[e.IsUnknownLikeUnionComputed = 33554432] = "IsUnknownLikeUnionComputed", e[e.IsUnknownLikeUnion = 67108864] = "IsUnknownLikeUnion", e[e.IsNeverIntersectionComputed = 16777216] = "IsNeverIntersectionComputed", e[e.IsNeverIntersection = 33554432] = "IsNeverIntersection", e[e.IsConstrainedTypeVariable = 67108864] = "IsConstrainedTypeVariable", e))(Zp || {});
var Em = ((e) => (e[e.None = 0] = "None", e[e.HasRestParameter = 1] = "HasRestParameter", e[e.HasLiteralTypes = 2] = "HasLiteralTypes", e[e.Abstract = 4] = "Abstract", e[e.IsInnerCallChain = 8] = "IsInnerCallChain", e[e.IsOuterCallChain = 16] = "IsOuterCallChain", e[e.IsUntypedSignatureInJSFile = 32] = "IsUntypedSignatureInJSFile", e[e.IsNonInferrable = 64] = "IsNonInferrable", e[e.IsSignatureCandidateForOverloadFailure = 128] = "IsSignatureCandidateForOverloadFailure", e[e.PropagatingFlags = 167] = "PropagatingFlags", e[e.CallChainFlags = 24] = "CallChainFlags", e))(Em || {});
var Pr = ((e) => (e[e.Unknown = 0] = "Unknown", e[e.JS = 1] = "JS", e[e.JSX = 2] = "JSX", e[e.TS = 3] = "TS", e[e.TSX = 4] = "TSX", e[e.External = 5] = "External", e[e.JSON = 6] = "JSON", e[e.Deferred = 7] = "Deferred", e))(Pr || {}), g_ = ((e) => (e[e.ES3 = 0] = "ES3", e[e.ES5 = 1] = "ES5", e[e.ES2015 = 2] = "ES2015", e[e.ES2016 = 3] = "ES2016", e[e.ES2017 = 4] = "ES2017", e[e.ES2018 = 5] = "ES2018", e[e.ES2019 = 6] = "ES2019", e[e.ES2020 = 7] = "ES2020", e[e.ES2021 = 8] = "ES2021", e[e.ES2022 = 9] = "ES2022", e[e.ES2023 = 10] = "ES2023", e[e.ES2024 = 11] = "ES2024", e[e.ESNext = 99] = "ESNext", e[e.JSON = 100] = "JSON", e[e.Latest = 99] = "Latest", e))(g_ || {}), wl = ((e) => (e[e.Standard = 0] = "Standard", e[e.JSX = 1] = "JSX", e))(wl || {});
var Cn = ((e) => (e.Ts = ".ts", e.Tsx = ".tsx", e.Dts = ".d.ts", e.Js = ".js", e.Jsx = ".jsx", e.Json = ".json", e.TsBuildInfo = ".tsbuildinfo", e.Mjs = ".mjs", e.Mts = ".mts", e.Dmts = ".d.mts", e.Cjs = ".cjs", e.Cts = ".cts", e.Dcts = ".d.cts", e))(Cn || {}), Am = ((e) => (e[e.None = 0] = "None", e[e.ContainsTypeScript = 1] = "ContainsTypeScript", e[e.ContainsJsx = 2] = "ContainsJsx", e[e.ContainsESNext = 4] = "ContainsESNext", e[e.ContainsES2022 = 8] = "ContainsES2022", e[e.ContainsES2021 = 16] = "ContainsES2021", e[e.ContainsES2020 = 32] = "ContainsES2020", e[e.ContainsES2019 = 64] = "ContainsES2019", e[e.ContainsES2018 = 128] = "ContainsES2018", e[e.ContainsES2017 = 256] = "ContainsES2017", e[e.ContainsES2016 = 512] = "ContainsES2016", e[e.ContainsES2015 = 1024] = "ContainsES2015", e[e.ContainsGenerator = 2048] = "ContainsGenerator", e[e.ContainsDestructuringAssignment = 4096] = "ContainsDestructuringAssignment", e[e.ContainsTypeScriptClassSyntax = 8192] = "ContainsTypeScriptClassSyntax", e[e.ContainsLexicalThis = 16384] = "ContainsLexicalThis", e[e.ContainsRestOrSpread = 32768] = "ContainsRestOrSpread", e[e.ContainsObjectRestOrSpread = 65536] = "ContainsObjectRestOrSpread", e[e.ContainsComputedPropertyName = 131072] = "ContainsComputedPropertyName", e[e.ContainsBlockScopedBinding = 262144] = "ContainsBlockScopedBinding", e[e.ContainsBindingPattern = 524288] = "ContainsBindingPattern", e[e.ContainsYield = 1048576] = "ContainsYield", e[e.ContainsAwait = 2097152] = "ContainsAwait", e[e.ContainsHoistedDeclarationOrCompletion = 4194304] = "ContainsHoistedDeclarationOrCompletion", e[e.ContainsDynamicImport = 8388608] = "ContainsDynamicImport", e[e.ContainsClassFields = 16777216] = "ContainsClassFields", e[e.ContainsDecorators = 33554432] = "ContainsDecorators", e[e.ContainsPossibleTopLevelAwait = 67108864] = "ContainsPossibleTopLevelAwait", e[e.ContainsLexicalSuper = 134217728] = "ContainsLexicalSuper", e[e.ContainsUpdateExpressionForIdentifier = 268435456] = "ContainsUpdateExpressionForIdentifier", e[e.ContainsPrivateIdentifierInExpression = 536870912] = "ContainsPrivateIdentifierInExpression", e[e.HasComputedFlags = -2147483648] = "HasComputedFlags", e[e.AssertTypeScript = 1] = "AssertTypeScript", e[e.AssertJsx = 2] = "AssertJsx", e[e.AssertESNext = 4] = "AssertESNext", e[e.AssertES2022 = 8] = "AssertES2022", e[e.AssertES2021 = 16] = "AssertES2021", e[e.AssertES2020 = 32] = "AssertES2020", e[e.AssertES2019 = 64] = "AssertES2019", e[e.AssertES2018 = 128] = "AssertES2018", e[e.AssertES2017 = 256] = "AssertES2017", e[e.AssertES2016 = 512] = "AssertES2016", e[e.AssertES2015 = 1024] = "AssertES2015", e[e.AssertGenerator = 2048] = "AssertGenerator", e[e.AssertDestructuringAssignment = 4096] = "AssertDestructuringAssignment", e[e.OuterExpressionExcludes = -2147483648] = "OuterExpressionExcludes", e[e.PropertyAccessExcludes = -2147483648] = "PropertyAccessExcludes", e[e.NodeExcludes = -2147483648] = "NodeExcludes", e[e.ArrowFunctionExcludes = -2072174592] = "ArrowFunctionExcludes", e[e.FunctionExcludes = -1937940480] = "FunctionExcludes", e[e.ConstructorExcludes = -1937948672] = "ConstructorExcludes", e[e.MethodOrAccessorExcludes = -2005057536] = "MethodOrAccessorExcludes", e[e.PropertyExcludes = -2013249536] = "PropertyExcludes", e[e.ClassExcludes = -2147344384] = "ClassExcludes", e[e.ModuleExcludes = -1941676032] = "ModuleExcludes", e[e.TypeExcludes = -2] = "TypeExcludes", e[e.ObjectLiteralExcludes = -2147278848] = "ObjectLiteralExcludes", e[e.ArrayLiteralOrCallOrNewExcludes = -2147450880] = "ArrayLiteralOrCallOrNewExcludes", e[e.VariableDeclarationListExcludes = -2146893824] = "VariableDeclarationListExcludes", e[e.ParameterExcludes = -2147483648] = "ParameterExcludes", e[e.CatchClauseExcludes = -2147418112] = "CatchClauseExcludes", e[e.BindingPatternExcludes = -2147450880] = "BindingPatternExcludes", e[e.ContainsLexicalThisOrSuper = 134234112] = "ContainsLexicalThisOrSuper", e[e.PropertyNamePropagatingFlags = 134234112] = "PropertyNamePropagatingFlags", e))(Am || {}), Cm = ((e) => (e[e.TabStop = 0] = "TabStop", e[e.Placeholder = 1] = "Placeholder", e[e.Choice = 2] = "Choice", e[e.Variable = 3] = "Variable", e))(Cm || {}), Dm = ((e) => (e[e.None = 0] = "None", e[e.SingleLine = 1] = "SingleLine", e[e.MultiLine = 2] = "MultiLine", e[e.AdviseOnEmitNode = 4] = "AdviseOnEmitNode", e[e.NoSubstitution = 8] = "NoSubstitution", e[e.CapturesThis = 16] = "CapturesThis", e[e.NoLeadingSourceMap = 32] = "NoLeadingSourceMap", e[e.NoTrailingSourceMap = 64] = "NoTrailingSourceMap", e[e.NoSourceMap = 96] = "NoSourceMap", e[e.NoNestedSourceMaps = 128] = "NoNestedSourceMaps", e[e.NoTokenLeadingSourceMaps = 256] = "NoTokenLeadingSourceMaps", e[e.NoTokenTrailingSourceMaps = 512] = "NoTokenTrailingSourceMaps", e[e.NoTokenSourceMaps = 768] = "NoTokenSourceMaps", e[e.NoLeadingComments = 1024] = "NoLeadingComments", e[e.NoTrailingComments = 2048] = "NoTrailingComments", e[e.NoComments = 3072] = "NoComments", e[e.NoNestedComments = 4096] = "NoNestedComments", e[e.HelperName = 8192] = "HelperName", e[e.ExportName = 16384] = "ExportName", e[e.LocalName = 32768] = "LocalName", e[e.InternalName = 65536] = "InternalName", e[e.Indented = 131072] = "Indented", e[e.NoIndentation = 262144] = "NoIndentation", e[e.AsyncFunctionBody = 524288] = "AsyncFunctionBody", e[e.ReuseTempVariableScope = 1048576] = "ReuseTempVariableScope", e[e.CustomPrologue = 2097152] = "CustomPrologue", e[e.NoHoisting = 4194304] = "NoHoisting", e[e.Iterator = 8388608] = "Iterator", e[e.NoAsciiEscaping = 16777216] = "NoAsciiEscaping", e))(Dm || {});
var $s = {
	Classes: 2,
	ForOf: 2,
	Generators: 2,
	Iteration: 2,
	SpreadElements: 2,
	RestElements: 2,
	TaggedTemplates: 2,
	DestructuringAssignment: 2,
	BindingPatterns: 2,
	ArrowFunctions: 2,
	BlockScopedVariables: 2,
	ObjectAssign: 2,
	RegularExpressionFlagsUnicode: 2,
	RegularExpressionFlagsSticky: 2,
	Exponentiation: 3,
	AsyncFunctions: 4,
	ForAwaitOf: 5,
	AsyncGenerators: 5,
	AsyncIteration: 5,
	ObjectSpreadRest: 5,
	RegularExpressionFlagsDotAll: 5,
	BindinglessCatch: 6,
	BigInt: 7,
	NullishCoalesce: 7,
	OptionalChaining: 7,
	LogicalAssignment: 8,
	TopLevelAwait: 9,
	ClassFields: 9,
	PrivateNamesAndClassStaticBlocks: 9,
	RegularExpressionFlagsHasIndices: 9,
	ShebangComments: 10,
	RegularExpressionFlagsUnicodeSets: 11,
	UsingAndAwaitUsing: 99,
	ClassAndClassElementDecorators: 99
};
var Pm = {
	reference: {
		args: [
			{
				name: "types",
				optional: !0,
				captureSpan: !0
			},
			{
				name: "lib",
				optional: !0,
				captureSpan: !0
			},
			{
				name: "path",
				optional: !0,
				captureSpan: !0
			},
			{
				name: "no-default-lib",
				optional: !0
			},
			{
				name: "resolution-mode",
				optional: !0
			},
			{
				name: "preserve",
				optional: !0
			}
		],
		kind: 1
	},
	"amd-dependency": {
		args: [{ name: "path" }, {
			name: "name",
			optional: !0
		}],
		kind: 1
	},
	"amd-module": {
		args: [{ name: "name" }],
		kind: 1
	},
	"ts-check": { kind: 2 },
	"ts-nocheck": { kind: 2 },
	jsx: {
		args: [{ name: "factory" }],
		kind: 4
	},
	jsxfrag: {
		args: [{ name: "factory" }],
		kind: 4
	},
	jsximportsource: {
		args: [{ name: "factory" }],
		kind: 4
	},
	jsxruntime: {
		args: [{ name: "factory" }],
		kind: 4
	}
}, Ya = ((e) => (e[e.ParseAll = 0] = "ParseAll", e[e.ParseNone = 1] = "ParseNone", e[e.ParseForTypeErrors = 2] = "ParseForTypeErrors", e[e.ParseForTypeInfo = 3] = "ParseForTypeInfo", e))(Ya || {});
var Xr = "/", My = "\\", vd = "://", Ly = /\\/g;
function Jy(e) {
	return e === 47 || e === 92;
}
function jy(e, t) {
	return e.length > t.length && Dy(e, t);
}
function ef(e) {
	return e.length > 0 && Jy(e.charCodeAt(e.length - 1));
}
function Td(e) {
	return e >= 97 && e <= 122 || e >= 65 && e <= 90;
}
function Ry(e, t) {
	let a = e.charCodeAt(t);
	if (a === 58) return t + 1;
	if (a === 37 && e.charCodeAt(t + 1) === 51) {
		let _ = e.charCodeAt(t + 2);
		if (_ === 97 || _ === 65) return t + 3;
	}
	return -1;
}
function Uy(e) {
	if (!e) return 0;
	let t = e.charCodeAt(0);
	if (t === 47 || t === 92) {
		if (e.charCodeAt(1) !== t) return 1;
		let _ = e.indexOf(t === 47 ? Xr : My, 2);
		return _ < 0 ? e.length : _ + 1;
	}
	if (Td(t) && e.charCodeAt(1) === 58) {
		let _ = e.charCodeAt(2);
		if (_ === 47 || _ === 92) return 3;
		if (e.length === 2) return 2;
	}
	let a = e.indexOf(vd);
	if (a !== -1) {
		let _ = a + vd.length, f = e.indexOf(Xr, _);
		if (f !== -1) {
			let h = e.slice(0, a), T = e.slice(_, f);
			if (h === "file" && (T === "" || T === "localhost") && Td(e.charCodeAt(f + 1))) {
				let k = Ry(e, f + 2);
				if (k !== -1) {
					if (e.charCodeAt(k) === 47) return ~(k + 1);
					if (k === e.length) return ~k;
				}
			}
			return ~(f + 1);
		}
		return ~e.length;
	}
	return 0;
}
function o_(e) {
	let t = Uy(e);
	return t < 0 ? ~t : t;
}
function Nm(e, t, a) {
	if (e = c_(e), o_(e) === e.length) return "";
	e = hl(e);
	let f = e.slice(Math.max(o_(e), e.lastIndexOf(Xr) + 1)), h = t !== void 0 && a !== void 0 ? Im(f, t, a) : void 0;
	return h ? f.slice(0, f.length - h.length) : f;
}
function xd(e, t, a) {
	if (ml(t, ".") || (t = "." + t), e.length >= t.length && e.charCodeAt(e.length - t.length) === 46) {
		let _ = e.slice(e.length - t.length);
		if (a(_, t)) return _;
	}
}
function By(e, t, a) {
	if (typeof t == "string") return xd(e, t, a) || "";
	for (let _ of t) {
		let f = xd(e, _, a);
		if (f) return f;
	}
	return "";
}
function Im(e, t, a) {
	if (t) return By(hl(e), t, a ? $p : ky);
	let _ = Nm(e), f = _.lastIndexOf(".");
	return f >= 0 ? _.substring(f) : "";
}
function c_(e) {
	return e.includes("\\") ? e.replace(Ly, Xr) : e;
}
function qy(e, ...t) {
	e && (e = c_(e));
	for (let a of t) a && (a = c_(a), !e || o_(a) !== 0 ? e = a : e = Mm(e) + a);
	return e;
}
function Fy(e, t) {
	let a = o_(e);
	a === 0 && t ? (e = qy(t, e), a = o_(e)) : e = c_(e);
	let _ = Om(e);
	if (_ !== void 0) return _.length > a ? hl(_) : _;
	let f = e.length, h = e.substring(0, a), T, k = a, c = k, W = k, y = a !== 0;
	for (; k < f;) {
		c = k;
		let G = e.charCodeAt(k);
		for (; G === 47 && k + 1 < f;) k++, G = e.charCodeAt(k);
		k > c && (T ?? (T = e.substring(0, c - 1)), c = k);
		let E = e.indexOf(Xr, k + 1);
		E === -1 && (E = f);
		let D = E - c;
		if (D === 1 && e.charCodeAt(k) === 46) T ?? (T = e.substring(0, W));
		else if (D === 2 && e.charCodeAt(k) === 46 && e.charCodeAt(k + 1) === 46) if (!y) T !== void 0 ? T += T.length === a ? ".." : "/.." : W = k + 2;
		else if (T === void 0) W - 2 >= 0 ? T = e.substring(0, Math.max(a, e.lastIndexOf(Xr, W - 2))) : T = e.substring(0, W);
		else {
			let R = T.lastIndexOf(Xr);
			R !== -1 ? T = T.substring(0, Math.max(a, R)) : T = h, T.length === a && (y = a !== 0);
		}
		else T !== void 0 ? (T.length !== a && (T += Xr), y = !0, T += e.substring(c, E)) : (y = !0, W = E);
		k = E + 1;
	}
	return T ?? (f > a ? hl(e) : e);
}
function zy(e) {
	e = c_(e);
	let t = Om(e);
	return t !== void 0 ? t : (t = Fy(e, ""), t && ef(e) ? Mm(t) : t);
}
function Om(e) {
	if (!Sd.test(e)) return e;
	let t = e.replace(/\/\.\//g, "/");
	if (t.startsWith("./") && (t = t.slice(2)), t !== e && (e = t, !Sd.test(e))) return e;
}
function hl(e) {
	return ef(e) ? e.substr(0, e.length - 1) : e;
}
function Mm(e) {
	return ef(e) ? e : e + Xr;
}
var Sd = /\/\/|(?:^|\/)\.\.?(?:$|\/)/;
function r(e, t, a, _, f, h, T) {
	return {
		code: e,
		category: t,
		key: a,
		message: _,
		reportsUnnecessary: f,
		elidedInCompatabilityPyramid: h,
		reportsDeprecated: T
	};
}
var A = {
	Unterminated_string_literal: r(1002, 1, "Unterminated_string_literal_1002", "Unterminated string literal."),
	Identifier_expected: r(1003, 1, "Identifier_expected_1003", "Identifier expected."),
	_0_expected: r(1005, 1, "_0_expected_1005", "'{0}' expected."),
	A_file_cannot_have_a_reference_to_itself: r(1006, 1, "A_file_cannot_have_a_reference_to_itself_1006", "A file cannot have a reference to itself."),
	The_parser_expected_to_find_a_1_to_match_the_0_token_here: r(1007, 1, "The_parser_expected_to_find_a_1_to_match_the_0_token_here_1007", "The parser expected to find a '{1}' to match the '{0}' token here."),
	Trailing_comma_not_allowed: r(1009, 1, "Trailing_comma_not_allowed_1009", "Trailing comma not allowed."),
	Asterisk_Slash_expected: r(1010, 1, "Asterisk_Slash_expected_1010", "'*/' expected."),
	An_element_access_expression_should_take_an_argument: r(1011, 1, "An_element_access_expression_should_take_an_argument_1011", "An element access expression should take an argument."),
	Unexpected_token: r(1012, 1, "Unexpected_token_1012", "Unexpected token."),
	A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma: r(1013, 1, "A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma_1013", "A rest parameter or binding pattern may not have a trailing comma."),
	A_rest_parameter_must_be_last_in_a_parameter_list: r(1014, 1, "A_rest_parameter_must_be_last_in_a_parameter_list_1014", "A rest parameter must be last in a parameter list."),
	Parameter_cannot_have_question_mark_and_initializer: r(1015, 1, "Parameter_cannot_have_question_mark_and_initializer_1015", "Parameter cannot have question mark and initializer."),
	A_required_parameter_cannot_follow_an_optional_parameter: r(1016, 1, "A_required_parameter_cannot_follow_an_optional_parameter_1016", "A required parameter cannot follow an optional parameter."),
	An_index_signature_cannot_have_a_rest_parameter: r(1017, 1, "An_index_signature_cannot_have_a_rest_parameter_1017", "An index signature cannot have a rest parameter."),
	An_index_signature_parameter_cannot_have_an_accessibility_modifier: r(1018, 1, "An_index_signature_parameter_cannot_have_an_accessibility_modifier_1018", "An index signature parameter cannot have an accessibility modifier."),
	An_index_signature_parameter_cannot_have_a_question_mark: r(1019, 1, "An_index_signature_parameter_cannot_have_a_question_mark_1019", "An index signature parameter cannot have a question mark."),
	An_index_signature_parameter_cannot_have_an_initializer: r(1020, 1, "An_index_signature_parameter_cannot_have_an_initializer_1020", "An index signature parameter cannot have an initializer."),
	An_index_signature_must_have_a_type_annotation: r(1021, 1, "An_index_signature_must_have_a_type_annotation_1021", "An index signature must have a type annotation."),
	An_index_signature_parameter_must_have_a_type_annotation: r(1022, 1, "An_index_signature_parameter_must_have_a_type_annotation_1022", "An index signature parameter must have a type annotation."),
	readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature: r(1024, 1, "readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature_1024", "'readonly' modifier can only appear on a property declaration or index signature."),
	An_index_signature_cannot_have_a_trailing_comma: r(1025, 1, "An_index_signature_cannot_have_a_trailing_comma_1025", "An index signature cannot have a trailing comma."),
	Accessibility_modifier_already_seen: r(1028, 1, "Accessibility_modifier_already_seen_1028", "Accessibility modifier already seen."),
	_0_modifier_must_precede_1_modifier: r(1029, 1, "_0_modifier_must_precede_1_modifier_1029", "'{0}' modifier must precede '{1}' modifier."),
	_0_modifier_already_seen: r(1030, 1, "_0_modifier_already_seen_1030", "'{0}' modifier already seen."),
	_0_modifier_cannot_appear_on_class_elements_of_this_kind: r(1031, 1, "_0_modifier_cannot_appear_on_class_elements_of_this_kind_1031", "'{0}' modifier cannot appear on class elements of this kind."),
	super_must_be_followed_by_an_argument_list_or_member_access: r(1034, 1, "super_must_be_followed_by_an_argument_list_or_member_access_1034", "'super' must be followed by an argument list or member access."),
	Only_ambient_modules_can_use_quoted_names: r(1035, 1, "Only_ambient_modules_can_use_quoted_names_1035", "Only ambient modules can use quoted names."),
	Statements_are_not_allowed_in_ambient_contexts: r(1036, 1, "Statements_are_not_allowed_in_ambient_contexts_1036", "Statements are not allowed in ambient contexts."),
	A_declare_modifier_cannot_be_used_in_an_already_ambient_context: r(1038, 1, "A_declare_modifier_cannot_be_used_in_an_already_ambient_context_1038", "A 'declare' modifier cannot be used in an already ambient context."),
	Initializers_are_not_allowed_in_ambient_contexts: r(1039, 1, "Initializers_are_not_allowed_in_ambient_contexts_1039", "Initializers are not allowed in ambient contexts."),
	_0_modifier_cannot_be_used_in_an_ambient_context: r(1040, 1, "_0_modifier_cannot_be_used_in_an_ambient_context_1040", "'{0}' modifier cannot be used in an ambient context."),
	_0_modifier_cannot_be_used_here: r(1042, 1, "_0_modifier_cannot_be_used_here_1042", "'{0}' modifier cannot be used here."),
	_0_modifier_cannot_appear_on_a_module_or_namespace_element: r(1044, 1, "_0_modifier_cannot_appear_on_a_module_or_namespace_element_1044", "'{0}' modifier cannot appear on a module or namespace element."),
	Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier: r(1046, 1, "Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier_1046", "Top-level declarations in .d.ts files must start with either a 'declare' or 'export' modifier."),
	A_rest_parameter_cannot_be_optional: r(1047, 1, "A_rest_parameter_cannot_be_optional_1047", "A rest parameter cannot be optional."),
	A_rest_parameter_cannot_have_an_initializer: r(1048, 1, "A_rest_parameter_cannot_have_an_initializer_1048", "A rest parameter cannot have an initializer."),
	A_set_accessor_must_have_exactly_one_parameter: r(1049, 1, "A_set_accessor_must_have_exactly_one_parameter_1049", "A 'set' accessor must have exactly one parameter."),
	A_set_accessor_cannot_have_an_optional_parameter: r(1051, 1, "A_set_accessor_cannot_have_an_optional_parameter_1051", "A 'set' accessor cannot have an optional parameter."),
	A_set_accessor_parameter_cannot_have_an_initializer: r(1052, 1, "A_set_accessor_parameter_cannot_have_an_initializer_1052", "A 'set' accessor parameter cannot have an initializer."),
	A_set_accessor_cannot_have_rest_parameter: r(1053, 1, "A_set_accessor_cannot_have_rest_parameter_1053", "A 'set' accessor cannot have rest parameter."),
	A_get_accessor_cannot_have_parameters: r(1054, 1, "A_get_accessor_cannot_have_parameters_1054", "A 'get' accessor cannot have parameters."),
	Type_0_is_not_a_valid_async_function_return_type_in_ES5_because_it_does_not_refer_to_a_Promise_compatible_constructor_value: r(1055, 1, "Type_0_is_not_a_valid_async_function_return_type_in_ES5_because_it_does_not_refer_to_a_Promise_compa_1055", "Type '{0}' is not a valid async function return type in ES5 because it does not refer to a Promise-compatible constructor value."),
	Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher: r(1056, 1, "Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher_1056", "Accessors are only available when targeting ECMAScript 5 and higher."),
	The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: r(1058, 1, "The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_t_1058", "The return type of an async function must either be a valid promise or must not contain a callable 'then' member."),
	A_promise_must_have_a_then_method: r(1059, 1, "A_promise_must_have_a_then_method_1059", "A promise must have a 'then' method."),
	The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback: r(1060, 1, "The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback_1060", "The first parameter of the 'then' method of a promise must be a callback."),
	Enum_member_must_have_initializer: r(1061, 1, "Enum_member_must_have_initializer_1061", "Enum member must have initializer."),
	Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method: r(1062, 1, "Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method_1062", "Type is referenced directly or indirectly in the fulfillment callback of its own 'then' method."),
	An_export_assignment_cannot_be_used_in_a_namespace: r(1063, 1, "An_export_assignment_cannot_be_used_in_a_namespace_1063", "An export assignment cannot be used in a namespace."),
	The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_write_Promise_0: r(1064, 1, "The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_wri_1064", "The return type of an async function or method must be the global Promise<T> type. Did you mean to write 'Promise<{0}>'?"),
	The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type: r(1065, 1, "The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_1065", "The return type of an async function or method must be the global Promise<T> type."),
	In_ambient_enum_declarations_member_initializer_must_be_constant_expression: r(1066, 1, "In_ambient_enum_declarations_member_initializer_must_be_constant_expression_1066", "In ambient enum declarations member initializer must be constant expression."),
	Unexpected_token_A_constructor_method_accessor_or_property_was_expected: r(1068, 1, "Unexpected_token_A_constructor_method_accessor_or_property_was_expected_1068", "Unexpected token. A constructor, method, accessor, or property was expected."),
	Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces: r(1069, 1, "Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces_1069", "Unexpected token. A type parameter name was expected without curly braces."),
	_0_modifier_cannot_appear_on_a_type_member: r(1070, 1, "_0_modifier_cannot_appear_on_a_type_member_1070", "'{0}' modifier cannot appear on a type member."),
	_0_modifier_cannot_appear_on_an_index_signature: r(1071, 1, "_0_modifier_cannot_appear_on_an_index_signature_1071", "'{0}' modifier cannot appear on an index signature."),
	A_0_modifier_cannot_be_used_with_an_import_declaration: r(1079, 1, "A_0_modifier_cannot_be_used_with_an_import_declaration_1079", "A '{0}' modifier cannot be used with an import declaration."),
	Invalid_reference_directive_syntax: r(1084, 1, "Invalid_reference_directive_syntax_1084", "Invalid 'reference' directive syntax."),
	_0_modifier_cannot_appear_on_a_constructor_declaration: r(1089, 1, "_0_modifier_cannot_appear_on_a_constructor_declaration_1089", "'{0}' modifier cannot appear on a constructor declaration."),
	_0_modifier_cannot_appear_on_a_parameter: r(1090, 1, "_0_modifier_cannot_appear_on_a_parameter_1090", "'{0}' modifier cannot appear on a parameter."),
	Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement: r(1091, 1, "Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement_1091", "Only a single variable declaration is allowed in a 'for...in' statement."),
	Type_parameters_cannot_appear_on_a_constructor_declaration: r(1092, 1, "Type_parameters_cannot_appear_on_a_constructor_declaration_1092", "Type parameters cannot appear on a constructor declaration."),
	Type_annotation_cannot_appear_on_a_constructor_declaration: r(1093, 1, "Type_annotation_cannot_appear_on_a_constructor_declaration_1093", "Type annotation cannot appear on a constructor declaration."),
	An_accessor_cannot_have_type_parameters: r(1094, 1, "An_accessor_cannot_have_type_parameters_1094", "An accessor cannot have type parameters."),
	A_set_accessor_cannot_have_a_return_type_annotation: r(1095, 1, "A_set_accessor_cannot_have_a_return_type_annotation_1095", "A 'set' accessor cannot have a return type annotation."),
	An_index_signature_must_have_exactly_one_parameter: r(1096, 1, "An_index_signature_must_have_exactly_one_parameter_1096", "An index signature must have exactly one parameter."),
	_0_list_cannot_be_empty: r(1097, 1, "_0_list_cannot_be_empty_1097", "'{0}' list cannot be empty."),
	Type_parameter_list_cannot_be_empty: r(1098, 1, "Type_parameter_list_cannot_be_empty_1098", "Type parameter list cannot be empty."),
	Type_argument_list_cannot_be_empty: r(1099, 1, "Type_argument_list_cannot_be_empty_1099", "Type argument list cannot be empty."),
	Invalid_use_of_0_in_strict_mode: r(1100, 1, "Invalid_use_of_0_in_strict_mode_1100", "Invalid use of '{0}' in strict mode."),
	with_statements_are_not_allowed_in_strict_mode: r(1101, 1, "with_statements_are_not_allowed_in_strict_mode_1101", "'with' statements are not allowed in strict mode."),
	delete_cannot_be_called_on_an_identifier_in_strict_mode: r(1102, 1, "delete_cannot_be_called_on_an_identifier_in_strict_mode_1102", "'delete' cannot be called on an identifier in strict mode."),
	for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules: r(1103, 1, "for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_1103", "'for await' loops are only allowed within async functions and at the top levels of modules."),
	A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement: r(1104, 1, "A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement_1104", "A 'continue' statement can only be used within an enclosing iteration statement."),
	A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement: r(1105, 1, "A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement_1105", "A 'break' statement can only be used within an enclosing iteration or switch statement."),
	The_left_hand_side_of_a_for_of_statement_may_not_be_async: r(1106, 1, "The_left_hand_side_of_a_for_of_statement_may_not_be_async_1106", "The left-hand side of a 'for...of' statement may not be 'async'."),
	Jump_target_cannot_cross_function_boundary: r(1107, 1, "Jump_target_cannot_cross_function_boundary_1107", "Jump target cannot cross function boundary."),
	A_return_statement_can_only_be_used_within_a_function_body: r(1108, 1, "A_return_statement_can_only_be_used_within_a_function_body_1108", "A 'return' statement can only be used within a function body."),
	Expression_expected: r(1109, 1, "Expression_expected_1109", "Expression expected."),
	Type_expected: r(1110, 1, "Type_expected_1110", "Type expected."),
	Private_field_0_must_be_declared_in_an_enclosing_class: r(1111, 1, "Private_field_0_must_be_declared_in_an_enclosing_class_1111", "Private field '{0}' must be declared in an enclosing class."),
	A_default_clause_cannot_appear_more_than_once_in_a_switch_statement: r(1113, 1, "A_default_clause_cannot_appear_more_than_once_in_a_switch_statement_1113", "A 'default' clause cannot appear more than once in a 'switch' statement."),
	Duplicate_label_0: r(1114, 1, "Duplicate_label_0_1114", "Duplicate label '{0}'."),
	A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement: r(1115, 1, "A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement_1115", "A 'continue' statement can only jump to a label of an enclosing iteration statement."),
	A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement: r(1116, 1, "A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement_1116", "A 'break' statement can only jump to a label of an enclosing statement."),
	An_object_literal_cannot_have_multiple_properties_with_the_same_name: r(1117, 1, "An_object_literal_cannot_have_multiple_properties_with_the_same_name_1117", "An object literal cannot have multiple properties with the same name."),
	An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name: r(1118, 1, "An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name_1118", "An object literal cannot have multiple get/set accessors with the same name."),
	An_object_literal_cannot_have_property_and_accessor_with_the_same_name: r(1119, 1, "An_object_literal_cannot_have_property_and_accessor_with_the_same_name_1119", "An object literal cannot have property and accessor with the same name."),
	An_export_assignment_cannot_have_modifiers: r(1120, 1, "An_export_assignment_cannot_have_modifiers_1120", "An export assignment cannot have modifiers."),
	Octal_literals_are_not_allowed_Use_the_syntax_0: r(1121, 1, "Octal_literals_are_not_allowed_Use_the_syntax_0_1121", "Octal literals are not allowed. Use the syntax '{0}'."),
	Variable_declaration_list_cannot_be_empty: r(1123, 1, "Variable_declaration_list_cannot_be_empty_1123", "Variable declaration list cannot be empty."),
	Digit_expected: r(1124, 1, "Digit_expected_1124", "Digit expected."),
	Hexadecimal_digit_expected: r(1125, 1, "Hexadecimal_digit_expected_1125", "Hexadecimal digit expected."),
	Unexpected_end_of_text: r(1126, 1, "Unexpected_end_of_text_1126", "Unexpected end of text."),
	Invalid_character: r(1127, 1, "Invalid_character_1127", "Invalid character."),
	Declaration_or_statement_expected: r(1128, 1, "Declaration_or_statement_expected_1128", "Declaration or statement expected."),
	Statement_expected: r(1129, 1, "Statement_expected_1129", "Statement expected."),
	case_or_default_expected: r(1130, 1, "case_or_default_expected_1130", "'case' or 'default' expected."),
	Property_or_signature_expected: r(1131, 1, "Property_or_signature_expected_1131", "Property or signature expected."),
	Enum_member_expected: r(1132, 1, "Enum_member_expected_1132", "Enum member expected."),
	Variable_declaration_expected: r(1134, 1, "Variable_declaration_expected_1134", "Variable declaration expected."),
	Argument_expression_expected: r(1135, 1, "Argument_expression_expected_1135", "Argument expression expected."),
	Property_assignment_expected: r(1136, 1, "Property_assignment_expected_1136", "Property assignment expected."),
	Expression_or_comma_expected: r(1137, 1, "Expression_or_comma_expected_1137", "Expression or comma expected."),
	Parameter_declaration_expected: r(1138, 1, "Parameter_declaration_expected_1138", "Parameter declaration expected."),
	Type_parameter_declaration_expected: r(1139, 1, "Type_parameter_declaration_expected_1139", "Type parameter declaration expected."),
	Type_argument_expected: r(1140, 1, "Type_argument_expected_1140", "Type argument expected."),
	String_literal_expected: r(1141, 1, "String_literal_expected_1141", "String literal expected."),
	Line_break_not_permitted_here: r(1142, 1, "Line_break_not_permitted_here_1142", "Line break not permitted here."),
	or_expected: r(1144, 1, "or_expected_1144", "'{' or ';' expected."),
	or_JSX_element_expected: r(1145, 1, "or_JSX_element_expected_1145", "'{' or JSX element expected."),
	Declaration_expected: r(1146, 1, "Declaration_expected_1146", "Declaration expected."),
	Import_declarations_in_a_namespace_cannot_reference_a_module: r(1147, 1, "Import_declarations_in_a_namespace_cannot_reference_a_module_1147", "Import declarations in a namespace cannot reference a module."),
	Cannot_use_imports_exports_or_module_augmentations_when_module_is_none: r(1148, 1, "Cannot_use_imports_exports_or_module_augmentations_when_module_is_none_1148", "Cannot use imports, exports, or module augmentations when '--module' is 'none'."),
	File_name_0_differs_from_already_included_file_name_1_only_in_casing: r(1149, 1, "File_name_0_differs_from_already_included_file_name_1_only_in_casing_1149", "File name '{0}' differs from already included file name '{1}' only in casing."),
	_0_declarations_must_be_initialized: r(1155, 1, "_0_declarations_must_be_initialized_1155", "'{0}' declarations must be initialized."),
	_0_declarations_can_only_be_declared_inside_a_block: r(1156, 1, "_0_declarations_can_only_be_declared_inside_a_block_1156", "'{0}' declarations can only be declared inside a block."),
	Unterminated_template_literal: r(1160, 1, "Unterminated_template_literal_1160", "Unterminated template literal."),
	Unterminated_regular_expression_literal: r(1161, 1, "Unterminated_regular_expression_literal_1161", "Unterminated regular expression literal."),
	An_object_member_cannot_be_declared_optional: r(1162, 1, "An_object_member_cannot_be_declared_optional_1162", "An object member cannot be declared optional."),
	A_yield_expression_is_only_allowed_in_a_generator_body: r(1163, 1, "A_yield_expression_is_only_allowed_in_a_generator_body_1163", "A 'yield' expression is only allowed in a generator body."),
	Computed_property_names_are_not_allowed_in_enums: r(1164, 1, "Computed_property_names_are_not_allowed_in_enums_1164", "Computed property names are not allowed in enums."),
	A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: r(1165, 1, "A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_t_1165", "A computed property name in an ambient context must refer to an expression whose type is a literal type or a 'unique symbol' type."),
	A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_symbol_type: r(1166, 1, "A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_1166", "A computed property name in a class property declaration must have a simple literal type or a 'unique symbol' type."),
	A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: r(1168, 1, "A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_ty_1168", "A computed property name in a method overload must refer to an expression whose type is a literal type or a 'unique symbol' type."),
	A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: r(1169, 1, "A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_1169", "A computed property name in an interface must refer to an expression whose type is a literal type or a 'unique symbol' type."),
	A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: r(1170, 1, "A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type__1170", "A computed property name in a type literal must refer to an expression whose type is a literal type or a 'unique symbol' type."),
	A_comma_expression_is_not_allowed_in_a_computed_property_name: r(1171, 1, "A_comma_expression_is_not_allowed_in_a_computed_property_name_1171", "A comma expression is not allowed in a computed property name."),
	extends_clause_already_seen: r(1172, 1, "extends_clause_already_seen_1172", "'extends' clause already seen."),
	extends_clause_must_precede_implements_clause: r(1173, 1, "extends_clause_must_precede_implements_clause_1173", "'extends' clause must precede 'implements' clause."),
	Classes_can_only_extend_a_single_class: r(1174, 1, "Classes_can_only_extend_a_single_class_1174", "Classes can only extend a single class."),
	implements_clause_already_seen: r(1175, 1, "implements_clause_already_seen_1175", "'implements' clause already seen."),
	Interface_declaration_cannot_have_implements_clause: r(1176, 1, "Interface_declaration_cannot_have_implements_clause_1176", "Interface declaration cannot have 'implements' clause."),
	Binary_digit_expected: r(1177, 1, "Binary_digit_expected_1177", "Binary digit expected."),
	Octal_digit_expected: r(1178, 1, "Octal_digit_expected_1178", "Octal digit expected."),
	Unexpected_token_expected: r(1179, 1, "Unexpected_token_expected_1179", "Unexpected token. '{' expected."),
	Property_destructuring_pattern_expected: r(1180, 1, "Property_destructuring_pattern_expected_1180", "Property destructuring pattern expected."),
	Array_element_destructuring_pattern_expected: r(1181, 1, "Array_element_destructuring_pattern_expected_1181", "Array element destructuring pattern expected."),
	A_destructuring_declaration_must_have_an_initializer: r(1182, 1, "A_destructuring_declaration_must_have_an_initializer_1182", "A destructuring declaration must have an initializer."),
	An_implementation_cannot_be_declared_in_ambient_contexts: r(1183, 1, "An_implementation_cannot_be_declared_in_ambient_contexts_1183", "An implementation cannot be declared in ambient contexts."),
	Modifiers_cannot_appear_here: r(1184, 1, "Modifiers_cannot_appear_here_1184", "Modifiers cannot appear here."),
	Merge_conflict_marker_encountered: r(1185, 1, "Merge_conflict_marker_encountered_1185", "Merge conflict marker encountered."),
	A_rest_element_cannot_have_an_initializer: r(1186, 1, "A_rest_element_cannot_have_an_initializer_1186", "A rest element cannot have an initializer."),
	A_parameter_property_may_not_be_declared_using_a_binding_pattern: r(1187, 1, "A_parameter_property_may_not_be_declared_using_a_binding_pattern_1187", "A parameter property may not be declared using a binding pattern."),
	Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement: r(1188, 1, "Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement_1188", "Only a single variable declaration is allowed in a 'for...of' statement."),
	The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer: r(1189, 1, "The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer_1189", "The variable declaration of a 'for...in' statement cannot have an initializer."),
	The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer: r(1190, 1, "The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer_1190", "The variable declaration of a 'for...of' statement cannot have an initializer."),
	An_import_declaration_cannot_have_modifiers: r(1191, 1, "An_import_declaration_cannot_have_modifiers_1191", "An import declaration cannot have modifiers."),
	Module_0_has_no_default_export: r(1192, 1, "Module_0_has_no_default_export_1192", "Module '{0}' has no default export."),
	An_export_declaration_cannot_have_modifiers: r(1193, 1, "An_export_declaration_cannot_have_modifiers_1193", "An export declaration cannot have modifiers."),
	Export_declarations_are_not_permitted_in_a_namespace: r(1194, 1, "Export_declarations_are_not_permitted_in_a_namespace_1194", "Export declarations are not permitted in a namespace."),
	export_Asterisk_does_not_re_export_a_default: r(1195, 1, "export_Asterisk_does_not_re_export_a_default_1195", "'export *' does not re-export a default."),
	Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified: r(1196, 1, "Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified_1196", "Catch clause variable type annotation must be 'any' or 'unknown' if specified."),
	Catch_clause_variable_cannot_have_an_initializer: r(1197, 1, "Catch_clause_variable_cannot_have_an_initializer_1197", "Catch clause variable cannot have an initializer."),
	An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive: r(1198, 1, "An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive_1198", "An extended Unicode escape value must be between 0x0 and 0x10FFFF inclusive."),
	Unterminated_Unicode_escape_sequence: r(1199, 1, "Unterminated_Unicode_escape_sequence_1199", "Unterminated Unicode escape sequence."),
	Line_terminator_not_permitted_before_arrow: r(1200, 1, "Line_terminator_not_permitted_before_arrow_1200", "Line terminator not permitted before arrow."),
	Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_ns_from_mod_import_a_from_mod_import_d_from_mod_or_another_module_format_instead: r(1202, 1, "Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_1202", `Import assignment cannot be used when targeting ECMAScript modules. Consider using 'import * as ns from "mod"', 'import {a} from "mod"', 'import d from "mod"', or another module format instead.`),
	Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or_another_module_format_instead: r(1203, 1, "Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or__1203", "Export assignment cannot be used when targeting ECMAScript modules. Consider using 'export default' or another module format instead."),
	Re_exporting_a_type_when_0_is_enabled_requires_using_export_type: r(1205, 1, "Re_exporting_a_type_when_0_is_enabled_requires_using_export_type_1205", "Re-exporting a type when '{0}' is enabled requires using 'export type'."),
	Decorators_are_not_valid_here: r(1206, 1, "Decorators_are_not_valid_here_1206", "Decorators are not valid here."),
	Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name: r(1207, 1, "Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name_1207", "Decorators cannot be applied to multiple get/set accessors of the same name."),
	Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0: r(1209, 1, "Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0_1209", "Invalid optional chain from new expression. Did you mean to call '{0}()'?"),
	Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of_0_For_more_information_see_https_Colon_Slash_Slashdeveloper_mozilla_org_Slashen_US_Slashdocs_SlashWeb_SlashJavaScript_SlashReference_SlashStrict_mode: r(1210, 1, "Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of__1210", "Code contained in a class is evaluated in JavaScript's strict mode which does not allow this use of '{0}'. For more information, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Strict_mode."),
	A_class_declaration_without_the_default_modifier_must_have_a_name: r(1211, 1, "A_class_declaration_without_the_default_modifier_must_have_a_name_1211", "A class declaration without the 'default' modifier must have a name."),
	Identifier_expected_0_is_a_reserved_word_in_strict_mode: r(1212, 1, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_1212", "Identifier expected. '{0}' is a reserved word in strict mode."),
	Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_strict_mode: r(1213, 1, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_stric_1213", "Identifier expected. '{0}' is a reserved word in strict mode. Class definitions are automatically in strict mode."),
	Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode: r(1214, 1, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode_1214", "Identifier expected. '{0}' is a reserved word in strict mode. Modules are automatically in strict mode."),
	Invalid_use_of_0_Modules_are_automatically_in_strict_mode: r(1215, 1, "Invalid_use_of_0_Modules_are_automatically_in_strict_mode_1215", "Invalid use of '{0}'. Modules are automatically in strict mode."),
	Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules: r(1216, 1, "Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules_1216", "Identifier expected. '__esModule' is reserved as an exported marker when transforming ECMAScript modules."),
	Export_assignment_is_not_supported_when_module_flag_is_system: r(1218, 1, "Export_assignment_is_not_supported_when_module_flag_is_system_1218", "Export assignment is not supported when '--module' flag is 'system'."),
	Generators_are_not_allowed_in_an_ambient_context: r(1221, 1, "Generators_are_not_allowed_in_an_ambient_context_1221", "Generators are not allowed in an ambient context."),
	An_overload_signature_cannot_be_declared_as_a_generator: r(1222, 1, "An_overload_signature_cannot_be_declared_as_a_generator_1222", "An overload signature cannot be declared as a generator."),
	_0_tag_already_specified: r(1223, 1, "_0_tag_already_specified_1223", "'{0}' tag already specified."),
	Signature_0_must_be_a_type_predicate: r(1224, 1, "Signature_0_must_be_a_type_predicate_1224", "Signature '{0}' must be a type predicate."),
	Cannot_find_parameter_0: r(1225, 1, "Cannot_find_parameter_0_1225", "Cannot find parameter '{0}'."),
	Type_predicate_0_is_not_assignable_to_1: r(1226, 1, "Type_predicate_0_is_not_assignable_to_1_1226", "Type predicate '{0}' is not assignable to '{1}'."),
	Parameter_0_is_not_in_the_same_position_as_parameter_1: r(1227, 1, "Parameter_0_is_not_in_the_same_position_as_parameter_1_1227", "Parameter '{0}' is not in the same position as parameter '{1}'."),
	A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods: r(1228, 1, "A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods_1228", "A type predicate is only allowed in return type position for functions and methods."),
	A_type_predicate_cannot_reference_a_rest_parameter: r(1229, 1, "A_type_predicate_cannot_reference_a_rest_parameter_1229", "A type predicate cannot reference a rest parameter."),
	A_type_predicate_cannot_reference_element_0_in_a_binding_pattern: r(1230, 1, "A_type_predicate_cannot_reference_element_0_in_a_binding_pattern_1230", "A type predicate cannot reference element '{0}' in a binding pattern."),
	An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration: r(1231, 1, "An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration_1231", "An export assignment must be at the top level of a file or module declaration."),
	An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module: r(1232, 1, "An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module_1232", "An import declaration can only be used at the top level of a namespace or module."),
	An_export_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module: r(1233, 1, "An_export_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module_1233", "An export declaration can only be used at the top level of a namespace or module."),
	An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file: r(1234, 1, "An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file_1234", "An ambient module declaration is only allowed at the top level in a file."),
	A_namespace_declaration_is_only_allowed_at_the_top_level_of_a_namespace_or_module: r(1235, 1, "A_namespace_declaration_is_only_allowed_at_the_top_level_of_a_namespace_or_module_1235", "A namespace declaration is only allowed at the top level of a namespace or module."),
	The_return_type_of_a_property_decorator_function_must_be_either_void_or_any: r(1236, 1, "The_return_type_of_a_property_decorator_function_must_be_either_void_or_any_1236", "The return type of a property decorator function must be either 'void' or 'any'."),
	The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any: r(1237, 1, "The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any_1237", "The return type of a parameter decorator function must be either 'void' or 'any'."),
	Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression: r(1238, 1, "Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression_1238", "Unable to resolve signature of class decorator when called as an expression."),
	Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression: r(1239, 1, "Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression_1239", "Unable to resolve signature of parameter decorator when called as an expression."),
	Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression: r(1240, 1, "Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression_1240", "Unable to resolve signature of property decorator when called as an expression."),
	Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression: r(1241, 1, "Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression_1241", "Unable to resolve signature of method decorator when called as an expression."),
	abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration: r(1242, 1, "abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration_1242", "'abstract' modifier can only appear on a class, method, or property declaration."),
	_0_modifier_cannot_be_used_with_1_modifier: r(1243, 1, "_0_modifier_cannot_be_used_with_1_modifier_1243", "'{0}' modifier cannot be used with '{1}' modifier."),
	Abstract_methods_can_only_appear_within_an_abstract_class: r(1244, 1, "Abstract_methods_can_only_appear_within_an_abstract_class_1244", "Abstract methods can only appear within an abstract class."),
	Method_0_cannot_have_an_implementation_because_it_is_marked_abstract: r(1245, 1, "Method_0_cannot_have_an_implementation_because_it_is_marked_abstract_1245", "Method '{0}' cannot have an implementation because it is marked abstract."),
	An_interface_property_cannot_have_an_initializer: r(1246, 1, "An_interface_property_cannot_have_an_initializer_1246", "An interface property cannot have an initializer."),
	A_type_literal_property_cannot_have_an_initializer: r(1247, 1, "A_type_literal_property_cannot_have_an_initializer_1247", "A type literal property cannot have an initializer."),
	A_class_member_cannot_have_the_0_keyword: r(1248, 1, "A_class_member_cannot_have_the_0_keyword_1248", "A class member cannot have the '{0}' keyword."),
	A_decorator_can_only_decorate_a_method_implementation_not_an_overload: r(1249, 1, "A_decorator_can_only_decorate_a_method_implementation_not_an_overload_1249", "A decorator can only decorate a method implementation, not an overload."),
	Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES5: r(1250, 1, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES5_1250", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES5'."),
	Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES5_Class_definitions_are_automatically_in_strict_mode: r(1251, 1, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES5_Class_definiti_1251", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES5'. Class definitions are automatically in strict mode."),
	Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES5_Modules_are_automatically_in_strict_mode: r(1252, 1, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES5_Modules_are_au_1252", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES5'. Modules are automatically in strict mode."),
	Abstract_properties_can_only_appear_within_an_abstract_class: r(1253, 1, "Abstract_properties_can_only_appear_within_an_abstract_class_1253", "Abstract properties can only appear within an abstract class."),
	A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_reference: r(1254, 1, "A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_refere_1254", "A 'const' initializer in an ambient context must be a string or numeric literal or literal enum reference."),
	A_definite_assignment_assertion_is_not_permitted_in_this_context: r(1255, 1, "A_definite_assignment_assertion_is_not_permitted_in_this_context_1255", "A definite assignment assertion '!' is not permitted in this context."),
	A_required_element_cannot_follow_an_optional_element: r(1257, 1, "A_required_element_cannot_follow_an_optional_element_1257", "A required element cannot follow an optional element."),
	A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration: r(1258, 1, "A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration_1258", "A default export must be at the top level of a file or module declaration."),
	Module_0_can_only_be_default_imported_using_the_1_flag: r(1259, 1, "Module_0_can_only_be_default_imported_using_the_1_flag_1259", "Module '{0}' can only be default-imported using the '{1}' flag"),
	Keywords_cannot_contain_escape_characters: r(1260, 1, "Keywords_cannot_contain_escape_characters_1260", "Keywords cannot contain escape characters."),
	Already_included_file_name_0_differs_from_file_name_1_only_in_casing: r(1261, 1, "Already_included_file_name_0_differs_from_file_name_1_only_in_casing_1261", "Already included file name '{0}' differs from file name '{1}' only in casing."),
	Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module: r(1262, 1, "Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module_1262", "Identifier expected. '{0}' is a reserved word at the top-level of a module."),
	Declarations_with_initializers_cannot_also_have_definite_assignment_assertions: r(1263, 1, "Declarations_with_initializers_cannot_also_have_definite_assignment_assertions_1263", "Declarations with initializers cannot also have definite assignment assertions."),
	Declarations_with_definite_assignment_assertions_must_also_have_type_annotations: r(1264, 1, "Declarations_with_definite_assignment_assertions_must_also_have_type_annotations_1264", "Declarations with definite assignment assertions must also have type annotations."),
	A_rest_element_cannot_follow_another_rest_element: r(1265, 1, "A_rest_element_cannot_follow_another_rest_element_1265", "A rest element cannot follow another rest element."),
	An_optional_element_cannot_follow_a_rest_element: r(1266, 1, "An_optional_element_cannot_follow_a_rest_element_1266", "An optional element cannot follow a rest element."),
	Property_0_cannot_have_an_initializer_because_it_is_marked_abstract: r(1267, 1, "Property_0_cannot_have_an_initializer_because_it_is_marked_abstract_1267", "Property '{0}' cannot have an initializer because it is marked abstract."),
	An_index_signature_parameter_type_must_be_string_number_symbol_or_a_template_literal_type: r(1268, 1, "An_index_signature_parameter_type_must_be_string_number_symbol_or_a_template_literal_type_1268", "An index signature parameter type must be 'string', 'number', 'symbol', or a template literal type."),
	Cannot_use_export_import_on_a_type_or_type_only_namespace_when_0_is_enabled: r(1269, 1, "Cannot_use_export_import_on_a_type_or_type_only_namespace_when_0_is_enabled_1269", "Cannot use 'export import' on a type or type-only namespace when '{0}' is enabled."),
	Decorator_function_return_type_0_is_not_assignable_to_type_1: r(1270, 1, "Decorator_function_return_type_0_is_not_assignable_to_type_1_1270", "Decorator function return type '{0}' is not assignable to type '{1}'."),
	Decorator_function_return_type_is_0_but_is_expected_to_be_void_or_any: r(1271, 1, "Decorator_function_return_type_is_0_but_is_expected_to_be_void_or_any_1271", "Decorator function return type is '{0}' but is expected to be 'void' or 'any'."),
	A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_when_isolatedModules_and_emitDecoratorMetadata_are_enabled: r(1272, 1, "A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_w_1272", "A type referenced in a decorated signature must be imported with 'import type' or a namespace import when 'isolatedModules' and 'emitDecoratorMetadata' are enabled."),
	_0_modifier_cannot_appear_on_a_type_parameter: r(1273, 1, "_0_modifier_cannot_appear_on_a_type_parameter_1273", "'{0}' modifier cannot appear on a type parameter"),
	_0_modifier_can_only_appear_on_a_type_parameter_of_a_class_interface_or_type_alias: r(1274, 1, "_0_modifier_can_only_appear_on_a_type_parameter_of_a_class_interface_or_type_alias_1274", "'{0}' modifier can only appear on a type parameter of a class, interface or type alias"),
	accessor_modifier_can_only_appear_on_a_property_declaration: r(1275, 1, "accessor_modifier_can_only_appear_on_a_property_declaration_1275", "'accessor' modifier can only appear on a property declaration."),
	An_accessor_property_cannot_be_declared_optional: r(1276, 1, "An_accessor_property_cannot_be_declared_optional_1276", "An 'accessor' property cannot be declared optional."),
	_0_modifier_can_only_appear_on_a_type_parameter_of_a_function_method_or_class: r(1277, 1, "_0_modifier_can_only_appear_on_a_type_parameter_of_a_function_method_or_class_1277", "'{0}' modifier can only appear on a type parameter of a function, method or class"),
	The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_0: r(1278, 1, "The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_0_1278", "The runtime will invoke the decorator with {1} arguments, but the decorator expects {0}."),
	The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_at_least_0: r(1279, 1, "The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_at_least_0_1279", "The runtime will invoke the decorator with {1} arguments, but the decorator expects at least {0}."),
	Namespaces_are_not_allowed_in_global_script_files_when_0_is_enabled_If_this_file_is_not_intended_to_be_a_global_script_set_moduleDetection_to_force_or_add_an_empty_export_statement: r(1280, 1, "Namespaces_are_not_allowed_in_global_script_files_when_0_is_enabled_If_this_file_is_not_intended_to__1280", "Namespaces are not allowed in global script files when '{0}' is enabled. If this file is not intended to be a global script, set 'moduleDetection' to 'force' or add an empty 'export {}' statement."),
	Cannot_access_0_from_another_file_without_qualification_when_1_is_enabled_Use_2_instead: r(1281, 1, "Cannot_access_0_from_another_file_without_qualification_when_1_is_enabled_Use_2_instead_1281", "Cannot access '{0}' from another file without qualification when '{1}' is enabled. Use '{2}' instead."),
	An_export_declaration_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_type: r(1282, 1, "An_export_declaration_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers__1282", "An 'export =' declaration must reference a value when 'verbatimModuleSyntax' is enabled, but '{0}' only refers to a type."),
	An_export_declaration_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_a_type_only_declaration: r(1283, 1, "An_export_declaration_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolve_1283", "An 'export =' declaration must reference a real value when 'verbatimModuleSyntax' is enabled, but '{0}' resolves to a type-only declaration."),
	An_export_default_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_type: r(1284, 1, "An_export_default_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_1284", "An 'export default' must reference a value when 'verbatimModuleSyntax' is enabled, but '{0}' only refers to a type."),
	An_export_default_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_a_type_only_declaration: r(1285, 1, "An_export_default_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_1285", "An 'export default' must reference a real value when 'verbatimModuleSyntax' is enabled, but '{0}' resolves to a type-only declaration."),
	ECMAScript_imports_and_exports_cannot_be_written_in_a_CommonJS_file_under_verbatimModuleSyntax: r(1286, 1, "ECMAScript_imports_and_exports_cannot_be_written_in_a_CommonJS_file_under_verbatimModuleSyntax_1286", "ECMAScript imports and exports cannot be written in a CommonJS file under 'verbatimModuleSyntax'."),
	A_top_level_export_modifier_cannot_be_used_on_value_declarations_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled: r(1287, 1, "A_top_level_export_modifier_cannot_be_used_on_value_declarations_in_a_CommonJS_module_when_verbatimM_1287", "A top-level 'export' modifier cannot be used on value declarations in a CommonJS module when 'verbatimModuleSyntax' is enabled."),
	An_import_alias_cannot_resolve_to_a_type_or_type_only_declaration_when_verbatimModuleSyntax_is_enabled: r(1288, 1, "An_import_alias_cannot_resolve_to_a_type_or_type_only_declaration_when_verbatimModuleSyntax_is_enabl_1288", "An import alias cannot resolve to a type or type-only declaration when 'verbatimModuleSyntax' is enabled."),
	_0_resolves_to_a_type_only_declaration_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_import_type_where_0_is_imported: r(1289, 1, "_0_resolves_to_a_type_only_declaration_and_must_be_marked_type_only_in_this_file_before_re_exporting_1289", "'{0}' resolves to a type-only declaration and must be marked type-only in this file before re-exporting when '{1}' is enabled. Consider using 'import type' where '{0}' is imported."),
	_0_resolves_to_a_type_only_declaration_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_export_type_0_as_default: r(1290, 1, "_0_resolves_to_a_type_only_declaration_and_must_be_marked_type_only_in_this_file_before_re_exporting_1290", "'{0}' resolves to a type-only declaration and must be marked type-only in this file before re-exporting when '{1}' is enabled. Consider using 'export type { {0} as default }'."),
	_0_resolves_to_a_type_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_import_type_where_0_is_imported: r(1291, 1, "_0_resolves_to_a_type_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enable_1291", "'{0}' resolves to a type and must be marked type-only in this file before re-exporting when '{1}' is enabled. Consider using 'import type' where '{0}' is imported."),
	_0_resolves_to_a_type_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_export_type_0_as_default: r(1292, 1, "_0_resolves_to_a_type_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enable_1292", "'{0}' resolves to a type and must be marked type-only in this file before re-exporting when '{1}' is enabled. Consider using 'export type { {0} as default }'."),
	ECMAScript_module_syntax_is_not_allowed_in_a_CommonJS_module_when_module_is_set_to_preserve: r(1293, 1, "ECMAScript_module_syntax_is_not_allowed_in_a_CommonJS_module_when_module_is_set_to_preserve_1293", "ECMAScript module syntax is not allowed in a CommonJS module when 'module' is set to 'preserve'."),
	This_syntax_is_not_allowed_when_erasableSyntaxOnly_is_enabled: r(1294, 1, "This_syntax_is_not_allowed_when_erasableSyntaxOnly_is_enabled_1294", "This syntax is not allowed when 'erasableSyntaxOnly' is enabled."),
	ECMAScript_imports_and_exports_cannot_be_written_in_a_CommonJS_file_under_verbatimModuleSyntax_Adjust_the_type_field_in_the_nearest_package_json_to_make_this_file_an_ECMAScript_module_or_adjust_your_verbatimModuleSyntax_module_and_moduleResolution_settings_in_TypeScript: r(1295, 1, "ECMAScript_imports_and_exports_cannot_be_written_in_a_CommonJS_file_under_verbatimModuleSyntax_Adjus_1295", "ECMAScript imports and exports cannot be written in a CommonJS file under 'verbatimModuleSyntax'. Adjust the 'type' field in the nearest 'package.json' to make this file an ECMAScript module, or adjust your 'verbatimModuleSyntax', 'module', and 'moduleResolution' settings in TypeScript."),
	with_statements_are_not_allowed_in_an_async_function_block: r(1300, 1, "with_statements_are_not_allowed_in_an_async_function_block_1300", "'with' statements are not allowed in an async function block."),
	await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules: r(1308, 1, "await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_1308", "'await' expressions are only allowed within async functions and at the top levels of modules."),
	The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level: r(1309, 1, "The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level_1309", "The current file is a CommonJS module and cannot use 'await' at the top level."),
	Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern: r(1312, 1, "Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_1312", "Did you mean to use a ':'? An '=' can only follow a property name when the containing object literal is part of a destructuring pattern."),
	The_body_of_an_if_statement_cannot_be_the_empty_statement: r(1313, 1, "The_body_of_an_if_statement_cannot_be_the_empty_statement_1313", "The body of an 'if' statement cannot be the empty statement."),
	Global_module_exports_may_only_appear_in_module_files: r(1314, 1, "Global_module_exports_may_only_appear_in_module_files_1314", "Global module exports may only appear in module files."),
	Global_module_exports_may_only_appear_in_declaration_files: r(1315, 1, "Global_module_exports_may_only_appear_in_declaration_files_1315", "Global module exports may only appear in declaration files."),
	Global_module_exports_may_only_appear_at_top_level: r(1316, 1, "Global_module_exports_may_only_appear_at_top_level_1316", "Global module exports may only appear at top level."),
	A_parameter_property_cannot_be_declared_using_a_rest_parameter: r(1317, 1, "A_parameter_property_cannot_be_declared_using_a_rest_parameter_1317", "A parameter property cannot be declared using a rest parameter."),
	An_abstract_accessor_cannot_have_an_implementation: r(1318, 1, "An_abstract_accessor_cannot_have_an_implementation_1318", "An abstract accessor cannot have an implementation."),
	A_default_export_can_only_be_used_in_an_ECMAScript_style_module: r(1319, 1, "A_default_export_can_only_be_used_in_an_ECMAScript_style_module_1319", "A default export can only be used in an ECMAScript-style module."),
	Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: r(1320, 1, "Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member_1320", "Type of 'await' operand must either be a valid promise or must not contain a callable 'then' member."),
	Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: r(1321, 1, "Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_cal_1321", "Type of 'yield' operand in an async generator must either be a valid promise or must not contain a callable 'then' member."),
	Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: r(1322, 1, "Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_con_1322", "Type of iterated elements of a 'yield*' operand must either be a valid promise or must not contain a callable 'then' member."),
	Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_es2022_esnext_commonjs_amd_system_umd_node16_node18_node20_or_nodenext: r(1323, 1, "Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_es2022_esnext_commonjs_amd__1323", "Dynamic imports are only supported when the '--module' flag is set to 'es2020', 'es2022', 'esnext', 'commonjs', 'amd', 'system', 'umd', 'node16', 'node18', 'node20', or 'nodenext'."),
	Dynamic_imports_only_support_a_second_argument_when_the_module_option_is_set_to_esnext_node16_node18_node20_nodenext_or_preserve: r(1324, 1, "Dynamic_imports_only_support_a_second_argument_when_the_module_option_is_set_to_esnext_node16_node18_1324", "Dynamic imports only support a second argument when the '--module' option is set to 'esnext', 'node16', 'node18', 'node20', 'nodenext', or 'preserve'."),
	Argument_of_dynamic_import_cannot_be_spread_element: r(1325, 1, "Argument_of_dynamic_import_cannot_be_spread_element_1325", "Argument of dynamic import cannot be spread element."),
	This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot_have_type_arguments: r(1326, 1, "This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot__1326", "This use of 'import' is invalid. 'import()' calls can be written, but they must have parentheses and cannot have type arguments."),
	String_literal_with_double_quotes_expected: r(1327, 1, "String_literal_with_double_quotes_expected_1327", "String literal with double quotes expected."),
	Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_literal: r(1328, 1, "Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_li_1328", "Property value can only be string literal, numeric literal, 'true', 'false', 'null', object literal or array literal."),
	_0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write_0: r(1329, 1, "_0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write__1329", "'{0}' accepts too few arguments to be used as a decorator here. Did you mean to call it first and write '@{0}()'?"),
	A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly: r(1330, 1, "A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly_1330", "A property of an interface or type literal whose type is a 'unique symbol' type must be 'readonly'."),
	A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly: r(1331, 1, "A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly_1331", "A property of a class whose type is a 'unique symbol' type must be both 'static' and 'readonly'."),
	A_variable_whose_type_is_a_unique_symbol_type_must_be_const: r(1332, 1, "A_variable_whose_type_is_a_unique_symbol_type_must_be_const_1332", "A variable whose type is a 'unique symbol' type must be 'const'."),
	unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name: r(1333, 1, "unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name_1333", "'unique symbol' types may not be used on a variable declaration with a binding name."),
	unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement: r(1334, 1, "unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement_1334", "'unique symbol' types are only allowed on variables in a variable statement."),
	unique_symbol_types_are_not_allowed_here: r(1335, 1, "unique_symbol_types_are_not_allowed_here_1335", "'unique symbol' types are not allowed here."),
	An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_object_type_instead: r(1337, 1, "An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_o_1337", "An index signature parameter type cannot be a literal type or generic type. Consider using a mapped object type instead."),
	infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type: r(1338, 1, "infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type_1338", "'infer' declarations are only permitted in the 'extends' clause of a conditional type."),
	Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here: r(1339, 1, "Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here_1339", "Module '{0}' does not refer to a value, but is used as a value here."),
	Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0: r(1340, 1, "Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0_1340", "Module '{0}' does not refer to a type, but is used as a type here. Did you mean 'typeof import('{0}')'?"),
	Class_constructor_may_not_be_an_accessor: r(1341, 1, "Class_constructor_may_not_be_an_accessor_1341", "Class constructor may not be an accessor."),
	The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_es2022_esnext_system_node16_node18_node20_or_nodenext: r(1343, 1, "The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_es2022_esnext_system__1343", "The 'import.meta' meta-property is only allowed when the '--module' option is 'es2020', 'es2022', 'esnext', 'system', 'node16', 'node18', 'node20', or 'nodenext'."),
	A_label_is_not_allowed_here: r(1344, 1, "A_label_is_not_allowed_here_1344", "'A label is not allowed here."),
	An_expression_of_type_void_cannot_be_tested_for_truthiness: r(1345, 1, "An_expression_of_type_void_cannot_be_tested_for_truthiness_1345", "An expression of type 'void' cannot be tested for truthiness."),
	This_parameter_is_not_allowed_with_use_strict_directive: r(1346, 1, "This_parameter_is_not_allowed_with_use_strict_directive_1346", "This parameter is not allowed with 'use strict' directive."),
	use_strict_directive_cannot_be_used_with_non_simple_parameter_list: r(1347, 1, "use_strict_directive_cannot_be_used_with_non_simple_parameter_list_1347", "'use strict' directive cannot be used with non-simple parameter list."),
	Non_simple_parameter_declared_here: r(1348, 1, "Non_simple_parameter_declared_here_1348", "Non-simple parameter declared here."),
	use_strict_directive_used_here: r(1349, 1, "use_strict_directive_used_here_1349", "'use strict' directive used here."),
	Print_the_final_configuration_instead_of_building: r(1350, 3, "Print_the_final_configuration_instead_of_building_1350", "Print the final configuration instead of building."),
	An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal: r(1351, 1, "An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal_1351", "An identifier or keyword cannot immediately follow a numeric literal."),
	A_bigint_literal_cannot_use_exponential_notation: r(1352, 1, "A_bigint_literal_cannot_use_exponential_notation_1352", "A bigint literal cannot use exponential notation."),
	A_bigint_literal_must_be_an_integer: r(1353, 1, "A_bigint_literal_must_be_an_integer_1353", "A bigint literal must be an integer."),
	readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types: r(1354, 1, "readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types_1354", "'readonly' type modifier is only permitted on array and tuple literal types."),
	A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array_or_object_literals: r(1355, 1, "A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array__1355", "A 'const' assertions can only be applied to references to enum members, or string, number, boolean, array, or object literals."),
	Did_you_mean_to_mark_this_function_as_async: r(1356, 1, "Did_you_mean_to_mark_this_function_as_async_1356", "Did you mean to mark this function as 'async'?"),
	An_enum_member_name_must_be_followed_by_a_or: r(1357, 1, "An_enum_member_name_must_be_followed_by_a_or_1357", "An enum member name must be followed by a ',', '=', or '}'."),
	Tagged_template_expressions_are_not_permitted_in_an_optional_chain: r(1358, 1, "Tagged_template_expressions_are_not_permitted_in_an_optional_chain_1358", "Tagged template expressions are not permitted in an optional chain."),
	Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here: r(1359, 1, "Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here_1359", "Identifier expected. '{0}' is a reserved word that cannot be used here."),
	Type_0_does_not_satisfy_the_expected_type_1: r(1360, 1, "Type_0_does_not_satisfy_the_expected_type_1_1360", "Type '{0}' does not satisfy the expected type '{1}'."),
	_0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type: r(1361, 1, "_0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type_1361", "'{0}' cannot be used as a value because it was imported using 'import type'."),
	_0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type: r(1362, 1, "_0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type_1362", "'{0}' cannot be used as a value because it was exported using 'export type'."),
	A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both: r(1363, 1, "A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both_1363", "A type-only import can specify a default import or named bindings, but not both."),
	Convert_to_type_only_export: r(1364, 3, "Convert_to_type_only_export_1364", "Convert to type-only export"),
	Convert_all_re_exported_types_to_type_only_exports: r(1365, 3, "Convert_all_re_exported_types_to_type_only_exports_1365", "Convert all re-exported types to type-only exports"),
	Split_into_two_separate_import_declarations: r(1366, 3, "Split_into_two_separate_import_declarations_1366", "Split into two separate import declarations"),
	Split_all_invalid_type_only_imports: r(1367, 3, "Split_all_invalid_type_only_imports_1367", "Split all invalid type-only imports"),
	Class_constructor_may_not_be_a_generator: r(1368, 1, "Class_constructor_may_not_be_a_generator_1368", "Class constructor may not be a generator."),
	Did_you_mean_0: r(1369, 3, "Did_you_mean_0_1369", "Did you mean '{0}'?"),
	await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module: r(1375, 1, "await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_fi_1375", "'await' expressions are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."),
	_0_was_imported_here: r(1376, 3, "_0_was_imported_here_1376", "'{0}' was imported here."),
	_0_was_exported_here: r(1377, 3, "_0_was_exported_here_1377", "'{0}' was exported here."),
	Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_node18_node20_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher: r(1378, 1, "Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_n_1378", "Top-level 'await' expressions are only allowed when the 'module' option is set to 'es2022', 'esnext', 'system', 'node16', 'node18', 'node20', 'nodenext', or 'preserve', and the 'target' option is set to 'es2017' or higher."),
	An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type: r(1379, 1, "An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type_1379", "An import alias cannot reference a declaration that was exported using 'export type'."),
	An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type: r(1380, 1, "An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type_1380", "An import alias cannot reference a declaration that was imported using 'import type'."),
	Unexpected_token_Did_you_mean_or_rbrace: r(1381, 1, "Unexpected_token_Did_you_mean_or_rbrace_1381", "Unexpected token. Did you mean `{'}'}` or `&rbrace;`?"),
	Unexpected_token_Did_you_mean_or_gt: r(1382, 1, "Unexpected_token_Did_you_mean_or_gt_1382", "Unexpected token. Did you mean `{'>'}` or `&gt;`?"),
	Function_type_notation_must_be_parenthesized_when_used_in_a_union_type: r(1385, 1, "Function_type_notation_must_be_parenthesized_when_used_in_a_union_type_1385", "Function type notation must be parenthesized when used in a union type."),
	Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type: r(1386, 1, "Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type_1386", "Constructor type notation must be parenthesized when used in a union type."),
	Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type: r(1387, 1, "Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type_1387", "Function type notation must be parenthesized when used in an intersection type."),
	Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type: r(1388, 1, "Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type_1388", "Constructor type notation must be parenthesized when used in an intersection type."),
	_0_is_not_allowed_as_a_variable_declaration_name: r(1389, 1, "_0_is_not_allowed_as_a_variable_declaration_name_1389", "'{0}' is not allowed as a variable declaration name."),
	_0_is_not_allowed_as_a_parameter_name: r(1390, 1, "_0_is_not_allowed_as_a_parameter_name_1390", "'{0}' is not allowed as a parameter name."),
	An_import_alias_cannot_use_import_type: r(1392, 1, "An_import_alias_cannot_use_import_type_1392", "An import alias cannot use 'import type'"),
	Imported_via_0_from_file_1: r(1393, 3, "Imported_via_0_from_file_1_1393", "Imported via {0} from file '{1}'"),
	Imported_via_0_from_file_1_with_packageId_2: r(1394, 3, "Imported_via_0_from_file_1_with_packageId_2_1394", "Imported via {0} from file '{1}' with packageId '{2}'"),
	Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions: r(1395, 3, "Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions_1395", "Imported via {0} from file '{1}' to import 'importHelpers' as specified in compilerOptions"),
	Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions: r(1396, 3, "Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions_1396", "Imported via {0} from file '{1}' with packageId '{2}' to import 'importHelpers' as specified in compilerOptions"),
	Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions: r(1397, 3, "Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions_1397", "Imported via {0} from file '{1}' to import 'jsx' and 'jsxs' factory functions"),
	Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions: r(1398, 3, "Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions_1398", "Imported via {0} from file '{1}' with packageId '{2}' to import 'jsx' and 'jsxs' factory functions"),
	File_is_included_via_import_here: r(1399, 3, "File_is_included_via_import_here_1399", "File is included via import here."),
	Referenced_via_0_from_file_1: r(1400, 3, "Referenced_via_0_from_file_1_1400", "Referenced via '{0}' from file '{1}'"),
	File_is_included_via_reference_here: r(1401, 3, "File_is_included_via_reference_here_1401", "File is included via reference here."),
	Type_library_referenced_via_0_from_file_1: r(1402, 3, "Type_library_referenced_via_0_from_file_1_1402", "Type library referenced via '{0}' from file '{1}'"),
	Type_library_referenced_via_0_from_file_1_with_packageId_2: r(1403, 3, "Type_library_referenced_via_0_from_file_1_with_packageId_2_1403", "Type library referenced via '{0}' from file '{1}' with packageId '{2}'"),
	File_is_included_via_type_library_reference_here: r(1404, 3, "File_is_included_via_type_library_reference_here_1404", "File is included via type library reference here."),
	Library_referenced_via_0_from_file_1: r(1405, 3, "Library_referenced_via_0_from_file_1_1405", "Library referenced via '{0}' from file '{1}'"),
	File_is_included_via_library_reference_here: r(1406, 3, "File_is_included_via_library_reference_here_1406", "File is included via library reference here."),
	Matched_by_include_pattern_0_in_1: r(1407, 3, "Matched_by_include_pattern_0_in_1_1407", "Matched by include pattern '{0}' in '{1}'"),
	File_is_matched_by_include_pattern_specified_here: r(1408, 3, "File_is_matched_by_include_pattern_specified_here_1408", "File is matched by include pattern specified here."),
	Part_of_files_list_in_tsconfig_json: r(1409, 3, "Part_of_files_list_in_tsconfig_json_1409", "Part of 'files' list in tsconfig.json"),
	File_is_matched_by_files_list_specified_here: r(1410, 3, "File_is_matched_by_files_list_specified_here_1410", "File is matched by 'files' list specified here."),
	Output_from_referenced_project_0_included_because_1_specified: r(1411, 3, "Output_from_referenced_project_0_included_because_1_specified_1411", "Output from referenced project '{0}' included because '{1}' specified"),
	Output_from_referenced_project_0_included_because_module_is_specified_as_none: r(1412, 3, "Output_from_referenced_project_0_included_because_module_is_specified_as_none_1412", "Output from referenced project '{0}' included because '--module' is specified as 'none'"),
	File_is_output_from_referenced_project_specified_here: r(1413, 3, "File_is_output_from_referenced_project_specified_here_1413", "File is output from referenced project specified here."),
	Source_from_referenced_project_0_included_because_1_specified: r(1414, 3, "Source_from_referenced_project_0_included_because_1_specified_1414", "Source from referenced project '{0}' included because '{1}' specified"),
	Source_from_referenced_project_0_included_because_module_is_specified_as_none: r(1415, 3, "Source_from_referenced_project_0_included_because_module_is_specified_as_none_1415", "Source from referenced project '{0}' included because '--module' is specified as 'none'"),
	File_is_source_from_referenced_project_specified_here: r(1416, 3, "File_is_source_from_referenced_project_specified_here_1416", "File is source from referenced project specified here."),
	Entry_point_of_type_library_0_specified_in_compilerOptions: r(1417, 3, "Entry_point_of_type_library_0_specified_in_compilerOptions_1417", "Entry point of type library '{0}' specified in compilerOptions"),
	Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1: r(1418, 3, "Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1_1418", "Entry point of type library '{0}' specified in compilerOptions with packageId '{1}'"),
	File_is_entry_point_of_type_library_specified_here: r(1419, 3, "File_is_entry_point_of_type_library_specified_here_1419", "File is entry point of type library specified here."),
	Entry_point_for_implicit_type_library_0: r(1420, 3, "Entry_point_for_implicit_type_library_0_1420", "Entry point for implicit type library '{0}'"),
	Entry_point_for_implicit_type_library_0_with_packageId_1: r(1421, 3, "Entry_point_for_implicit_type_library_0_with_packageId_1_1421", "Entry point for implicit type library '{0}' with packageId '{1}'"),
	Library_0_specified_in_compilerOptions: r(1422, 3, "Library_0_specified_in_compilerOptions_1422", "Library '{0}' specified in compilerOptions"),
	File_is_library_specified_here: r(1423, 3, "File_is_library_specified_here_1423", "File is library specified here."),
	Default_library: r(1424, 3, "Default_library_1424", "Default library"),
	Default_library_for_target_0: r(1425, 3, "Default_library_for_target_0_1425", "Default library for target '{0}'"),
	File_is_default_library_for_target_specified_here: r(1426, 3, "File_is_default_library_for_target_specified_here_1426", "File is default library for target specified here."),
	Root_file_specified_for_compilation: r(1427, 3, "Root_file_specified_for_compilation_1427", "Root file specified for compilation"),
	File_is_output_of_project_reference_source_0: r(1428, 3, "File_is_output_of_project_reference_source_0_1428", "File is output of project reference source '{0}'"),
	File_redirects_to_file_0: r(1429, 3, "File_redirects_to_file_0_1429", "File redirects to file '{0}'"),
	The_file_is_in_the_program_because_Colon: r(1430, 3, "The_file_is_in_the_program_because_Colon_1430", "The file is in the program because:"),
	for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module: r(1431, 1, "for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_1431", "'for await' loops are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."),
	Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_node18_node20_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher: r(1432, 1, "Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_nod_1432", "Top-level 'for await' loops are only allowed when the 'module' option is set to 'es2022', 'esnext', 'system', 'node16', 'node18', 'node20', 'nodenext', or 'preserve', and the 'target' option is set to 'es2017' or higher."),
	Neither_decorators_nor_modifiers_may_be_applied_to_this_parameters: r(1433, 1, "Neither_decorators_nor_modifiers_may_be_applied_to_this_parameters_1433", "Neither decorators nor modifiers may be applied to 'this' parameters."),
	Unexpected_keyword_or_identifier: r(1434, 1, "Unexpected_keyword_or_identifier_1434", "Unexpected keyword or identifier."),
	Unknown_keyword_or_identifier_Did_you_mean_0: r(1435, 1, "Unknown_keyword_or_identifier_Did_you_mean_0_1435", "Unknown keyword or identifier. Did you mean '{0}'?"),
	Decorators_must_precede_the_name_and_all_keywords_of_property_declarations: r(1436, 1, "Decorators_must_precede_the_name_and_all_keywords_of_property_declarations_1436", "Decorators must precede the name and all keywords of property declarations."),
	Namespace_must_be_given_a_name: r(1437, 1, "Namespace_must_be_given_a_name_1437", "Namespace must be given a name."),
	Interface_must_be_given_a_name: r(1438, 1, "Interface_must_be_given_a_name_1438", "Interface must be given a name."),
	Type_alias_must_be_given_a_name: r(1439, 1, "Type_alias_must_be_given_a_name_1439", "Type alias must be given a name."),
	Variable_declaration_not_allowed_at_this_location: r(1440, 1, "Variable_declaration_not_allowed_at_this_location_1440", "Variable declaration not allowed at this location."),
	Cannot_start_a_function_call_in_a_type_annotation: r(1441, 1, "Cannot_start_a_function_call_in_a_type_annotation_1441", "Cannot start a function call in a type annotation."),
	Expected_for_property_initializer: r(1442, 1, "Expected_for_property_initializer_1442", "Expected '=' for property initializer."),
	Module_declaration_names_may_only_use_or_quoted_strings: r(1443, 1, "Module_declaration_names_may_only_use_or_quoted_strings_1443", `Module declaration names may only use ' or " quoted strings.`),
	_0_resolves_to_a_type_only_declaration_and_must_be_re_exported_using_a_type_only_re_export_when_1_is_enabled: r(1448, 1, "_0_resolves_to_a_type_only_declaration_and_must_be_re_exported_using_a_type_only_re_export_when_1_is_1448", "'{0}' resolves to a type-only declaration and must be re-exported using a type-only re-export when '{1}' is enabled."),
	Preserve_unused_imported_values_in_the_JavaScript_output_that_would_otherwise_be_removed: r(1449, 3, "Preserve_unused_imported_values_in_the_JavaScript_output_that_would_otherwise_be_removed_1449", "Preserve unused imported values in the JavaScript output that would otherwise be removed."),
	Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_set_of_attributes_as_arguments: r(1450, 3, "Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_set_of_attributes_as_arguments_1450", "Dynamic imports can only accept a module specifier and an optional set of attributes as arguments"),
	Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member_declaration_property_access_or_on_the_left_hand_side_of_an_in_expression: r(1451, 1, "Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member__1451", "Private identifiers are only allowed in class bodies and may only be used as part of a class member declaration, property access, or on the left-hand-side of an 'in' expression"),
	resolution_mode_should_be_either_require_or_import: r(1453, 1, "resolution_mode_should_be_either_require_or_import_1453", "`resolution-mode` should be either `require` or `import`."),
	resolution_mode_can_only_be_set_for_type_only_imports: r(1454, 1, "resolution_mode_can_only_be_set_for_type_only_imports_1454", "`resolution-mode` can only be set for type-only imports."),
	resolution_mode_is_the_only_valid_key_for_type_import_assertions: r(1455, 1, "resolution_mode_is_the_only_valid_key_for_type_import_assertions_1455", "`resolution-mode` is the only valid key for type import assertions."),
	Type_import_assertions_should_have_exactly_one_key_resolution_mode_with_value_import_or_require: r(1456, 1, "Type_import_assertions_should_have_exactly_one_key_resolution_mode_with_value_import_or_require_1456", "Type import assertions should have exactly one key - `resolution-mode` - with value `import` or `require`."),
	Matched_by_default_include_pattern_Asterisk_Asterisk_Slash_Asterisk: r(1457, 3, "Matched_by_default_include_pattern_Asterisk_Asterisk_Slash_Asterisk_1457", "Matched by default include pattern '**/*'"),
	File_is_ECMAScript_module_because_0_has_field_type_with_value_module: r(1458, 3, "File_is_ECMAScript_module_because_0_has_field_type_with_value_module_1458", `File is ECMAScript module because '{0}' has field "type" with value "module"`),
	File_is_CommonJS_module_because_0_has_field_type_whose_value_is_not_module: r(1459, 3, "File_is_CommonJS_module_because_0_has_field_type_whose_value_is_not_module_1459", `File is CommonJS module because '{0}' has field "type" whose value is not "module"`),
	File_is_CommonJS_module_because_0_does_not_have_field_type: r(1460, 3, "File_is_CommonJS_module_because_0_does_not_have_field_type_1460", `File is CommonJS module because '{0}' does not have field "type"`),
	File_is_CommonJS_module_because_package_json_was_not_found: r(1461, 3, "File_is_CommonJS_module_because_package_json_was_not_found_1461", "File is CommonJS module because 'package.json' was not found"),
	resolution_mode_is_the_only_valid_key_for_type_import_attributes: r(1463, 1, "resolution_mode_is_the_only_valid_key_for_type_import_attributes_1463", "'resolution-mode' is the only valid key for type import attributes."),
	Type_import_attributes_should_have_exactly_one_key_resolution_mode_with_value_import_or_require: r(1464, 1, "Type_import_attributes_should_have_exactly_one_key_resolution_mode_with_value_import_or_require_1464", "Type import attributes should have exactly one key - 'resolution-mode' - with value 'import' or 'require'."),
	The_import_meta_meta_property_is_not_allowed_in_files_which_will_build_into_CommonJS_output: r(1470, 1, "The_import_meta_meta_property_is_not_allowed_in_files_which_will_build_into_CommonJS_output_1470", "The 'import.meta' meta-property is not allowed in files which will build into CommonJS output."),
	Module_0_cannot_be_imported_using_this_construct_The_specifier_only_resolves_to_an_ES_module_which_cannot_be_imported_with_require_Use_an_ECMAScript_import_instead: r(1471, 1, "Module_0_cannot_be_imported_using_this_construct_The_specifier_only_resolves_to_an_ES_module_which_c_1471", "Module '{0}' cannot be imported using this construct. The specifier only resolves to an ES module, which cannot be imported with 'require'. Use an ECMAScript import instead."),
	catch_or_finally_expected: r(1472, 1, "catch_or_finally_expected_1472", "'catch' or 'finally' expected."),
	An_import_declaration_can_only_be_used_at_the_top_level_of_a_module: r(1473, 1, "An_import_declaration_can_only_be_used_at_the_top_level_of_a_module_1473", "An import declaration can only be used at the top level of a module."),
	An_export_declaration_can_only_be_used_at_the_top_level_of_a_module: r(1474, 1, "An_export_declaration_can_only_be_used_at_the_top_level_of_a_module_1474", "An export declaration can only be used at the top level of a module."),
	Control_what_method_is_used_to_detect_module_format_JS_files: r(1475, 3, "Control_what_method_is_used_to_detect_module_format_JS_files_1475", "Control what method is used to detect module-format JS files."),
	auto_Colon_Treat_files_with_imports_exports_import_meta_jsx_with_jsx_Colon_react_jsx_or_esm_format_with_module_Colon_node16_as_modules: r(1476, 3, "auto_Colon_Treat_files_with_imports_exports_import_meta_jsx_with_jsx_Colon_react_jsx_or_esm_format_w_1476", "\"auto\": Treat files with imports, exports, import.meta, jsx (with jsx: react-jsx), or esm format (with module: node16+) as modules."),
	An_instantiation_expression_cannot_be_followed_by_a_property_access: r(1477, 1, "An_instantiation_expression_cannot_be_followed_by_a_property_access_1477", "An instantiation expression cannot be followed by a property access."),
	Identifier_or_string_literal_expected: r(1478, 1, "Identifier_or_string_literal_expected_1478", "Identifier or string literal expected."),
	The_current_file_is_a_CommonJS_module_whose_imports_will_produce_require_calls_however_the_referenced_file_is_an_ECMAScript_module_and_cannot_be_imported_with_require_Consider_writing_a_dynamic_import_0_call_instead: r(1479, 1, "The_current_file_is_a_CommonJS_module_whose_imports_will_produce_require_calls_however_the_reference_1479", `The current file is a CommonJS module whose imports will produce 'require' calls; however, the referenced file is an ECMAScript module and cannot be imported with 'require'. Consider writing a dynamic 'import("{0}")' call instead.`),
	To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_create_a_local_package_json_file_with_type_Colon_module: r(1480, 3, "To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_create_a_local_packag_1480", "To convert this file to an ECMAScript module, change its file extension to '{0}' or create a local package.json file with `{ \"type\": \"module\" }`."),
	To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_add_the_field_type_Colon_module_to_1: r(1481, 3, "To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_add_the_field_type_Co_1481", `To convert this file to an ECMAScript module, change its file extension to '{0}', or add the field \`"type": "module"\` to '{1}'.`),
	To_convert_this_file_to_an_ECMAScript_module_add_the_field_type_Colon_module_to_0: r(1482, 3, "To_convert_this_file_to_an_ECMAScript_module_add_the_field_type_Colon_module_to_0_1482", "To convert this file to an ECMAScript module, add the field `\"type\": \"module\"` to '{0}'."),
	To_convert_this_file_to_an_ECMAScript_module_create_a_local_package_json_file_with_type_Colon_module: r(1483, 3, "To_convert_this_file_to_an_ECMAScript_module_create_a_local_package_json_file_with_type_Colon_module_1483", "To convert this file to an ECMAScript module, create a local package.json file with `{ \"type\": \"module\" }`."),
	_0_is_a_type_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled: r(1484, 1, "_0_is_a_type_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled_1484", "'{0}' is a type and must be imported using a type-only import when 'verbatimModuleSyntax' is enabled."),
	_0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled: r(1485, 1, "_0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_verbatimMo_1485", "'{0}' resolves to a type-only declaration and must be imported using a type-only import when 'verbatimModuleSyntax' is enabled."),
	Decorator_used_before_export_here: r(1486, 1, "Decorator_used_before_export_here_1486", "Decorator used before 'export' here."),
	Octal_escape_sequences_are_not_allowed_Use_the_syntax_0: r(1487, 1, "Octal_escape_sequences_are_not_allowed_Use_the_syntax_0_1487", "Octal escape sequences are not allowed. Use the syntax '{0}'."),
	Escape_sequence_0_is_not_allowed: r(1488, 1, "Escape_sequence_0_is_not_allowed_1488", "Escape sequence '{0}' is not allowed."),
	Decimals_with_leading_zeros_are_not_allowed: r(1489, 1, "Decimals_with_leading_zeros_are_not_allowed_1489", "Decimals with leading zeros are not allowed."),
	File_appears_to_be_binary: r(1490, 1, "File_appears_to_be_binary_1490", "File appears to be binary."),
	_0_modifier_cannot_appear_on_a_using_declaration: r(1491, 1, "_0_modifier_cannot_appear_on_a_using_declaration_1491", "'{0}' modifier cannot appear on a 'using' declaration."),
	_0_declarations_may_not_have_binding_patterns: r(1492, 1, "_0_declarations_may_not_have_binding_patterns_1492", "'{0}' declarations may not have binding patterns."),
	The_left_hand_side_of_a_for_in_statement_cannot_be_a_using_declaration: r(1493, 1, "The_left_hand_side_of_a_for_in_statement_cannot_be_a_using_declaration_1493", "The left-hand side of a 'for...in' statement cannot be a 'using' declaration."),
	The_left_hand_side_of_a_for_in_statement_cannot_be_an_await_using_declaration: r(1494, 1, "The_left_hand_side_of_a_for_in_statement_cannot_be_an_await_using_declaration_1494", "The left-hand side of a 'for...in' statement cannot be an 'await using' declaration."),
	_0_modifier_cannot_appear_on_an_await_using_declaration: r(1495, 1, "_0_modifier_cannot_appear_on_an_await_using_declaration_1495", "'{0}' modifier cannot appear on an 'await using' declaration."),
	Identifier_string_literal_or_number_literal_expected: r(1496, 1, "Identifier_string_literal_or_number_literal_expected_1496", "Identifier, string literal, or number literal expected."),
	Expression_must_be_enclosed_in_parentheses_to_be_used_as_a_decorator: r(1497, 1, "Expression_must_be_enclosed_in_parentheses_to_be_used_as_a_decorator_1497", "Expression must be enclosed in parentheses to be used as a decorator."),
	Invalid_syntax_in_decorator: r(1498, 1, "Invalid_syntax_in_decorator_1498", "Invalid syntax in decorator."),
	Unknown_regular_expression_flag: r(1499, 1, "Unknown_regular_expression_flag_1499", "Unknown regular expression flag."),
	Duplicate_regular_expression_flag: r(1500, 1, "Duplicate_regular_expression_flag_1500", "Duplicate regular expression flag."),
	This_regular_expression_flag_is_only_available_when_targeting_0_or_later: r(1501, 1, "This_regular_expression_flag_is_only_available_when_targeting_0_or_later_1501", "This regular expression flag is only available when targeting '{0}' or later."),
	The_Unicode_u_flag_and_the_Unicode_Sets_v_flag_cannot_be_set_simultaneously: r(1502, 1, "The_Unicode_u_flag_and_the_Unicode_Sets_v_flag_cannot_be_set_simultaneously_1502", "The Unicode (u) flag and the Unicode Sets (v) flag cannot be set simultaneously."),
	Named_capturing_groups_are_only_available_when_targeting_ES2018_or_later: r(1503, 1, "Named_capturing_groups_are_only_available_when_targeting_ES2018_or_later_1503", "Named capturing groups are only available when targeting 'ES2018' or later."),
	Subpattern_flags_must_be_present_when_there_is_a_minus_sign: r(1504, 1, "Subpattern_flags_must_be_present_when_there_is_a_minus_sign_1504", "Subpattern flags must be present when there is a minus sign."),
	Incomplete_quantifier_Digit_expected: r(1505, 1, "Incomplete_quantifier_Digit_expected_1505", "Incomplete quantifier. Digit expected."),
	Numbers_out_of_order_in_quantifier: r(1506, 1, "Numbers_out_of_order_in_quantifier_1506", "Numbers out of order in quantifier."),
	There_is_nothing_available_for_repetition: r(1507, 1, "There_is_nothing_available_for_repetition_1507", "There is nothing available for repetition."),
	Unexpected_0_Did_you_mean_to_escape_it_with_backslash: r(1508, 1, "Unexpected_0_Did_you_mean_to_escape_it_with_backslash_1508", "Unexpected '{0}'. Did you mean to escape it with backslash?"),
	This_regular_expression_flag_cannot_be_toggled_within_a_subpattern: r(1509, 1, "This_regular_expression_flag_cannot_be_toggled_within_a_subpattern_1509", "This regular expression flag cannot be toggled within a subpattern."),
	k_must_be_followed_by_a_capturing_group_name_enclosed_in_angle_brackets: r(1510, 1, "k_must_be_followed_by_a_capturing_group_name_enclosed_in_angle_brackets_1510", "'\\k' must be followed by a capturing group name enclosed in angle brackets."),
	q_is_only_available_inside_character_class: r(1511, 1, "q_is_only_available_inside_character_class_1511", "'\\q' is only available inside character class."),
	c_must_be_followed_by_an_ASCII_letter: r(1512, 1, "c_must_be_followed_by_an_ASCII_letter_1512", "'\\c' must be followed by an ASCII letter."),
	Undetermined_character_escape: r(1513, 1, "Undetermined_character_escape_1513", "Undetermined character escape."),
	Expected_a_capturing_group_name: r(1514, 1, "Expected_a_capturing_group_name_1514", "Expected a capturing group name."),
	Named_capturing_groups_with_the_same_name_must_be_mutually_exclusive_to_each_other: r(1515, 1, "Named_capturing_groups_with_the_same_name_must_be_mutually_exclusive_to_each_other_1515", "Named capturing groups with the same name must be mutually exclusive to each other."),
	A_character_class_range_must_not_be_bounded_by_another_character_class: r(1516, 1, "A_character_class_range_must_not_be_bounded_by_another_character_class_1516", "A character class range must not be bounded by another character class."),
	Range_out_of_order_in_character_class: r(1517, 1, "Range_out_of_order_in_character_class_1517", "Range out of order in character class."),
	Anything_that_would_possibly_match_more_than_a_single_character_is_invalid_inside_a_negated_character_class: r(1518, 1, "Anything_that_would_possibly_match_more_than_a_single_character_is_invalid_inside_a_negated_characte_1518", "Anything that would possibly match more than a single character is invalid inside a negated character class."),
	Operators_must_not_be_mixed_within_a_character_class_Wrap_it_in_a_nested_class_instead: r(1519, 1, "Operators_must_not_be_mixed_within_a_character_class_Wrap_it_in_a_nested_class_instead_1519", "Operators must not be mixed within a character class. Wrap it in a nested class instead."),
	Expected_a_class_set_operand: r(1520, 1, "Expected_a_class_set_operand_1520", "Expected a class set operand."),
	q_must_be_followed_by_string_alternatives_enclosed_in_braces: r(1521, 1, "q_must_be_followed_by_string_alternatives_enclosed_in_braces_1521", "'\\q' must be followed by string alternatives enclosed in braces."),
	A_character_class_must_not_contain_a_reserved_double_punctuator_Did_you_mean_to_escape_it_with_backslash: r(1522, 1, "A_character_class_must_not_contain_a_reserved_double_punctuator_Did_you_mean_to_escape_it_with_backs_1522", "A character class must not contain a reserved double punctuator. Did you mean to escape it with backslash?"),
	Expected_a_Unicode_property_name: r(1523, 1, "Expected_a_Unicode_property_name_1523", "Expected a Unicode property name."),
	Unknown_Unicode_property_name: r(1524, 1, "Unknown_Unicode_property_name_1524", "Unknown Unicode property name."),
	Expected_a_Unicode_property_value: r(1525, 1, "Expected_a_Unicode_property_value_1525", "Expected a Unicode property value."),
	Unknown_Unicode_property_value: r(1526, 1, "Unknown_Unicode_property_value_1526", "Unknown Unicode property value."),
	Expected_a_Unicode_property_name_or_value: r(1527, 1, "Expected_a_Unicode_property_name_or_value_1527", "Expected a Unicode property name or value."),
	Any_Unicode_property_that_would_possibly_match_more_than_a_single_character_is_only_available_when_the_Unicode_Sets_v_flag_is_set: r(1528, 1, "Any_Unicode_property_that_would_possibly_match_more_than_a_single_character_is_only_available_when_t_1528", "Any Unicode property that would possibly match more than a single character is only available when the Unicode Sets (v) flag is set."),
	Unknown_Unicode_property_name_or_value: r(1529, 1, "Unknown_Unicode_property_name_or_value_1529", "Unknown Unicode property name or value."),
	Unicode_property_value_expressions_are_only_available_when_the_Unicode_u_flag_or_the_Unicode_Sets_v_flag_is_set: r(1530, 1, "Unicode_property_value_expressions_are_only_available_when_the_Unicode_u_flag_or_the_Unicode_Sets_v__1530", "Unicode property value expressions are only available when the Unicode (u) flag or the Unicode Sets (v) flag is set."),
	_0_must_be_followed_by_a_Unicode_property_value_expression_enclosed_in_braces: r(1531, 1, "_0_must_be_followed_by_a_Unicode_property_value_expression_enclosed_in_braces_1531", "'\\{0}' must be followed by a Unicode property value expression enclosed in braces."),
	There_is_no_capturing_group_named_0_in_this_regular_expression: r(1532, 1, "There_is_no_capturing_group_named_0_in_this_regular_expression_1532", "There is no capturing group named '{0}' in this regular expression."),
	This_backreference_refers_to_a_group_that_does_not_exist_There_are_only_0_capturing_groups_in_this_regular_expression: r(1533, 1, "This_backreference_refers_to_a_group_that_does_not_exist_There_are_only_0_capturing_groups_in_this_r_1533", "This backreference refers to a group that does not exist. There are only {0} capturing groups in this regular expression."),
	This_backreference_refers_to_a_group_that_does_not_exist_There_are_no_capturing_groups_in_this_regular_expression: r(1534, 1, "This_backreference_refers_to_a_group_that_does_not_exist_There_are_no_capturing_groups_in_this_regul_1534", "This backreference refers to a group that does not exist. There are no capturing groups in this regular expression."),
	This_character_cannot_be_escaped_in_a_regular_expression: r(1535, 1, "This_character_cannot_be_escaped_in_a_regular_expression_1535", "This character cannot be escaped in a regular expression."),
	Octal_escape_sequences_and_backreferences_are_not_allowed_in_a_character_class_If_this_was_intended_as_an_escape_sequence_use_the_syntax_0_instead: r(1536, 1, "Octal_escape_sequences_and_backreferences_are_not_allowed_in_a_character_class_If_this_was_intended__1536", "Octal escape sequences and backreferences are not allowed in a character class. If this was intended as an escape sequence, use the syntax '{0}' instead."),
	Decimal_escape_sequences_and_backreferences_are_not_allowed_in_a_character_class: r(1537, 1, "Decimal_escape_sequences_and_backreferences_are_not_allowed_in_a_character_class_1537", "Decimal escape sequences and backreferences are not allowed in a character class."),
	Unicode_escape_sequences_are_only_available_when_the_Unicode_u_flag_or_the_Unicode_Sets_v_flag_is_set: r(1538, 1, "Unicode_escape_sequences_are_only_available_when_the_Unicode_u_flag_or_the_Unicode_Sets_v_flag_is_se_1538", "Unicode escape sequences are only available when the Unicode (u) flag or the Unicode Sets (v) flag is set."),
	A_bigint_literal_cannot_be_used_as_a_property_name: r(1539, 1, "A_bigint_literal_cannot_be_used_as_a_property_name_1539", "A 'bigint' literal cannot be used as a property name."),
	A_namespace_declaration_should_not_be_declared_using_the_module_keyword_Please_use_the_namespace_keyword_instead: r(1540, 2, "A_namespace_declaration_should_not_be_declared_using_the_module_keyword_Please_use_the_namespace_key_1540", "A 'namespace' declaration should not be declared using the 'module' keyword. Please use the 'namespace' keyword instead.", void 0, void 0, !0),
	Type_only_import_of_an_ECMAScript_module_from_a_CommonJS_module_must_have_a_resolution_mode_attribute: r(1541, 1, "Type_only_import_of_an_ECMAScript_module_from_a_CommonJS_module_must_have_a_resolution_mode_attribut_1541", "Type-only import of an ECMAScript module from a CommonJS module must have a 'resolution-mode' attribute."),
	Type_import_of_an_ECMAScript_module_from_a_CommonJS_module_must_have_a_resolution_mode_attribute: r(1542, 1, "Type_import_of_an_ECMAScript_module_from_a_CommonJS_module_must_have_a_resolution_mode_attribute_1542", "Type import of an ECMAScript module from a CommonJS module must have a 'resolution-mode' attribute."),
	Importing_a_JSON_file_into_an_ECMAScript_module_requires_a_type_Colon_json_import_attribute_when_module_is_set_to_0: r(1543, 1, "Importing_a_JSON_file_into_an_ECMAScript_module_requires_a_type_Colon_json_import_attribute_when_mod_1543", `Importing a JSON file into an ECMAScript module requires a 'type: "json"' import attribute when 'module' is set to '{0}'.`),
	Named_imports_from_a_JSON_file_into_an_ECMAScript_module_are_not_allowed_when_module_is_set_to_0: r(1544, 1, "Named_imports_from_a_JSON_file_into_an_ECMAScript_module_are_not_allowed_when_module_is_set_to_0_1544", "Named imports from a JSON file into an ECMAScript module are not allowed when 'module' is set to '{0}'."),
	using_declarations_are_not_allowed_in_ambient_contexts: r(1545, 1, "using_declarations_are_not_allowed_in_ambient_contexts_1545", "'using' declarations are not allowed in ambient contexts."),
	await_using_declarations_are_not_allowed_in_ambient_contexts: r(1546, 1, "await_using_declarations_are_not_allowed_in_ambient_contexts_1546", "'await using' declarations are not allowed in ambient contexts."),
	The_types_of_0_are_incompatible_between_these_types: r(2200, 1, "The_types_of_0_are_incompatible_between_these_types_2200", "The types of '{0}' are incompatible between these types."),
	The_types_returned_by_0_are_incompatible_between_these_types: r(2201, 1, "The_types_returned_by_0_are_incompatible_between_these_types_2201", "The types returned by '{0}' are incompatible between these types."),
	Call_signature_return_types_0_and_1_are_incompatible: r(2202, 1, "Call_signature_return_types_0_and_1_are_incompatible_2202", "Call signature return types '{0}' and '{1}' are incompatible.", void 0, !0),
	Construct_signature_return_types_0_and_1_are_incompatible: r(2203, 1, "Construct_signature_return_types_0_and_1_are_incompatible_2203", "Construct signature return types '{0}' and '{1}' are incompatible.", void 0, !0),
	Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1: r(2204, 1, "Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1_2204", "Call signatures with no arguments have incompatible return types '{0}' and '{1}'.", void 0, !0),
	Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1: r(2205, 1, "Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1_2205", "Construct signatures with no arguments have incompatible return types '{0}' and '{1}'.", void 0, !0),
	The_type_modifier_cannot_be_used_on_a_named_import_when_import_type_is_used_on_its_import_statement: r(2206, 1, "The_type_modifier_cannot_be_used_on_a_named_import_when_import_type_is_used_on_its_import_statement_2206", "The 'type' modifier cannot be used on a named import when 'import type' is used on its import statement."),
	The_type_modifier_cannot_be_used_on_a_named_export_when_export_type_is_used_on_its_export_statement: r(2207, 1, "The_type_modifier_cannot_be_used_on_a_named_export_when_export_type_is_used_on_its_export_statement_2207", "The 'type' modifier cannot be used on a named export when 'export type' is used on its export statement."),
	This_type_parameter_might_need_an_extends_0_constraint: r(2208, 1, "This_type_parameter_might_need_an_extends_0_constraint_2208", "This type parameter might need an `extends {0}` constraint."),
	The_project_root_is_ambiguous_but_is_required_to_resolve_export_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate: r(2209, 1, "The_project_root_is_ambiguous_but_is_required_to_resolve_export_map_entry_0_in_file_1_Supply_the_roo_2209", "The project root is ambiguous, but is required to resolve export map entry '{0}' in file '{1}'. Supply the `rootDir` compiler option to disambiguate."),
	The_project_root_is_ambiguous_but_is_required_to_resolve_import_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate: r(2210, 1, "The_project_root_is_ambiguous_but_is_required_to_resolve_import_map_entry_0_in_file_1_Supply_the_roo_2210", "The project root is ambiguous, but is required to resolve import map entry '{0}' in file '{1}'. Supply the `rootDir` compiler option to disambiguate."),
	Add_extends_constraint: r(2211, 3, "Add_extends_constraint_2211", "Add `extends` constraint."),
	Add_extends_constraint_to_all_type_parameters: r(2212, 3, "Add_extends_constraint_to_all_type_parameters_2212", "Add `extends` constraint to all type parameters"),
	Duplicate_identifier_0: r(2300, 1, "Duplicate_identifier_0_2300", "Duplicate identifier '{0}'."),
	Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor: r(2301, 1, "Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor_2301", "Initializer of instance member variable '{0}' cannot reference identifier '{1}' declared in the constructor."),
	Static_members_cannot_reference_class_type_parameters: r(2302, 1, "Static_members_cannot_reference_class_type_parameters_2302", "Static members cannot reference class type parameters."),
	Circular_definition_of_import_alias_0: r(2303, 1, "Circular_definition_of_import_alias_0_2303", "Circular definition of import alias '{0}'."),
	Cannot_find_name_0: r(2304, 1, "Cannot_find_name_0_2304", "Cannot find name '{0}'."),
	Module_0_has_no_exported_member_1: r(2305, 1, "Module_0_has_no_exported_member_1_2305", "Module '{0}' has no exported member '{1}'."),
	File_0_is_not_a_module: r(2306, 1, "File_0_is_not_a_module_2306", "File '{0}' is not a module."),
	Cannot_find_module_0_or_its_corresponding_type_declarations: r(2307, 1, "Cannot_find_module_0_or_its_corresponding_type_declarations_2307", "Cannot find module '{0}' or its corresponding type declarations."),
	Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambiguity: r(2308, 1, "Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambig_2308", "Module {0} has already exported a member named '{1}'. Consider explicitly re-exporting to resolve the ambiguity."),
	An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements: r(2309, 1, "An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements_2309", "An export assignment cannot be used in a module with other exported elements."),
	Type_0_recursively_references_itself_as_a_base_type: r(2310, 1, "Type_0_recursively_references_itself_as_a_base_type_2310", "Type '{0}' recursively references itself as a base type."),
	Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function: r(2311, 1, "Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function_2311", "Cannot find name '{0}'. Did you mean to write this in an async function?"),
	An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_members: r(2312, 1, "An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_me_2312", "An interface can only extend an object type or intersection of object types with statically known members."),
	Type_parameter_0_has_a_circular_constraint: r(2313, 1, "Type_parameter_0_has_a_circular_constraint_2313", "Type parameter '{0}' has a circular constraint."),
	Generic_type_0_requires_1_type_argument_s: r(2314, 1, "Generic_type_0_requires_1_type_argument_s_2314", "Generic type '{0}' requires {1} type argument(s)."),
	Type_0_is_not_generic: r(2315, 1, "Type_0_is_not_generic_2315", "Type '{0}' is not generic."),
	Global_type_0_must_be_a_class_or_interface_type: r(2316, 1, "Global_type_0_must_be_a_class_or_interface_type_2316", "Global type '{0}' must be a class or interface type."),
	Global_type_0_must_have_1_type_parameter_s: r(2317, 1, "Global_type_0_must_have_1_type_parameter_s_2317", "Global type '{0}' must have {1} type parameter(s)."),
	Cannot_find_global_type_0: r(2318, 1, "Cannot_find_global_type_0_2318", "Cannot find global type '{0}'."),
	Named_property_0_of_types_1_and_2_are_not_identical: r(2319, 1, "Named_property_0_of_types_1_and_2_are_not_identical_2319", "Named property '{0}' of types '{1}' and '{2}' are not identical."),
	Interface_0_cannot_simultaneously_extend_types_1_and_2: r(2320, 1, "Interface_0_cannot_simultaneously_extend_types_1_and_2_2320", "Interface '{0}' cannot simultaneously extend types '{1}' and '{2}'."),
	Excessive_stack_depth_comparing_types_0_and_1: r(2321, 1, "Excessive_stack_depth_comparing_types_0_and_1_2321", "Excessive stack depth comparing types '{0}' and '{1}'."),
	Type_0_is_not_assignable_to_type_1: r(2322, 1, "Type_0_is_not_assignable_to_type_1_2322", "Type '{0}' is not assignable to type '{1}'."),
	Cannot_redeclare_exported_variable_0: r(2323, 1, "Cannot_redeclare_exported_variable_0_2323", "Cannot redeclare exported variable '{0}'."),
	Property_0_is_missing_in_type_1: r(2324, 1, "Property_0_is_missing_in_type_1_2324", "Property '{0}' is missing in type '{1}'."),
	Property_0_is_private_in_type_1_but_not_in_type_2: r(2325, 1, "Property_0_is_private_in_type_1_but_not_in_type_2_2325", "Property '{0}' is private in type '{1}' but not in type '{2}'."),
	Types_of_property_0_are_incompatible: r(2326, 1, "Types_of_property_0_are_incompatible_2326", "Types of property '{0}' are incompatible."),
	Property_0_is_optional_in_type_1_but_required_in_type_2: r(2327, 1, "Property_0_is_optional_in_type_1_but_required_in_type_2_2327", "Property '{0}' is optional in type '{1}' but required in type '{2}'."),
	Types_of_parameters_0_and_1_are_incompatible: r(2328, 1, "Types_of_parameters_0_and_1_are_incompatible_2328", "Types of parameters '{0}' and '{1}' are incompatible."),
	Index_signature_for_type_0_is_missing_in_type_1: r(2329, 1, "Index_signature_for_type_0_is_missing_in_type_1_2329", "Index signature for type '{0}' is missing in type '{1}'."),
	_0_and_1_index_signatures_are_incompatible: r(2330, 1, "_0_and_1_index_signatures_are_incompatible_2330", "'{0}' and '{1}' index signatures are incompatible."),
	this_cannot_be_referenced_in_a_module_or_namespace_body: r(2331, 1, "this_cannot_be_referenced_in_a_module_or_namespace_body_2331", "'this' cannot be referenced in a module or namespace body."),
	this_cannot_be_referenced_in_current_location: r(2332, 1, "this_cannot_be_referenced_in_current_location_2332", "'this' cannot be referenced in current location."),
	this_cannot_be_referenced_in_a_static_property_initializer: r(2334, 1, "this_cannot_be_referenced_in_a_static_property_initializer_2334", "'this' cannot be referenced in a static property initializer."),
	super_can_only_be_referenced_in_a_derived_class: r(2335, 1, "super_can_only_be_referenced_in_a_derived_class_2335", "'super' can only be referenced in a derived class."),
	super_cannot_be_referenced_in_constructor_arguments: r(2336, 1, "super_cannot_be_referenced_in_constructor_arguments_2336", "'super' cannot be referenced in constructor arguments."),
	Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors: r(2337, 1, "Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors_2337", "Super calls are not permitted outside constructors or in nested functions inside constructors."),
	super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_derived_class: r(2338, 1, "super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_der_2338", "'super' property access is permitted only in a constructor, member function, or member accessor of a derived class."),
	Property_0_does_not_exist_on_type_1: r(2339, 1, "Property_0_does_not_exist_on_type_1_2339", "Property '{0}' does not exist on type '{1}'."),
	Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword: r(2340, 1, "Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword_2340", "Only public and protected methods of the base class are accessible via the 'super' keyword."),
	Property_0_is_private_and_only_accessible_within_class_1: r(2341, 1, "Property_0_is_private_and_only_accessible_within_class_1_2341", "Property '{0}' is private and only accessible within class '{1}'."),
	This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_version_of_0: r(2343, 1, "This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_ve_2343", "This syntax requires an imported helper named '{1}' which does not exist in '{0}'. Consider upgrading your version of '{0}'."),
	Type_0_does_not_satisfy_the_constraint_1: r(2344, 1, "Type_0_does_not_satisfy_the_constraint_1_2344", "Type '{0}' does not satisfy the constraint '{1}'."),
	Argument_of_type_0_is_not_assignable_to_parameter_of_type_1: r(2345, 1, "Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_2345", "Argument of type '{0}' is not assignable to parameter of type '{1}'."),
	Call_target_does_not_contain_any_signatures: r(2346, 1, "Call_target_does_not_contain_any_signatures_2346", "Call target does not contain any signatures."),
	Untyped_function_calls_may_not_accept_type_arguments: r(2347, 1, "Untyped_function_calls_may_not_accept_type_arguments_2347", "Untyped function calls may not accept type arguments."),
	Value_of_type_0_is_not_callable_Did_you_mean_to_include_new: r(2348, 1, "Value_of_type_0_is_not_callable_Did_you_mean_to_include_new_2348", "Value of type '{0}' is not callable. Did you mean to include 'new'?"),
	This_expression_is_not_callable: r(2349, 1, "This_expression_is_not_callable_2349", "This expression is not callable."),
	Only_a_void_function_can_be_called_with_the_new_keyword: r(2350, 1, "Only_a_void_function_can_be_called_with_the_new_keyword_2350", "Only a void function can be called with the 'new' keyword."),
	This_expression_is_not_constructable: r(2351, 1, "This_expression_is_not_constructable_2351", "This expression is not constructable."),
	Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the_other_If_this_was_intentional_convert_the_expression_to_unknown_first: r(2352, 1, "Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the__2352", "Conversion of type '{0}' to type '{1}' may be a mistake because neither type sufficiently overlaps with the other. If this was intentional, convert the expression to 'unknown' first."),
	Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1: r(2353, 1, "Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1_2353", "Object literal may only specify known properties, and '{0}' does not exist in type '{1}'."),
	This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found: r(2354, 1, "This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found_2354", "This syntax requires an imported helper but module '{0}' cannot be found."),
	A_function_whose_declared_type_is_neither_undefined_void_nor_any_must_return_a_value: r(2355, 1, "A_function_whose_declared_type_is_neither_undefined_void_nor_any_must_return_a_value_2355", "A function whose declared type is neither 'undefined', 'void', nor 'any' must return a value."),
	An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type: r(2356, 1, "An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type_2356", "An arithmetic operand must be of type 'any', 'number', 'bigint' or an enum type."),
	The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access: r(2357, 1, "The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access_2357", "The operand of an increment or decrement operator must be a variable or a property access."),
	The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_parameter: r(2358, 1, "The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_paramete_2358", "The left-hand side of an 'instanceof' expression must be of type 'any', an object type or a type parameter."),
	The_right_hand_side_of_an_instanceof_expression_must_be_either_of_type_any_a_class_function_or_other_type_assignable_to_the_Function_interface_type_or_an_object_type_with_a_Symbol_hasInstance_method: r(2359, 1, "The_right_hand_side_of_an_instanceof_expression_must_be_either_of_type_any_a_class_function_or_other_2359", "The right-hand side of an 'instanceof' expression must be either of type 'any', a class, function, or other type assignable to the 'Function' interface type, or an object type with a 'Symbol.hasInstance' method."),
	The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type: r(2362, 1, "The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type_2362", "The left-hand side of an arithmetic operation must be of type 'any', 'number', 'bigint' or an enum type."),
	The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type: r(2363, 1, "The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type_2363", "The right-hand side of an arithmetic operation must be of type 'any', 'number', 'bigint' or an enum type."),
	The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access: r(2364, 1, "The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access_2364", "The left-hand side of an assignment expression must be a variable or a property access."),
	Operator_0_cannot_be_applied_to_types_1_and_2: r(2365, 1, "Operator_0_cannot_be_applied_to_types_1_and_2_2365", "Operator '{0}' cannot be applied to types '{1}' and '{2}'."),
	Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined: r(2366, 1, "Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined_2366", "Function lacks ending return statement and return type does not include 'undefined'."),
	This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap: r(2367, 1, "This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap_2367", "This comparison appears to be unintentional because the types '{0}' and '{1}' have no overlap."),
	Type_parameter_name_cannot_be_0: r(2368, 1, "Type_parameter_name_cannot_be_0_2368", "Type parameter name cannot be '{0}'."),
	A_parameter_property_is_only_allowed_in_a_constructor_implementation: r(2369, 1, "A_parameter_property_is_only_allowed_in_a_constructor_implementation_2369", "A parameter property is only allowed in a constructor implementation."),
	A_rest_parameter_must_be_of_an_array_type: r(2370, 1, "A_rest_parameter_must_be_of_an_array_type_2370", "A rest parameter must be of an array type."),
	A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation: r(2371, 1, "A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation_2371", "A parameter initializer is only allowed in a function or constructor implementation."),
	Parameter_0_cannot_reference_itself: r(2372, 1, "Parameter_0_cannot_reference_itself_2372", "Parameter '{0}' cannot reference itself."),
	Parameter_0_cannot_reference_identifier_1_declared_after_it: r(2373, 1, "Parameter_0_cannot_reference_identifier_1_declared_after_it_2373", "Parameter '{0}' cannot reference identifier '{1}' declared after it."),
	Duplicate_index_signature_for_type_0: r(2374, 1, "Duplicate_index_signature_for_type_0_2374", "Duplicate index signature for type '{0}'."),
	Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties: r(2375, 1, "Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefi_2375", "Type '{0}' is not assignable to type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the types of the target's properties."),
	A_super_call_must_be_the_first_statement_in_the_constructor_to_refer_to_super_or_this_when_a_derived_class_contains_initialized_properties_parameter_properties_or_private_identifiers: r(2376, 1, "A_super_call_must_be_the_first_statement_in_the_constructor_to_refer_to_super_or_this_when_a_derived_2376", "A 'super' call must be the first statement in the constructor to refer to 'super' or 'this' when a derived class contains initialized properties, parameter properties, or private identifiers."),
	Constructors_for_derived_classes_must_contain_a_super_call: r(2377, 1, "Constructors_for_derived_classes_must_contain_a_super_call_2377", "Constructors for derived classes must contain a 'super' call."),
	A_get_accessor_must_return_a_value: r(2378, 1, "A_get_accessor_must_return_a_value_2378", "A 'get' accessor must return a value."),
	Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties: r(2379, 1, "Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_tr_2379", "Argument of type '{0}' is not assignable to parameter of type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the types of the target's properties."),
	Overload_signatures_must_all_be_exported_or_non_exported: r(2383, 1, "Overload_signatures_must_all_be_exported_or_non_exported_2383", "Overload signatures must all be exported or non-exported."),
	Overload_signatures_must_all_be_ambient_or_non_ambient: r(2384, 1, "Overload_signatures_must_all_be_ambient_or_non_ambient_2384", "Overload signatures must all be ambient or non-ambient."),
	Overload_signatures_must_all_be_public_private_or_protected: r(2385, 1, "Overload_signatures_must_all_be_public_private_or_protected_2385", "Overload signatures must all be public, private or protected."),
	Overload_signatures_must_all_be_optional_or_required: r(2386, 1, "Overload_signatures_must_all_be_optional_or_required_2386", "Overload signatures must all be optional or required."),
	Function_overload_must_be_static: r(2387, 1, "Function_overload_must_be_static_2387", "Function overload must be static."),
	Function_overload_must_not_be_static: r(2388, 1, "Function_overload_must_not_be_static_2388", "Function overload must not be static."),
	Function_implementation_name_must_be_0: r(2389, 1, "Function_implementation_name_must_be_0_2389", "Function implementation name must be '{0}'."),
	Constructor_implementation_is_missing: r(2390, 1, "Constructor_implementation_is_missing_2390", "Constructor implementation is missing."),
	Function_implementation_is_missing_or_not_immediately_following_the_declaration: r(2391, 1, "Function_implementation_is_missing_or_not_immediately_following_the_declaration_2391", "Function implementation is missing or not immediately following the declaration."),
	Multiple_constructor_implementations_are_not_allowed: r(2392, 1, "Multiple_constructor_implementations_are_not_allowed_2392", "Multiple constructor implementations are not allowed."),
	Duplicate_function_implementation: r(2393, 1, "Duplicate_function_implementation_2393", "Duplicate function implementation."),
	This_overload_signature_is_not_compatible_with_its_implementation_signature: r(2394, 1, "This_overload_signature_is_not_compatible_with_its_implementation_signature_2394", "This overload signature is not compatible with its implementation signature."),
	Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local: r(2395, 1, "Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local_2395", "Individual declarations in merged declaration '{0}' must be all exported or all local."),
	Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters: r(2396, 1, "Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters_2396", "Duplicate identifier 'arguments'. Compiler uses 'arguments' to initialize rest parameters."),
	Declaration_name_conflicts_with_built_in_global_identifier_0: r(2397, 1, "Declaration_name_conflicts_with_built_in_global_identifier_0_2397", "Declaration name conflicts with built-in global identifier '{0}'."),
	constructor_cannot_be_used_as_a_parameter_property_name: r(2398, 1, "constructor_cannot_be_used_as_a_parameter_property_name_2398", "'constructor' cannot be used as a parameter property name."),
	Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference: r(2399, 1, "Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference_2399", "Duplicate identifier '_this'. Compiler uses variable declaration '_this' to capture 'this' reference."),
	Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference: r(2400, 1, "Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference_2400", "Expression resolves to variable declaration '_this' that compiler uses to capture 'this' reference."),
	A_super_call_must_be_a_root_level_statement_within_a_constructor_of_a_derived_class_that_contains_initialized_properties_parameter_properties_or_private_identifiers: r(2401, 1, "A_super_call_must_be_a_root_level_statement_within_a_constructor_of_a_derived_class_that_contains_in_2401", "A 'super' call must be a root-level statement within a constructor of a derived class that contains initialized properties, parameter properties, or private identifiers."),
	Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference: r(2402, 1, "Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference_2402", "Expression resolves to '_super' that compiler uses to capture base class reference."),
	Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_type_2: r(2403, 1, "Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_t_2403", "Subsequent variable declarations must have the same type.  Variable '{0}' must be of type '{1}', but here has type '{2}'."),
	The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation: r(2404, 1, "The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation_2404", "The left-hand side of a 'for...in' statement cannot use a type annotation."),
	The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any: r(2405, 1, "The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any_2405", "The left-hand side of a 'for...in' statement must be of type 'string' or 'any'."),
	The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access: r(2406, 1, "The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access_2406", "The left-hand side of a 'for...in' statement must be a variable or a property access."),
	The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_here_has_type_0: r(2407, 1, "The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_2407", "The right-hand side of a 'for...in' statement must be of type 'any', an object type or a type parameter, but here has type '{0}'."),
	Setters_cannot_return_a_value: r(2408, 1, "Setters_cannot_return_a_value_2408", "Setters cannot return a value."),
	Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class: r(2409, 1, "Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class_2409", "Return type of constructor signature must be assignable to the instance type of the class."),
	The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any: r(2410, 1, "The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any_2410", "The 'with' statement is not supported. All symbols in a 'with' block will have type 'any'."),
	Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target: r(2412, 1, "Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefi_2412", "Type '{0}' is not assignable to type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the type of the target."),
	Property_0_of_type_1_is_not_assignable_to_2_index_type_3: r(2411, 1, "Property_0_of_type_1_is_not_assignable_to_2_index_type_3_2411", "Property '{0}' of type '{1}' is not assignable to '{2}' index type '{3}'."),
	_0_index_type_1_is_not_assignable_to_2_index_type_3: r(2413, 1, "_0_index_type_1_is_not_assignable_to_2_index_type_3_2413", "'{0}' index type '{1}' is not assignable to '{2}' index type '{3}'."),
	Class_name_cannot_be_0: r(2414, 1, "Class_name_cannot_be_0_2414", "Class name cannot be '{0}'."),
	Class_0_incorrectly_extends_base_class_1: r(2415, 1, "Class_0_incorrectly_extends_base_class_1_2415", "Class '{0}' incorrectly extends base class '{1}'."),
	Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2: r(2416, 1, "Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2_2416", "Property '{0}' in type '{1}' is not assignable to the same property in base type '{2}'."),
	Class_static_side_0_incorrectly_extends_base_class_static_side_1: r(2417, 1, "Class_static_side_0_incorrectly_extends_base_class_static_side_1_2417", "Class static side '{0}' incorrectly extends base class static side '{1}'."),
	Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1: r(2418, 1, "Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1_2418", "Type of computed property's value is '{0}', which is not assignable to type '{1}'."),
	Types_of_construct_signatures_are_incompatible: r(2419, 1, "Types_of_construct_signatures_are_incompatible_2419", "Types of construct signatures are incompatible."),
	Class_0_incorrectly_implements_interface_1: r(2420, 1, "Class_0_incorrectly_implements_interface_1_2420", "Class '{0}' incorrectly implements interface '{1}'."),
	A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_members: r(2422, 1, "A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_memb_2422", "A class can only implement an object type or intersection of object types with statically known members."),
	Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_accessor: r(2423, 1, "Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_access_2423", "Class '{0}' defines instance member function '{1}', but extended class '{2}' defines it as instance member accessor."),
	Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_function: r(2425, 1, "Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_functi_2425", "Class '{0}' defines instance member property '{1}', but extended class '{2}' defines it as instance member function."),
	Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_function: r(2426, 1, "Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_functi_2426", "Class '{0}' defines instance member accessor '{1}', but extended class '{2}' defines it as instance member function."),
	Interface_name_cannot_be_0: r(2427, 1, "Interface_name_cannot_be_0_2427", "Interface name cannot be '{0}'."),
	All_declarations_of_0_must_have_identical_type_parameters: r(2428, 1, "All_declarations_of_0_must_have_identical_type_parameters_2428", "All declarations of '{0}' must have identical type parameters."),
	Interface_0_incorrectly_extends_interface_1: r(2430, 1, "Interface_0_incorrectly_extends_interface_1_2430", "Interface '{0}' incorrectly extends interface '{1}'."),
	Enum_name_cannot_be_0: r(2431, 1, "Enum_name_cannot_be_0_2431", "Enum name cannot be '{0}'."),
	In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enum_element: r(2432, 1, "In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enu_2432", "In an enum with multiple declarations, only one declaration can omit an initializer for its first enum element."),
	A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merged: r(2433, 1, "A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merg_2433", "A namespace declaration cannot be in a different file from a class or function with which it is merged."),
	A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged: r(2434, 1, "A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged_2434", "A namespace declaration cannot be located prior to a class or function with which it is merged."),
	Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces: r(2435, 1, "Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces_2435", "Ambient modules cannot be nested in other modules or namespaces."),
	Ambient_module_declaration_cannot_specify_relative_module_name: r(2436, 1, "Ambient_module_declaration_cannot_specify_relative_module_name_2436", "Ambient module declaration cannot specify relative module name."),
	Module_0_is_hidden_by_a_local_declaration_with_the_same_name: r(2437, 1, "Module_0_is_hidden_by_a_local_declaration_with_the_same_name_2437", "Module '{0}' is hidden by a local declaration with the same name."),
	Import_name_cannot_be_0: r(2438, 1, "Import_name_cannot_be_0_2438", "Import name cannot be '{0}'."),
	Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relative_module_name: r(2439, 1, "Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relati_2439", "Import or export declaration in an ambient module declaration cannot reference module through relative module name."),
	Import_declaration_conflicts_with_local_declaration_of_0: r(2440, 1, "Import_declaration_conflicts_with_local_declaration_of_0_2440", "Import declaration conflicts with local declaration of '{0}'."),
	Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module: r(2441, 1, "Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_2441", "Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module."),
	Types_have_separate_declarations_of_a_private_property_0: r(2442, 1, "Types_have_separate_declarations_of_a_private_property_0_2442", "Types have separate declarations of a private property '{0}'."),
	Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2: r(2443, 1, "Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2_2443", "Property '{0}' is protected but type '{1}' is not a class derived from '{2}'."),
	Property_0_is_protected_in_type_1_but_public_in_type_2: r(2444, 1, "Property_0_is_protected_in_type_1_but_public_in_type_2_2444", "Property '{0}' is protected in type '{1}' but public in type '{2}'."),
	Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses: r(2445, 1, "Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses_2445", "Property '{0}' is protected and only accessible within class '{1}' and its subclasses."),
	Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_class_2: r(2446, 1, "Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_cl_2446", "Property '{0}' is protected and only accessible through an instance of class '{1}'. This is an instance of class '{2}'."),
	The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead: r(2447, 1, "The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead_2447", "The '{0}' operator is not allowed for boolean types. Consider using '{1}' instead."),
	Block_scoped_variable_0_used_before_its_declaration: r(2448, 1, "Block_scoped_variable_0_used_before_its_declaration_2448", "Block-scoped variable '{0}' used before its declaration."),
	Class_0_used_before_its_declaration: r(2449, 1, "Class_0_used_before_its_declaration_2449", "Class '{0}' used before its declaration."),
	Enum_0_used_before_its_declaration: r(2450, 1, "Enum_0_used_before_its_declaration_2450", "Enum '{0}' used before its declaration."),
	Cannot_redeclare_block_scoped_variable_0: r(2451, 1, "Cannot_redeclare_block_scoped_variable_0_2451", "Cannot redeclare block-scoped variable '{0}'."),
	An_enum_member_cannot_have_a_numeric_name: r(2452, 1, "An_enum_member_cannot_have_a_numeric_name_2452", "An enum member cannot have a numeric name."),
	Variable_0_is_used_before_being_assigned: r(2454, 1, "Variable_0_is_used_before_being_assigned_2454", "Variable '{0}' is used before being assigned."),
	Type_alias_0_circularly_references_itself: r(2456, 1, "Type_alias_0_circularly_references_itself_2456", "Type alias '{0}' circularly references itself."),
	Type_alias_name_cannot_be_0: r(2457, 1, "Type_alias_name_cannot_be_0_2457", "Type alias name cannot be '{0}'."),
	An_AMD_module_cannot_have_multiple_name_assignments: r(2458, 1, "An_AMD_module_cannot_have_multiple_name_assignments_2458", "An AMD module cannot have multiple name assignments."),
	Module_0_declares_1_locally_but_it_is_not_exported: r(2459, 1, "Module_0_declares_1_locally_but_it_is_not_exported_2459", "Module '{0}' declares '{1}' locally, but it is not exported."),
	Module_0_declares_1_locally_but_it_is_exported_as_2: r(2460, 1, "Module_0_declares_1_locally_but_it_is_exported_as_2_2460", "Module '{0}' declares '{1}' locally, but it is exported as '{2}'."),
	Type_0_is_not_an_array_type: r(2461, 1, "Type_0_is_not_an_array_type_2461", "Type '{0}' is not an array type."),
	A_rest_element_must_be_last_in_a_destructuring_pattern: r(2462, 1, "A_rest_element_must_be_last_in_a_destructuring_pattern_2462", "A rest element must be last in a destructuring pattern."),
	A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature: r(2463, 1, "A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature_2463", "A binding pattern parameter cannot be optional in an implementation signature."),
	A_computed_property_name_must_be_of_type_string_number_symbol_or_any: r(2464, 1, "A_computed_property_name_must_be_of_type_string_number_symbol_or_any_2464", "A computed property name must be of type 'string', 'number', 'symbol', or 'any'."),
	this_cannot_be_referenced_in_a_computed_property_name: r(2465, 1, "this_cannot_be_referenced_in_a_computed_property_name_2465", "'this' cannot be referenced in a computed property name."),
	super_cannot_be_referenced_in_a_computed_property_name: r(2466, 1, "super_cannot_be_referenced_in_a_computed_property_name_2466", "'super' cannot be referenced in a computed property name."),
	A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type: r(2467, 1, "A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type_2467", "A computed property name cannot reference a type parameter from its containing type."),
	Cannot_find_global_value_0: r(2468, 1, "Cannot_find_global_value_0_2468", "Cannot find global value '{0}'."),
	The_0_operator_cannot_be_applied_to_type_symbol: r(2469, 1, "The_0_operator_cannot_be_applied_to_type_symbol_2469", "The '{0}' operator cannot be applied to type 'symbol'."),
	Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher: r(2472, 1, "Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher_2472", "Spread operator in 'new' expressions is only available when targeting ECMAScript 5 and higher."),
	Enum_declarations_must_all_be_const_or_non_const: r(2473, 1, "Enum_declarations_must_all_be_const_or_non_const_2473", "Enum declarations must all be const or non-const."),
	const_enum_member_initializers_must_be_constant_expressions: r(2474, 1, "const_enum_member_initializers_must_be_constant_expressions_2474", "const enum member initializers must be constant expressions."),
	const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_import_declaration_or_export_assignment_or_type_query: r(2475, 1, "const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_im_2475", "'const' enums can only be used in property or index access expressions or the right hand side of an import declaration or export assignment or type query."),
	A_const_enum_member_can_only_be_accessed_using_a_string_literal: r(2476, 1, "A_const_enum_member_can_only_be_accessed_using_a_string_literal_2476", "A const enum member can only be accessed using a string literal."),
	const_enum_member_initializer_was_evaluated_to_a_non_finite_value: r(2477, 1, "const_enum_member_initializer_was_evaluated_to_a_non_finite_value_2477", "'const' enum member initializer was evaluated to a non-finite value."),
	const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN: r(2478, 1, "const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN_2478", "'const' enum member initializer was evaluated to disallowed value 'NaN'."),
	let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations: r(2480, 1, "let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations_2480", "'let' is not allowed to be used as a name in 'let' or 'const' declarations."),
	Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1: r(2481, 1, "Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1_2481", "Cannot initialize outer scoped variable '{0}' in the same scope as block scoped declaration '{1}'."),
	The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation: r(2483, 1, "The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation_2483", "The left-hand side of a 'for...of' statement cannot use a type annotation."),
	Export_declaration_conflicts_with_exported_declaration_of_0: r(2484, 1, "Export_declaration_conflicts_with_exported_declaration_of_0_2484", "Export declaration conflicts with exported declaration of '{0}'."),
	The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access: r(2487, 1, "The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access_2487", "The left-hand side of a 'for...of' statement must be a variable or a property access."),
	Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator: r(2488, 1, "Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator_2488", "Type '{0}' must have a '[Symbol.iterator]()' method that returns an iterator."),
	An_iterator_must_have_a_next_method: r(2489, 1, "An_iterator_must_have_a_next_method_2489", "An iterator must have a 'next()' method."),
	The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property: r(2490, 1, "The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property_2490", "The type returned by the '{0}()' method of an iterator must have a 'value' property."),
	The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern: r(2491, 1, "The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern_2491", "The left-hand side of a 'for...in' statement cannot be a destructuring pattern."),
	Cannot_redeclare_identifier_0_in_catch_clause: r(2492, 1, "Cannot_redeclare_identifier_0_in_catch_clause_2492", "Cannot redeclare identifier '{0}' in catch clause."),
	Tuple_type_0_of_length_1_has_no_element_at_index_2: r(2493, 1, "Tuple_type_0_of_length_1_has_no_element_at_index_2_2493", "Tuple type '{0}' of length '{1}' has no element at index '{2}'."),
	Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher: r(2494, 1, "Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher_2494", "Using a string in a 'for...of' statement is only supported in ECMAScript 5 and higher."),
	Type_0_is_not_an_array_type_or_a_string_type: r(2495, 1, "Type_0_is_not_an_array_type_or_a_string_type_2495", "Type '{0}' is not an array type or a string type."),
	The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES5_Consider_using_a_standard_function_expression: r(2496, 1, "The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES5_Consider_using_a_standard_func_2496", "The 'arguments' object cannot be referenced in an arrow function in ES5. Consider using a standard function expression."),
	This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_referencing_its_default_export: r(2497, 1, "This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_2497", "This module can only be referenced with ECMAScript imports/exports by turning on the '{0}' flag and referencing its default export."),
	Module_0_uses_export_and_cannot_be_used_with_export_Asterisk: r(2498, 1, "Module_0_uses_export_and_cannot_be_used_with_export_Asterisk_2498", "Module '{0}' uses 'export =' and cannot be used with 'export *'."),
	An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments: r(2499, 1, "An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments_2499", "An interface can only extend an identifier/qualified-name with optional type arguments."),
	A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments: r(2500, 1, "A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments_2500", "A class can only implement an identifier/qualified-name with optional type arguments."),
	A_rest_element_cannot_contain_a_binding_pattern: r(2501, 1, "A_rest_element_cannot_contain_a_binding_pattern_2501", "A rest element cannot contain a binding pattern."),
	_0_is_referenced_directly_or_indirectly_in_its_own_type_annotation: r(2502, 1, "_0_is_referenced_directly_or_indirectly_in_its_own_type_annotation_2502", "'{0}' is referenced directly or indirectly in its own type annotation."),
	Cannot_find_namespace_0: r(2503, 1, "Cannot_find_namespace_0_2503", "Cannot find namespace '{0}'."),
	Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator: r(2504, 1, "Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator_2504", "Type '{0}' must have a '[Symbol.asyncIterator]()' method that returns an async iterator."),
	A_generator_cannot_have_a_void_type_annotation: r(2505, 1, "A_generator_cannot_have_a_void_type_annotation_2505", "A generator cannot have a 'void' type annotation."),
	_0_is_referenced_directly_or_indirectly_in_its_own_base_expression: r(2506, 1, "_0_is_referenced_directly_or_indirectly_in_its_own_base_expression_2506", "'{0}' is referenced directly or indirectly in its own base expression."),
	Type_0_is_not_a_constructor_function_type: r(2507, 1, "Type_0_is_not_a_constructor_function_type_2507", "Type '{0}' is not a constructor function type."),
	No_base_constructor_has_the_specified_number_of_type_arguments: r(2508, 1, "No_base_constructor_has_the_specified_number_of_type_arguments_2508", "No base constructor has the specified number of type arguments."),
	Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_known_members: r(2509, 1, "Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_2509", "Base constructor return type '{0}' is not an object type or intersection of object types with statically known members."),
	Base_constructors_must_all_have_the_same_return_type: r(2510, 1, "Base_constructors_must_all_have_the_same_return_type_2510", "Base constructors must all have the same return type."),
	Cannot_create_an_instance_of_an_abstract_class: r(2511, 1, "Cannot_create_an_instance_of_an_abstract_class_2511", "Cannot create an instance of an abstract class."),
	Overload_signatures_must_all_be_abstract_or_non_abstract: r(2512, 1, "Overload_signatures_must_all_be_abstract_or_non_abstract_2512", "Overload signatures must all be abstract or non-abstract."),
	Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression: r(2513, 1, "Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression_2513", "Abstract method '{0}' in class '{1}' cannot be accessed via super expression."),
	A_tuple_type_cannot_be_indexed_with_a_negative_value: r(2514, 1, "A_tuple_type_cannot_be_indexed_with_a_negative_value_2514", "A tuple type cannot be indexed with a negative value."),
	Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2: r(2515, 1, "Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2_2515", "Non-abstract class '{0}' does not implement inherited abstract member {1} from class '{2}'."),
	All_declarations_of_an_abstract_method_must_be_consecutive: r(2516, 1, "All_declarations_of_an_abstract_method_must_be_consecutive_2516", "All declarations of an abstract method must be consecutive."),
	Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type: r(2517, 1, "Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type_2517", "Cannot assign an abstract constructor type to a non-abstract constructor type."),
	A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard: r(2518, 1, "A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard_2518", "A 'this'-based type guard is not compatible with a parameter-based type guard."),
	An_async_iterator_must_have_a_next_method: r(2519, 1, "An_async_iterator_must_have_a_next_method_2519", "An async iterator must have a 'next()' method."),
	Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions: r(2520, 1, "Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions_2520", "Duplicate identifier '{0}'. Compiler uses declaration '{1}' to support async functions."),
	The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES5_Consider_using_a_standard_function_or_method: r(2522, 1, "The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES5_Consider_using_a_sta_2522", "The 'arguments' object cannot be referenced in an async function or method in ES5. Consider using a standard function or method."),
	yield_expressions_cannot_be_used_in_a_parameter_initializer: r(2523, 1, "yield_expressions_cannot_be_used_in_a_parameter_initializer_2523", "'yield' expressions cannot be used in a parameter initializer."),
	await_expressions_cannot_be_used_in_a_parameter_initializer: r(2524, 1, "await_expressions_cannot_be_used_in_a_parameter_initializer_2524", "'await' expressions cannot be used in a parameter initializer."),
	A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface: r(2526, 1, "A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface_2526", "A 'this' type is available only in a non-static member of a class or interface."),
	The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary: r(2527, 1, "The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary_2527", "The inferred type of '{0}' references an inaccessible '{1}' type. A type annotation is necessary."),
	A_module_cannot_have_multiple_default_exports: r(2528, 1, "A_module_cannot_have_multiple_default_exports_2528", "A module cannot have multiple default exports."),
	Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_functions: r(2529, 1, "Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_func_2529", "Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module containing async functions."),
	Property_0_is_incompatible_with_index_signature: r(2530, 1, "Property_0_is_incompatible_with_index_signature_2530", "Property '{0}' is incompatible with index signature."),
	Object_is_possibly_null: r(2531, 1, "Object_is_possibly_null_2531", "Object is possibly 'null'."),
	Object_is_possibly_undefined: r(2532, 1, "Object_is_possibly_undefined_2532", "Object is possibly 'undefined'."),
	Object_is_possibly_null_or_undefined: r(2533, 1, "Object_is_possibly_null_or_undefined_2533", "Object is possibly 'null' or 'undefined'."),
	A_function_returning_never_cannot_have_a_reachable_end_point: r(2534, 1, "A_function_returning_never_cannot_have_a_reachable_end_point_2534", "A function returning 'never' cannot have a reachable end point."),
	Type_0_cannot_be_used_to_index_type_1: r(2536, 1, "Type_0_cannot_be_used_to_index_type_1_2536", "Type '{0}' cannot be used to index type '{1}'."),
	Type_0_has_no_matching_index_signature_for_type_1: r(2537, 1, "Type_0_has_no_matching_index_signature_for_type_1_2537", "Type '{0}' has no matching index signature for type '{1}'."),
	Type_0_cannot_be_used_as_an_index_type: r(2538, 1, "Type_0_cannot_be_used_as_an_index_type_2538", "Type '{0}' cannot be used as an index type."),
	Cannot_assign_to_0_because_it_is_not_a_variable: r(2539, 1, "Cannot_assign_to_0_because_it_is_not_a_variable_2539", "Cannot assign to '{0}' because it is not a variable."),
	Cannot_assign_to_0_because_it_is_a_read_only_property: r(2540, 1, "Cannot_assign_to_0_because_it_is_a_read_only_property_2540", "Cannot assign to '{0}' because it is a read-only property."),
	Index_signature_in_type_0_only_permits_reading: r(2542, 1, "Index_signature_in_type_0_only_permits_reading_2542", "Index signature in type '{0}' only permits reading."),
	Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_meta_property_reference: r(2543, 1, "Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_me_2543", "Duplicate identifier '_newTarget'. Compiler uses variable declaration '_newTarget' to capture 'new.target' meta-property reference."),
	Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta_property_reference: r(2544, 1, "Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta__2544", "Expression resolves to variable declaration '_newTarget' that compiler uses to capture 'new.target' meta-property reference."),
	A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any: r(2545, 1, "A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any_2545", "A mixin class must have a constructor with a single rest parameter of type 'any[]'."),
	The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_property: r(2547, 1, "The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_pro_2547", "The type returned by the '{0}()' method of an async iterator must be a promise for a type with a 'value' property."),
	Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator: r(2548, 1, "Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator_2548", "Type '{0}' is not an array type or does not have a '[Symbol.iterator]()' method that returns an iterator."),
	Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator: r(2549, 1, "Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns__2549", "Type '{0}' is not an array type or a string type or does not have a '[Symbol.iterator]()' method that returns an iterator."),
	Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2_or_later: r(2550, 1, "Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_c_2550", "Property '{0}' does not exist on type '{1}'. Do you need to change your target library? Try changing the 'lib' compiler option to '{2}' or later."),
	Property_0_does_not_exist_on_type_1_Did_you_mean_2: r(2551, 1, "Property_0_does_not_exist_on_type_1_Did_you_mean_2_2551", "Property '{0}' does not exist on type '{1}'. Did you mean '{2}'?"),
	Cannot_find_name_0_Did_you_mean_1: r(2552, 1, "Cannot_find_name_0_Did_you_mean_1_2552", "Cannot find name '{0}'. Did you mean '{1}'?"),
	Computed_values_are_not_permitted_in_an_enum_with_string_valued_members: r(2553, 1, "Computed_values_are_not_permitted_in_an_enum_with_string_valued_members_2553", "Computed values are not permitted in an enum with string valued members."),
	Expected_0_arguments_but_got_1: r(2554, 1, "Expected_0_arguments_but_got_1_2554", "Expected {0} arguments, but got {1}."),
	Expected_at_least_0_arguments_but_got_1: r(2555, 1, "Expected_at_least_0_arguments_but_got_1_2555", "Expected at least {0} arguments, but got {1}."),
	A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter: r(2556, 1, "A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter_2556", "A spread argument must either have a tuple type or be passed to a rest parameter."),
	Expected_0_type_arguments_but_got_1: r(2558, 1, "Expected_0_type_arguments_but_got_1_2558", "Expected {0} type arguments, but got {1}."),
	Type_0_has_no_properties_in_common_with_type_1: r(2559, 1, "Type_0_has_no_properties_in_common_with_type_1_2559", "Type '{0}' has no properties in common with type '{1}'."),
	Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it: r(2560, 1, "Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it_2560", "Value of type '{0}' has no properties in common with type '{1}'. Did you mean to call it?"),
	Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_write_2: r(2561, 1, "Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_writ_2561", "Object literal may only specify known properties, but '{0}' does not exist in type '{1}'. Did you mean to write '{2}'?"),
	Base_class_expressions_cannot_reference_class_type_parameters: r(2562, 1, "Base_class_expressions_cannot_reference_class_type_parameters_2562", "Base class expressions cannot reference class type parameters."),
	The_containing_function_or_module_body_is_too_large_for_control_flow_analysis: r(2563, 1, "The_containing_function_or_module_body_is_too_large_for_control_flow_analysis_2563", "The containing function or module body is too large for control flow analysis."),
	Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor: r(2564, 1, "Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor_2564", "Property '{0}' has no initializer and is not definitely assigned in the constructor."),
	Property_0_is_used_before_being_assigned: r(2565, 1, "Property_0_is_used_before_being_assigned_2565", "Property '{0}' is used before being assigned."),
	A_rest_element_cannot_have_a_property_name: r(2566, 1, "A_rest_element_cannot_have_a_property_name_2566", "A rest element cannot have a property name."),
	Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations: r(2567, 1, "Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations_2567", "Enum declarations can only merge with namespace or other enum declarations."),
	Property_0_may_not_exist_on_type_1_Did_you_mean_2: r(2568, 1, "Property_0_may_not_exist_on_type_1_Did_you_mean_2_2568", "Property '{0}' may not exist on type '{1}'. Did you mean '{2}'?"),
	Could_not_find_name_0_Did_you_mean_1: r(2570, 1, "Could_not_find_name_0_Did_you_mean_1_2570", "Could not find name '{0}'. Did you mean '{1}'?"),
	Object_is_of_type_unknown: r(2571, 1, "Object_is_of_type_unknown_2571", "Object is of type 'unknown'."),
	A_rest_element_type_must_be_an_array_type: r(2574, 1, "A_rest_element_type_must_be_an_array_type_2574", "A rest element type must be an array type."),
	No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments: r(2575, 1, "No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments_2575", "No overload expects {0} arguments, but overloads do exist that expect either {1} or {2} arguments."),
	Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead: r(2576, 1, "Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead_2576", "Property '{0}' does not exist on type '{1}'. Did you mean to access the static member '{2}' instead?"),
	Return_type_annotation_circularly_references_itself: r(2577, 1, "Return_type_annotation_circularly_references_itself_2577", "Return type annotation circularly references itself."),
	Unused_ts_expect_error_directive: r(2578, 1, "Unused_ts_expect_error_directive_2578", "Unused '@ts-expect-error' directive."),
	Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode: r(2580, 1, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashno_2580", "Cannot find name '{0}'. Do you need to install type definitions for node? Try `npm i --save-dev @types/node`."),
	Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery: r(2581, 1, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slash_2581", "Cannot find name '{0}'. Do you need to install type definitions for jQuery? Try `npm i --save-dev @types/jquery`."),
	Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha: r(2582, 1, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_type_2582", "Cannot find name '{0}'. Do you need to install type definitions for a test runner? Try `npm i --save-dev @types/jest` or `npm i --save-dev @types/mocha`."),
	Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_1_or_later: r(2583, 1, "Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2583", "Cannot find name '{0}'. Do you need to change your target library? Try changing the 'lib' compiler option to '{1}' or later."),
	Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_include_dom: r(2584, 1, "Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2584", "Cannot find name '{0}'. Do you need to change your target library? Try changing the 'lib' compiler option to include 'dom'."),
	_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_es2015_or_later: r(2585, 1, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_2585", "'{0}' only refers to a type, but is being used as a value here. Do you need to change your target library? Try changing the 'lib' compiler option to es2015 or later."),
	Cannot_assign_to_0_because_it_is_a_constant: r(2588, 1, "Cannot_assign_to_0_because_it_is_a_constant_2588", "Cannot assign to '{0}' because it is a constant."),
	Type_instantiation_is_excessively_deep_and_possibly_infinite: r(2589, 1, "Type_instantiation_is_excessively_deep_and_possibly_infinite_2589", "Type instantiation is excessively deep and possibly infinite."),
	Expression_produces_a_union_type_that_is_too_complex_to_represent: r(2590, 1, "Expression_produces_a_union_type_that_is_too_complex_to_represent_2590", "Expression produces a union type that is too complex to represent."),
	Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode_and_then_add_node_to_the_types_field_in_your_tsconfig: r(2591, 1, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashno_2591", "Cannot find name '{0}'. Do you need to install type definitions for node? Try `npm i --save-dev @types/node` and then add 'node' to the types field in your tsconfig."),
	Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery_and_then_add_jquery_to_the_types_field_in_your_tsconfig: r(2592, 1, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slash_2592", "Cannot find name '{0}'. Do you need to install type definitions for jQuery? Try `npm i --save-dev @types/jquery` and then add 'jquery' to the types field in your tsconfig."),
	Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha_and_then_add_jest_or_mocha_to_the_types_field_in_your_tsconfig: r(2593, 1, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_type_2593", "Cannot find name '{0}'. Do you need to install type definitions for a test runner? Try `npm i --save-dev @types/jest` or `npm i --save-dev @types/mocha` and then add 'jest' or 'mocha' to the types field in your tsconfig."),
	This_module_is_declared_with_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag: r(2594, 1, "This_module_is_declared_with_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag_2594", "This module is declared with 'export =', and can only be used with a default import when using the '{0}' flag."),
	_0_can_only_be_imported_by_using_a_default_import: r(2595, 1, "_0_can_only_be_imported_by_using_a_default_import_2595", "'{0}' can only be imported by using a default import."),
	_0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: r(2596, 1, "_0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import_2596", "'{0}' can only be imported by turning on the 'esModuleInterop' flag and using a default import."),
	_0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import: r(2597, 1, "_0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import_2597", "'{0}' can only be imported by using a 'require' call or by using a default import."),
	_0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: r(2598, 1, "_0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using__2598", "'{0}' can only be imported by using a 'require' call or by turning on the 'esModuleInterop' flag and using a default import."),
	JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist: r(2602, 1, "JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist_2602", "JSX element implicitly has type 'any' because the global type 'JSX.Element' does not exist."),
	Property_0_in_type_1_is_not_assignable_to_type_2: r(2603, 1, "Property_0_in_type_1_is_not_assignable_to_type_2_2603", "Property '{0}' in type '{1}' is not assignable to type '{2}'."),
	JSX_element_type_0_does_not_have_any_construct_or_call_signatures: r(2604, 1, "JSX_element_type_0_does_not_have_any_construct_or_call_signatures_2604", "JSX element type '{0}' does not have any construct or call signatures."),
	Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property: r(2606, 1, "Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property_2606", "Property '{0}' of JSX spread attribute is not assignable to target property."),
	JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property: r(2607, 1, "JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property_2607", "JSX element class does not support attributes because it does not have a '{0}' property."),
	The_global_type_JSX_0_may_not_have_more_than_one_property: r(2608, 1, "The_global_type_JSX_0_may_not_have_more_than_one_property_2608", "The global type 'JSX.{0}' may not have more than one property."),
	JSX_spread_child_must_be_an_array_type: r(2609, 1, "JSX_spread_child_must_be_an_array_type_2609", "JSX spread child must be an array type."),
	_0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property: r(2610, 1, "_0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property_2610", "'{0}' is defined as an accessor in class '{1}', but is overridden here in '{2}' as an instance property."),
	_0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor: r(2611, 1, "_0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor_2611", "'{0}' is defined as a property in class '{1}', but is overridden here in '{2}' as an accessor."),
	Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_add_a_declare_modifier_or_remove_the_redundant_declaration: r(2612, 1, "Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_2612", "Property '{0}' will overwrite the base property in '{1}'. If this is intentional, add an initializer. Otherwise, add a 'declare' modifier or remove the redundant declaration."),
	Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead: r(2613, 1, "Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead_2613", "Module '{0}' has no default export. Did you mean to use 'import { {1} } from {0}' instead?"),
	Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead: r(2614, 1, "Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead_2614", "Module '{0}' has no exported member '{1}'. Did you mean to use 'import {1} from {0}' instead?"),
	Type_of_property_0_circularly_references_itself_in_mapped_type_1: r(2615, 1, "Type_of_property_0_circularly_references_itself_in_mapped_type_1_2615", "Type of property '{0}' circularly references itself in mapped type '{1}'."),
	_0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import: r(2616, 1, "_0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import_2616", "'{0}' can only be imported by using 'import {1} = require({2})' or a default import."),
	_0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: r(2617, 1, "_0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_us_2617", "'{0}' can only be imported by using 'import {1} = require({2})' or by turning on the 'esModuleInterop' flag and using a default import."),
	Source_has_0_element_s_but_target_requires_1: r(2618, 1, "Source_has_0_element_s_but_target_requires_1_2618", "Source has {0} element(s) but target requires {1}."),
	Source_has_0_element_s_but_target_allows_only_1: r(2619, 1, "Source_has_0_element_s_but_target_allows_only_1_2619", "Source has {0} element(s) but target allows only {1}."),
	Target_requires_0_element_s_but_source_may_have_fewer: r(2620, 1, "Target_requires_0_element_s_but_source_may_have_fewer_2620", "Target requires {0} element(s) but source may have fewer."),
	Target_allows_only_0_element_s_but_source_may_have_more: r(2621, 1, "Target_allows_only_0_element_s_but_source_may_have_more_2621", "Target allows only {0} element(s) but source may have more."),
	Source_provides_no_match_for_required_element_at_position_0_in_target: r(2623, 1, "Source_provides_no_match_for_required_element_at_position_0_in_target_2623", "Source provides no match for required element at position {0} in target."),
	Source_provides_no_match_for_variadic_element_at_position_0_in_target: r(2624, 1, "Source_provides_no_match_for_variadic_element_at_position_0_in_target_2624", "Source provides no match for variadic element at position {0} in target."),
	Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target: r(2625, 1, "Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target_2625", "Variadic element at position {0} in source does not match element at position {1} in target."),
	Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target: r(2626, 1, "Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target_2626", "Type at position {0} in source is not compatible with type at position {1} in target."),
	Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target: r(2627, 1, "Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target_2627", "Type at positions {0} through {1} in source is not compatible with type at position {2} in target."),
	Cannot_assign_to_0_because_it_is_an_enum: r(2628, 1, "Cannot_assign_to_0_because_it_is_an_enum_2628", "Cannot assign to '{0}' because it is an enum."),
	Cannot_assign_to_0_because_it_is_a_class: r(2629, 1, "Cannot_assign_to_0_because_it_is_a_class_2629", "Cannot assign to '{0}' because it is a class."),
	Cannot_assign_to_0_because_it_is_a_function: r(2630, 1, "Cannot_assign_to_0_because_it_is_a_function_2630", "Cannot assign to '{0}' because it is a function."),
	Cannot_assign_to_0_because_it_is_a_namespace: r(2631, 1, "Cannot_assign_to_0_because_it_is_a_namespace_2631", "Cannot assign to '{0}' because it is a namespace."),
	Cannot_assign_to_0_because_it_is_an_import: r(2632, 1, "Cannot_assign_to_0_because_it_is_an_import_2632", "Cannot assign to '{0}' because it is an import."),
	JSX_property_access_expressions_cannot_include_JSX_namespace_names: r(2633, 1, "JSX_property_access_expressions_cannot_include_JSX_namespace_names_2633", "JSX property access expressions cannot include JSX namespace names"),
	_0_index_signatures_are_incompatible: r(2634, 1, "_0_index_signatures_are_incompatible_2634", "'{0}' index signatures are incompatible."),
	Type_0_has_no_signatures_for_which_the_type_argument_list_is_applicable: r(2635, 1, "Type_0_has_no_signatures_for_which_the_type_argument_list_is_applicable_2635", "Type '{0}' has no signatures for which the type argument list is applicable."),
	Type_0_is_not_assignable_to_type_1_as_implied_by_variance_annotation: r(2636, 1, "Type_0_is_not_assignable_to_type_1_as_implied_by_variance_annotation_2636", "Type '{0}' is not assignable to type '{1}' as implied by variance annotation."),
	Variance_annotations_are_only_supported_in_type_aliases_for_object_function_constructor_and_mapped_types: r(2637, 1, "Variance_annotations_are_only_supported_in_type_aliases_for_object_function_constructor_and_mapped_t_2637", "Variance annotations are only supported in type aliases for object, function, constructor, and mapped types."),
	Type_0_may_represent_a_primitive_value_which_is_not_permitted_as_the_right_operand_of_the_in_operator: r(2638, 1, "Type_0_may_represent_a_primitive_value_which_is_not_permitted_as_the_right_operand_of_the_in_operato_2638", "Type '{0}' may represent a primitive value, which is not permitted as the right operand of the 'in' operator."),
	React_components_cannot_include_JSX_namespace_names: r(2639, 1, "React_components_cannot_include_JSX_namespace_names_2639", "React components cannot include JSX namespace names"),
	Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity: r(2649, 1, "Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity_2649", "Cannot augment module '{0}' with value exports because it resolves to a non-module entity."),
	Non_abstract_class_expression_is_missing_implementations_for_the_following_members_of_0_Colon_1_and_2_more: r(2650, 1, "Non_abstract_class_expression_is_missing_implementations_for_the_following_members_of_0_Colon_1_and__2650", "Non-abstract class expression is missing implementations for the following members of '{0}': {1} and {2} more."),
	A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_members_defined_in_other_enums: r(2651, 1, "A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_memb_2651", "A member initializer in a enum declaration cannot reference members declared after it, including members defined in other enums."),
	Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_default_0_declaration_instead: r(2652, 1, "Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_d_2652", "Merged declaration '{0}' cannot include a default export declaration. Consider adding a separate 'export default {0}' declaration instead."),
	Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1: r(2653, 1, "Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1_2653", "Non-abstract class expression does not implement inherited abstract member '{0}' from class '{1}'."),
	Non_abstract_class_0_is_missing_implementations_for_the_following_members_of_1_Colon_2: r(2654, 1, "Non_abstract_class_0_is_missing_implementations_for_the_following_members_of_1_Colon_2_2654", "Non-abstract class '{0}' is missing implementations for the following members of '{1}': {2}."),
	Non_abstract_class_0_is_missing_implementations_for_the_following_members_of_1_Colon_2_and_3_more: r(2655, 1, "Non_abstract_class_0_is_missing_implementations_for_the_following_members_of_1_Colon_2_and_3_more_2655", "Non-abstract class '{0}' is missing implementations for the following members of '{1}': {2} and {3} more."),
	Non_abstract_class_expression_is_missing_implementations_for_the_following_members_of_0_Colon_1: r(2656, 1, "Non_abstract_class_expression_is_missing_implementations_for_the_following_members_of_0_Colon_1_2656", "Non-abstract class expression is missing implementations for the following members of '{0}': {1}."),
	JSX_expressions_must_have_one_parent_element: r(2657, 1, "JSX_expressions_must_have_one_parent_element_2657", "JSX expressions must have one parent element."),
	Type_0_provides_no_match_for_the_signature_1: r(2658, 1, "Type_0_provides_no_match_for_the_signature_1_2658", "Type '{0}' provides no match for the signature '{1}'."),
	super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_higher: r(2659, 1, "super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_highe_2659", "'super' is only allowed in members of object literal expressions when option 'target' is 'ES2015' or higher."),
	super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions: r(2660, 1, "super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions_2660", "'super' can only be referenced in members of derived classes or object literal expressions."),
	Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module: r(2661, 1, "Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module_2661", "Cannot export '{0}'. Only local declarations can be exported from a module."),
	Cannot_find_name_0_Did_you_mean_the_static_member_1_0: r(2662, 1, "Cannot_find_name_0_Did_you_mean_the_static_member_1_0_2662", "Cannot find name '{0}'. Did you mean the static member '{1}.{0}'?"),
	Cannot_find_name_0_Did_you_mean_the_instance_member_this_0: r(2663, 1, "Cannot_find_name_0_Did_you_mean_the_instance_member_this_0_2663", "Cannot find name '{0}'. Did you mean the instance member 'this.{0}'?"),
	Invalid_module_name_in_augmentation_module_0_cannot_be_found: r(2664, 1, "Invalid_module_name_in_augmentation_module_0_cannot_be_found_2664", "Invalid module name in augmentation, module '{0}' cannot be found."),
	Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augmented: r(2665, 1, "Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augm_2665", "Invalid module name in augmentation. Module '{0}' resolves to an untyped module at '{1}', which cannot be augmented."),
	Exports_and_export_assignments_are_not_permitted_in_module_augmentations: r(2666, 1, "Exports_and_export_assignments_are_not_permitted_in_module_augmentations_2666", "Exports and export assignments are not permitted in module augmentations."),
	Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_module: r(2667, 1, "Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_mod_2667", "Imports are not permitted in module augmentations. Consider moving them to the enclosing external module."),
	export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always_visible: r(2668, 1, "export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always__2668", "'export' modifier cannot be applied to ambient modules and module augmentations since they are always visible."),
	Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations: r(2669, 1, "Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_2669", "Augmentations for the global scope can only be directly nested in external modules or ambient module declarations."),
	Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambient_context: r(2670, 1, "Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambien_2670", "Augmentations for the global scope should have 'declare' modifier unless they appear in already ambient context."),
	Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity: r(2671, 1, "Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity_2671", "Cannot augment module '{0}' because it resolves to a non-module entity."),
	Cannot_assign_a_0_constructor_type_to_a_1_constructor_type: r(2672, 1, "Cannot_assign_a_0_constructor_type_to_a_1_constructor_type_2672", "Cannot assign a '{0}' constructor type to a '{1}' constructor type."),
	Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration: r(2673, 1, "Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration_2673", "Constructor of class '{0}' is private and only accessible within the class declaration."),
	Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration: r(2674, 1, "Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration_2674", "Constructor of class '{0}' is protected and only accessible within the class declaration."),
	Cannot_extend_a_class_0_Class_constructor_is_marked_as_private: r(2675, 1, "Cannot_extend_a_class_0_Class_constructor_is_marked_as_private_2675", "Cannot extend a class '{0}'. Class constructor is marked as private."),
	Accessors_must_both_be_abstract_or_non_abstract: r(2676, 1, "Accessors_must_both_be_abstract_or_non_abstract_2676", "Accessors must both be abstract or non-abstract."),
	A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type: r(2677, 1, "A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type_2677", "A type predicate's type must be assignable to its parameter's type."),
	Type_0_is_not_comparable_to_type_1: r(2678, 1, "Type_0_is_not_comparable_to_type_1_2678", "Type '{0}' is not comparable to type '{1}'."),
	A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void: r(2679, 1, "A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void_2679", "A function that is called with the 'new' keyword cannot have a 'this' type that is 'void'."),
	A_0_parameter_must_be_the_first_parameter: r(2680, 1, "A_0_parameter_must_be_the_first_parameter_2680", "A '{0}' parameter must be the first parameter."),
	A_constructor_cannot_have_a_this_parameter: r(2681, 1, "A_constructor_cannot_have_a_this_parameter_2681", "A constructor cannot have a 'this' parameter."),
	this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation: r(2683, 1, "this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_2683", "'this' implicitly has type 'any' because it does not have a type annotation."),
	The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1: r(2684, 1, "The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1_2684", "The 'this' context of type '{0}' is not assignable to method's 'this' of type '{1}'."),
	The_this_types_of_each_signature_are_incompatible: r(2685, 1, "The_this_types_of_each_signature_are_incompatible_2685", "The 'this' types of each signature are incompatible."),
	_0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead: r(2686, 1, "_0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead_2686", "'{0}' refers to a UMD global, but the current file is a module. Consider adding an import instead."),
	All_declarations_of_0_must_have_identical_modifiers: r(2687, 1, "All_declarations_of_0_must_have_identical_modifiers_2687", "All declarations of '{0}' must have identical modifiers."),
	Cannot_find_type_definition_file_for_0: r(2688, 1, "Cannot_find_type_definition_file_for_0_2688", "Cannot find type definition file for '{0}'."),
	Cannot_extend_an_interface_0_Did_you_mean_implements: r(2689, 1, "Cannot_extend_an_interface_0_Did_you_mean_implements_2689", "Cannot extend an interface '{0}'. Did you mean 'implements'?"),
	_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0: r(2690, 1, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0_2690", "'{0}' only refers to a type, but is being used as a value here. Did you mean to use '{1} in {0}'?"),
	_0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible: r(2692, 1, "_0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible_2692", "'{0}' is a primitive, but '{1}' is a wrapper object. Prefer using '{0}' when possible."),
	_0_only_refers_to_a_type_but_is_being_used_as_a_value_here: r(2693, 1, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_2693", "'{0}' only refers to a type, but is being used as a value here."),
	Namespace_0_has_no_exported_member_1: r(2694, 1, "Namespace_0_has_no_exported_member_1_2694", "Namespace '{0}' has no exported member '{1}'."),
	Left_side_of_comma_operator_is_unused_and_has_no_side_effects: r(2695, 1, "Left_side_of_comma_operator_is_unused_and_has_no_side_effects_2695", "Left side of comma operator is unused and has no side effects.", !0),
	The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead: r(2696, 1, "The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead_2696", "The 'Object' type is assignable to very few other types. Did you mean to use the 'any' type instead?"),
	An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option: r(2697, 1, "An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_in_2697", "An async function or method must return a 'Promise'. Make sure you have a declaration for 'Promise' or include 'ES2015' in your '--lib' option."),
	Spread_types_may_only_be_created_from_object_types: r(2698, 1, "Spread_types_may_only_be_created_from_object_types_2698", "Spread types may only be created from object types."),
	Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1: r(2699, 1, "Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1_2699", "Static property '{0}' conflicts with built-in property 'Function.{0}' of constructor function '{1}'."),
	Rest_types_may_only_be_created_from_object_types: r(2700, 1, "Rest_types_may_only_be_created_from_object_types_2700", "Rest types may only be created from object types."),
	The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access: r(2701, 1, "The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access_2701", "The target of an object rest assignment must be a variable or a property access."),
	_0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here: r(2702, 1, "_0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here_2702", "'{0}' only refers to a type, but is being used as a namespace here."),
	The_operand_of_a_delete_operator_must_be_a_property_reference: r(2703, 1, "The_operand_of_a_delete_operator_must_be_a_property_reference_2703", "The operand of a 'delete' operator must be a property reference."),
	The_operand_of_a_delete_operator_cannot_be_a_read_only_property: r(2704, 1, "The_operand_of_a_delete_operator_cannot_be_a_read_only_property_2704", "The operand of a 'delete' operator cannot be a read-only property."),
	An_async_function_or_method_in_ES5_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option: r(2705, 1, "An_async_function_or_method_in_ES5_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_2705", "An async function or method in ES5 requires the 'Promise' constructor.  Make sure you have a declaration for the 'Promise' constructor or include 'ES2015' in your '--lib' option."),
	Required_type_parameters_may_not_follow_optional_type_parameters: r(2706, 1, "Required_type_parameters_may_not_follow_optional_type_parameters_2706", "Required type parameters may not follow optional type parameters."),
	Generic_type_0_requires_between_1_and_2_type_arguments: r(2707, 1, "Generic_type_0_requires_between_1_and_2_type_arguments_2707", "Generic type '{0}' requires between {1} and {2} type arguments."),
	Cannot_use_namespace_0_as_a_value: r(2708, 1, "Cannot_use_namespace_0_as_a_value_2708", "Cannot use namespace '{0}' as a value."),
	Cannot_use_namespace_0_as_a_type: r(2709, 1, "Cannot_use_namespace_0_as_a_type_2709", "Cannot use namespace '{0}' as a type."),
	_0_are_specified_twice_The_attribute_named_0_will_be_overwritten: r(2710, 1, "_0_are_specified_twice_The_attribute_named_0_will_be_overwritten_2710", "'{0}' are specified twice. The attribute named '{0}' will be overwritten."),
	A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option: r(2711, 1, "A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES20_2711", "A dynamic import call returns a 'Promise'. Make sure you have a declaration for 'Promise' or include 'ES2015' in your '--lib' option."),
	A_dynamic_import_call_in_ES5_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option: r(2712, 1, "A_dynamic_import_call_in_ES5_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_t_2712", "A dynamic import call in ES5 requires the 'Promise' constructor.  Make sure you have a declaration for the 'Promise' constructor or include 'ES2015' in your '--lib' option."),
	Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1: r(2713, 1, "Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_p_2713", `Cannot access '{0}.{1}' because '{0}' is a type, but not a namespace. Did you mean to retrieve the type of the property '{1}' in '{0}' with '{0}["{1}"]'?`),
	The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context: r(2714, 1, "The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context_2714", "The expression of an export assignment must be an identifier or qualified name in an ambient context."),
	Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor: r(2715, 1, "Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor_2715", "Abstract property '{0}' in class '{1}' cannot be accessed in the constructor."),
	Type_parameter_0_has_a_circular_default: r(2716, 1, "Type_parameter_0_has_a_circular_default_2716", "Type parameter '{0}' has a circular default."),
	Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_type_2: r(2717, 1, "Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_t_2717", "Subsequent property declarations must have the same type.  Property '{0}' must be of type '{1}', but here has type '{2}'."),
	Duplicate_property_0: r(2718, 1, "Duplicate_property_0_2718", "Duplicate property '{0}'."),
	Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated: r(2719, 1, "Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated_2719", "Type '{0}' is not assignable to type '{1}'. Two different types with this name exist, but they are unrelated."),
	Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass: r(2720, 1, "Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclas_2720", "Class '{0}' incorrectly implements class '{1}'. Did you mean to extend '{1}' and inherit its members as a subclass?"),
	Cannot_invoke_an_object_which_is_possibly_null: r(2721, 1, "Cannot_invoke_an_object_which_is_possibly_null_2721", "Cannot invoke an object which is possibly 'null'."),
	Cannot_invoke_an_object_which_is_possibly_undefined: r(2722, 1, "Cannot_invoke_an_object_which_is_possibly_undefined_2722", "Cannot invoke an object which is possibly 'undefined'."),
	Cannot_invoke_an_object_which_is_possibly_null_or_undefined: r(2723, 1, "Cannot_invoke_an_object_which_is_possibly_null_or_undefined_2723", "Cannot invoke an object which is possibly 'null' or 'undefined'."),
	_0_has_no_exported_member_named_1_Did_you_mean_2: r(2724, 1, "_0_has_no_exported_member_named_1_Did_you_mean_2_2724", "'{0}' has no exported member named '{1}'. Did you mean '{2}'?"),
	Class_name_cannot_be_Object_when_targeting_ES5_and_above_with_module_0: r(2725, 1, "Class_name_cannot_be_Object_when_targeting_ES5_and_above_with_module_0_2725", "Class name cannot be 'Object' when targeting ES5 and above with module {0}."),
	Cannot_find_lib_definition_for_0: r(2726, 1, "Cannot_find_lib_definition_for_0_2726", "Cannot find lib definition for '{0}'."),
	Cannot_find_lib_definition_for_0_Did_you_mean_1: r(2727, 1, "Cannot_find_lib_definition_for_0_Did_you_mean_1_2727", "Cannot find lib definition for '{0}'. Did you mean '{1}'?"),
	_0_is_declared_here: r(2728, 3, "_0_is_declared_here_2728", "'{0}' is declared here."),
	Property_0_is_used_before_its_initialization: r(2729, 1, "Property_0_is_used_before_its_initialization_2729", "Property '{0}' is used before its initialization."),
	An_arrow_function_cannot_have_a_this_parameter: r(2730, 1, "An_arrow_function_cannot_have_a_this_parameter_2730", "An arrow function cannot have a 'this' parameter."),
	Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_in_String: r(2731, 1, "Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_i_2731", "Implicit conversion of a 'symbol' to a 'string' will fail at runtime. Consider wrapping this expression in 'String(...)'."),
	Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension: r(2732, 1, "Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension_2732", "Cannot find module '{0}'. Consider using '--resolveJsonModule' to import module with '.json' extension."),
	Property_0_was_also_declared_here: r(2733, 1, "Property_0_was_also_declared_here_2733", "Property '{0}' was also declared here."),
	Are_you_missing_a_semicolon: r(2734, 1, "Are_you_missing_a_semicolon_2734", "Are you missing a semicolon?"),
	Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1: r(2735, 1, "Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1_2735", "Did you mean for '{0}' to be constrained to type 'new (...args: any[]) => {1}'?"),
	Operator_0_cannot_be_applied_to_type_1: r(2736, 1, "Operator_0_cannot_be_applied_to_type_1_2736", "Operator '{0}' cannot be applied to type '{1}'."),
	BigInt_literals_are_not_available_when_targeting_lower_than_ES2020: r(2737, 1, "BigInt_literals_are_not_available_when_targeting_lower_than_ES2020_2737", "BigInt literals are not available when targeting lower than ES2020."),
	An_outer_value_of_this_is_shadowed_by_this_container: r(2738, 3, "An_outer_value_of_this_is_shadowed_by_this_container_2738", "An outer value of 'this' is shadowed by this container."),
	Type_0_is_missing_the_following_properties_from_type_1_Colon_2: r(2739, 1, "Type_0_is_missing_the_following_properties_from_type_1_Colon_2_2739", "Type '{0}' is missing the following properties from type '{1}': {2}"),
	Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more: r(2740, 1, "Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more_2740", "Type '{0}' is missing the following properties from type '{1}': {2}, and {3} more."),
	Property_0_is_missing_in_type_1_but_required_in_type_2: r(2741, 1, "Property_0_is_missing_in_type_1_but_required_in_type_2_2741", "Property '{0}' is missing in type '{1}' but required in type '{2}'."),
	The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_annotation_is_necessary: r(2742, 1, "The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_a_2742", "The inferred type of '{0}' cannot be named without a reference to '{1}'. This is likely not portable. A type annotation is necessary."),
	No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments: r(2743, 1, "No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments_2743", "No overload expects {0} type arguments, but overloads do exist that expect either {1} or {2} type arguments."),
	Type_parameter_defaults_can_only_reference_previously_declared_type_parameters: r(2744, 1, "Type_parameter_defaults_can_only_reference_previously_declared_type_parameters_2744", "Type parameter defaults can only reference previously declared type parameters."),
	This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_provided: r(2745, 1, "This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_pr_2745", "This JSX tag's '{0}' prop expects type '{1}' which requires multiple children, but only a single child was provided."),
	This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided: r(2746, 1, "This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided_2746", "This JSX tag's '{0}' prop expects a single child of type '{1}', but multiple children were provided."),
	_0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_type_of_1_is_2: r(2747, 1, "_0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_t_2747", "'{0}' components don't accept text as child elements. Text in JSX has the type 'string', but the expected type of '{1}' is '{2}'."),
	Cannot_access_ambient_const_enums_when_0_is_enabled: r(2748, 1, "Cannot_access_ambient_const_enums_when_0_is_enabled_2748", "Cannot access ambient const enums when '{0}' is enabled."),
	_0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0: r(2749, 1, "_0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0_2749", "'{0}' refers to a value, but is being used as a type here. Did you mean 'typeof {0}'?"),
	The_implementation_signature_is_declared_here: r(2750, 1, "The_implementation_signature_is_declared_here_2750", "The implementation signature is declared here."),
	Circularity_originates_in_type_at_this_location: r(2751, 1, "Circularity_originates_in_type_at_this_location_2751", "Circularity originates in type at this location."),
	The_first_export_default_is_here: r(2752, 1, "The_first_export_default_is_here_2752", "The first export default is here."),
	Another_export_default_is_here: r(2753, 1, "Another_export_default_is_here_2753", "Another export default is here."),
	super_may_not_use_type_arguments: r(2754, 1, "super_may_not_use_type_arguments_2754", "'super' may not use type arguments."),
	No_constituent_of_type_0_is_callable: r(2755, 1, "No_constituent_of_type_0_is_callable_2755", "No constituent of type '{0}' is callable."),
	Not_all_constituents_of_type_0_are_callable: r(2756, 1, "Not_all_constituents_of_type_0_are_callable_2756", "Not all constituents of type '{0}' are callable."),
	Type_0_has_no_call_signatures: r(2757, 1, "Type_0_has_no_call_signatures_2757", "Type '{0}' has no call signatures."),
	Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_other: r(2758, 1, "Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_2758", "Each member of the union type '{0}' has signatures, but none of those signatures are compatible with each other."),
	No_constituent_of_type_0_is_constructable: r(2759, 1, "No_constituent_of_type_0_is_constructable_2759", "No constituent of type '{0}' is constructable."),
	Not_all_constituents_of_type_0_are_constructable: r(2760, 1, "Not_all_constituents_of_type_0_are_constructable_2760", "Not all constituents of type '{0}' are constructable."),
	Type_0_has_no_construct_signatures: r(2761, 1, "Type_0_has_no_construct_signatures_2761", "Type '{0}' has no construct signatures."),
	Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_with_each_other: r(2762, 1, "Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_2762", "Each member of the union type '{0}' has construct signatures, but none of those signatures are compatible with each other."),
	Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_send_0: r(2763, 1, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_s_2763", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but for-of will always send '{0}'."),
	Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_always_send_0: r(2764, 1, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_al_2764", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but array spread will always send '{0}'."),
	Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring_will_always_send_0: r(2765, 1, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring__2765", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but array destructuring will always send '{0}'."),
	Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_containing_generator_will_always_send_0: r(2766, 1, "Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_co_2766", "Cannot delegate iteration to value because the 'next' method of its iterator expects type '{1}', but the containing generator will always send '{0}'."),
	The_0_property_of_an_iterator_must_be_a_method: r(2767, 1, "The_0_property_of_an_iterator_must_be_a_method_2767", "The '{0}' property of an iterator must be a method."),
	The_0_property_of_an_async_iterator_must_be_a_method: r(2768, 1, "The_0_property_of_an_async_iterator_must_be_a_method_2768", "The '{0}' property of an async iterator must be a method."),
	No_overload_matches_this_call: r(2769, 1, "No_overload_matches_this_call_2769", "No overload matches this call."),
	The_last_overload_gave_the_following_error: r(2770, 1, "The_last_overload_gave_the_following_error_2770", "The last overload gave the following error."),
	The_last_overload_is_declared_here: r(2771, 1, "The_last_overload_is_declared_here_2771", "The last overload is declared here."),
	Overload_0_of_1_2_gave_the_following_error: r(2772, 1, "Overload_0_of_1_2_gave_the_following_error_2772", "Overload {0} of {1}, '{2}', gave the following error."),
	Did_you_forget_to_use_await: r(2773, 1, "Did_you_forget_to_use_await_2773", "Did you forget to use 'await'?"),
	This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_instead: r(2774, 1, "This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_2774", "This condition will always return true since this function is always defined. Did you mean to call it instead?"),
	Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation: r(2775, 1, "Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation_2775", "Assertions require every name in the call target to be declared with an explicit type annotation."),
	Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name: r(2776, 1, "Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name_2776", "Assertions require the call target to be an identifier or qualified name."),
	The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access: r(2777, 1, "The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access_2777", "The operand of an increment or decrement operator may not be an optional property access."),
	The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access: r(2778, 1, "The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access_2778", "The target of an object rest assignment may not be an optional property access."),
	The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access: r(2779, 1, "The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access_2779", "The left-hand side of an assignment expression may not be an optional property access."),
	The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access: r(2780, 1, "The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access_2780", "The left-hand side of a 'for...in' statement may not be an optional property access."),
	The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access: r(2781, 1, "The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access_2781", "The left-hand side of a 'for...of' statement may not be an optional property access."),
	_0_needs_an_explicit_type_annotation: r(2782, 3, "_0_needs_an_explicit_type_annotation_2782", "'{0}' needs an explicit type annotation."),
	_0_is_specified_more_than_once_so_this_usage_will_be_overwritten: r(2783, 1, "_0_is_specified_more_than_once_so_this_usage_will_be_overwritten_2783", "'{0}' is specified more than once, so this usage will be overwritten."),
	get_and_set_accessors_cannot_declare_this_parameters: r(2784, 1, "get_and_set_accessors_cannot_declare_this_parameters_2784", "'get' and 'set' accessors cannot declare 'this' parameters."),
	This_spread_always_overwrites_this_property: r(2785, 1, "This_spread_always_overwrites_this_property_2785", "This spread always overwrites this property."),
	_0_cannot_be_used_as_a_JSX_component: r(2786, 1, "_0_cannot_be_used_as_a_JSX_component_2786", "'{0}' cannot be used as a JSX component."),
	Its_return_type_0_is_not_a_valid_JSX_element: r(2787, 1, "Its_return_type_0_is_not_a_valid_JSX_element_2787", "Its return type '{0}' is not a valid JSX element."),
	Its_instance_type_0_is_not_a_valid_JSX_element: r(2788, 1, "Its_instance_type_0_is_not_a_valid_JSX_element_2788", "Its instance type '{0}' is not a valid JSX element."),
	Its_element_type_0_is_not_a_valid_JSX_element: r(2789, 1, "Its_element_type_0_is_not_a_valid_JSX_element_2789", "Its element type '{0}' is not a valid JSX element."),
	The_operand_of_a_delete_operator_must_be_optional: r(2790, 1, "The_operand_of_a_delete_operator_must_be_optional_2790", "The operand of a 'delete' operator must be optional."),
	Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_later: r(2791, 1, "Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_lat_2791", "Exponentiation cannot be performed on 'bigint' values unless the 'target' option is set to 'es2016' or later."),
	Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_nodenext_or_to_add_aliases_to_the_paths_option: r(2792, 1, "Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_nodenext_or_to_add_aliases_t_2792", "Cannot find module '{0}'. Did you mean to set the 'moduleResolution' option to 'nodenext', or to add aliases to the 'paths' option?"),
	The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_are_not_externally_visible: r(2793, 1, "The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_2793", "The call would have succeeded against this implementation, but implementation signatures of overloads are not externally visible."),
	Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise: r(2794, 1, "Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise_2794", "Expected {0} arguments, but got {1}. Did you forget to include 'void' in your type argument to 'Promise'?"),
	The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types: r(2795, 1, "The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types_2795", "The 'intrinsic' keyword can only be used to declare compiler provided intrinsic types."),
	It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tagged_template_expression_which_cannot_be_invoked: r(2796, 1, "It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tag_2796", "It is likely that you are missing a comma to separate these two template expressions. They form a tagged template expression which cannot be invoked."),
	A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_be_declared_abstract: r(2797, 1, "A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_2797", "A mixin class that extends from a type variable containing an abstract construct signature must also be declared 'abstract'."),
	The_declaration_was_marked_as_deprecated_here: r(2798, 1, "The_declaration_was_marked_as_deprecated_here_2798", "The declaration was marked as deprecated here."),
	Type_produces_a_tuple_type_that_is_too_large_to_represent: r(2799, 1, "Type_produces_a_tuple_type_that_is_too_large_to_represent_2799", "Type produces a tuple type that is too large to represent."),
	Expression_produces_a_tuple_type_that_is_too_large_to_represent: r(2800, 1, "Expression_produces_a_tuple_type_that_is_too_large_to_represent_2800", "Expression produces a tuple type that is too large to represent."),
	This_condition_will_always_return_true_since_this_0_is_always_defined: r(2801, 1, "This_condition_will_always_return_true_since_this_0_is_always_defined_2801", "This condition will always return true since this '{0}' is always defined."),
	Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher: r(2802, 1, "Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es201_2802", "Type '{0}' can only be iterated through when using the '--downlevelIteration' flag or with a '--target' of 'es2015' or higher."),
	Cannot_assign_to_private_method_0_Private_methods_are_not_writable: r(2803, 1, "Cannot_assign_to_private_method_0_Private_methods_are_not_writable_2803", "Cannot assign to private method '{0}'. Private methods are not writable."),
	Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name: r(2804, 1, "Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name_2804", "Duplicate identifier '{0}'. Static and instance elements cannot share the same private name."),
	Private_accessor_was_defined_without_a_getter: r(2806, 1, "Private_accessor_was_defined_without_a_getter_2806", "Private accessor was defined without a getter."),
	This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0: r(2807, 1, "This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_o_2807", "This syntax requires an imported helper named '{1}' with {2} parameters, which is not compatible with the one in '{0}'. Consider upgrading your version of '{0}'."),
	A_get_accessor_must_be_at_least_as_accessible_as_the_setter: r(2808, 1, "A_get_accessor_must_be_at_least_as_accessible_as_the_setter_2808", "A get accessor must be at least as accessible as the setter"),
	Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_destructuring_assignment_you_might_need_to_wrap_the_whole_assignment_in_parentheses: r(2809, 1, "Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_d_2809", "Declaration or statement expected. This '=' follows a block of statements, so if you intended to write a destructuring assignment, you might need to wrap the whole assignment in parentheses."),
	Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_without_arguments: r(2810, 1, "Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_2810", "Expected 1 argument, but got 0. 'new Promise()' needs a JSDoc hint to produce a 'resolve' that can be called without arguments."),
	Initializer_for_property_0: r(2811, 1, "Initializer_for_property_0_2811", "Initializer for property '{0}'"),
	Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom: r(2812, 1, "Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom_2812", "Property '{0}' does not exist on type '{1}'. Try changing the 'lib' compiler option to include 'dom'."),
	Class_declaration_cannot_implement_overload_list_for_0: r(2813, 1, "Class_declaration_cannot_implement_overload_list_for_0_2813", "Class declaration cannot implement overload list for '{0}'."),
	Function_with_bodies_can_only_merge_with_classes_that_are_ambient: r(2814, 1, "Function_with_bodies_can_only_merge_with_classes_that_are_ambient_2814", "Function with bodies can only merge with classes that are ambient."),
	arguments_cannot_be_referenced_in_property_initializers_or_class_static_initialization_blocks: r(2815, 1, "arguments_cannot_be_referenced_in_property_initializers_or_class_static_initialization_blocks_2815", "'arguments' cannot be referenced in property initializers or class static initialization blocks."),
	Cannot_use_this_in_a_static_property_initializer_of_a_decorated_class: r(2816, 1, "Cannot_use_this_in_a_static_property_initializer_of_a_decorated_class_2816", "Cannot use 'this' in a static property initializer of a decorated class."),
	Property_0_has_no_initializer_and_is_not_definitely_assigned_in_a_class_static_block: r(2817, 1, "Property_0_has_no_initializer_and_is_not_definitely_assigned_in_a_class_static_block_2817", "Property '{0}' has no initializer and is not definitely assigned in a class static block."),
	Duplicate_identifier_0_Compiler_reserves_name_1_when_emitting_super_references_in_static_initializers: r(2818, 1, "Duplicate_identifier_0_Compiler_reserves_name_1_when_emitting_super_references_in_static_initializer_2818", "Duplicate identifier '{0}'. Compiler reserves name '{1}' when emitting 'super' references in static initializers."),
	Namespace_name_cannot_be_0: r(2819, 1, "Namespace_name_cannot_be_0_2819", "Namespace name cannot be '{0}'."),
	Type_0_is_not_assignable_to_type_1_Did_you_mean_2: r(2820, 1, "Type_0_is_not_assignable_to_type_1_Did_you_mean_2_2820", "Type '{0}' is not assignable to type '{1}'. Did you mean '{2}'?"),
	Import_assertions_are_only_supported_when_the_module_option_is_set_to_esnext_node18_node20_nodenext_or_preserve: r(2821, 1, "Import_assertions_are_only_supported_when_the_module_option_is_set_to_esnext_node18_node20_nodenext__2821", "Import assertions are only supported when the '--module' option is set to 'esnext', 'node18', 'node20', 'nodenext', or 'preserve'."),
	Import_assertions_cannot_be_used_with_type_only_imports_or_exports: r(2822, 1, "Import_assertions_cannot_be_used_with_type_only_imports_or_exports_2822", "Import assertions cannot be used with type-only imports or exports."),
	Import_attributes_are_only_supported_when_the_module_option_is_set_to_esnext_node18_node20_nodenext_or_preserve: r(2823, 1, "Import_attributes_are_only_supported_when_the_module_option_is_set_to_esnext_node18_node20_nodenext__2823", "Import attributes are only supported when the '--module' option is set to 'esnext', 'node18', 'node20', 'nodenext', or 'preserve'."),
	Cannot_find_namespace_0_Did_you_mean_1: r(2833, 1, "Cannot_find_namespace_0_Did_you_mean_1_2833", "Cannot find namespace '{0}'. Did you mean '{1}'?"),
	Relative_import_paths_need_explicit_file_extensions_in_ECMAScript_imports_when_moduleResolution_is_node16_or_nodenext_Consider_adding_an_extension_to_the_import_path: r(2834, 1, "Relative_import_paths_need_explicit_file_extensions_in_ECMAScript_imports_when_moduleResolution_is_n_2834", "Relative import paths need explicit file extensions in ECMAScript imports when '--moduleResolution' is 'node16' or 'nodenext'. Consider adding an extension to the import path."),
	Relative_import_paths_need_explicit_file_extensions_in_ECMAScript_imports_when_moduleResolution_is_node16_or_nodenext_Did_you_mean_0: r(2835, 1, "Relative_import_paths_need_explicit_file_extensions_in_ECMAScript_imports_when_moduleResolution_is_n_2835", "Relative import paths need explicit file extensions in ECMAScript imports when '--moduleResolution' is 'node16' or 'nodenext'. Did you mean '{0}'?"),
	Import_assertions_are_not_allowed_on_statements_that_compile_to_CommonJS_require_calls: r(2836, 1, "Import_assertions_are_not_allowed_on_statements_that_compile_to_CommonJS_require_calls_2836", "Import assertions are not allowed on statements that compile to CommonJS 'require' calls."),
	Import_assertion_values_must_be_string_literal_expressions: r(2837, 1, "Import_assertion_values_must_be_string_literal_expressions_2837", "Import assertion values must be string literal expressions."),
	All_declarations_of_0_must_have_identical_constraints: r(2838, 1, "All_declarations_of_0_must_have_identical_constraints_2838", "All declarations of '{0}' must have identical constraints."),
	This_condition_will_always_return_0_since_JavaScript_compares_objects_by_reference_not_value: r(2839, 1, "This_condition_will_always_return_0_since_JavaScript_compares_objects_by_reference_not_value_2839", "This condition will always return '{0}' since JavaScript compares objects by reference, not value."),
	An_interface_cannot_extend_a_primitive_type_like_0_It_can_only_extend_other_named_object_types: r(2840, 1, "An_interface_cannot_extend_a_primitive_type_like_0_It_can_only_extend_other_named_object_types_2840", "An interface cannot extend a primitive type like '{0}'. It can only extend other named object types."),
	_0_is_an_unused_renaming_of_1_Did_you_intend_to_use_it_as_a_type_annotation: r(2842, 1, "_0_is_an_unused_renaming_of_1_Did_you_intend_to_use_it_as_a_type_annotation_2842", "'{0}' is an unused renaming of '{1}'. Did you intend to use it as a type annotation?"),
	We_can_only_write_a_type_for_0_by_adding_a_type_for_the_entire_parameter_here: r(2843, 1, "We_can_only_write_a_type_for_0_by_adding_a_type_for_the_entire_parameter_here_2843", "We can only write a type for '{0}' by adding a type for the entire parameter here."),
	Type_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor: r(2844, 1, "Type_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor_2844", "Type of instance member variable '{0}' cannot reference identifier '{1}' declared in the constructor."),
	This_condition_will_always_return_0: r(2845, 1, "This_condition_will_always_return_0_2845", "This condition will always return '{0}'."),
	A_declaration_file_cannot_be_imported_without_import_type_Did_you_mean_to_import_an_implementation_file_0_instead: r(2846, 1, "A_declaration_file_cannot_be_imported_without_import_type_Did_you_mean_to_import_an_implementation_f_2846", "A declaration file cannot be imported without 'import type'. Did you mean to import an implementation file '{0}' instead?"),
	The_right_hand_side_of_an_instanceof_expression_must_not_be_an_instantiation_expression: r(2848, 1, "The_right_hand_side_of_an_instanceof_expression_must_not_be_an_instantiation_expression_2848", "The right-hand side of an 'instanceof' expression must not be an instantiation expression."),
	Target_signature_provides_too_few_arguments_Expected_0_or_more_but_got_1: r(2849, 1, "Target_signature_provides_too_few_arguments_Expected_0_or_more_but_got_1_2849", "Target signature provides too few arguments. Expected {0} or more, but got {1}."),
	The_initializer_of_a_using_declaration_must_be_either_an_object_with_a_Symbol_dispose_method_or_be_null_or_undefined: r(2850, 1, "The_initializer_of_a_using_declaration_must_be_either_an_object_with_a_Symbol_dispose_method_or_be_n_2850", "The initializer of a 'using' declaration must be either an object with a '[Symbol.dispose]()' method, or be 'null' or 'undefined'."),
	The_initializer_of_an_await_using_declaration_must_be_either_an_object_with_a_Symbol_asyncDispose_or_Symbol_dispose_method_or_be_null_or_undefined: r(2851, 1, "The_initializer_of_an_await_using_declaration_must_be_either_an_object_with_a_Symbol_asyncDispose_or_2851", "The initializer of an 'await using' declaration must be either an object with a '[Symbol.asyncDispose]()' or '[Symbol.dispose]()' method, or be 'null' or 'undefined'."),
	await_using_statements_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules: r(2852, 1, "await_using_statements_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_2852", "'await using' statements are only allowed within async functions and at the top levels of modules."),
	await_using_statements_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module: r(2853, 1, "await_using_statements_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_th_2853", "'await using' statements are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."),
	Top_level_await_using_statements_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_node18_node20_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher: r(2854, 1, "Top_level_await_using_statements_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_sys_2854", "Top-level 'await using' statements are only allowed when the 'module' option is set to 'es2022', 'esnext', 'system', 'node16', 'node18', 'node20', 'nodenext', or 'preserve', and the 'target' option is set to 'es2017' or higher."),
	Class_field_0_defined_by_the_parent_class_is_not_accessible_in_the_child_class_via_super: r(2855, 1, "Class_field_0_defined_by_the_parent_class_is_not_accessible_in_the_child_class_via_super_2855", "Class field '{0}' defined by the parent class is not accessible in the child class via super."),
	Import_attributes_are_not_allowed_on_statements_that_compile_to_CommonJS_require_calls: r(2856, 1, "Import_attributes_are_not_allowed_on_statements_that_compile_to_CommonJS_require_calls_2856", "Import attributes are not allowed on statements that compile to CommonJS 'require' calls."),
	Import_attributes_cannot_be_used_with_type_only_imports_or_exports: r(2857, 1, "Import_attributes_cannot_be_used_with_type_only_imports_or_exports_2857", "Import attributes cannot be used with type-only imports or exports."),
	Import_attribute_values_must_be_string_literal_expressions: r(2858, 1, "Import_attribute_values_must_be_string_literal_expressions_2858", "Import attribute values must be string literal expressions."),
	Excessive_complexity_comparing_types_0_and_1: r(2859, 1, "Excessive_complexity_comparing_types_0_and_1_2859", "Excessive complexity comparing types '{0}' and '{1}'."),
	The_left_hand_side_of_an_instanceof_expression_must_be_assignable_to_the_first_argument_of_the_right_hand_side_s_Symbol_hasInstance_method: r(2860, 1, "The_left_hand_side_of_an_instanceof_expression_must_be_assignable_to_the_first_argument_of_the_right_2860", "The left-hand side of an 'instanceof' expression must be assignable to the first argument of the right-hand side's '[Symbol.hasInstance]' method."),
	An_object_s_Symbol_hasInstance_method_must_return_a_boolean_value_for_it_to_be_used_on_the_right_hand_side_of_an_instanceof_expression: r(2861, 1, "An_object_s_Symbol_hasInstance_method_must_return_a_boolean_value_for_it_to_be_used_on_the_right_han_2861", "An object's '[Symbol.hasInstance]' method must return a boolean value for it to be used on the right-hand side of an 'instanceof' expression."),
	Type_0_is_generic_and_can_only_be_indexed_for_reading: r(2862, 1, "Type_0_is_generic_and_can_only_be_indexed_for_reading_2862", "Type '{0}' is generic and can only be indexed for reading."),
	A_class_cannot_extend_a_primitive_type_like_0_Classes_can_only_extend_constructable_values: r(2863, 1, "A_class_cannot_extend_a_primitive_type_like_0_Classes_can_only_extend_constructable_values_2863", "A class cannot extend a primitive type like '{0}'. Classes can only extend constructable values."),
	A_class_cannot_implement_a_primitive_type_like_0_It_can_only_implement_other_named_object_types: r(2864, 1, "A_class_cannot_implement_a_primitive_type_like_0_It_can_only_implement_other_named_object_types_2864", "A class cannot implement a primitive type like '{0}'. It can only implement other named object types."),
	Import_0_conflicts_with_local_value_so_must_be_declared_with_a_type_only_import_when_isolatedModules_is_enabled: r(2865, 1, "Import_0_conflicts_with_local_value_so_must_be_declared_with_a_type_only_import_when_isolatedModules_2865", "Import '{0}' conflicts with local value, so must be declared with a type-only import when 'isolatedModules' is enabled."),
	Import_0_conflicts_with_global_value_used_in_this_file_so_must_be_declared_with_a_type_only_import_when_isolatedModules_is_enabled: r(2866, 1, "Import_0_conflicts_with_global_value_used_in_this_file_so_must_be_declared_with_a_type_only_import_w_2866", "Import '{0}' conflicts with global value used in this file, so must be declared with a type-only import when 'isolatedModules' is enabled."),
	Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_Bun_Try_npm_i_save_dev_types_Slashbun: r(2867, 1, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_Bun_Try_npm_i_save_dev_types_Slashbun_2867", "Cannot find name '{0}'. Do you need to install type definitions for Bun? Try `npm i --save-dev @types/bun`."),
	Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_Bun_Try_npm_i_save_dev_types_Slashbun_and_then_add_bun_to_the_types_field_in_your_tsconfig: r(2868, 1, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_Bun_Try_npm_i_save_dev_types_Slashbun_2868", "Cannot find name '{0}'. Do you need to install type definitions for Bun? Try `npm i --save-dev @types/bun` and then add 'bun' to the types field in your tsconfig."),
	Right_operand_of_is_unreachable_because_the_left_operand_is_never_nullish: r(2869, 1, "Right_operand_of_is_unreachable_because_the_left_operand_is_never_nullish_2869", "Right operand of ?? is unreachable because the left operand is never nullish."),
	This_binary_expression_is_never_nullish_Are_you_missing_parentheses: r(2870, 1, "This_binary_expression_is_never_nullish_Are_you_missing_parentheses_2870", "This binary expression is never nullish. Are you missing parentheses?"),
	This_expression_is_always_nullish: r(2871, 1, "This_expression_is_always_nullish_2871", "This expression is always nullish."),
	This_kind_of_expression_is_always_truthy: r(2872, 1, "This_kind_of_expression_is_always_truthy_2872", "This kind of expression is always truthy."),
	This_kind_of_expression_is_always_falsy: r(2873, 1, "This_kind_of_expression_is_always_falsy_2873", "This kind of expression is always falsy."),
	This_JSX_tag_requires_0_to_be_in_scope_but_it_could_not_be_found: r(2874, 1, "This_JSX_tag_requires_0_to_be_in_scope_but_it_could_not_be_found_2874", "This JSX tag requires '{0}' to be in scope, but it could not be found."),
	This_JSX_tag_requires_the_module_path_0_to_exist_but_none_could_be_found_Make_sure_you_have_types_for_the_appropriate_package_installed: r(2875, 1, "This_JSX_tag_requires_the_module_path_0_to_exist_but_none_could_be_found_Make_sure_you_have_types_fo_2875", "This JSX tag requires the module path '{0}' to exist, but none could be found. Make sure you have types for the appropriate package installed."),
	This_relative_import_path_is_unsafe_to_rewrite_because_it_looks_like_a_file_name_but_actually_resolves_to_0: r(2876, 1, "This_relative_import_path_is_unsafe_to_rewrite_because_it_looks_like_a_file_name_but_actually_resolv_2876", "This relative import path is unsafe to rewrite because it looks like a file name, but actually resolves to \"{0}\"."),
	This_import_uses_a_0_extension_to_resolve_to_an_input_TypeScript_file_but_will_not_be_rewritten_during_emit_because_it_is_not_a_relative_path: r(2877, 1, "This_import_uses_a_0_extension_to_resolve_to_an_input_TypeScript_file_but_will_not_be_rewritten_duri_2877", "This import uses a '{0}' extension to resolve to an input TypeScript file, but will not be rewritten during emit because it is not a relative path."),
	This_import_path_is_unsafe_to_rewrite_because_it_resolves_to_another_project_and_the_relative_path_between_the_projects_output_files_is_not_the_same_as_the_relative_path_between_its_input_files: r(2878, 1, "This_import_path_is_unsafe_to_rewrite_because_it_resolves_to_another_project_and_the_relative_path_b_2878", "This import path is unsafe to rewrite because it resolves to another project, and the relative path between the projects' output files is not the same as the relative path between its input files."),
	Using_JSX_fragments_requires_fragment_factory_0_to_be_in_scope_but_it_could_not_be_found: r(2879, 1, "Using_JSX_fragments_requires_fragment_factory_0_to_be_in_scope_but_it_could_not_be_found_2879", "Using JSX fragments requires fragment factory '{0}' to be in scope, but it could not be found."),
	Import_assertions_have_been_replaced_by_import_attributes_Use_with_instead_of_assert: r(2880, 1, "Import_assertions_have_been_replaced_by_import_attributes_Use_with_instead_of_assert_2880", "Import assertions have been replaced by import attributes. Use 'with' instead of 'assert'."),
	This_expression_is_never_nullish: r(2881, 1, "This_expression_is_never_nullish_2881", "This expression is never nullish."),
	Import_declaration_0_is_using_private_name_1: r(4e3, 1, "Import_declaration_0_is_using_private_name_1_4000", "Import declaration '{0}' is using private name '{1}'."),
	Type_parameter_0_of_exported_class_has_or_is_using_private_name_1: r(4002, 1, "Type_parameter_0_of_exported_class_has_or_is_using_private_name_1_4002", "Type parameter '{0}' of exported class has or is using private name '{1}'."),
	Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1: r(4004, 1, "Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1_4004", "Type parameter '{0}' of exported interface has or is using private name '{1}'."),
	Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1: r(4006, 1, "Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4006", "Type parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'."),
	Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1: r(4008, 1, "Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4008", "Type parameter '{0}' of call signature from exported interface has or is using private name '{1}'."),
	Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1: r(4010, 1, "Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4010", "Type parameter '{0}' of public static method from exported class has or is using private name '{1}'."),
	Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1: r(4012, 1, "Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4012", "Type parameter '{0}' of public method from exported class has or is using private name '{1}'."),
	Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1: r(4014, 1, "Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4014", "Type parameter '{0}' of method from exported interface has or is using private name '{1}'."),
	Type_parameter_0_of_exported_function_has_or_is_using_private_name_1: r(4016, 1, "Type_parameter_0_of_exported_function_has_or_is_using_private_name_1_4016", "Type parameter '{0}' of exported function has or is using private name '{1}'."),
	Implements_clause_of_exported_class_0_has_or_is_using_private_name_1: r(4019, 1, "Implements_clause_of_exported_class_0_has_or_is_using_private_name_1_4019", "Implements clause of exported class '{0}' has or is using private name '{1}'."),
	extends_clause_of_exported_class_0_has_or_is_using_private_name_1: r(4020, 1, "extends_clause_of_exported_class_0_has_or_is_using_private_name_1_4020", "'extends' clause of exported class '{0}' has or is using private name '{1}'."),
	extends_clause_of_exported_class_has_or_is_using_private_name_0: r(4021, 1, "extends_clause_of_exported_class_has_or_is_using_private_name_0_4021", "'extends' clause of exported class has or is using private name '{0}'."),
	extends_clause_of_exported_interface_0_has_or_is_using_private_name_1: r(4022, 1, "extends_clause_of_exported_interface_0_has_or_is_using_private_name_1_4022", "'extends' clause of exported interface '{0}' has or is using private name '{1}'."),
	Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4023, 1, "Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4023", "Exported variable '{0}' has or is using name '{1}' from external module {2} but cannot be named."),
	Exported_variable_0_has_or_is_using_name_1_from_private_module_2: r(4024, 1, "Exported_variable_0_has_or_is_using_name_1_from_private_module_2_4024", "Exported variable '{0}' has or is using name '{1}' from private module '{2}'."),
	Exported_variable_0_has_or_is_using_private_name_1: r(4025, 1, "Exported_variable_0_has_or_is_using_private_name_1_4025", "Exported variable '{0}' has or is using private name '{1}'."),
	Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4026, 1, "Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot__4026", "Public static property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
	Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: r(4027, 1, "Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4027", "Public static property '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
	Public_static_property_0_of_exported_class_has_or_is_using_private_name_1: r(4028, 1, "Public_static_property_0_of_exported_class_has_or_is_using_private_name_1_4028", "Public static property '{0}' of exported class has or is using private name '{1}'."),
	Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4029, 1, "Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_name_4029", "Public property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
	Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: r(4030, 1, "Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4030", "Public property '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
	Public_property_0_of_exported_class_has_or_is_using_private_name_1: r(4031, 1, "Public_property_0_of_exported_class_has_or_is_using_private_name_1_4031", "Public property '{0}' of exported class has or is using private name '{1}'."),
	Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2: r(4032, 1, "Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2_4032", "Property '{0}' of exported interface has or is using name '{1}' from private module '{2}'."),
	Property_0_of_exported_interface_has_or_is_using_private_name_1: r(4033, 1, "Property_0_of_exported_interface_has_or_is_using_private_name_1_4033", "Property '{0}' of exported interface has or is using private name '{1}'."),
	Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: r(4034, 1, "Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_mod_4034", "Parameter type of public static setter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
	Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1: r(4035, 1, "Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1_4035", "Parameter type of public static setter '{0}' from exported class has or is using private name '{1}'."),
	Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: r(4036, 1, "Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2_4036", "Parameter type of public setter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
	Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1: r(4037, 1, "Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1_4037", "Parameter type of public setter '{0}' from exported class has or is using private name '{1}'."),
	Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4038, 1, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_modul_4038", "Return type of public static getter '{0}' from exported class has or is using name '{1}' from external module {2} but cannot be named."),
	Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: r(4039, 1, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_4039", "Return type of public static getter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
	Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1: r(4040, 1, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1_4040", "Return type of public static getter '{0}' from exported class has or is using private name '{1}'."),
	Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4041, 1, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_4041", "Return type of public getter '{0}' from exported class has or is using name '{1}' from external module {2} but cannot be named."),
	Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: r(4042, 1, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2_4042", "Return type of public getter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
	Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1: r(4043, 1, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1_4043", "Return type of public getter '{0}' from exported class has or is using private name '{1}'."),
	Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: r(4044, 1, "Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_mod_4044", "Return type of constructor signature from exported interface has or is using name '{0}' from private module '{1}'."),
	Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0: r(4045, 1, "Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0_4045", "Return type of constructor signature from exported interface has or is using private name '{0}'."),
	Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: r(4046, 1, "Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4046", "Return type of call signature from exported interface has or is using name '{0}' from private module '{1}'."),
	Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0: r(4047, 1, "Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0_4047", "Return type of call signature from exported interface has or is using private name '{0}'."),
	Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: r(4048, 1, "Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4048", "Return type of index signature from exported interface has or is using name '{0}' from private module '{1}'."),
	Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0: r(4049, 1, "Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0_4049", "Return type of index signature from exported interface has or is using private name '{0}'."),
	Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: r(4050, 1, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module__4050", "Return type of public static method from exported class has or is using name '{0}' from external module {1} but cannot be named."),
	Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1: r(4051, 1, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4051", "Return type of public static method from exported class has or is using name '{0}' from private module '{1}'."),
	Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0: r(4052, 1, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0_4052", "Return type of public static method from exported class has or is using private name '{0}'."),
	Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: r(4053, 1, "Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_c_4053", "Return type of public method from exported class has or is using name '{0}' from external module {1} but cannot be named."),
	Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1: r(4054, 1, "Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4054", "Return type of public method from exported class has or is using name '{0}' from private module '{1}'."),
	Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0: r(4055, 1, "Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0_4055", "Return type of public method from exported class has or is using private name '{0}'."),
	Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1: r(4056, 1, "Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4056", "Return type of method from exported interface has or is using name '{0}' from private module '{1}'."),
	Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0: r(4057, 1, "Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0_4057", "Return type of method from exported interface has or is using private name '{0}'."),
	Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: r(4058, 1, "Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named_4058", "Return type of exported function has or is using name '{0}' from external module {1} but cannot be named."),
	Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1: r(4059, 1, "Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1_4059", "Return type of exported function has or is using name '{0}' from private module '{1}'."),
	Return_type_of_exported_function_has_or_is_using_private_name_0: r(4060, 1, "Return_type_of_exported_function_has_or_is_using_private_name_0_4060", "Return type of exported function has or is using private name '{0}'."),
	Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4061, 1, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_can_4061", "Parameter '{0}' of constructor from exported class has or is using name '{1}' from external module {2} but cannot be named."),
	Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2: r(4062, 1, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2_4062", "Parameter '{0}' of constructor from exported class has or is using name '{1}' from private module '{2}'."),
	Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1: r(4063, 1, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1_4063", "Parameter '{0}' of constructor from exported class has or is using private name '{1}'."),
	Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: r(4064, 1, "Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_mod_4064", "Parameter '{0}' of constructor signature from exported interface has or is using name '{1}' from private module '{2}'."),
	Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1: r(4065, 1, "Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4065", "Parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'."),
	Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: r(4066, 1, "Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4066", "Parameter '{0}' of call signature from exported interface has or is using name '{1}' from private module '{2}'."),
	Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1: r(4067, 1, "Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4067", "Parameter '{0}' of call signature from exported interface has or is using private name '{1}'."),
	Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4068, 1, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module__4068", "Parameter '{0}' of public static method from exported class has or is using name '{1}' from external module {2} but cannot be named."),
	Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2: r(4069, 1, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4069", "Parameter '{0}' of public static method from exported class has or is using name '{1}' from private module '{2}'."),
	Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1: r(4070, 1, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4070", "Parameter '{0}' of public static method from exported class has or is using private name '{1}'."),
	Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4071, 1, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_c_4071", "Parameter '{0}' of public method from exported class has or is using name '{1}' from external module {2} but cannot be named."),
	Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2: r(4072, 1, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4072", "Parameter '{0}' of public method from exported class has or is using name '{1}' from private module '{2}'."),
	Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1: r(4073, 1, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4073", "Parameter '{0}' of public method from exported class has or is using private name '{1}'."),
	Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2: r(4074, 1, "Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4074", "Parameter '{0}' of method from exported interface has or is using name '{1}' from private module '{2}'."),
	Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1: r(4075, 1, "Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4075", "Parameter '{0}' of method from exported interface has or is using private name '{1}'."),
	Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4076, 1, "Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4076", "Parameter '{0}' of exported function has or is using name '{1}' from external module {2} but cannot be named."),
	Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2: r(4077, 1, "Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2_4077", "Parameter '{0}' of exported function has or is using name '{1}' from private module '{2}'."),
	Parameter_0_of_exported_function_has_or_is_using_private_name_1: r(4078, 1, "Parameter_0_of_exported_function_has_or_is_using_private_name_1_4078", "Parameter '{0}' of exported function has or is using private name '{1}'."),
	Exported_type_alias_0_has_or_is_using_private_name_1: r(4081, 1, "Exported_type_alias_0_has_or_is_using_private_name_1_4081", "Exported type alias '{0}' has or is using private name '{1}'."),
	Default_export_of_the_module_has_or_is_using_private_name_0: r(4082, 1, "Default_export_of_the_module_has_or_is_using_private_name_0_4082", "Default export of the module has or is using private name '{0}'."),
	Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1: r(4083, 1, "Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1_4083", "Type parameter '{0}' of exported type alias has or is using private name '{1}'."),
	Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2: r(4084, 1, "Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2_4084", "Exported type alias '{0}' has or is using private name '{1}' from module {2}."),
	Extends_clause_for_inferred_type_0_has_or_is_using_private_name_1: r(4085, 1, "Extends_clause_for_inferred_type_0_has_or_is_using_private_name_1_4085", "Extends clause for inferred type '{0}' has or is using private name '{1}'."),
	Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: r(4091, 1, "Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4091", "Parameter '{0}' of index signature from exported interface has or is using name '{1}' from private module '{2}'."),
	Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1: r(4092, 1, "Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1_4092", "Parameter '{0}' of index signature from exported interface has or is using private name '{1}'."),
	Property_0_of_exported_anonymous_class_type_may_not_be_private_or_protected: r(4094, 1, "Property_0_of_exported_anonymous_class_type_may_not_be_private_or_protected_4094", "Property '{0}' of exported anonymous class type may not be private or protected."),
	Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4095, 1, "Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_4095", "Public static method '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
	Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: r(4096, 1, "Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4096", "Public static method '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
	Public_static_method_0_of_exported_class_has_or_is_using_private_name_1: r(4097, 1, "Public_static_method_0_of_exported_class_has_or_is_using_private_name_1_4097", "Public static method '{0}' of exported class has or is using private name '{1}'."),
	Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4098, 1, "Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4098", "Public method '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
	Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: r(4099, 1, "Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4099", "Public method '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
	Public_method_0_of_exported_class_has_or_is_using_private_name_1: r(4100, 1, "Public_method_0_of_exported_class_has_or_is_using_private_name_1_4100", "Public method '{0}' of exported class has or is using private name '{1}'."),
	Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2: r(4101, 1, "Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2_4101", "Method '{0}' of exported interface has or is using name '{1}' from private module '{2}'."),
	Method_0_of_exported_interface_has_or_is_using_private_name_1: r(4102, 1, "Method_0_of_exported_interface_has_or_is_using_private_name_1_4102", "Method '{0}' of exported interface has or is using private name '{1}'."),
	Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1: r(4103, 1, "Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1_4103", "Type parameter '{0}' of exported mapped object type is using private name '{1}'."),
	The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1: r(4104, 1, "The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1_4104", "The type '{0}' is 'readonly' and cannot be assigned to the mutable type '{1}'."),
	Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter: r(4105, 1, "Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter_4105", "Private or protected member '{0}' cannot be accessed on a type parameter."),
	Parameter_0_of_accessor_has_or_is_using_private_name_1: r(4106, 1, "Parameter_0_of_accessor_has_or_is_using_private_name_1_4106", "Parameter '{0}' of accessor has or is using private name '{1}'."),
	Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2: r(4107, 1, "Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2_4107", "Parameter '{0}' of accessor has or is using name '{1}' from private module '{2}'."),
	Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: r(4108, 1, "Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4108", "Parameter '{0}' of accessor has or is using name '{1}' from external module '{2}' but cannot be named."),
	Type_arguments_for_0_circularly_reference_themselves: r(4109, 1, "Type_arguments_for_0_circularly_reference_themselves_4109", "Type arguments for '{0}' circularly reference themselves."),
	Tuple_type_arguments_circularly_reference_themselves: r(4110, 1, "Tuple_type_arguments_circularly_reference_themselves_4110", "Tuple type arguments circularly reference themselves."),
	Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0: r(4111, 1, "Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0_4111", "Property '{0}' comes from an index signature, so it must be accessed with ['{0}']."),
	This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class: r(4112, 1, "This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another__4112", "This member cannot have an 'override' modifier because its containing class '{0}' does not extend another class."),
	This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0: r(4113, 1, "This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_4113", "This member cannot have an 'override' modifier because it is not declared in the base class '{0}'."),
	This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0: r(4114, 1, "This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0_4114", "This member must have an 'override' modifier because it overrides a member in the base class '{0}'."),
	This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0: r(4115, 1, "This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0_4115", "This parameter property must have an 'override' modifier because it overrides a member in base class '{0}'."),
	This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0: r(4116, 1, "This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared__4116", "This member must have an 'override' modifier because it overrides an abstract method that is declared in the base class '{0}'."),
	This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1: r(4117, 1, "This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you__4117", "This member cannot have an 'override' modifier because it is not declared in the base class '{0}'. Did you mean '{1}'?"),
	The_type_of_this_node_cannot_be_serialized_because_its_property_0_cannot_be_serialized: r(4118, 1, "The_type_of_this_node_cannot_be_serialized_because_its_property_0_cannot_be_serialized_4118", "The type of this node cannot be serialized because its property '{0}' cannot be serialized."),
	This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0: r(4119, 1, "This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_4119", "This member must have a JSDoc comment with an '@override' tag because it overrides a member in the base class '{0}'."),
	This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0: r(4120, 1, "This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_4120", "This parameter property must have a JSDoc comment with an '@override' tag because it overrides a member in the base class '{0}'."),
	This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class: r(4121, 1, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_4121", "This member cannot have a JSDoc comment with an '@override' tag because its containing class '{0}' does not extend another class."),
	This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0: r(4122, 1, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base__4122", "This member cannot have a JSDoc comment with an '@override' tag because it is not declared in the base class '{0}'."),
	This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1: r(4123, 1, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base__4123", "This member cannot have a JSDoc comment with an 'override' tag because it is not declared in the base class '{0}'. Did you mean '{1}'?"),
	Compiler_option_0_of_value_1_is_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next: r(4124, 1, "Compiler_option_0_of_value_1_is_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_w_4124", "Compiler option '{0}' of value '{1}' is unstable. Use nightly TypeScript to silence this error. Try updating with 'npm install -D typescript@next'."),
	Each_declaration_of_0_1_differs_in_its_value_where_2_was_expected_but_3_was_given: r(4125, 1, "Each_declaration_of_0_1_differs_in_its_value_where_2_was_expected_but_3_was_given_4125", "Each declaration of '{0}.{1}' differs in its value, where '{2}' was expected but '{3}' was given."),
	One_value_of_0_1_is_the_string_2_and_the_other_is_assumed_to_be_an_unknown_numeric_value: r(4126, 1, "One_value_of_0_1_is_the_string_2_and_the_other_is_assumed_to_be_an_unknown_numeric_value_4126", "One value of '{0}.{1}' is the string '{2}', and the other is assumed to be an unknown numeric value."),
	This_member_cannot_have_an_override_modifier_because_its_name_is_dynamic: r(4127, 1, "This_member_cannot_have_an_override_modifier_because_its_name_is_dynamic_4127", "This member cannot have an 'override' modifier because its name is dynamic."),
	This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_name_is_dynamic: r(4128, 1, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_name_is_dynamic_4128", "This member cannot have a JSDoc comment with an '@override' tag because its name is dynamic."),
	The_current_host_does_not_support_the_0_option: r(5001, 1, "The_current_host_does_not_support_the_0_option_5001", "The current host does not support the '{0}' option."),
	Cannot_find_the_common_subdirectory_path_for_the_input_files: r(5009, 1, "Cannot_find_the_common_subdirectory_path_for_the_input_files_5009", "Cannot find the common subdirectory path for the input files."),
	File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0: r(5010, 1, "File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0_5010", "File specification cannot end in a recursive directory wildcard ('**'): '{0}'."),
	Cannot_read_file_0_Colon_1: r(5012, 1, "Cannot_read_file_0_Colon_1_5012", "Cannot read file '{0}': {1}."),
	Unknown_compiler_option_0: r(5023, 1, "Unknown_compiler_option_0_5023", "Unknown compiler option '{0}'."),
	Compiler_option_0_requires_a_value_of_type_1: r(5024, 1, "Compiler_option_0_requires_a_value_of_type_1_5024", "Compiler option '{0}' requires a value of type {1}."),
	Unknown_compiler_option_0_Did_you_mean_1: r(5025, 1, "Unknown_compiler_option_0_Did_you_mean_1_5025", "Unknown compiler option '{0}'. Did you mean '{1}'?"),
	Could_not_write_file_0_Colon_1: r(5033, 1, "Could_not_write_file_0_Colon_1_5033", "Could not write file '{0}': {1}."),
	Option_project_cannot_be_mixed_with_source_files_on_a_command_line: r(5042, 1, "Option_project_cannot_be_mixed_with_source_files_on_a_command_line_5042", "Option 'project' cannot be mixed with source files on a command line."),
	Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES2015_or_higher: r(5047, 1, "Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES_5047", "Option 'isolatedModules' can only be used when either option '--module' is provided or option 'target' is 'ES2015' or higher."),
	Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided: r(5051, 1, "Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided_5051", "Option '{0} can only be used when either option '--inlineSourceMap' or option '--sourceMap' is provided."),
	Option_0_cannot_be_specified_without_specifying_option_1: r(5052, 1, "Option_0_cannot_be_specified_without_specifying_option_1_5052", "Option '{0}' cannot be specified without specifying option '{1}'."),
	Option_0_cannot_be_specified_with_option_1: r(5053, 1, "Option_0_cannot_be_specified_with_option_1_5053", "Option '{0}' cannot be specified with option '{1}'."),
	A_tsconfig_json_file_is_already_defined_at_Colon_0: r(5054, 1, "A_tsconfig_json_file_is_already_defined_at_Colon_0_5054", "A 'tsconfig.json' file is already defined at: '{0}'."),
	Cannot_write_file_0_because_it_would_overwrite_input_file: r(5055, 1, "Cannot_write_file_0_because_it_would_overwrite_input_file_5055", "Cannot write file '{0}' because it would overwrite input file."),
	Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files: r(5056, 1, "Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files_5056", "Cannot write file '{0}' because it would be overwritten by multiple input files."),
	Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0: r(5057, 1, "Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0_5057", "Cannot find a tsconfig.json file at the specified directory: '{0}'."),
	The_specified_path_does_not_exist_Colon_0: r(5058, 1, "The_specified_path_does_not_exist_Colon_0_5058", "The specified path does not exist: '{0}'."),
	Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier: r(5059, 1, "Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier_5059", "Invalid value for '--reactNamespace'. '{0}' is not a valid identifier."),
	Pattern_0_can_have_at_most_one_Asterisk_character: r(5061, 1, "Pattern_0_can_have_at_most_one_Asterisk_character_5061", "Pattern '{0}' can have at most one '*' character."),
	Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character: r(5062, 1, "Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character_5062", "Substitution '{0}' in pattern '{1}' can have at most one '*' character."),
	Substitutions_for_pattern_0_should_be_an_array: r(5063, 1, "Substitutions_for_pattern_0_should_be_an_array_5063", "Substitutions for pattern '{0}' should be an array."),
	Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2: r(5064, 1, "Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2_5064", "Substitution '{0}' for pattern '{1}' has incorrect type, expected 'string', got '{2}'."),
	File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0: r(5065, 1, "File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildca_5065", "File specification cannot contain a parent directory ('..') that appears after a recursive directory wildcard ('**'): '{0}'."),
	Substitutions_for_pattern_0_shouldn_t_be_an_empty_array: r(5066, 1, "Substitutions_for_pattern_0_shouldn_t_be_an_empty_array_5066", "Substitutions for pattern '{0}' shouldn't be an empty array."),
	Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name: r(5067, 1, "Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name_5067", "Invalid value for 'jsxFactory'. '{0}' is not a valid identifier or qualified-name."),
	Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript_files_Learn_more_at_https_Colon_Slash_Slashaka_ms_Slashtsconfig: r(5068, 1, "Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript__5068", "Adding a tsconfig.json file will help organize projects that contain both TypeScript and JavaScript files. Learn more at https://aka.ms/tsconfig."),
	Option_0_cannot_be_specified_without_specifying_option_1_or_option_2: r(5069, 1, "Option_0_cannot_be_specified_without_specifying_option_1_or_option_2_5069", "Option '{0}' cannot be specified without specifying option '{1}' or option '{2}'."),
	Option_resolveJsonModule_cannot_be_specified_when_moduleResolution_is_set_to_classic: r(5070, 1, "Option_resolveJsonModule_cannot_be_specified_when_moduleResolution_is_set_to_classic_5070", "Option '--resolveJsonModule' cannot be specified when 'moduleResolution' is set to 'classic'."),
	Option_resolveJsonModule_cannot_be_specified_when_module_is_set_to_none_system_or_umd: r(5071, 1, "Option_resolveJsonModule_cannot_be_specified_when_module_is_set_to_none_system_or_umd_5071", "Option '--resolveJsonModule' cannot be specified when 'module' is set to 'none', 'system', or 'umd'."),
	Unknown_build_option_0: r(5072, 1, "Unknown_build_option_0_5072", "Unknown build option '{0}'."),
	Build_option_0_requires_a_value_of_type_1: r(5073, 1, "Build_option_0_requires_a_value_of_type_1_5073", "Build option '{0}' requires a value of type {1}."),
	Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBuildInfoFile_is_specified: r(5074, 1, "Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBui_5074", "Option '--incremental' can only be specified using tsconfig, emitting to single file or when option '--tsBuildInfoFile' is specified."),
	_0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_constraint_2: r(5075, 1, "_0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_5075", "'{0}' is assignable to the constraint of type '{1}', but '{1}' could be instantiated with a different subtype of constraint '{2}'."),
	_0_and_1_operations_cannot_be_mixed_without_parentheses: r(5076, 1, "_0_and_1_operations_cannot_be_mixed_without_parentheses_5076", "'{0}' and '{1}' operations cannot be mixed without parentheses."),
	Unknown_build_option_0_Did_you_mean_1: r(5077, 1, "Unknown_build_option_0_Did_you_mean_1_5077", "Unknown build option '{0}'. Did you mean '{1}'?"),
	Unknown_watch_option_0: r(5078, 1, "Unknown_watch_option_0_5078", "Unknown watch option '{0}'."),
	Unknown_watch_option_0_Did_you_mean_1: r(5079, 1, "Unknown_watch_option_0_Did_you_mean_1_5079", "Unknown watch option '{0}'. Did you mean '{1}'?"),
	Watch_option_0_requires_a_value_of_type_1: r(5080, 1, "Watch_option_0_requires_a_value_of_type_1_5080", "Watch option '{0}' requires a value of type {1}."),
	Cannot_find_a_tsconfig_json_file_at_the_current_directory_Colon_0: r(5081, 1, "Cannot_find_a_tsconfig_json_file_at_the_current_directory_Colon_0_5081", "Cannot find a tsconfig.json file at the current directory: {0}."),
	_0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1: r(5082, 1, "_0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1_5082", "'{0}' could be instantiated with an arbitrary type which could be unrelated to '{1}'."),
	Cannot_read_file_0: r(5083, 1, "Cannot_read_file_0_5083", "Cannot read file '{0}'."),
	A_tuple_member_cannot_be_both_optional_and_rest: r(5085, 1, "A_tuple_member_cannot_be_both_optional_and_rest_5085", "A tuple member cannot be both optional and rest."),
	A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_colon_rather_than_after_the_type: r(5086, 1, "A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_c_5086", "A labeled tuple element is declared as optional with a question mark after the name and before the colon, rather than after the type."),
	A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type: r(5087, 1, "A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type_5087", "A labeled tuple element is declared as rest with a '...' before the name, rather than before the type."),
	The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialized_A_type_annotation_is_necessary: r(5088, 1, "The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialize_5088", "The inferred type of '{0}' references a type with a cyclic structure which cannot be trivially serialized. A type annotation is necessary."),
	Option_0_cannot_be_specified_when_option_jsx_is_1: r(5089, 1, "Option_0_cannot_be_specified_when_option_jsx_is_1_5089", "Option '{0}' cannot be specified when option 'jsx' is '{1}'."),
	Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash: r(5090, 1, "Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash_5090", "Non-relative paths are not allowed when 'baseUrl' is not set. Did you forget a leading './'?"),
	Option_preserveConstEnums_cannot_be_disabled_when_0_is_enabled: r(5091, 1, "Option_preserveConstEnums_cannot_be_disabled_when_0_is_enabled_5091", "Option 'preserveConstEnums' cannot be disabled when '{0}' is enabled."),
	The_root_value_of_a_0_file_must_be_an_object: r(5092, 1, "The_root_value_of_a_0_file_must_be_an_object_5092", "The root value of a '{0}' file must be an object."),
	Compiler_option_0_may_only_be_used_with_build: r(5093, 1, "Compiler_option_0_may_only_be_used_with_build_5093", "Compiler option '--{0}' may only be used with '--build'."),
	Compiler_option_0_may_not_be_used_with_build: r(5094, 1, "Compiler_option_0_may_not_be_used_with_build_5094", "Compiler option '--{0}' may not be used with '--build'."),
	Option_0_can_only_be_used_when_module_is_set_to_preserve_or_to_es2015_or_later: r(5095, 1, "Option_0_can_only_be_used_when_module_is_set_to_preserve_or_to_es2015_or_later_5095", "Option '{0}' can only be used when 'module' is set to 'preserve' or to 'es2015' or later."),
	Option_allowImportingTsExtensions_can_only_be_used_when_either_noEmit_or_emitDeclarationOnly_is_set: r(5096, 1, "Option_allowImportingTsExtensions_can_only_be_used_when_either_noEmit_or_emitDeclarationOnly_is_set_5096", "Option 'allowImportingTsExtensions' can only be used when either 'noEmit' or 'emitDeclarationOnly' is set."),
	An_import_path_can_only_end_with_a_0_extension_when_allowImportingTsExtensions_is_enabled: r(5097, 1, "An_import_path_can_only_end_with_a_0_extension_when_allowImportingTsExtensions_is_enabled_5097", "An import path can only end with a '{0}' extension when 'allowImportingTsExtensions' is enabled."),
	Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler: r(5098, 1, "Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler_5098", "Option '{0}' can only be used when 'moduleResolution' is set to 'node16', 'nodenext', or 'bundler'."),
	Option_0_is_deprecated_and_will_stop_functioning_in_TypeScript_1_Specify_compilerOption_ignoreDeprecations_Colon_2_to_silence_this_error: r(5101, 1, "Option_0_is_deprecated_and_will_stop_functioning_in_TypeScript_1_Specify_compilerOption_ignoreDeprec_5101", `Option '{0}' is deprecated and will stop functioning in TypeScript {1}. Specify compilerOption '"ignoreDeprecations": "{2}"' to silence this error.`),
	Option_0_has_been_removed_Please_remove_it_from_your_configuration: r(5102, 1, "Option_0_has_been_removed_Please_remove_it_from_your_configuration_5102", "Option '{0}' has been removed. Please remove it from your configuration."),
	Invalid_value_for_ignoreDeprecations: r(5103, 1, "Invalid_value_for_ignoreDeprecations_5103", "Invalid value for '--ignoreDeprecations'."),
	Option_0_is_redundant_and_cannot_be_specified_with_option_1: r(5104, 1, "Option_0_is_redundant_and_cannot_be_specified_with_option_1_5104", "Option '{0}' is redundant and cannot be specified with option '{1}'."),
	Option_verbatimModuleSyntax_cannot_be_used_when_module_is_set_to_UMD_AMD_or_System: r(5105, 1, "Option_verbatimModuleSyntax_cannot_be_used_when_module_is_set_to_UMD_AMD_or_System_5105", "Option 'verbatimModuleSyntax' cannot be used when 'module' is set to 'UMD', 'AMD', or 'System'."),
	Use_0_instead: r(5106, 3, "Use_0_instead_5106", "Use '{0}' instead."),
	Option_0_1_is_deprecated_and_will_stop_functioning_in_TypeScript_2_Specify_compilerOption_ignoreDeprecations_Colon_3_to_silence_this_error: r(5107, 1, "Option_0_1_is_deprecated_and_will_stop_functioning_in_TypeScript_2_Specify_compilerOption_ignoreDepr_5107", `Option '{0}={1}' is deprecated and will stop functioning in TypeScript {2}. Specify compilerOption '"ignoreDeprecations": "{3}"' to silence this error.`),
	Option_0_1_has_been_removed_Please_remove_it_from_your_configuration: r(5108, 1, "Option_0_1_has_been_removed_Please_remove_it_from_your_configuration_5108", "Option '{0}={1}' has been removed. Please remove it from your configuration."),
	Option_moduleResolution_must_be_set_to_0_or_left_unspecified_when_option_module_is_set_to_1: r(5109, 1, "Option_moduleResolution_must_be_set_to_0_or_left_unspecified_when_option_module_is_set_to_1_5109", "Option 'moduleResolution' must be set to '{0}' (or left unspecified) when option 'module' is set to '{1}'."),
	Option_module_must_be_set_to_0_when_option_moduleResolution_is_set_to_1: r(5110, 1, "Option_module_must_be_set_to_0_when_option_moduleResolution_is_set_to_1_5110", "Option 'module' must be set to '{0}' when option 'moduleResolution' is set to '{1}'."),
	Generates_a_sourcemap_for_each_corresponding_d_ts_file: r(6e3, 3, "Generates_a_sourcemap_for_each_corresponding_d_ts_file_6000", "Generates a sourcemap for each corresponding '.d.ts' file."),
	Concatenate_and_emit_output_to_single_file: r(6001, 3, "Concatenate_and_emit_output_to_single_file_6001", "Concatenate and emit output to single file."),
	Generates_corresponding_d_ts_file: r(6002, 3, "Generates_corresponding_d_ts_file_6002", "Generates corresponding '.d.ts' file."),
	Specify_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations: r(6004, 3, "Specify_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations_6004", "Specify the location where debugger should locate TypeScript files instead of source locations."),
	Watch_input_files: r(6005, 3, "Watch_input_files_6005", "Watch input files."),
	Redirect_output_structure_to_the_directory: r(6006, 3, "Redirect_output_structure_to_the_directory_6006", "Redirect output structure to the directory."),
	Do_not_erase_const_enum_declarations_in_generated_code: r(6007, 3, "Do_not_erase_const_enum_declarations_in_generated_code_6007", "Do not erase const enum declarations in generated code."),
	Do_not_emit_outputs_if_any_errors_were_reported: r(6008, 3, "Do_not_emit_outputs_if_any_errors_were_reported_6008", "Do not emit outputs if any errors were reported."),
	Do_not_emit_comments_to_output: r(6009, 3, "Do_not_emit_comments_to_output_6009", "Do not emit comments to output."),
	Do_not_emit_outputs: r(6010, 3, "Do_not_emit_outputs_6010", "Do not emit outputs."),
	Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typechecking: r(6011, 3, "Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typech_6011", "Allow default imports from modules with no default export. This does not affect code emit, just typechecking."),
	Skip_type_checking_of_declaration_files: r(6012, 3, "Skip_type_checking_of_declaration_files_6012", "Skip type checking of declaration files."),
	Do_not_resolve_the_real_path_of_symlinks: r(6013, 3, "Do_not_resolve_the_real_path_of_symlinks_6013", "Do not resolve the real path of symlinks."),
	Only_emit_d_ts_declaration_files: r(6014, 3, "Only_emit_d_ts_declaration_files_6014", "Only emit '.d.ts' declaration files."),
	Specify_ECMAScript_target_version: r(6015, 3, "Specify_ECMAScript_target_version_6015", "Specify ECMAScript target version."),
	Specify_module_code_generation: r(6016, 3, "Specify_module_code_generation_6016", "Specify module code generation."),
	Print_this_message: r(6017, 3, "Print_this_message_6017", "Print this message."),
	Print_the_compiler_s_version: r(6019, 3, "Print_the_compiler_s_version_6019", "Print the compiler's version."),
	Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json: r(6020, 3, "Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json_6020", "Compile the project given the path to its configuration file, or to a folder with a 'tsconfig.json'."),
	Syntax_Colon_0: r(6023, 3, "Syntax_Colon_0_6023", "Syntax: {0}"),
	options: r(6024, 3, "options_6024", "options"),
	file: r(6025, 3, "file_6025", "file"),
	Examples_Colon_0: r(6026, 3, "Examples_Colon_0_6026", "Examples: {0}"),
	Options_Colon: r(6027, 3, "Options_Colon_6027", "Options:"),
	Version_0: r(6029, 3, "Version_0_6029", "Version {0}"),
	Insert_command_line_options_and_files_from_a_file: r(6030, 3, "Insert_command_line_options_and_files_from_a_file_6030", "Insert command line options and files from a file."),
	Starting_compilation_in_watch_mode: r(6031, 3, "Starting_compilation_in_watch_mode_6031", "Starting compilation in watch mode..."),
	File_change_detected_Starting_incremental_compilation: r(6032, 3, "File_change_detected_Starting_incremental_compilation_6032", "File change detected. Starting incremental compilation..."),
	KIND: r(6034, 3, "KIND_6034", "KIND"),
	FILE: r(6035, 3, "FILE_6035", "FILE"),
	VERSION: r(6036, 3, "VERSION_6036", "VERSION"),
	LOCATION: r(6037, 3, "LOCATION_6037", "LOCATION"),
	DIRECTORY: r(6038, 3, "DIRECTORY_6038", "DIRECTORY"),
	STRATEGY: r(6039, 3, "STRATEGY_6039", "STRATEGY"),
	FILE_OR_DIRECTORY: r(6040, 3, "FILE_OR_DIRECTORY_6040", "FILE OR DIRECTORY"),
	Errors_Files: r(6041, 3, "Errors_Files_6041", "Errors  Files"),
	Generates_corresponding_map_file: r(6043, 3, "Generates_corresponding_map_file_6043", "Generates corresponding '.map' file."),
	Compiler_option_0_expects_an_argument: r(6044, 1, "Compiler_option_0_expects_an_argument_6044", "Compiler option '{0}' expects an argument."),
	Unterminated_quoted_string_in_response_file_0: r(6045, 1, "Unterminated_quoted_string_in_response_file_0_6045", "Unterminated quoted string in response file '{0}'."),
	Argument_for_0_option_must_be_Colon_1: r(6046, 1, "Argument_for_0_option_must_be_Colon_1_6046", "Argument for '{0}' option must be: {1}."),
	Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1: r(6048, 1, "Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1_6048", "Locale must be of the form <language> or <language>-<territory>. For example '{0}' or '{1}'."),
	Unable_to_open_file_0: r(6050, 1, "Unable_to_open_file_0_6050", "Unable to open file '{0}'."),
	Corrupted_locale_file_0: r(6051, 1, "Corrupted_locale_file_0_6051", "Corrupted locale file {0}."),
	Raise_error_on_expressions_and_declarations_with_an_implied_any_type: r(6052, 3, "Raise_error_on_expressions_and_declarations_with_an_implied_any_type_6052", "Raise error on expressions and declarations with an implied 'any' type."),
	File_0_not_found: r(6053, 1, "File_0_not_found_6053", "File '{0}' not found."),
	File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1: r(6054, 1, "File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1_6054", "File '{0}' has an unsupported extension. The only supported extensions are {1}."),
	Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures: r(6055, 3, "Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures_6055", "Suppress noImplicitAny errors for indexing objects lacking index signatures."),
	Do_not_emit_declarations_for_code_that_has_an_internal_annotation: r(6056, 3, "Do_not_emit_declarations_for_code_that_has_an_internal_annotation_6056", "Do not emit declarations for code that has an '@internal' annotation."),
	Specify_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir: r(6058, 3, "Specify_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir_6058", "Specify the root directory of input files. Use to control the output directory structure with --outDir."),
	File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files: r(6059, 1, "File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files_6059", "File '{0}' is not under 'rootDir' '{1}'. 'rootDir' is expected to contain all source files."),
	Specify_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix: r(6060, 3, "Specify_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix_6060", "Specify the end of line sequence to be used when emitting files: 'CRLF' (dos) or 'LF' (unix)."),
	NEWLINE: r(6061, 3, "NEWLINE_6061", "NEWLINE"),
	Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line: r(6064, 1, "Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line_6064", "Option '{0}' can only be specified in 'tsconfig.json' file or set to 'null' on command line."),
	Enables_experimental_support_for_ES7_decorators: r(6065, 3, "Enables_experimental_support_for_ES7_decorators_6065", "Enables experimental support for ES7 decorators."),
	Enables_experimental_support_for_emitting_type_metadata_for_decorators: r(6066, 3, "Enables_experimental_support_for_emitting_type_metadata_for_decorators_6066", "Enables experimental support for emitting type metadata for decorators."),
	Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file: r(6070, 3, "Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file_6070", "Initializes a TypeScript project and creates a tsconfig.json file."),
	Successfully_created_a_tsconfig_json_file: r(6071, 3, "Successfully_created_a_tsconfig_json_file_6071", "Successfully created a tsconfig.json file."),
	Suppress_excess_property_checks_for_object_literals: r(6072, 3, "Suppress_excess_property_checks_for_object_literals_6072", "Suppress excess property checks for object literals."),
	Stylize_errors_and_messages_using_color_and_context_experimental: r(6073, 3, "Stylize_errors_and_messages_using_color_and_context_experimental_6073", "Stylize errors and messages using color and context (experimental)."),
	Do_not_report_errors_on_unused_labels: r(6074, 3, "Do_not_report_errors_on_unused_labels_6074", "Do not report errors on unused labels."),
	Report_error_when_not_all_code_paths_in_function_return_a_value: r(6075, 3, "Report_error_when_not_all_code_paths_in_function_return_a_value_6075", "Report error when not all code paths in function return a value."),
	Report_errors_for_fallthrough_cases_in_switch_statement: r(6076, 3, "Report_errors_for_fallthrough_cases_in_switch_statement_6076", "Report errors for fallthrough cases in switch statement."),
	Do_not_report_errors_on_unreachable_code: r(6077, 3, "Do_not_report_errors_on_unreachable_code_6077", "Do not report errors on unreachable code."),
	Disallow_inconsistently_cased_references_to_the_same_file: r(6078, 3, "Disallow_inconsistently_cased_references_to_the_same_file_6078", "Disallow inconsistently-cased references to the same file."),
	Specify_library_files_to_be_included_in_the_compilation: r(6079, 3, "Specify_library_files_to_be_included_in_the_compilation_6079", "Specify library files to be included in the compilation."),
	Specify_JSX_code_generation: r(6080, 3, "Specify_JSX_code_generation_6080", "Specify JSX code generation."),
	Only_amd_and_system_modules_are_supported_alongside_0: r(6082, 1, "Only_amd_and_system_modules_are_supported_alongside_0_6082", "Only 'amd' and 'system' modules are supported alongside --{0}."),
	Base_directory_to_resolve_non_absolute_module_names: r(6083, 3, "Base_directory_to_resolve_non_absolute_module_names_6083", "Base directory to resolve non-absolute module names."),
	Deprecated_Use_jsxFactory_instead_Specify_the_object_invoked_for_createElement_when_targeting_react_JSX_emit: r(6084, 3, "Deprecated_Use_jsxFactory_instead_Specify_the_object_invoked_for_createElement_when_targeting_react__6084", "[Deprecated] Use '--jsxFactory' instead. Specify the object invoked for createElement when targeting 'react' JSX emit"),
	Enable_tracing_of_the_name_resolution_process: r(6085, 3, "Enable_tracing_of_the_name_resolution_process_6085", "Enable tracing of the name resolution process."),
	Resolving_module_0_from_1: r(6086, 3, "Resolving_module_0_from_1_6086", "======== Resolving module '{0}' from '{1}'. ========"),
	Explicitly_specified_module_resolution_kind_Colon_0: r(6087, 3, "Explicitly_specified_module_resolution_kind_Colon_0_6087", "Explicitly specified module resolution kind: '{0}'."),
	Module_resolution_kind_is_not_specified_using_0: r(6088, 3, "Module_resolution_kind_is_not_specified_using_0_6088", "Module resolution kind is not specified, using '{0}'."),
	Module_name_0_was_successfully_resolved_to_1: r(6089, 3, "Module_name_0_was_successfully_resolved_to_1_6089", "======== Module name '{0}' was successfully resolved to '{1}'. ========"),
	Module_name_0_was_not_resolved: r(6090, 3, "Module_name_0_was_not_resolved_6090", "======== Module name '{0}' was not resolved. ========"),
	paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0: r(6091, 3, "paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0_6091", "'paths' option is specified, looking for a pattern to match module name '{0}'."),
	Module_name_0_matched_pattern_1: r(6092, 3, "Module_name_0_matched_pattern_1_6092", "Module name '{0}', matched pattern '{1}'."),
	Trying_substitution_0_candidate_module_location_Colon_1: r(6093, 3, "Trying_substitution_0_candidate_module_location_Colon_1_6093", "Trying substitution '{0}', candidate module location: '{1}'."),
	Resolving_module_name_0_relative_to_base_url_1_2: r(6094, 3, "Resolving_module_name_0_relative_to_base_url_1_2_6094", "Resolving module name '{0}' relative to base url '{1}' - '{2}'."),
	Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_types_Colon_1: r(6095, 3, "Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_types_Colon_1_6095", "Loading module as file / folder, candidate module location '{0}', target file types: {1}."),
	File_0_does_not_exist: r(6096, 3, "File_0_does_not_exist_6096", "File '{0}' does not exist."),
	File_0_exists_use_it_as_a_name_resolution_result: r(6097, 3, "File_0_exists_use_it_as_a_name_resolution_result_6097", "File '{0}' exists - use it as a name resolution result."),
	Loading_module_0_from_node_modules_folder_target_file_types_Colon_1: r(6098, 3, "Loading_module_0_from_node_modules_folder_target_file_types_Colon_1_6098", "Loading module '{0}' from 'node_modules' folder, target file types: {1}."),
	Found_package_json_at_0: r(6099, 3, "Found_package_json_at_0_6099", "Found 'package.json' at '{0}'."),
	package_json_does_not_have_a_0_field: r(6100, 3, "package_json_does_not_have_a_0_field_6100", "'package.json' does not have a '{0}' field."),
	package_json_has_0_field_1_that_references_2: r(6101, 3, "package_json_has_0_field_1_that_references_2_6101", "'package.json' has '{0}' field '{1}' that references '{2}'."),
	Allow_javascript_files_to_be_compiled: r(6102, 3, "Allow_javascript_files_to_be_compiled_6102", "Allow javascript files to be compiled."),
	Checking_if_0_is_the_longest_matching_prefix_for_1_2: r(6104, 3, "Checking_if_0_is_the_longest_matching_prefix_for_1_2_6104", "Checking if '{0}' is the longest matching prefix for '{1}' - '{2}'."),
	Expected_type_of_0_field_in_package_json_to_be_1_got_2: r(6105, 3, "Expected_type_of_0_field_in_package_json_to_be_1_got_2_6105", "Expected type of '{0}' field in 'package.json' to be '{1}', got '{2}'."),
	baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1: r(6106, 3, "baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1_6106", "'baseUrl' option is set to '{0}', using this value to resolve non-relative module name '{1}'."),
	rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0: r(6107, 3, "rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0_6107", "'rootDirs' option is set, using it to resolve relative module name '{0}'."),
	Longest_matching_prefix_for_0_is_1: r(6108, 3, "Longest_matching_prefix_for_0_is_1_6108", "Longest matching prefix for '{0}' is '{1}'."),
	Loading_0_from_the_root_dir_1_candidate_location_2: r(6109, 3, "Loading_0_from_the_root_dir_1_candidate_location_2_6109", "Loading '{0}' from the root dir '{1}', candidate location '{2}'."),
	Trying_other_entries_in_rootDirs: r(6110, 3, "Trying_other_entries_in_rootDirs_6110", "Trying other entries in 'rootDirs'."),
	Module_resolution_using_rootDirs_has_failed: r(6111, 3, "Module_resolution_using_rootDirs_has_failed_6111", "Module resolution using 'rootDirs' has failed."),
	Do_not_emit_use_strict_directives_in_module_output: r(6112, 3, "Do_not_emit_use_strict_directives_in_module_output_6112", "Do not emit 'use strict' directives in module output."),
	Enable_strict_null_checks: r(6113, 3, "Enable_strict_null_checks_6113", "Enable strict null checks."),
	Unknown_option_excludes_Did_you_mean_exclude: r(6114, 1, "Unknown_option_excludes_Did_you_mean_exclude_6114", "Unknown option 'excludes'. Did you mean 'exclude'?"),
	Raise_error_on_this_expressions_with_an_implied_any_type: r(6115, 3, "Raise_error_on_this_expressions_with_an_implied_any_type_6115", "Raise error on 'this' expressions with an implied 'any' type."),
	Resolving_type_reference_directive_0_containing_file_1_root_directory_2: r(6116, 3, "Resolving_type_reference_directive_0_containing_file_1_root_directory_2_6116", "======== Resolving type reference directive '{0}', containing file '{1}', root directory '{2}'. ========"),
	Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2: r(6119, 3, "Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2_6119", "======== Type reference directive '{0}' was successfully resolved to '{1}', primary: {2}. ========"),
	Type_reference_directive_0_was_not_resolved: r(6120, 3, "Type_reference_directive_0_was_not_resolved_6120", "======== Type reference directive '{0}' was not resolved. ========"),
	Resolving_with_primary_search_path_0: r(6121, 3, "Resolving_with_primary_search_path_0_6121", "Resolving with primary search path '{0}'."),
	Root_directory_cannot_be_determined_skipping_primary_search_paths: r(6122, 3, "Root_directory_cannot_be_determined_skipping_primary_search_paths_6122", "Root directory cannot be determined, skipping primary search paths."),
	Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set: r(6123, 3, "Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set_6123", "======== Resolving type reference directive '{0}', containing file '{1}', root directory not set. ========"),
	Type_declaration_files_to_be_included_in_compilation: r(6124, 3, "Type_declaration_files_to_be_included_in_compilation_6124", "Type declaration files to be included in compilation."),
	Looking_up_in_node_modules_folder_initial_location_0: r(6125, 3, "Looking_up_in_node_modules_folder_initial_location_0_6125", "Looking up in 'node_modules' folder, initial location '{0}'."),
	Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_modules_folder: r(6126, 3, "Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_mod_6126", "Containing file is not specified and root directory cannot be determined, skipping lookup in 'node_modules' folder."),
	Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1: r(6127, 3, "Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1_6127", "======== Resolving type reference directive '{0}', containing file not set, root directory '{1}'. ========"),
	Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set: r(6128, 3, "Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set_6128", "======== Resolving type reference directive '{0}', containing file not set, root directory not set. ========"),
	Resolving_real_path_for_0_result_1: r(6130, 3, "Resolving_real_path_for_0_result_1_6130", "Resolving real path for '{0}', result '{1}'."),
	Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system: r(6131, 1, "Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system_6131", "Cannot compile modules using option '{0}' unless the '--module' flag is 'amd' or 'system'."),
	File_name_0_has_a_1_extension_stripping_it: r(6132, 3, "File_name_0_has_a_1_extension_stripping_it_6132", "File name '{0}' has a '{1}' extension - stripping it."),
	_0_is_declared_but_its_value_is_never_read: r(6133, 1, "_0_is_declared_but_its_value_is_never_read_6133", "'{0}' is declared but its value is never read.", !0),
	Report_errors_on_unused_locals: r(6134, 3, "Report_errors_on_unused_locals_6134", "Report errors on unused locals."),
	Report_errors_on_unused_parameters: r(6135, 3, "Report_errors_on_unused_parameters_6135", "Report errors on unused parameters."),
	The_maximum_dependency_depth_to_search_under_node_modules_and_load_JavaScript_files: r(6136, 3, "The_maximum_dependency_depth_to_search_under_node_modules_and_load_JavaScript_files_6136", "The maximum dependency depth to search under node_modules and load JavaScript files."),
	Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1: r(6137, 1, "Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1_6137", "Cannot import type declaration files. Consider importing '{0}' instead of '{1}'."),
	Property_0_is_declared_but_its_value_is_never_read: r(6138, 1, "Property_0_is_declared_but_its_value_is_never_read_6138", "Property '{0}' is declared but its value is never read.", !0),
	Import_emit_helpers_from_tslib: r(6139, 3, "Import_emit_helpers_from_tslib_6139", "Import emit helpers from 'tslib'."),
	Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using_cache_location_2: r(6140, 1, "Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using__6140", "Auto discovery for typings is enabled in project '{0}'. Running extra resolution pass for module '{1}' using cache location '{2}'."),
	Parse_in_strict_mode_and_emit_use_strict_for_each_source_file: r(6141, 3, "Parse_in_strict_mode_and_emit_use_strict_for_each_source_file_6141", "Parse in strict mode and emit \"use strict\" for each source file."),
	Module_0_was_resolved_to_1_but_jsx_is_not_set: r(6142, 1, "Module_0_was_resolved_to_1_but_jsx_is_not_set_6142", "Module '{0}' was resolved to '{1}', but '--jsx' is not set."),
	Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1: r(6144, 3, "Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1_6144", "Module '{0}' was resolved as locally declared ambient module in file '{1}'."),
	Specify_the_JSX_factory_function_to_use_when_targeting_react_JSX_emit_e_g_React_createElement_or_h: r(6146, 3, "Specify_the_JSX_factory_function_to_use_when_targeting_react_JSX_emit_e_g_React_createElement_or_h_6146", "Specify the JSX factory function to use when targeting 'react' JSX emit, e.g. 'React.createElement' or 'h'."),
	Resolution_for_module_0_was_found_in_cache_from_location_1: r(6147, 3, "Resolution_for_module_0_was_found_in_cache_from_location_1_6147", "Resolution for module '{0}' was found in cache from location '{1}'."),
	Directory_0_does_not_exist_skipping_all_lookups_in_it: r(6148, 3, "Directory_0_does_not_exist_skipping_all_lookups_in_it_6148", "Directory '{0}' does not exist, skipping all lookups in it."),
	Show_diagnostic_information: r(6149, 3, "Show_diagnostic_information_6149", "Show diagnostic information."),
	Show_verbose_diagnostic_information: r(6150, 3, "Show_verbose_diagnostic_information_6150", "Show verbose diagnostic information."),
	Emit_a_single_file_with_source_maps_instead_of_having_a_separate_file: r(6151, 3, "Emit_a_single_file_with_source_maps_instead_of_having_a_separate_file_6151", "Emit a single file with source maps instead of having a separate file."),
	Emit_the_source_alongside_the_sourcemaps_within_a_single_file_requires_inlineSourceMap_or_sourceMap_to_be_set: r(6152, 3, "Emit_the_source_alongside_the_sourcemaps_within_a_single_file_requires_inlineSourceMap_or_sourceMap__6152", "Emit the source alongside the sourcemaps within a single file; requires '--inlineSourceMap' or '--sourceMap' to be set."),
	Transpile_each_file_as_a_separate_module_similar_to_ts_transpileModule: r(6153, 3, "Transpile_each_file_as_a_separate_module_similar_to_ts_transpileModule_6153", "Transpile each file as a separate module (similar to 'ts.transpileModule')."),
	Print_names_of_generated_files_part_of_the_compilation: r(6154, 3, "Print_names_of_generated_files_part_of_the_compilation_6154", "Print names of generated files part of the compilation."),
	Print_names_of_files_part_of_the_compilation: r(6155, 3, "Print_names_of_files_part_of_the_compilation_6155", "Print names of files part of the compilation."),
	The_locale_used_when_displaying_messages_to_the_user_e_g_en_us: r(6156, 3, "The_locale_used_when_displaying_messages_to_the_user_e_g_en_us_6156", "The locale used when displaying messages to the user (e.g. 'en-us')"),
	Do_not_generate_custom_helper_functions_like_extends_in_compiled_output: r(6157, 3, "Do_not_generate_custom_helper_functions_like_extends_in_compiled_output_6157", "Do not generate custom helper functions like '__extends' in compiled output."),
	Do_not_include_the_default_library_file_lib_d_ts: r(6158, 3, "Do_not_include_the_default_library_file_lib_d_ts_6158", "Do not include the default library file (lib.d.ts)."),
	Do_not_add_triple_slash_references_or_imported_modules_to_the_list_of_compiled_files: r(6159, 3, "Do_not_add_triple_slash_references_or_imported_modules_to_the_list_of_compiled_files_6159", "Do not add triple-slash references or imported modules to the list of compiled files."),
	Deprecated_Use_skipLibCheck_instead_Skip_type_checking_of_default_library_declaration_files: r(6160, 3, "Deprecated_Use_skipLibCheck_instead_Skip_type_checking_of_default_library_declaration_files_6160", "[Deprecated] Use '--skipLibCheck' instead. Skip type checking of default library declaration files."),
	List_of_folders_to_include_type_definitions_from: r(6161, 3, "List_of_folders_to_include_type_definitions_from_6161", "List of folders to include type definitions from."),
	Disable_size_limitations_on_JavaScript_projects: r(6162, 3, "Disable_size_limitations_on_JavaScript_projects_6162", "Disable size limitations on JavaScript projects."),
	The_character_set_of_the_input_files: r(6163, 3, "The_character_set_of_the_input_files_6163", "The character set of the input files."),
	Skipping_module_0_that_looks_like_an_absolute_URI_target_file_types_Colon_1: r(6164, 3, "Skipping_module_0_that_looks_like_an_absolute_URI_target_file_types_Colon_1_6164", "Skipping module '{0}' that looks like an absolute URI, target file types: {1}."),
	Do_not_truncate_error_messages: r(6165, 3, "Do_not_truncate_error_messages_6165", "Do not truncate error messages."),
	Output_directory_for_generated_declaration_files: r(6166, 3, "Output_directory_for_generated_declaration_files_6166", "Output directory for generated declaration files."),
	A_series_of_entries_which_re_map_imports_to_lookup_locations_relative_to_the_baseUrl: r(6167, 3, "A_series_of_entries_which_re_map_imports_to_lookup_locations_relative_to_the_baseUrl_6167", "A series of entries which re-map imports to lookup locations relative to the 'baseUrl'."),
	List_of_root_folders_whose_combined_content_represents_the_structure_of_the_project_at_runtime: r(6168, 3, "List_of_root_folders_whose_combined_content_represents_the_structure_of_the_project_at_runtime_6168", "List of root folders whose combined content represents the structure of the project at runtime."),
	Show_all_compiler_options: r(6169, 3, "Show_all_compiler_options_6169", "Show all compiler options."),
	Deprecated_Use_outFile_instead_Concatenate_and_emit_output_to_single_file: r(6170, 3, "Deprecated_Use_outFile_instead_Concatenate_and_emit_output_to_single_file_6170", "[Deprecated] Use '--outFile' instead. Concatenate and emit output to single file"),
	Command_line_Options: r(6171, 3, "Command_line_Options_6171", "Command-line Options"),
	Provide_full_support_for_iterables_in_for_of_spread_and_destructuring_when_targeting_ES5: r(6179, 3, "Provide_full_support_for_iterables_in_for_of_spread_and_destructuring_when_targeting_ES5_6179", "Provide full support for iterables in 'for-of', spread, and destructuring when targeting 'ES5'."),
	Enable_all_strict_type_checking_options: r(6180, 3, "Enable_all_strict_type_checking_options_6180", "Enable all strict type-checking options."),
	Scoped_package_detected_looking_in_0: r(6182, 3, "Scoped_package_detected_looking_in_0_6182", "Scoped package detected, looking in '{0}'"),
	Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2: r(6183, 3, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_6183", "Reusing resolution of module '{0}' from '{1}' of old program, it was successfully resolved to '{2}'."),
	Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3: r(6184, 3, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package__6184", "Reusing resolution of module '{0}' from '{1}' of old program, it was successfully resolved to '{2}' with Package ID '{3}'."),
	Enable_strict_checking_of_function_types: r(6186, 3, "Enable_strict_checking_of_function_types_6186", "Enable strict checking of function types."),
	Enable_strict_checking_of_property_initialization_in_classes: r(6187, 3, "Enable_strict_checking_of_property_initialization_in_classes_6187", "Enable strict checking of property initialization in classes."),
	Numeric_separators_are_not_allowed_here: r(6188, 1, "Numeric_separators_are_not_allowed_here_6188", "Numeric separators are not allowed here."),
	Multiple_consecutive_numeric_separators_are_not_permitted: r(6189, 1, "Multiple_consecutive_numeric_separators_are_not_permitted_6189", "Multiple consecutive numeric separators are not permitted."),
	Whether_to_keep_outdated_console_output_in_watch_mode_instead_of_clearing_the_screen: r(6191, 3, "Whether_to_keep_outdated_console_output_in_watch_mode_instead_of_clearing_the_screen_6191", "Whether to keep outdated console output in watch mode instead of clearing the screen."),
	All_imports_in_import_declaration_are_unused: r(6192, 1, "All_imports_in_import_declaration_are_unused_6192", "All imports in import declaration are unused.", !0),
	Found_1_error_Watching_for_file_changes: r(6193, 3, "Found_1_error_Watching_for_file_changes_6193", "Found 1 error. Watching for file changes."),
	Found_0_errors_Watching_for_file_changes: r(6194, 3, "Found_0_errors_Watching_for_file_changes_6194", "Found {0} errors. Watching for file changes."),
	Resolve_keyof_to_string_valued_property_names_only_no_numbers_or_symbols: r(6195, 3, "Resolve_keyof_to_string_valued_property_names_only_no_numbers_or_symbols_6195", "Resolve 'keyof' to string valued property names only (no numbers or symbols)."),
	_0_is_declared_but_never_used: r(6196, 1, "_0_is_declared_but_never_used_6196", "'{0}' is declared but never used.", !0),
	Include_modules_imported_with_json_extension: r(6197, 3, "Include_modules_imported_with_json_extension_6197", "Include modules imported with '.json' extension"),
	All_destructured_elements_are_unused: r(6198, 1, "All_destructured_elements_are_unused_6198", "All destructured elements are unused.", !0),
	All_variables_are_unused: r(6199, 1, "All_variables_are_unused_6199", "All variables are unused.", !0),
	Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0: r(6200, 1, "Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0_6200", "Definitions of the following identifiers conflict with those in another file: {0}"),
	Conflicts_are_in_this_file: r(6201, 3, "Conflicts_are_in_this_file_6201", "Conflicts are in this file."),
	Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0: r(6202, 1, "Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0_6202", "Project references may not form a circular graph. Cycle detected: {0}"),
	_0_was_also_declared_here: r(6203, 3, "_0_was_also_declared_here_6203", "'{0}' was also declared here."),
	and_here: r(6204, 3, "and_here_6204", "and here."),
	All_type_parameters_are_unused: r(6205, 1, "All_type_parameters_are_unused_6205", "All type parameters are unused."),
	package_json_has_a_typesVersions_field_with_version_specific_path_mappings: r(6206, 3, "package_json_has_a_typesVersions_field_with_version_specific_path_mappings_6206", "'package.json' has a 'typesVersions' field with version-specific path mappings."),
	package_json_does_not_have_a_typesVersions_entry_that_matches_version_0: r(6207, 3, "package_json_does_not_have_a_typesVersions_entry_that_matches_version_0_6207", "'package.json' does not have a 'typesVersions' entry that matches version '{0}'."),
	package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_match_module_name_2: r(6208, 3, "package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_ma_6208", "'package.json' has a 'typesVersions' entry '{0}' that matches compiler version '{1}', looking for a pattern to match module name '{2}'."),
	package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range: r(6209, 3, "package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range_6209", "'package.json' has a 'typesVersions' entry '{0}' that is not a valid semver range."),
	An_argument_for_0_was_not_provided: r(6210, 3, "An_argument_for_0_was_not_provided_6210", "An argument for '{0}' was not provided."),
	An_argument_matching_this_binding_pattern_was_not_provided: r(6211, 3, "An_argument_matching_this_binding_pattern_was_not_provided_6211", "An argument matching this binding pattern was not provided."),
	Did_you_mean_to_call_this_expression: r(6212, 3, "Did_you_mean_to_call_this_expression_6212", "Did you mean to call this expression?"),
	Did_you_mean_to_use_new_with_this_expression: r(6213, 3, "Did_you_mean_to_use_new_with_this_expression_6213", "Did you mean to use 'new' with this expression?"),
	Enable_strict_bind_call_and_apply_methods_on_functions: r(6214, 3, "Enable_strict_bind_call_and_apply_methods_on_functions_6214", "Enable strict 'bind', 'call', and 'apply' methods on functions."),
	Using_compiler_options_of_project_reference_redirect_0: r(6215, 3, "Using_compiler_options_of_project_reference_redirect_0_6215", "Using compiler options of project reference redirect '{0}'."),
	Found_1_error: r(6216, 3, "Found_1_error_6216", "Found 1 error."),
	Found_0_errors: r(6217, 3, "Found_0_errors_6217", "Found {0} errors."),
	Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2: r(6218, 3, "Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2_6218", "======== Module name '{0}' was successfully resolved to '{1}' with Package ID '{2}'. ========"),
	Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3: r(6219, 3, "Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3_6219", "======== Type reference directive '{0}' was successfully resolved to '{1}' with Package ID '{2}', primary: {3}. ========"),
	package_json_had_a_falsy_0_field: r(6220, 3, "package_json_had_a_falsy_0_field_6220", "'package.json' had a falsy '{0}' field."),
	Disable_use_of_source_files_instead_of_declaration_files_from_referenced_projects: r(6221, 3, "Disable_use_of_source_files_instead_of_declaration_files_from_referenced_projects_6221", "Disable use of source files instead of declaration files from referenced projects."),
	Emit_class_fields_with_Define_instead_of_Set: r(6222, 3, "Emit_class_fields_with_Define_instead_of_Set_6222", "Emit class fields with Define instead of Set."),
	Generates_a_CPU_profile: r(6223, 3, "Generates_a_CPU_profile_6223", "Generates a CPU profile."),
	Disable_solution_searching_for_this_project: r(6224, 3, "Disable_solution_searching_for_this_project_6224", "Disable solution searching for this project."),
	Specify_strategy_for_watching_file_Colon_FixedPollingInterval_default_PriorityPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling_UseFsEvents_UseFsEventsOnParentDirectory: r(6225, 3, "Specify_strategy_for_watching_file_Colon_FixedPollingInterval_default_PriorityPollingInterval_Dynami_6225", "Specify strategy for watching file: 'FixedPollingInterval' (default), 'PriorityPollingInterval', 'DynamicPriorityPolling', 'FixedChunkSizePolling', 'UseFsEvents', 'UseFsEventsOnParentDirectory'."),
	Specify_strategy_for_watching_directory_on_platforms_that_don_t_support_recursive_watching_natively_Colon_UseFsEvents_default_FixedPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling: r(6226, 3, "Specify_strategy_for_watching_directory_on_platforms_that_don_t_support_recursive_watching_natively__6226", "Specify strategy for watching directory on platforms that don't support recursive watching natively: 'UseFsEvents' (default), 'FixedPollingInterval', 'DynamicPriorityPolling', 'FixedChunkSizePolling'."),
	Specify_strategy_for_creating_a_polling_watch_when_it_fails_to_create_using_file_system_events_Colon_FixedInterval_default_PriorityInterval_DynamicPriority_FixedChunkSize: r(6227, 3, "Specify_strategy_for_creating_a_polling_watch_when_it_fails_to_create_using_file_system_events_Colon_6227", "Specify strategy for creating a polling watch when it fails to create using file system events: 'FixedInterval' (default), 'PriorityInterval', 'DynamicPriority', 'FixedChunkSize'."),
	Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3: r(6229, 1, "Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3_6229", "Tag '{0}' expects at least '{1}' arguments, but the JSX factory '{2}' provides at most '{3}'."),
	Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line: r(6230, 1, "Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line_6230", "Option '{0}' can only be specified in 'tsconfig.json' file or set to 'false' or 'null' on command line."),
	Could_not_resolve_the_path_0_with_the_extensions_Colon_1: r(6231, 1, "Could_not_resolve_the_path_0_with_the_extensions_Colon_1_6231", "Could not resolve the path '{0}' with the extensions: {1}."),
	Declaration_augments_declaration_in_another_file_This_cannot_be_serialized: r(6232, 1, "Declaration_augments_declaration_in_another_file_This_cannot_be_serialized_6232", "Declaration augments declaration in another file. This cannot be serialized."),
	This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_file: r(6233, 1, "This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_fil_6233", "This is the declaration being augmented. Consider moving the augmenting declaration into the same file."),
	This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without: r(6234, 1, "This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without_6234", "This expression is not callable because it is a 'get' accessor. Did you mean to use it without '()'?"),
	Disable_loading_referenced_projects: r(6235, 3, "Disable_loading_referenced_projects_6235", "Disable loading referenced projects."),
	Arguments_for_the_rest_parameter_0_were_not_provided: r(6236, 1, "Arguments_for_the_rest_parameter_0_were_not_provided_6236", "Arguments for the rest parameter '{0}' were not provided."),
	Generates_an_event_trace_and_a_list_of_types: r(6237, 3, "Generates_an_event_trace_and_a_list_of_types_6237", "Generates an event trace and a list of types."),
	Specify_the_module_specifier_to_be_used_to_import_the_jsx_and_jsxs_factory_functions_from_eg_react: r(6238, 1, "Specify_the_module_specifier_to_be_used_to_import_the_jsx_and_jsxs_factory_functions_from_eg_react_6238", "Specify the module specifier to be used to import the 'jsx' and 'jsxs' factory functions from. eg, react"),
	File_0_exists_according_to_earlier_cached_lookups: r(6239, 3, "File_0_exists_according_to_earlier_cached_lookups_6239", "File '{0}' exists according to earlier cached lookups."),
	File_0_does_not_exist_according_to_earlier_cached_lookups: r(6240, 3, "File_0_does_not_exist_according_to_earlier_cached_lookups_6240", "File '{0}' does not exist according to earlier cached lookups."),
	Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1: r(6241, 3, "Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1_6241", "Resolution for type reference directive '{0}' was found in cache from location '{1}'."),
	Resolving_type_reference_directive_0_containing_file_1: r(6242, 3, "Resolving_type_reference_directive_0_containing_file_1_6242", "======== Resolving type reference directive '{0}', containing file '{1}'. ========"),
	Interpret_optional_property_types_as_written_rather_than_adding_undefined: r(6243, 3, "Interpret_optional_property_types_as_written_rather_than_adding_undefined_6243", "Interpret optional property types as written, rather than adding 'undefined'."),
	Modules: r(6244, 3, "Modules_6244", "Modules"),
	File_Management: r(6245, 3, "File_Management_6245", "File Management"),
	Emit: r(6246, 3, "Emit_6246", "Emit"),
	JavaScript_Support: r(6247, 3, "JavaScript_Support_6247", "JavaScript Support"),
	Type_Checking: r(6248, 3, "Type_Checking_6248", "Type Checking"),
	Editor_Support: r(6249, 3, "Editor_Support_6249", "Editor Support"),
	Watch_and_Build_Modes: r(6250, 3, "Watch_and_Build_Modes_6250", "Watch and Build Modes"),
	Compiler_Diagnostics: r(6251, 3, "Compiler_Diagnostics_6251", "Compiler Diagnostics"),
	Interop_Constraints: r(6252, 3, "Interop_Constraints_6252", "Interop Constraints"),
	Backwards_Compatibility: r(6253, 3, "Backwards_Compatibility_6253", "Backwards Compatibility"),
	Language_and_Environment: r(6254, 3, "Language_and_Environment_6254", "Language and Environment"),
	Projects: r(6255, 3, "Projects_6255", "Projects"),
	Output_Formatting: r(6256, 3, "Output_Formatting_6256", "Output Formatting"),
	Completeness: r(6257, 3, "Completeness_6257", "Completeness"),
	_0_should_be_set_inside_the_compilerOptions_object_of_the_config_json_file: r(6258, 1, "_0_should_be_set_inside_the_compilerOptions_object_of_the_config_json_file_6258", "'{0}' should be set inside the 'compilerOptions' object of the config json file"),
	Found_1_error_in_0: r(6259, 3, "Found_1_error_in_0_6259", "Found 1 error in {0}"),
	Found_0_errors_in_the_same_file_starting_at_Colon_1: r(6260, 3, "Found_0_errors_in_the_same_file_starting_at_Colon_1_6260", "Found {0} errors in the same file, starting at: {1}"),
	Found_0_errors_in_1_files: r(6261, 3, "Found_0_errors_in_1_files_6261", "Found {0} errors in {1} files."),
	File_name_0_has_a_1_extension_looking_up_2_instead: r(6262, 3, "File_name_0_has_a_1_extension_looking_up_2_instead_6262", "File name '{0}' has a '{1}' extension - looking up '{2}' instead."),
	Module_0_was_resolved_to_1_but_allowArbitraryExtensions_is_not_set: r(6263, 1, "Module_0_was_resolved_to_1_but_allowArbitraryExtensions_is_not_set_6263", "Module '{0}' was resolved to '{1}', but '--allowArbitraryExtensions' is not set."),
	Enable_importing_files_with_any_extension_provided_a_declaration_file_is_present: r(6264, 3, "Enable_importing_files_with_any_extension_provided_a_declaration_file_is_present_6264", "Enable importing files with any extension, provided a declaration file is present."),
	Resolving_type_reference_directive_for_program_that_specifies_custom_typeRoots_skipping_lookup_in_node_modules_folder: r(6265, 3, "Resolving_type_reference_directive_for_program_that_specifies_custom_typeRoots_skipping_lookup_in_no_6265", "Resolving type reference directive for program that specifies custom typeRoots, skipping lookup in 'node_modules' folder."),
	Option_0_can_only_be_specified_on_command_line: r(6266, 1, "Option_0_can_only_be_specified_on_command_line_6266", "Option '{0}' can only be specified on command line."),
	Directory_0_has_no_containing_package_json_scope_Imports_will_not_resolve: r(6270, 3, "Directory_0_has_no_containing_package_json_scope_Imports_will_not_resolve_6270", "Directory '{0}' has no containing package.json scope. Imports will not resolve."),
	Import_specifier_0_does_not_exist_in_package_json_scope_at_path_1: r(6271, 3, "Import_specifier_0_does_not_exist_in_package_json_scope_at_path_1_6271", "Import specifier '{0}' does not exist in package.json scope at path '{1}'."),
	Invalid_import_specifier_0_has_no_possible_resolutions: r(6272, 3, "Invalid_import_specifier_0_has_no_possible_resolutions_6272", "Invalid import specifier '{0}' has no possible resolutions."),
	package_json_scope_0_has_no_imports_defined: r(6273, 3, "package_json_scope_0_has_no_imports_defined_6273", "package.json scope '{0}' has no imports defined."),
	package_json_scope_0_explicitly_maps_specifier_1_to_null: r(6274, 3, "package_json_scope_0_explicitly_maps_specifier_1_to_null_6274", "package.json scope '{0}' explicitly maps specifier '{1}' to null."),
	package_json_scope_0_has_invalid_type_for_target_of_specifier_1: r(6275, 3, "package_json_scope_0_has_invalid_type_for_target_of_specifier_1_6275", "package.json scope '{0}' has invalid type for target of specifier '{1}'"),
	Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1: r(6276, 3, "Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1_6276", "Export specifier '{0}' does not exist in package.json scope at path '{1}'."),
	Resolution_of_non_relative_name_failed_trying_with_modern_Node_resolution_features_disabled_to_see_if_npm_library_needs_configuration_update: r(6277, 3, "Resolution_of_non_relative_name_failed_trying_with_modern_Node_resolution_features_disabled_to_see_i_6277", "Resolution of non-relative name failed; trying with modern Node resolution features disabled to see if npm library needs configuration update."),
	There_are_types_at_0_but_this_result_could_not_be_resolved_when_respecting_package_json_exports_The_1_library_may_need_to_update_its_package_json_or_typings: r(6278, 3, "There_are_types_at_0_but_this_result_could_not_be_resolved_when_respecting_package_json_exports_The__6278", `There are types at '{0}', but this result could not be resolved when respecting package.json "exports". The '{1}' library may need to update its package.json or typings.`),
	Resolution_of_non_relative_name_failed_trying_with_moduleResolution_bundler_to_see_if_project_may_need_configuration_update: r(6279, 3, "Resolution_of_non_relative_name_failed_trying_with_moduleResolution_bundler_to_see_if_project_may_ne_6279", "Resolution of non-relative name failed; trying with '--moduleResolution bundler' to see if project may need configuration update."),
	There_are_types_at_0_but_this_result_could_not_be_resolved_under_your_current_moduleResolution_setting_Consider_updating_to_node16_nodenext_or_bundler: r(6280, 3, "There_are_types_at_0_but_this_result_could_not_be_resolved_under_your_current_moduleResolution_setti_6280", "There are types at '{0}', but this result could not be resolved under your current 'moduleResolution' setting. Consider updating to 'node16', 'nodenext', or 'bundler'."),
	package_json_has_a_peerDependencies_field: r(6281, 3, "package_json_has_a_peerDependencies_field_6281", "'package.json' has a 'peerDependencies' field."),
	Found_peerDependency_0_with_1_version: r(6282, 3, "Found_peerDependency_0_with_1_version_6282", "Found peerDependency '{0}' with '{1}' version."),
	Failed_to_find_peerDependency_0: r(6283, 3, "Failed_to_find_peerDependency_0_6283", "Failed to find peerDependency '{0}'."),
	File_Layout: r(6284, 3, "File_Layout_6284", "File Layout"),
	Environment_Settings: r(6285, 3, "Environment_Settings_6285", "Environment Settings"),
	See_also_https_Colon_Slash_Slashaka_ms_Slashtsconfig_Slashmodule: r(6286, 3, "See_also_https_Colon_Slash_Slashaka_ms_Slashtsconfig_Slashmodule_6286", "See also https://aka.ms/tsconfig/module"),
	For_nodejs_Colon: r(6287, 3, "For_nodejs_Colon_6287", "For nodejs:"),
	and_npm_install_D_types_Slashnode: r(6290, 3, "and_npm_install_D_types_Slashnode_6290", "and npm install -D @types/node"),
	Other_Outputs: r(6291, 3, "Other_Outputs_6291", "Other Outputs"),
	Stricter_Typechecking_Options: r(6292, 3, "Stricter_Typechecking_Options_6292", "Stricter Typechecking Options"),
	Style_Options: r(6293, 3, "Style_Options_6293", "Style Options"),
	Recommended_Options: r(6294, 3, "Recommended_Options_6294", "Recommended Options"),
	Enable_project_compilation: r(6302, 3, "Enable_project_compilation_6302", "Enable project compilation"),
	Composite_projects_may_not_disable_declaration_emit: r(6304, 1, "Composite_projects_may_not_disable_declaration_emit_6304", "Composite projects may not disable declaration emit."),
	Output_file_0_has_not_been_built_from_source_file_1: r(6305, 1, "Output_file_0_has_not_been_built_from_source_file_1_6305", "Output file '{0}' has not been built from source file '{1}'."),
	Referenced_project_0_must_have_setting_composite_Colon_true: r(6306, 1, "Referenced_project_0_must_have_setting_composite_Colon_true_6306", `Referenced project '{0}' must have setting "composite": true.`),
	File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_include_pattern: r(6307, 1, "File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_includ_6307", "File '{0}' is not listed within the file list of project '{1}'. Projects must list all files or use an 'include' pattern."),
	Referenced_project_0_may_not_disable_emit: r(6310, 1, "Referenced_project_0_may_not_disable_emit_6310", "Referenced project '{0}' may not disable emit."),
	Project_0_is_out_of_date_because_output_1_is_older_than_input_2: r(6350, 3, "Project_0_is_out_of_date_because_output_1_is_older_than_input_2_6350", "Project '{0}' is out of date because output '{1}' is older than input '{2}'"),
	Project_0_is_up_to_date_because_newest_input_1_is_older_than_output_2: r(6351, 3, "Project_0_is_up_to_date_because_newest_input_1_is_older_than_output_2_6351", "Project '{0}' is up to date because newest input '{1}' is older than output '{2}'"),
	Project_0_is_out_of_date_because_output_file_1_does_not_exist: r(6352, 3, "Project_0_is_out_of_date_because_output_file_1_does_not_exist_6352", "Project '{0}' is out of date because output file '{1}' does not exist"),
	Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date: r(6353, 3, "Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date_6353", "Project '{0}' is out of date because its dependency '{1}' is out of date"),
	Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies: r(6354, 3, "Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies_6354", "Project '{0}' is up to date with .d.ts files from its dependencies"),
	Projects_in_this_build_Colon_0: r(6355, 3, "Projects_in_this_build_Colon_0_6355", "Projects in this build: {0}"),
	A_non_dry_build_would_delete_the_following_files_Colon_0: r(6356, 3, "A_non_dry_build_would_delete_the_following_files_Colon_0_6356", "A non-dry build would delete the following files: {0}"),
	A_non_dry_build_would_build_project_0: r(6357, 3, "A_non_dry_build_would_build_project_0_6357", "A non-dry build would build project '{0}'"),
	Building_project_0: r(6358, 3, "Building_project_0_6358", "Building project '{0}'..."),
	Updating_output_timestamps_of_project_0: r(6359, 3, "Updating_output_timestamps_of_project_0_6359", "Updating output timestamps of project '{0}'..."),
	Project_0_is_up_to_date: r(6361, 3, "Project_0_is_up_to_date_6361", "Project '{0}' is up to date"),
	Skipping_build_of_project_0_because_its_dependency_1_has_errors: r(6362, 3, "Skipping_build_of_project_0_because_its_dependency_1_has_errors_6362", "Skipping build of project '{0}' because its dependency '{1}' has errors"),
	Project_0_can_t_be_built_because_its_dependency_1_has_errors: r(6363, 3, "Project_0_can_t_be_built_because_its_dependency_1_has_errors_6363", "Project '{0}' can't be built because its dependency '{1}' has errors"),
	Build_one_or_more_projects_and_their_dependencies_if_out_of_date: r(6364, 3, "Build_one_or_more_projects_and_their_dependencies_if_out_of_date_6364", "Build one or more projects and their dependencies, if out of date"),
	Delete_the_outputs_of_all_projects: r(6365, 3, "Delete_the_outputs_of_all_projects_6365", "Delete the outputs of all projects."),
	Show_what_would_be_built_or_deleted_if_specified_with_clean: r(6367, 3, "Show_what_would_be_built_or_deleted_if_specified_with_clean_6367", "Show what would be built (or deleted, if specified with '--clean')"),
	Option_build_must_be_the_first_command_line_argument: r(6369, 1, "Option_build_must_be_the_first_command_line_argument_6369", "Option '--build' must be the first command line argument."),
	Options_0_and_1_cannot_be_combined: r(6370, 1, "Options_0_and_1_cannot_be_combined_6370", "Options '{0}' and '{1}' cannot be combined."),
	Updating_unchanged_output_timestamps_of_project_0: r(6371, 3, "Updating_unchanged_output_timestamps_of_project_0_6371", "Updating unchanged output timestamps of project '{0}'..."),
	A_non_dry_build_would_update_timestamps_for_output_of_project_0: r(6374, 3, "A_non_dry_build_would_update_timestamps_for_output_of_project_0_6374", "A non-dry build would update timestamps for output of project '{0}'"),
	Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1: r(6377, 1, "Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1_6377", "Cannot write file '{0}' because it will overwrite '.tsbuildinfo' file generated by referenced project '{1}'"),
	Composite_projects_may_not_disable_incremental_compilation: r(6379, 1, "Composite_projects_may_not_disable_incremental_compilation_6379", "Composite projects may not disable incremental compilation."),
	Specify_file_to_store_incremental_compilation_information: r(6380, 3, "Specify_file_to_store_incremental_compilation_information_6380", "Specify file to store incremental compilation information"),
	Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_current_version_2: r(6381, 3, "Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_curren_6381", "Project '{0}' is out of date because output for it was generated with version '{1}' that differs with current version '{2}'"),
	Skipping_build_of_project_0_because_its_dependency_1_was_not_built: r(6382, 3, "Skipping_build_of_project_0_because_its_dependency_1_was_not_built_6382", "Skipping build of project '{0}' because its dependency '{1}' was not built"),
	Project_0_can_t_be_built_because_its_dependency_1_was_not_built: r(6383, 3, "Project_0_can_t_be_built_because_its_dependency_1_was_not_built_6383", "Project '{0}' can't be built because its dependency '{1}' was not built"),
	Have_recompiles_in_incremental_and_watch_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it: r(6384, 3, "Have_recompiles_in_incremental_and_watch_assume_that_changes_within_a_file_will_only_affect_files_di_6384", "Have recompiles in '--incremental' and '--watch' assume that changes within a file will only affect files directly depending on it."),
	_0_is_deprecated: r(6385, 2, "_0_is_deprecated_6385", "'{0}' is deprecated.", void 0, void 0, !0),
	Performance_timings_for_diagnostics_or_extendedDiagnostics_are_not_available_in_this_session_A_native_implementation_of_the_Web_Performance_API_could_not_be_found: r(6386, 3, "Performance_timings_for_diagnostics_or_extendedDiagnostics_are_not_available_in_this_session_A_nativ_6386", "Performance timings for '--diagnostics' or '--extendedDiagnostics' are not available in this session. A native implementation of the Web Performance API could not be found."),
	The_signature_0_of_1_is_deprecated: r(6387, 2, "The_signature_0_of_1_is_deprecated_6387", "The signature '{0}' of '{1}' is deprecated.", void 0, void 0, !0),
	Project_0_is_being_forcibly_rebuilt: r(6388, 3, "Project_0_is_being_forcibly_rebuilt_6388", "Project '{0}' is being forcibly rebuilt"),
	Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved: r(6389, 3, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved_6389", "Reusing resolution of module '{0}' from '{1}' of old program, it was not resolved."),
	Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2: r(6390, 3, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved__6390", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was successfully resolved to '{2}'."),
	Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3: r(6391, 3, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved__6391", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was successfully resolved to '{2}' with Package ID '{3}'."),
	Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_not_resolved: r(6392, 3, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_not_resolved_6392", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was not resolved."),
	Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3: r(6393, 3, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_6393", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}'."),
	Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3_with_Package_ID_4: r(6394, 3, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_6394", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}' with Package ID '{4}'."),
	Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_not_resolved: r(6395, 3, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_not_resolved_6395", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was not resolved."),
	Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3: r(6396, 3, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_succes_6396", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}'."),
	Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3_with_Package_ID_4: r(6397, 3, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_succes_6397", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}' with Package ID '{4}'."),
	Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_not_resolved: r(6398, 3, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_not_re_6398", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was not resolved."),
	Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_some_of_the_changes_were_not_emitted: r(6399, 3, "Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_some_of_the_changes_were_not_emitte_6399", "Project '{0}' is out of date because buildinfo file '{1}' indicates that some of the changes were not emitted"),
	Project_0_is_up_to_date_but_needs_to_update_timestamps_of_output_files_that_are_older_than_input_files: r(6400, 3, "Project_0_is_up_to_date_but_needs_to_update_timestamps_of_output_files_that_are_older_than_input_fil_6400", "Project '{0}' is up to date but needs to update timestamps of output files that are older than input files"),
	Project_0_is_out_of_date_because_there_was_error_reading_file_1: r(6401, 3, "Project_0_is_out_of_date_because_there_was_error_reading_file_1_6401", "Project '{0}' is out of date because there was error reading file '{1}'"),
	Resolving_in_0_mode_with_conditions_1: r(6402, 3, "Resolving_in_0_mode_with_conditions_1_6402", "Resolving in {0} mode with conditions {1}."),
	Matched_0_condition_1: r(6403, 3, "Matched_0_condition_1_6403", "Matched '{0}' condition '{1}'."),
	Using_0_subpath_1_with_target_2: r(6404, 3, "Using_0_subpath_1_with_target_2_6404", "Using '{0}' subpath '{1}' with target '{2}'."),
	Saw_non_matching_condition_0: r(6405, 3, "Saw_non_matching_condition_0_6405", "Saw non-matching condition '{0}'."),
	Project_0_is_out_of_date_because_buildinfo_file_1_indicates_there_is_change_in_compilerOptions: r(6406, 3, "Project_0_is_out_of_date_because_buildinfo_file_1_indicates_there_is_change_in_compilerOptions_6406", "Project '{0}' is out of date because buildinfo file '{1}' indicates there is change in compilerOptions"),
	Allow_imports_to_include_TypeScript_file_extensions_Requires_moduleResolution_bundler_and_either_noEmit_or_emitDeclarationOnly_to_be_set: r(6407, 3, "Allow_imports_to_include_TypeScript_file_extensions_Requires_moduleResolution_bundler_and_either_noE_6407", "Allow imports to include TypeScript file extensions. Requires '--moduleResolution bundler' and either '--noEmit' or '--emitDeclarationOnly' to be set."),
	Use_the_package_json_exports_field_when_resolving_package_imports: r(6408, 3, "Use_the_package_json_exports_field_when_resolving_package_imports_6408", "Use the package.json 'exports' field when resolving package imports."),
	Use_the_package_json_imports_field_when_resolving_imports: r(6409, 3, "Use_the_package_json_imports_field_when_resolving_imports_6409", "Use the package.json 'imports' field when resolving imports."),
	Conditions_to_set_in_addition_to_the_resolver_specific_defaults_when_resolving_imports: r(6410, 3, "Conditions_to_set_in_addition_to_the_resolver_specific_defaults_when_resolving_imports_6410", "Conditions to set in addition to the resolver-specific defaults when resolving imports."),
	true_when_moduleResolution_is_node16_nodenext_or_bundler_otherwise_false: r(6411, 3, "true_when_moduleResolution_is_node16_nodenext_or_bundler_otherwise_false_6411", "`true` when 'moduleResolution' is 'node16', 'nodenext', or 'bundler'; otherwise `false`."),
	Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_file_2_was_root_file_of_compilation_but_not_any_more: r(6412, 3, "Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_file_2_was_root_file_of_compilation_6412", "Project '{0}' is out of date because buildinfo file '{1}' indicates that file '{2}' was root file of compilation but not any more."),
	Entering_conditional_exports: r(6413, 3, "Entering_conditional_exports_6413", "Entering conditional exports."),
	Resolved_under_condition_0: r(6414, 3, "Resolved_under_condition_0_6414", "Resolved under condition '{0}'."),
	Failed_to_resolve_under_condition_0: r(6415, 3, "Failed_to_resolve_under_condition_0_6415", "Failed to resolve under condition '{0}'."),
	Exiting_conditional_exports: r(6416, 3, "Exiting_conditional_exports_6416", "Exiting conditional exports."),
	Searching_all_ancestor_node_modules_directories_for_preferred_extensions_Colon_0: r(6417, 3, "Searching_all_ancestor_node_modules_directories_for_preferred_extensions_Colon_0_6417", "Searching all ancestor node_modules directories for preferred extensions: {0}."),
	Searching_all_ancestor_node_modules_directories_for_fallback_extensions_Colon_0: r(6418, 3, "Searching_all_ancestor_node_modules_directories_for_fallback_extensions_Colon_0_6418", "Searching all ancestor node_modules directories for fallback extensions: {0}."),
	Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_program_needs_to_report_errors: r(6419, 3, "Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_program_needs_to_report_errors_6419", "Project '{0}' is out of date because buildinfo file '{1}' indicates that program needs to report errors."),
	Project_0_is_out_of_date_because_1: r(6420, 3, "Project_0_is_out_of_date_because_1_6420", "Project '{0}' is out of date because {1}."),
	Rewrite_ts_tsx_mts_and_cts_file_extensions_in_relative_import_paths_to_their_JavaScript_equivalent_in_output_files: r(6421, 3, "Rewrite_ts_tsx_mts_and_cts_file_extensions_in_relative_import_paths_to_their_JavaScript_equivalent_i_6421", "Rewrite '.ts', '.tsx', '.mts', and '.cts' file extensions in relative import paths to their JavaScript equivalent in output files."),
	The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1: r(6500, 3, "The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1_6500", "The expected type comes from property '{0}' which is declared here on type '{1}'"),
	The_expected_type_comes_from_this_index_signature: r(6501, 3, "The_expected_type_comes_from_this_index_signature_6501", "The expected type comes from this index signature."),
	The_expected_type_comes_from_the_return_type_of_this_signature: r(6502, 3, "The_expected_type_comes_from_the_return_type_of_this_signature_6502", "The expected type comes from the return type of this signature."),
	Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing: r(6503, 3, "Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing_6503", "Print names of files that are part of the compilation and then stop processing."),
	File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option: r(6504, 1, "File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option_6504", "File '{0}' is a JavaScript file. Did you mean to enable the 'allowJs' option?"),
	Print_names_of_files_and_the_reason_they_are_part_of_the_compilation: r(6505, 3, "Print_names_of_files_and_the_reason_they_are_part_of_the_compilation_6505", "Print names of files and the reason they are part of the compilation."),
	Consider_adding_a_declare_modifier_to_this_class: r(6506, 3, "Consider_adding_a_declare_modifier_to_this_class_6506", "Consider adding a 'declare' modifier to this class."),
	Allow_JavaScript_files_to_be_a_part_of_your_program_Use_the_checkJs_option_to_get_errors_from_these_files: r(6600, 3, "Allow_JavaScript_files_to_be_a_part_of_your_program_Use_the_checkJs_option_to_get_errors_from_these__6600", "Allow JavaScript files to be a part of your program. Use the 'checkJs' option to get errors from these files."),
	Allow_import_x_from_y_when_a_module_doesn_t_have_a_default_export: r(6601, 3, "Allow_import_x_from_y_when_a_module_doesn_t_have_a_default_export_6601", "Allow 'import x from y' when a module doesn't have a default export."),
	Allow_accessing_UMD_globals_from_modules: r(6602, 3, "Allow_accessing_UMD_globals_from_modules_6602", "Allow accessing UMD globals from modules."),
	Disable_error_reporting_for_unreachable_code: r(6603, 3, "Disable_error_reporting_for_unreachable_code_6603", "Disable error reporting for unreachable code."),
	Disable_error_reporting_for_unused_labels: r(6604, 3, "Disable_error_reporting_for_unused_labels_6604", "Disable error reporting for unused labels."),
	Ensure_use_strict_is_always_emitted: r(6605, 3, "Ensure_use_strict_is_always_emitted_6605", "Ensure 'use strict' is always emitted."),
	Have_recompiles_in_projects_that_use_incremental_and_watch_mode_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it: r(6606, 3, "Have_recompiles_in_projects_that_use_incremental_and_watch_mode_assume_that_changes_within_a_file_wi_6606", "Have recompiles in projects that use 'incremental' and 'watch' mode assume that changes within a file will only affect files directly depending on it."),
	Specify_the_base_directory_to_resolve_non_relative_module_names: r(6607, 3, "Specify_the_base_directory_to_resolve_non_relative_module_names_6607", "Specify the base directory to resolve non-relative module names."),
	No_longer_supported_In_early_versions_manually_set_the_text_encoding_for_reading_files: r(6608, 3, "No_longer_supported_In_early_versions_manually_set_the_text_encoding_for_reading_files_6608", "No longer supported. In early versions, manually set the text encoding for reading files."),
	Enable_error_reporting_in_type_checked_JavaScript_files: r(6609, 3, "Enable_error_reporting_in_type_checked_JavaScript_files_6609", "Enable error reporting in type-checked JavaScript files."),
	Enable_constraints_that_allow_a_TypeScript_project_to_be_used_with_project_references: r(6611, 3, "Enable_constraints_that_allow_a_TypeScript_project_to_be_used_with_project_references_6611", "Enable constraints that allow a TypeScript project to be used with project references."),
	Generate_d_ts_files_from_TypeScript_and_JavaScript_files_in_your_project: r(6612, 3, "Generate_d_ts_files_from_TypeScript_and_JavaScript_files_in_your_project_6612", "Generate .d.ts files from TypeScript and JavaScript files in your project."),
	Specify_the_output_directory_for_generated_declaration_files: r(6613, 3, "Specify_the_output_directory_for_generated_declaration_files_6613", "Specify the output directory for generated declaration files."),
	Create_sourcemaps_for_d_ts_files: r(6614, 3, "Create_sourcemaps_for_d_ts_files_6614", "Create sourcemaps for d.ts files."),
	Output_compiler_performance_information_after_building: r(6615, 3, "Output_compiler_performance_information_after_building_6615", "Output compiler performance information after building."),
	Disables_inference_for_type_acquisition_by_looking_at_filenames_in_a_project: r(6616, 3, "Disables_inference_for_type_acquisition_by_looking_at_filenames_in_a_project_6616", "Disables inference for type acquisition by looking at filenames in a project."),
	Reduce_the_number_of_projects_loaded_automatically_by_TypeScript: r(6617, 3, "Reduce_the_number_of_projects_loaded_automatically_by_TypeScript_6617", "Reduce the number of projects loaded automatically by TypeScript."),
	Remove_the_20mb_cap_on_total_source_code_size_for_JavaScript_files_in_the_TypeScript_language_server: r(6618, 3, "Remove_the_20mb_cap_on_total_source_code_size_for_JavaScript_files_in_the_TypeScript_language_server_6618", "Remove the 20mb cap on total source code size for JavaScript files in the TypeScript language server."),
	Opt_a_project_out_of_multi_project_reference_checking_when_editing: r(6619, 3, "Opt_a_project_out_of_multi_project_reference_checking_when_editing_6619", "Opt a project out of multi-project reference checking when editing."),
	Disable_preferring_source_files_instead_of_declaration_files_when_referencing_composite_projects: r(6620, 3, "Disable_preferring_source_files_instead_of_declaration_files_when_referencing_composite_projects_6620", "Disable preferring source files instead of declaration files when referencing composite projects."),
	Emit_more_compliant_but_verbose_and_less_performant_JavaScript_for_iteration: r(6621, 3, "Emit_more_compliant_but_verbose_and_less_performant_JavaScript_for_iteration_6621", "Emit more compliant, but verbose and less performant JavaScript for iteration."),
	Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files: r(6622, 3, "Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files_6622", "Emit a UTF-8 Byte Order Mark (BOM) in the beginning of output files."),
	Only_output_d_ts_files_and_not_JavaScript_files: r(6623, 3, "Only_output_d_ts_files_and_not_JavaScript_files_6623", "Only output d.ts files and not JavaScript files."),
	Emit_design_type_metadata_for_decorated_declarations_in_source_files: r(6624, 3, "Emit_design_type_metadata_for_decorated_declarations_in_source_files_6624", "Emit design-type metadata for decorated declarations in source files."),
	Disable_the_type_acquisition_for_JavaScript_projects: r(6625, 3, "Disable_the_type_acquisition_for_JavaScript_projects_6625", "Disable the type acquisition for JavaScript projects"),
	Emit_additional_JavaScript_to_ease_support_for_importing_CommonJS_modules_This_enables_allowSyntheticDefaultImports_for_type_compatibility: r(6626, 3, "Emit_additional_JavaScript_to_ease_support_for_importing_CommonJS_modules_This_enables_allowSyntheti_6626", "Emit additional JavaScript to ease support for importing CommonJS modules. This enables 'allowSyntheticDefaultImports' for type compatibility."),
	Filters_results_from_the_include_option: r(6627, 3, "Filters_results_from_the_include_option_6627", "Filters results from the `include` option."),
	Remove_a_list_of_directories_from_the_watch_process: r(6628, 3, "Remove_a_list_of_directories_from_the_watch_process_6628", "Remove a list of directories from the watch process."),
	Remove_a_list_of_files_from_the_watch_mode_s_processing: r(6629, 3, "Remove_a_list_of_files_from_the_watch_mode_s_processing_6629", "Remove a list of files from the watch mode's processing."),
	Enable_experimental_support_for_legacy_experimental_decorators: r(6630, 3, "Enable_experimental_support_for_legacy_experimental_decorators_6630", "Enable experimental support for legacy experimental decorators."),
	Print_files_read_during_the_compilation_including_why_it_was_included: r(6631, 3, "Print_files_read_during_the_compilation_including_why_it_was_included_6631", "Print files read during the compilation including why it was included."),
	Output_more_detailed_compiler_performance_information_after_building: r(6632, 3, "Output_more_detailed_compiler_performance_information_after_building_6632", "Output more detailed compiler performance information after building."),
	Specify_one_or_more_path_or_node_module_references_to_base_configuration_files_from_which_settings_are_inherited: r(6633, 3, "Specify_one_or_more_path_or_node_module_references_to_base_configuration_files_from_which_settings_a_6633", "Specify one or more path or node module references to base configuration files from which settings are inherited."),
	Specify_what_approach_the_watcher_should_use_if_the_system_runs_out_of_native_file_watchers: r(6634, 3, "Specify_what_approach_the_watcher_should_use_if_the_system_runs_out_of_native_file_watchers_6634", "Specify what approach the watcher should use if the system runs out of native file watchers."),
	Include_a_list_of_files_This_does_not_support_glob_patterns_as_opposed_to_include: r(6635, 3, "Include_a_list_of_files_This_does_not_support_glob_patterns_as_opposed_to_include_6635", "Include a list of files. This does not support glob patterns, as opposed to `include`."),
	Build_all_projects_including_those_that_appear_to_be_up_to_date: r(6636, 3, "Build_all_projects_including_those_that_appear_to_be_up_to_date_6636", "Build all projects, including those that appear to be up to date."),
	Ensure_that_casing_is_correct_in_imports: r(6637, 3, "Ensure_that_casing_is_correct_in_imports_6637", "Ensure that casing is correct in imports."),
	Emit_a_v8_CPU_profile_of_the_compiler_run_for_debugging: r(6638, 3, "Emit_a_v8_CPU_profile_of_the_compiler_run_for_debugging_6638", "Emit a v8 CPU profile of the compiler run for debugging."),
	Allow_importing_helper_functions_from_tslib_once_per_project_instead_of_including_them_per_file: r(6639, 3, "Allow_importing_helper_functions_from_tslib_once_per_project_instead_of_including_them_per_file_6639", "Allow importing helper functions from tslib once per project, instead of including them per-file."),
	Skip_building_downstream_projects_on_error_in_upstream_project: r(6640, 3, "Skip_building_downstream_projects_on_error_in_upstream_project_6640", "Skip building downstream projects on error in upstream project."),
	Specify_a_list_of_glob_patterns_that_match_files_to_be_included_in_compilation: r(6641, 3, "Specify_a_list_of_glob_patterns_that_match_files_to_be_included_in_compilation_6641", "Specify a list of glob patterns that match files to be included in compilation."),
	Save_tsbuildinfo_files_to_allow_for_incremental_compilation_of_projects: r(6642, 3, "Save_tsbuildinfo_files_to_allow_for_incremental_compilation_of_projects_6642", "Save .tsbuildinfo files to allow for incremental compilation of projects."),
	Include_sourcemap_files_inside_the_emitted_JavaScript: r(6643, 3, "Include_sourcemap_files_inside_the_emitted_JavaScript_6643", "Include sourcemap files inside the emitted JavaScript."),
	Include_source_code_in_the_sourcemaps_inside_the_emitted_JavaScript: r(6644, 3, "Include_source_code_in_the_sourcemaps_inside_the_emitted_JavaScript_6644", "Include source code in the sourcemaps inside the emitted JavaScript."),
	Ensure_that_each_file_can_be_safely_transpiled_without_relying_on_other_imports: r(6645, 3, "Ensure_that_each_file_can_be_safely_transpiled_without_relying_on_other_imports_6645", "Ensure that each file can be safely transpiled without relying on other imports."),
	Specify_what_JSX_code_is_generated: r(6646, 3, "Specify_what_JSX_code_is_generated_6646", "Specify what JSX code is generated."),
	Specify_the_JSX_factory_function_used_when_targeting_React_JSX_emit_e_g_React_createElement_or_h: r(6647, 3, "Specify_the_JSX_factory_function_used_when_targeting_React_JSX_emit_e_g_React_createElement_or_h_6647", "Specify the JSX factory function used when targeting React JSX emit, e.g. 'React.createElement' or 'h'."),
	Specify_the_JSX_Fragment_reference_used_for_fragments_when_targeting_React_JSX_emit_e_g_React_Fragment_or_Fragment: r(6648, 3, "Specify_the_JSX_Fragment_reference_used_for_fragments_when_targeting_React_JSX_emit_e_g_React_Fragme_6648", "Specify the JSX Fragment reference used for fragments when targeting React JSX emit e.g. 'React.Fragment' or 'Fragment'."),
	Specify_module_specifier_used_to_import_the_JSX_factory_functions_when_using_jsx_Colon_react_jsx_Asterisk: r(6649, 3, "Specify_module_specifier_used_to_import_the_JSX_factory_functions_when_using_jsx_Colon_react_jsx_Ast_6649", "Specify module specifier used to import the JSX factory functions when using 'jsx: react-jsx*'."),
	Make_keyof_only_return_strings_instead_of_string_numbers_or_symbols_Legacy_option: r(6650, 3, "Make_keyof_only_return_strings_instead_of_string_numbers_or_symbols_Legacy_option_6650", "Make keyof only return strings instead of string, numbers or symbols. Legacy option."),
	Specify_a_set_of_bundled_library_declaration_files_that_describe_the_target_runtime_environment: r(6651, 3, "Specify_a_set_of_bundled_library_declaration_files_that_describe_the_target_runtime_environment_6651", "Specify a set of bundled library declaration files that describe the target runtime environment."),
	Print_the_names_of_emitted_files_after_a_compilation: r(6652, 3, "Print_the_names_of_emitted_files_after_a_compilation_6652", "Print the names of emitted files after a compilation."),
	Print_all_of_the_files_read_during_the_compilation: r(6653, 3, "Print_all_of_the_files_read_during_the_compilation_6653", "Print all of the files read during the compilation."),
	Set_the_language_of_the_messaging_from_TypeScript_This_does_not_affect_emit: r(6654, 3, "Set_the_language_of_the_messaging_from_TypeScript_This_does_not_affect_emit_6654", "Set the language of the messaging from TypeScript. This does not affect emit."),
	Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations: r(6655, 3, "Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations_6655", "Specify the location where debugger should locate map files instead of generated locations."),
	Specify_the_maximum_folder_depth_used_for_checking_JavaScript_files_from_node_modules_Only_applicable_with_allowJs: r(6656, 3, "Specify_the_maximum_folder_depth_used_for_checking_JavaScript_files_from_node_modules_Only_applicabl_6656", "Specify the maximum folder depth used for checking JavaScript files from 'node_modules'. Only applicable with 'allowJs'."),
	Specify_what_module_code_is_generated: r(6657, 3, "Specify_what_module_code_is_generated_6657", "Specify what module code is generated."),
	Specify_how_TypeScript_looks_up_a_file_from_a_given_module_specifier: r(6658, 3, "Specify_how_TypeScript_looks_up_a_file_from_a_given_module_specifier_6658", "Specify how TypeScript looks up a file from a given module specifier."),
	Set_the_newline_character_for_emitting_files: r(6659, 3, "Set_the_newline_character_for_emitting_files_6659", "Set the newline character for emitting files."),
	Disable_emitting_files_from_a_compilation: r(6660, 3, "Disable_emitting_files_from_a_compilation_6660", "Disable emitting files from a compilation."),
	Disable_generating_custom_helper_functions_like_extends_in_compiled_output: r(6661, 3, "Disable_generating_custom_helper_functions_like_extends_in_compiled_output_6661", "Disable generating custom helper functions like '__extends' in compiled output."),
	Disable_emitting_files_if_any_type_checking_errors_are_reported: r(6662, 3, "Disable_emitting_files_if_any_type_checking_errors_are_reported_6662", "Disable emitting files if any type checking errors are reported."),
	Disable_truncating_types_in_error_messages: r(6663, 3, "Disable_truncating_types_in_error_messages_6663", "Disable truncating types in error messages."),
	Enable_error_reporting_for_fallthrough_cases_in_switch_statements: r(6664, 3, "Enable_error_reporting_for_fallthrough_cases_in_switch_statements_6664", "Enable error reporting for fallthrough cases in switch statements."),
	Enable_error_reporting_for_expressions_and_declarations_with_an_implied_any_type: r(6665, 3, "Enable_error_reporting_for_expressions_and_declarations_with_an_implied_any_type_6665", "Enable error reporting for expressions and declarations with an implied 'any' type."),
	Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier: r(6666, 3, "Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier_6666", "Ensure overriding members in derived classes are marked with an override modifier."),
	Enable_error_reporting_for_codepaths_that_do_not_explicitly_return_in_a_function: r(6667, 3, "Enable_error_reporting_for_codepaths_that_do_not_explicitly_return_in_a_function_6667", "Enable error reporting for codepaths that do not explicitly return in a function."),
	Enable_error_reporting_when_this_is_given_the_type_any: r(6668, 3, "Enable_error_reporting_when_this_is_given_the_type_any_6668", "Enable error reporting when 'this' is given the type 'any'."),
	Disable_adding_use_strict_directives_in_emitted_JavaScript_files: r(6669, 3, "Disable_adding_use_strict_directives_in_emitted_JavaScript_files_6669", "Disable adding 'use strict' directives in emitted JavaScript files."),
	Disable_including_any_library_files_including_the_default_lib_d_ts: r(6670, 3, "Disable_including_any_library_files_including_the_default_lib_d_ts_6670", "Disable including any library files, including the default lib.d.ts."),
	Enforces_using_indexed_accessors_for_keys_declared_using_an_indexed_type: r(6671, 3, "Enforces_using_indexed_accessors_for_keys_declared_using_an_indexed_type_6671", "Enforces using indexed accessors for keys declared using an indexed type."),
	Disallow_import_s_require_s_or_reference_s_from_expanding_the_number_of_files_TypeScript_should_add_to_a_project: r(6672, 3, "Disallow_import_s_require_s_or_reference_s_from_expanding_the_number_of_files_TypeScript_should_add__6672", "Disallow 'import's, 'require's or '<reference>'s from expanding the number of files TypeScript should add to a project."),
	Disable_strict_checking_of_generic_signatures_in_function_types: r(6673, 3, "Disable_strict_checking_of_generic_signatures_in_function_types_6673", "Disable strict checking of generic signatures in function types."),
	Add_undefined_to_a_type_when_accessed_using_an_index: r(6674, 3, "Add_undefined_to_a_type_when_accessed_using_an_index_6674", "Add 'undefined' to a type when accessed using an index."),
	Enable_error_reporting_when_local_variables_aren_t_read: r(6675, 3, "Enable_error_reporting_when_local_variables_aren_t_read_6675", "Enable error reporting when local variables aren't read."),
	Raise_an_error_when_a_function_parameter_isn_t_read: r(6676, 3, "Raise_an_error_when_a_function_parameter_isn_t_read_6676", "Raise an error when a function parameter isn't read."),
	Deprecated_setting_Use_outFile_instead: r(6677, 3, "Deprecated_setting_Use_outFile_instead_6677", "Deprecated setting. Use 'outFile' instead."),
	Specify_an_output_folder_for_all_emitted_files: r(6678, 3, "Specify_an_output_folder_for_all_emitted_files_6678", "Specify an output folder for all emitted files."),
	Specify_a_file_that_bundles_all_outputs_into_one_JavaScript_file_If_declaration_is_true_also_designates_a_file_that_bundles_all_d_ts_output: r(6679, 3, "Specify_a_file_that_bundles_all_outputs_into_one_JavaScript_file_If_declaration_is_true_also_designa_6679", "Specify a file that bundles all outputs into one JavaScript file. If 'declaration' is true, also designates a file that bundles all .d.ts output."),
	Specify_a_set_of_entries_that_re_map_imports_to_additional_lookup_locations: r(6680, 3, "Specify_a_set_of_entries_that_re_map_imports_to_additional_lookup_locations_6680", "Specify a set of entries that re-map imports to additional lookup locations."),
	Specify_a_list_of_language_service_plugins_to_include: r(6681, 3, "Specify_a_list_of_language_service_plugins_to_include_6681", "Specify a list of language service plugins to include."),
	Disable_erasing_const_enum_declarations_in_generated_code: r(6682, 3, "Disable_erasing_const_enum_declarations_in_generated_code_6682", "Disable erasing 'const enum' declarations in generated code."),
	Disable_resolving_symlinks_to_their_realpath_This_correlates_to_the_same_flag_in_node: r(6683, 3, "Disable_resolving_symlinks_to_their_realpath_This_correlates_to_the_same_flag_in_node_6683", "Disable resolving symlinks to their realpath. This correlates to the same flag in node."),
	Disable_wiping_the_console_in_watch_mode: r(6684, 3, "Disable_wiping_the_console_in_watch_mode_6684", "Disable wiping the console in watch mode."),
	Enable_color_and_formatting_in_TypeScript_s_output_to_make_compiler_errors_easier_to_read: r(6685, 3, "Enable_color_and_formatting_in_TypeScript_s_output_to_make_compiler_errors_easier_to_read_6685", "Enable color and formatting in TypeScript's output to make compiler errors easier to read."),
	Specify_the_object_invoked_for_createElement_This_only_applies_when_targeting_react_JSX_emit: r(6686, 3, "Specify_the_object_invoked_for_createElement_This_only_applies_when_targeting_react_JSX_emit_6686", "Specify the object invoked for 'createElement'. This only applies when targeting 'react' JSX emit."),
	Specify_an_array_of_objects_that_specify_paths_for_projects_Used_in_project_references: r(6687, 3, "Specify_an_array_of_objects_that_specify_paths_for_projects_Used_in_project_references_6687", "Specify an array of objects that specify paths for projects. Used in project references."),
	Disable_emitting_comments: r(6688, 3, "Disable_emitting_comments_6688", "Disable emitting comments."),
	Enable_importing_json_files: r(6689, 3, "Enable_importing_json_files_6689", "Enable importing .json files."),
	Specify_the_root_folder_within_your_source_files: r(6690, 3, "Specify_the_root_folder_within_your_source_files_6690", "Specify the root folder within your source files."),
	Allow_multiple_folders_to_be_treated_as_one_when_resolving_modules: r(6691, 3, "Allow_multiple_folders_to_be_treated_as_one_when_resolving_modules_6691", "Allow multiple folders to be treated as one when resolving modules."),
	Skip_type_checking_d_ts_files_that_are_included_with_TypeScript: r(6692, 3, "Skip_type_checking_d_ts_files_that_are_included_with_TypeScript_6692", "Skip type checking .d.ts files that are included with TypeScript."),
	Skip_type_checking_all_d_ts_files: r(6693, 3, "Skip_type_checking_all_d_ts_files_6693", "Skip type checking all .d.ts files."),
	Create_source_map_files_for_emitted_JavaScript_files: r(6694, 3, "Create_source_map_files_for_emitted_JavaScript_files_6694", "Create source map files for emitted JavaScript files."),
	Specify_the_root_path_for_debuggers_to_find_the_reference_source_code: r(6695, 3, "Specify_the_root_path_for_debuggers_to_find_the_reference_source_code_6695", "Specify the root path for debuggers to find the reference source code."),
	Check_that_the_arguments_for_bind_call_and_apply_methods_match_the_original_function: r(6697, 3, "Check_that_the_arguments_for_bind_call_and_apply_methods_match_the_original_function_6697", "Check that the arguments for 'bind', 'call', and 'apply' methods match the original function."),
	When_assigning_functions_check_to_ensure_parameters_and_the_return_values_are_subtype_compatible: r(6698, 3, "When_assigning_functions_check_to_ensure_parameters_and_the_return_values_are_subtype_compatible_6698", "When assigning functions, check to ensure parameters and the return values are subtype-compatible."),
	When_type_checking_take_into_account_null_and_undefined: r(6699, 3, "When_type_checking_take_into_account_null_and_undefined_6699", "When type checking, take into account 'null' and 'undefined'."),
	Check_for_class_properties_that_are_declared_but_not_set_in_the_constructor: r(6700, 3, "Check_for_class_properties_that_are_declared_but_not_set_in_the_constructor_6700", "Check for class properties that are declared but not set in the constructor."),
	Disable_emitting_declarations_that_have_internal_in_their_JSDoc_comments: r(6701, 3, "Disable_emitting_declarations_that_have_internal_in_their_JSDoc_comments_6701", "Disable emitting declarations that have '@internal' in their JSDoc comments."),
	Disable_reporting_of_excess_property_errors_during_the_creation_of_object_literals: r(6702, 3, "Disable_reporting_of_excess_property_errors_during_the_creation_of_object_literals_6702", "Disable reporting of excess property errors during the creation of object literals."),
	Suppress_noImplicitAny_errors_when_indexing_objects_that_lack_index_signatures: r(6703, 3, "Suppress_noImplicitAny_errors_when_indexing_objects_that_lack_index_signatures_6703", "Suppress 'noImplicitAny' errors when indexing objects that lack index signatures."),
	Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_support_recursive_watching_natively: r(6704, 3, "Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_supp_6704", "Synchronously call callbacks and update the state of directory watchers on platforms that don`t support recursive watching natively."),
	Set_the_JavaScript_language_version_for_emitted_JavaScript_and_include_compatible_library_declarations: r(6705, 3, "Set_the_JavaScript_language_version_for_emitted_JavaScript_and_include_compatible_library_declaratio_6705", "Set the JavaScript language version for emitted JavaScript and include compatible library declarations."),
	Log_paths_used_during_the_moduleResolution_process: r(6706, 3, "Log_paths_used_during_the_moduleResolution_process_6706", "Log paths used during the 'moduleResolution' process."),
	Specify_the_path_to_tsbuildinfo_incremental_compilation_file: r(6707, 3, "Specify_the_path_to_tsbuildinfo_incremental_compilation_file_6707", "Specify the path to .tsbuildinfo incremental compilation file."),
	Specify_options_for_automatic_acquisition_of_declaration_files: r(6709, 3, "Specify_options_for_automatic_acquisition_of_declaration_files_6709", "Specify options for automatic acquisition of declaration files."),
	Specify_multiple_folders_that_act_like_Slashnode_modules_Slash_types: r(6710, 3, "Specify_multiple_folders_that_act_like_Slashnode_modules_Slash_types_6710", "Specify multiple folders that act like './node_modules/@types'."),
	Specify_type_package_names_to_be_included_without_being_referenced_in_a_source_file: r(6711, 3, "Specify_type_package_names_to_be_included_without_being_referenced_in_a_source_file_6711", "Specify type package names to be included without being referenced in a source file."),
	Emit_ECMAScript_standard_compliant_class_fields: r(6712, 3, "Emit_ECMAScript_standard_compliant_class_fields_6712", "Emit ECMAScript-standard-compliant class fields."),
	Enable_verbose_logging: r(6713, 3, "Enable_verbose_logging_6713", "Enable verbose logging."),
	Specify_how_directories_are_watched_on_systems_that_lack_recursive_file_watching_functionality: r(6714, 3, "Specify_how_directories_are_watched_on_systems_that_lack_recursive_file_watching_functionality_6714", "Specify how directories are watched on systems that lack recursive file-watching functionality."),
	Specify_how_the_TypeScript_watch_mode_works: r(6715, 3, "Specify_how_the_TypeScript_watch_mode_works_6715", "Specify how the TypeScript watch mode works."),
	Require_undeclared_properties_from_index_signatures_to_use_element_accesses: r(6717, 3, "Require_undeclared_properties_from_index_signatures_to_use_element_accesses_6717", "Require undeclared properties from index signatures to use element accesses."),
	Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types: r(6718, 3, "Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types_6718", "Specify emit/checking behavior for imports that are only used for types."),
	Require_sufficient_annotation_on_exports_so_other_tools_can_trivially_generate_declaration_files: r(6719, 3, "Require_sufficient_annotation_on_exports_so_other_tools_can_trivially_generate_declaration_files_6719", "Require sufficient annotation on exports so other tools can trivially generate declaration files."),
	Built_in_iterators_are_instantiated_with_a_TReturn_type_of_undefined_instead_of_any: r(6720, 3, "Built_in_iterators_are_instantiated_with_a_TReturn_type_of_undefined_instead_of_any_6720", "Built-in iterators are instantiated with a 'TReturn' type of 'undefined' instead of 'any'."),
	Do_not_allow_runtime_constructs_that_are_not_part_of_ECMAScript: r(6721, 3, "Do_not_allow_runtime_constructs_that_are_not_part_of_ECMAScript_6721", "Do not allow runtime constructs that are not part of ECMAScript."),
	Default_catch_clause_variables_as_unknown_instead_of_any: r(6803, 3, "Default_catch_clause_variables_as_unknown_instead_of_any_6803", "Default catch clause variables as 'unknown' instead of 'any'."),
	Do_not_transform_or_elide_any_imports_or_exports_not_marked_as_type_only_ensuring_they_are_written_in_the_output_file_s_format_based_on_the_module_setting: r(6804, 3, "Do_not_transform_or_elide_any_imports_or_exports_not_marked_as_type_only_ensuring_they_are_written_i_6804", "Do not transform or elide any imports or exports not marked as type-only, ensuring they are written in the output file's format based on the 'module' setting."),
	Disable_full_type_checking_only_critical_parse_and_emit_errors_will_be_reported: r(6805, 3, "Disable_full_type_checking_only_critical_parse_and_emit_errors_will_be_reported_6805", "Disable full type checking (only critical parse and emit errors will be reported)."),
	Check_side_effect_imports: r(6806, 3, "Check_side_effect_imports_6806", "Check side effect imports."),
	This_operation_can_be_simplified_This_shift_is_identical_to_0_1_2: r(6807, 1, "This_operation_can_be_simplified_This_shift_is_identical_to_0_1_2_6807", "This operation can be simplified. This shift is identical to `{0} {1} {2}`."),
	Enable_lib_replacement: r(6808, 3, "Enable_lib_replacement_6808", "Enable lib replacement."),
	one_of_Colon: r(6900, 3, "one_of_Colon_6900", "one of:"),
	one_or_more_Colon: r(6901, 3, "one_or_more_Colon_6901", "one or more:"),
	type_Colon: r(6902, 3, "type_Colon_6902", "type:"),
	default_Colon: r(6903, 3, "default_Colon_6903", "default:"),
	module_system_or_esModuleInterop: r(6904, 3, "module_system_or_esModuleInterop_6904", "module === \"system\" or esModuleInterop"),
	false_unless_strict_is_set: r(6905, 3, "false_unless_strict_is_set_6905", "`false`, unless `strict` is set"),
	false_unless_composite_is_set: r(6906, 3, "false_unless_composite_is_set_6906", "`false`, unless `composite` is set"),
	node_modules_bower_components_jspm_packages_plus_the_value_of_outDir_if_one_is_specified: r(6907, 3, "node_modules_bower_components_jspm_packages_plus_the_value_of_outDir_if_one_is_specified_6907", "`[\"node_modules\", \"bower_components\", \"jspm_packages\"]`, plus the value of `outDir` if one is specified."),
	if_files_is_specified_otherwise_Asterisk_Asterisk_Slash_Asterisk: r(6908, 3, "if_files_is_specified_otherwise_Asterisk_Asterisk_Slash_Asterisk_6908", "`[]` if `files` is specified, otherwise `[\"**/*\"]`"),
	true_if_composite_false_otherwise: r(6909, 3, "true_if_composite_false_otherwise_6909", "`true` if `composite`, `false` otherwise"),
	module_AMD_or_UMD_or_System_or_ES6_then_Classic_Otherwise_Node: r(69010, 3, "module_AMD_or_UMD_or_System_or_ES6_then_Classic_Otherwise_Node_69010", "module === `AMD` or `UMD` or `System` or `ES6`, then `Classic`, Otherwise `Node`"),
	Computed_from_the_list_of_input_files: r(6911, 3, "Computed_from_the_list_of_input_files_6911", "Computed from the list of input files"),
	Platform_specific: r(6912, 3, "Platform_specific_6912", "Platform specific"),
	You_can_learn_about_all_of_the_compiler_options_at_0: r(6913, 3, "You_can_learn_about_all_of_the_compiler_options_at_0_6913", "You can learn about all of the compiler options at {0}"),
	Including_watch_w_will_start_watching_the_current_project_for_the_file_changes_Once_set_you_can_config_watch_mode_with_Colon: r(6914, 3, "Including_watch_w_will_start_watching_the_current_project_for_the_file_changes_Once_set_you_can_conf_6914", "Including --watch, -w will start watching the current project for the file changes. Once set, you can config watch mode with:"),
	Using_build_b_will_make_tsc_behave_more_like_a_build_orchestrator_than_a_compiler_This_is_used_to_trigger_building_composite_projects_which_you_can_learn_more_about_at_0: r(6915, 3, "Using_build_b_will_make_tsc_behave_more_like_a_build_orchestrator_than_a_compiler_This_is_used_to_tr_6915", "Using --build, -b will make tsc behave more like a build orchestrator than a compiler. This is used to trigger building composite projects which you can learn more about at {0}"),
	COMMON_COMMANDS: r(6916, 3, "COMMON_COMMANDS_6916", "COMMON COMMANDS"),
	ALL_COMPILER_OPTIONS: r(6917, 3, "ALL_COMPILER_OPTIONS_6917", "ALL COMPILER OPTIONS"),
	WATCH_OPTIONS: r(6918, 3, "WATCH_OPTIONS_6918", "WATCH OPTIONS"),
	BUILD_OPTIONS: r(6919, 3, "BUILD_OPTIONS_6919", "BUILD OPTIONS"),
	COMMON_COMPILER_OPTIONS: r(6920, 3, "COMMON_COMPILER_OPTIONS_6920", "COMMON COMPILER OPTIONS"),
	COMMAND_LINE_FLAGS: r(6921, 3, "COMMAND_LINE_FLAGS_6921", "COMMAND LINE FLAGS"),
	tsc_Colon_The_TypeScript_Compiler: r(6922, 3, "tsc_Colon_The_TypeScript_Compiler_6922", "tsc: The TypeScript Compiler"),
	Compiles_the_current_project_tsconfig_json_in_the_working_directory: r(6923, 3, "Compiles_the_current_project_tsconfig_json_in_the_working_directory_6923", "Compiles the current project (tsconfig.json in the working directory.)"),
	Ignoring_tsconfig_json_compiles_the_specified_files_with_default_compiler_options: r(6924, 3, "Ignoring_tsconfig_json_compiles_the_specified_files_with_default_compiler_options_6924", "Ignoring tsconfig.json, compiles the specified files with default compiler options."),
	Build_a_composite_project_in_the_working_directory: r(6925, 3, "Build_a_composite_project_in_the_working_directory_6925", "Build a composite project in the working directory."),
	Creates_a_tsconfig_json_with_the_recommended_settings_in_the_working_directory: r(6926, 3, "Creates_a_tsconfig_json_with_the_recommended_settings_in_the_working_directory_6926", "Creates a tsconfig.json with the recommended settings in the working directory."),
	Compiles_the_TypeScript_project_located_at_the_specified_path: r(6927, 3, "Compiles_the_TypeScript_project_located_at_the_specified_path_6927", "Compiles the TypeScript project located at the specified path."),
	An_expanded_version_of_this_information_showing_all_possible_compiler_options: r(6928, 3, "An_expanded_version_of_this_information_showing_all_possible_compiler_options_6928", "An expanded version of this information, showing all possible compiler options"),
	Compiles_the_current_project_with_additional_settings: r(6929, 3, "Compiles_the_current_project_with_additional_settings_6929", "Compiles the current project, with additional settings."),
	true_for_ES2022_and_above_including_ESNext: r(6930, 3, "true_for_ES2022_and_above_including_ESNext_6930", "`true` for ES2022 and above, including ESNext."),
	List_of_file_name_suffixes_to_search_when_resolving_a_module: r(6931, 1, "List_of_file_name_suffixes_to_search_when_resolving_a_module_6931", "List of file name suffixes to search when resolving a module."),
	Variable_0_implicitly_has_an_1_type: r(7005, 1, "Variable_0_implicitly_has_an_1_type_7005", "Variable '{0}' implicitly has an '{1}' type."),
	Parameter_0_implicitly_has_an_1_type: r(7006, 1, "Parameter_0_implicitly_has_an_1_type_7006", "Parameter '{0}' implicitly has an '{1}' type."),
	Member_0_implicitly_has_an_1_type: r(7008, 1, "Member_0_implicitly_has_an_1_type_7008", "Member '{0}' implicitly has an '{1}' type."),
	new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type: r(7009, 1, "new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type_7009", "'new' expression, whose target lacks a construct signature, implicitly has an 'any' type."),
	_0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type: r(7010, 1, "_0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type_7010", "'{0}', which lacks return-type annotation, implicitly has an '{1}' return type."),
	Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type: r(7011, 1, "Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type_7011", "Function expression, which lacks return-type annotation, implicitly has an '{0}' return type."),
	This_overload_implicitly_returns_the_type_0_because_it_lacks_a_return_type_annotation: r(7012, 1, "This_overload_implicitly_returns_the_type_0_because_it_lacks_a_return_type_annotation_7012", "This overload implicitly returns the type '{0}' because it lacks a return type annotation."),
	Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type: r(7013, 1, "Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7013", "Construct signature, which lacks return-type annotation, implicitly has an 'any' return type."),
	Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type: r(7014, 1, "Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type_7014", "Function type, which lacks return-type annotation, implicitly has an '{0}' return type."),
	Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number: r(7015, 1, "Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number_7015", "Element implicitly has an 'any' type because index expression is not of type 'number'."),
	Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type: r(7016, 1, "Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type_7016", "Could not find a declaration file for module '{0}'. '{1}' implicitly has an 'any' type."),
	Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature: r(7017, 1, "Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_7017", "Element implicitly has an 'any' type because type '{0}' has no index signature."),
	Object_literal_s_property_0_implicitly_has_an_1_type: r(7018, 1, "Object_literal_s_property_0_implicitly_has_an_1_type_7018", "Object literal's property '{0}' implicitly has an '{1}' type."),
	Rest_parameter_0_implicitly_has_an_any_type: r(7019, 1, "Rest_parameter_0_implicitly_has_an_any_type_7019", "Rest parameter '{0}' implicitly has an 'any[]' type."),
	Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type: r(7020, 1, "Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7020", "Call signature, which lacks return-type annotation, implicitly has an 'any' return type."),
	_0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or_indirectly_in_its_own_initializer: r(7022, 1, "_0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or__7022", "'{0}' implicitly has type 'any' because it does not have a type annotation and is referenced directly or indirectly in its own initializer."),
	_0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions: r(7023, 1, "_0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_reference_7023", "'{0}' implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions."),
	Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions: r(7024, 1, "Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_ref_7024", "Function implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions."),
	Generator_implicitly_has_yield_type_0_Consider_supplying_a_return_type_annotation: r(7025, 1, "Generator_implicitly_has_yield_type_0_Consider_supplying_a_return_type_annotation_7025", "Generator implicitly has yield type '{0}'. Consider supplying a return type annotation."),
	JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists: r(7026, 1, "JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists_7026", "JSX element implicitly has type 'any' because no interface 'JSX.{0}' exists."),
	Unreachable_code_detected: r(7027, 1, "Unreachable_code_detected_7027", "Unreachable code detected.", !0),
	Unused_label: r(7028, 1, "Unused_label_7028", "Unused label.", !0),
	Fallthrough_case_in_switch: r(7029, 1, "Fallthrough_case_in_switch_7029", "Fallthrough case in switch."),
	Not_all_code_paths_return_a_value: r(7030, 1, "Not_all_code_paths_return_a_value_7030", "Not all code paths return a value."),
	Binding_element_0_implicitly_has_an_1_type: r(7031, 1, "Binding_element_0_implicitly_has_an_1_type_7031", "Binding element '{0}' implicitly has an '{1}' type."),
	Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation: r(7032, 1, "Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation_7032", "Property '{0}' implicitly has type 'any', because its set accessor lacks a parameter type annotation."),
	Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation: r(7033, 1, "Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation_7033", "Property '{0}' implicitly has type 'any', because its get accessor lacks a return type annotation."),
	Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined: r(7034, 1, "Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined_7034", "Variable '{0}' implicitly has type '{1}' in some locations where its type cannot be determined."),
	Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare_module_0: r(7035, 1, "Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare__7035", "Try `npm i --save-dev @types/{1}` if it exists or add a new declaration (.d.ts) file containing `declare module '{0}';`"),
	Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0: r(7036, 1, "Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0_7036", "Dynamic import's specifier must be of type 'string', but here has type '{0}'."),
	Enables_emit_interoperability_between_CommonJS_and_ES_Modules_via_creation_of_namespace_objects_for_all_imports_Implies_allowSyntheticDefaultImports: r(7037, 3, "Enables_emit_interoperability_between_CommonJS_and_ES_Modules_via_creation_of_namespace_objects_for__7037", "Enables emit interoperability between CommonJS and ES Modules via creation of namespace objects for all imports. Implies 'allowSyntheticDefaultImports'."),
	Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cause_a_failure_at_runtime_Consider_using_a_default_import_or_import_require_here_instead: r(7038, 3, "Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cau_7038", "Type originates at this import. A namespace-style import cannot be called or constructed, and will cause a failure at runtime. Consider using a default import or import require here instead."),
	Mapped_object_type_implicitly_has_an_any_template_type: r(7039, 1, "Mapped_object_type_implicitly_has_an_any_template_type_7039", "Mapped object type implicitly has an 'any' template type."),
	If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_Slash_Slashgithub_com_SlashDefinitelyTyped_SlashDefinitelyTyped_Slashtree_Slashmaster_Slashtypes_Slash_1: r(7040, 1, "If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_S_7040", "If the '{0}' package actually exposes this module, consider sending a pull request to amend 'https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/{1}'"),
	The_containing_arrow_function_captures_the_global_value_of_this: r(7041, 1, "The_containing_arrow_function_captures_the_global_value_of_this_7041", "The containing arrow function captures the global value of 'this'."),
	Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used: r(7042, 1, "Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used_7042", "Module '{0}' was resolved to '{1}', but '--resolveJsonModule' is not used."),
	Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: r(7043, 2, "Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7043", "Variable '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),
	Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: r(7044, 2, "Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7044", "Parameter '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),
	Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: r(7045, 2, "Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7045", "Member '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),
	Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage: r(7046, 2, "Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage_7046", "Variable '{0}' implicitly has type '{1}' in some locations, but a better type may be inferred from usage."),
	Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage: r(7047, 2, "Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage_7047", "Rest parameter '{0}' implicitly has an 'any[]' type, but a better type may be inferred from usage."),
	Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage: r(7048, 2, "Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage_7048", "Property '{0}' implicitly has type 'any', but a better type for its get accessor may be inferred from usage."),
	Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage: r(7049, 2, "Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage_7049", "Property '{0}' implicitly has type 'any', but a better type for its set accessor may be inferred from usage."),
	_0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage: r(7050, 2, "_0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage_7050", "'{0}' implicitly has an '{1}' return type, but a better type may be inferred from usage."),
	Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1: r(7051, 1, "Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1_7051", "Parameter has a name but no type. Did you mean '{0}: {1}'?"),
	Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1: r(7052, 1, "Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1_7052", "Element implicitly has an 'any' type because type '{0}' has no index signature. Did you mean to call '{1}'?"),
	Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1: r(7053, 1, "Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1_7053", "Element implicitly has an 'any' type because expression of type '{0}' can't be used to index type '{1}'."),
	No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1: r(7054, 1, "No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1_7054", "No index signature with a parameter of type '{0}' was found on type '{1}'."),
	_0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type: r(7055, 1, "_0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type_7055", "'{0}', which lacks return-type annotation, implicitly has an '{1}' yield type."),
	The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_type_annotation_is_needed: r(7056, 1, "The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_ty_7056", "The inferred type of this node exceeds the maximum length the compiler will serialize. An explicit type annotation is needed."),
	yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_type_annotation: r(7057, 1, "yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_t_7057", "'yield' expression implicitly results in an 'any' type because its containing generator lacks a return-type annotation."),
	If_the_0_package_actually_exposes_this_module_try_adding_a_new_declaration_d_ts_file_containing_declare_module_1: r(7058, 1, "If_the_0_package_actually_exposes_this_module_try_adding_a_new_declaration_d_ts_file_containing_decl_7058", "If the '{0}' package actually exposes this module, try adding a new declaration (.d.ts) file containing `declare module '{1}';`"),
	This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Use_an_as_expression_instead: r(7059, 1, "This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Use_an_as_expression_instead_7059", "This syntax is reserved in files with the .mts or .cts extension. Use an `as` expression instead."),
	This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Add_a_trailing_comma_or_explicit_constraint: r(7060, 1, "This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Add_a_trailing_comma_or_explicit_cons_7060", "This syntax is reserved in files with the .mts or .cts extension. Add a trailing comma or explicit constraint."),
	A_mapped_type_may_not_declare_properties_or_methods: r(7061, 1, "A_mapped_type_may_not_declare_properties_or_methods_7061", "A mapped type may not declare properties or methods."),
	You_cannot_rename_this_element: r(8e3, 1, "You_cannot_rename_this_element_8000", "You cannot rename this element."),
	You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library: r(8001, 1, "You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library_8001", "You cannot rename elements that are defined in the standard TypeScript library."),
	import_can_only_be_used_in_TypeScript_files: r(8002, 1, "import_can_only_be_used_in_TypeScript_files_8002", "'import ... =' can only be used in TypeScript files."),
	export_can_only_be_used_in_TypeScript_files: r(8003, 1, "export_can_only_be_used_in_TypeScript_files_8003", "'export =' can only be used in TypeScript files."),
	Type_parameter_declarations_can_only_be_used_in_TypeScript_files: r(8004, 1, "Type_parameter_declarations_can_only_be_used_in_TypeScript_files_8004", "Type parameter declarations can only be used in TypeScript files."),
	implements_clauses_can_only_be_used_in_TypeScript_files: r(8005, 1, "implements_clauses_can_only_be_used_in_TypeScript_files_8005", "'implements' clauses can only be used in TypeScript files."),
	_0_declarations_can_only_be_used_in_TypeScript_files: r(8006, 1, "_0_declarations_can_only_be_used_in_TypeScript_files_8006", "'{0}' declarations can only be used in TypeScript files."),
	Type_aliases_can_only_be_used_in_TypeScript_files: r(8008, 1, "Type_aliases_can_only_be_used_in_TypeScript_files_8008", "Type aliases can only be used in TypeScript files."),
	The_0_modifier_can_only_be_used_in_TypeScript_files: r(8009, 1, "The_0_modifier_can_only_be_used_in_TypeScript_files_8009", "The '{0}' modifier can only be used in TypeScript files."),
	Type_annotations_can_only_be_used_in_TypeScript_files: r(8010, 1, "Type_annotations_can_only_be_used_in_TypeScript_files_8010", "Type annotations can only be used in TypeScript files."),
	Type_arguments_can_only_be_used_in_TypeScript_files: r(8011, 1, "Type_arguments_can_only_be_used_in_TypeScript_files_8011", "Type arguments can only be used in TypeScript files."),
	Parameter_modifiers_can_only_be_used_in_TypeScript_files: r(8012, 1, "Parameter_modifiers_can_only_be_used_in_TypeScript_files_8012", "Parameter modifiers can only be used in TypeScript files."),
	Non_null_assertions_can_only_be_used_in_TypeScript_files: r(8013, 1, "Non_null_assertions_can_only_be_used_in_TypeScript_files_8013", "Non-null assertions can only be used in TypeScript files."),
	Type_assertion_expressions_can_only_be_used_in_TypeScript_files: r(8016, 1, "Type_assertion_expressions_can_only_be_used_in_TypeScript_files_8016", "Type assertion expressions can only be used in TypeScript files."),
	Signature_declarations_can_only_be_used_in_TypeScript_files: r(8017, 1, "Signature_declarations_can_only_be_used_in_TypeScript_files_8017", "Signature declarations can only be used in TypeScript files."),
	Report_errors_in_js_files: r(8019, 3, "Report_errors_in_js_files_8019", "Report errors in .js files."),
	JSDoc_types_can_only_be_used_inside_documentation_comments: r(8020, 1, "JSDoc_types_can_only_be_used_inside_documentation_comments_8020", "JSDoc types can only be used inside documentation comments."),
	JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags: r(8021, 1, "JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags_8021", "JSDoc '@typedef' tag should either have a type annotation or be followed by '@property' or '@member' tags."),
	JSDoc_0_is_not_attached_to_a_class: r(8022, 1, "JSDoc_0_is_not_attached_to_a_class_8022", "JSDoc '@{0}' is not attached to a class."),
	JSDoc_0_1_does_not_match_the_extends_2_clause: r(8023, 1, "JSDoc_0_1_does_not_match_the_extends_2_clause_8023", "JSDoc '@{0} {1}' does not match the 'extends {2}' clause."),
	JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name: r(8024, 1, "JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_8024", "JSDoc '@param' tag has name '{0}', but there is no parameter with that name."),
	Class_declarations_cannot_have_more_than_one_augments_or_extends_tag: r(8025, 1, "Class_declarations_cannot_have_more_than_one_augments_or_extends_tag_8025", "Class declarations cannot have more than one '@augments' or '@extends' tag."),
	Expected_0_type_arguments_provide_these_with_an_extends_tag: r(8026, 1, "Expected_0_type_arguments_provide_these_with_an_extends_tag_8026", "Expected {0} type arguments; provide these with an '@extends' tag."),
	Expected_0_1_type_arguments_provide_these_with_an_extends_tag: r(8027, 1, "Expected_0_1_type_arguments_provide_these_with_an_extends_tag_8027", "Expected {0}-{1} type arguments; provide these with an '@extends' tag."),
	JSDoc_may_only_appear_in_the_last_parameter_of_a_signature: r(8028, 1, "JSDoc_may_only_appear_in_the_last_parameter_of_a_signature_8028", "JSDoc '...' may only appear in the last parameter of a signature."),
	JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_had_an_array_type: r(8029, 1, "JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_h_8029", "JSDoc '@param' tag has name '{0}', but there is no parameter with that name. It would match 'arguments' if it had an array type."),
	The_type_of_a_function_declaration_must_match_the_function_s_signature: r(8030, 1, "The_type_of_a_function_declaration_must_match_the_function_s_signature_8030", "The type of a function declaration must match the function's signature."),
	You_cannot_rename_a_module_via_a_global_import: r(8031, 1, "You_cannot_rename_a_module_via_a_global_import_8031", "You cannot rename a module via a global import."),
	Qualified_name_0_is_not_allowed_without_a_leading_param_object_1: r(8032, 1, "Qualified_name_0_is_not_allowed_without_a_leading_param_object_1_8032", "Qualified name '{0}' is not allowed without a leading '@param {object} {1}'."),
	A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags: r(8033, 1, "A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags_8033", "A JSDoc '@typedef' comment may not contain multiple '@type' tags."),
	The_tag_was_first_specified_here: r(8034, 1, "The_tag_was_first_specified_here_8034", "The tag was first specified here."),
	You_cannot_rename_elements_that_are_defined_in_a_node_modules_folder: r(8035, 1, "You_cannot_rename_elements_that_are_defined_in_a_node_modules_folder_8035", "You cannot rename elements that are defined in a 'node_modules' folder."),
	You_cannot_rename_elements_that_are_defined_in_another_node_modules_folder: r(8036, 1, "You_cannot_rename_elements_that_are_defined_in_another_node_modules_folder_8036", "You cannot rename elements that are defined in another 'node_modules' folder."),
	Type_satisfaction_expressions_can_only_be_used_in_TypeScript_files: r(8037, 1, "Type_satisfaction_expressions_can_only_be_used_in_TypeScript_files_8037", "Type satisfaction expressions can only be used in TypeScript files."),
	Decorators_may_not_appear_after_export_or_export_default_if_they_also_appear_before_export: r(8038, 1, "Decorators_may_not_appear_after_export_or_export_default_if_they_also_appear_before_export_8038", "Decorators may not appear after 'export' or 'export default' if they also appear before 'export'."),
	A_JSDoc_template_tag_may_not_follow_a_typedef_callback_or_overload_tag: r(8039, 1, "A_JSDoc_template_tag_may_not_follow_a_typedef_callback_or_overload_tag_8039", "A JSDoc '@template' tag may not follow a '@typedef', '@callback', or '@overload' tag"),
	Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_declaration_emit: r(9005, 1, "Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_9005", "Declaration emit for this file requires using private name '{0}'. An explicit type annotation may unblock declaration emit."),
	Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotation_may_unblock_declaration_emit: r(9006, 1, "Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotati_9006", "Declaration emit for this file requires using private name '{0}' from module '{1}'. An explicit type annotation may unblock declaration emit."),
	Function_must_have_an_explicit_return_type_annotation_with_isolatedDeclarations: r(9007, 1, "Function_must_have_an_explicit_return_type_annotation_with_isolatedDeclarations_9007", "Function must have an explicit return type annotation with --isolatedDeclarations."),
	Method_must_have_an_explicit_return_type_annotation_with_isolatedDeclarations: r(9008, 1, "Method_must_have_an_explicit_return_type_annotation_with_isolatedDeclarations_9008", "Method must have an explicit return type annotation with --isolatedDeclarations."),
	At_least_one_accessor_must_have_an_explicit_type_annotation_with_isolatedDeclarations: r(9009, 1, "At_least_one_accessor_must_have_an_explicit_type_annotation_with_isolatedDeclarations_9009", "At least one accessor must have an explicit type annotation with --isolatedDeclarations."),
	Variable_must_have_an_explicit_type_annotation_with_isolatedDeclarations: r(9010, 1, "Variable_must_have_an_explicit_type_annotation_with_isolatedDeclarations_9010", "Variable must have an explicit type annotation with --isolatedDeclarations."),
	Parameter_must_have_an_explicit_type_annotation_with_isolatedDeclarations: r(9011, 1, "Parameter_must_have_an_explicit_type_annotation_with_isolatedDeclarations_9011", "Parameter must have an explicit type annotation with --isolatedDeclarations."),
	Property_must_have_an_explicit_type_annotation_with_isolatedDeclarations: r(9012, 1, "Property_must_have_an_explicit_type_annotation_with_isolatedDeclarations_9012", "Property must have an explicit type annotation with --isolatedDeclarations."),
	Expression_type_can_t_be_inferred_with_isolatedDeclarations: r(9013, 1, "Expression_type_can_t_be_inferred_with_isolatedDeclarations_9013", "Expression type can't be inferred with --isolatedDeclarations."),
	Computed_properties_must_be_number_or_string_literals_variables_or_dotted_expressions_with_isolatedDeclarations: r(9014, 1, "Computed_properties_must_be_number_or_string_literals_variables_or_dotted_expressions_with_isolatedD_9014", "Computed properties must be number or string literals, variables or dotted expressions with --isolatedDeclarations."),
	Objects_that_contain_spread_assignments_can_t_be_inferred_with_isolatedDeclarations: r(9015, 1, "Objects_that_contain_spread_assignments_can_t_be_inferred_with_isolatedDeclarations_9015", "Objects that contain spread assignments can't be inferred with --isolatedDeclarations."),
	Objects_that_contain_shorthand_properties_can_t_be_inferred_with_isolatedDeclarations: r(9016, 1, "Objects_that_contain_shorthand_properties_can_t_be_inferred_with_isolatedDeclarations_9016", "Objects that contain shorthand properties can't be inferred with --isolatedDeclarations."),
	Only_const_arrays_can_be_inferred_with_isolatedDeclarations: r(9017, 1, "Only_const_arrays_can_be_inferred_with_isolatedDeclarations_9017", "Only const arrays can be inferred with --isolatedDeclarations."),
	Arrays_with_spread_elements_can_t_inferred_with_isolatedDeclarations: r(9018, 1, "Arrays_with_spread_elements_can_t_inferred_with_isolatedDeclarations_9018", "Arrays with spread elements can't inferred with --isolatedDeclarations."),
	Binding_elements_can_t_be_exported_directly_with_isolatedDeclarations: r(9019, 1, "Binding_elements_can_t_be_exported_directly_with_isolatedDeclarations_9019", "Binding elements can't be exported directly with --isolatedDeclarations."),
	Enum_member_initializers_must_be_computable_without_references_to_external_symbols_with_isolatedDeclarations: r(9020, 1, "Enum_member_initializers_must_be_computable_without_references_to_external_symbols_with_isolatedDecl_9020", "Enum member initializers must be computable without references to external symbols with --isolatedDeclarations."),
	Extends_clause_can_t_contain_an_expression_with_isolatedDeclarations: r(9021, 1, "Extends_clause_can_t_contain_an_expression_with_isolatedDeclarations_9021", "Extends clause can't contain an expression with --isolatedDeclarations."),
	Inference_from_class_expressions_is_not_supported_with_isolatedDeclarations: r(9022, 1, "Inference_from_class_expressions_is_not_supported_with_isolatedDeclarations_9022", "Inference from class expressions is not supported with --isolatedDeclarations."),
	Assigning_properties_to_functions_without_declaring_them_is_not_supported_with_isolatedDeclarations_Add_an_explicit_declaration_for_the_properties_assigned_to_this_function: r(9023, 1, "Assigning_properties_to_functions_without_declaring_them_is_not_supported_with_isolatedDeclarations__9023", "Assigning properties to functions without declaring them is not supported with --isolatedDeclarations. Add an explicit declaration for the properties assigned to this function."),
	Declaration_emit_for_this_parameter_requires_implicitly_adding_undefined_to_its_type_This_is_not_supported_with_isolatedDeclarations: r(9025, 1, "Declaration_emit_for_this_parameter_requires_implicitly_adding_undefined_to_its_type_This_is_not_sup_9025", "Declaration emit for this parameter requires implicitly adding undefined to its type. This is not supported with --isolatedDeclarations."),
	Declaration_emit_for_this_file_requires_preserving_this_import_for_augmentations_This_is_not_supported_with_isolatedDeclarations: r(9026, 1, "Declaration_emit_for_this_file_requires_preserving_this_import_for_augmentations_This_is_not_support_9026", "Declaration emit for this file requires preserving this import for augmentations. This is not supported with --isolatedDeclarations."),
	Add_a_type_annotation_to_the_variable_0: r(9027, 1, "Add_a_type_annotation_to_the_variable_0_9027", "Add a type annotation to the variable {0}."),
	Add_a_type_annotation_to_the_parameter_0: r(9028, 1, "Add_a_type_annotation_to_the_parameter_0_9028", "Add a type annotation to the parameter {0}."),
	Add_a_type_annotation_to_the_property_0: r(9029, 1, "Add_a_type_annotation_to_the_property_0_9029", "Add a type annotation to the property {0}."),
	Add_a_return_type_to_the_function_expression: r(9030, 1, "Add_a_return_type_to_the_function_expression_9030", "Add a return type to the function expression."),
	Add_a_return_type_to_the_function_declaration: r(9031, 1, "Add_a_return_type_to_the_function_declaration_9031", "Add a return type to the function declaration."),
	Add_a_return_type_to_the_get_accessor_declaration: r(9032, 1, "Add_a_return_type_to_the_get_accessor_declaration_9032", "Add a return type to the get accessor declaration."),
	Add_a_type_to_parameter_of_the_set_accessor_declaration: r(9033, 1, "Add_a_type_to_parameter_of_the_set_accessor_declaration_9033", "Add a type to parameter of the set accessor declaration."),
	Add_a_return_type_to_the_method: r(9034, 1, "Add_a_return_type_to_the_method_9034", "Add a return type to the method"),
	Add_satisfies_and_a_type_assertion_to_this_expression_satisfies_T_as_T_to_make_the_type_explicit: r(9035, 1, "Add_satisfies_and_a_type_assertion_to_this_expression_satisfies_T_as_T_to_make_the_type_explicit_9035", "Add satisfies and a type assertion to this expression (satisfies T as T) to make the type explicit."),
	Move_the_expression_in_default_export_to_a_variable_and_add_a_type_annotation_to_it: r(9036, 1, "Move_the_expression_in_default_export_to_a_variable_and_add_a_type_annotation_to_it_9036", "Move the expression in default export to a variable and add a type annotation to it."),
	Default_exports_can_t_be_inferred_with_isolatedDeclarations: r(9037, 1, "Default_exports_can_t_be_inferred_with_isolatedDeclarations_9037", "Default exports can't be inferred with --isolatedDeclarations."),
	Computed_property_names_on_class_or_object_literals_cannot_be_inferred_with_isolatedDeclarations: r(9038, 1, "Computed_property_names_on_class_or_object_literals_cannot_be_inferred_with_isolatedDeclarations_9038", "Computed property names on class or object literals cannot be inferred with --isolatedDeclarations."),
	Type_containing_private_name_0_can_t_be_used_with_isolatedDeclarations: r(9039, 1, "Type_containing_private_name_0_can_t_be_used_with_isolatedDeclarations_9039", "Type containing private name '{0}' can't be used with --isolatedDeclarations."),
	JSX_attributes_must_only_be_assigned_a_non_empty_expression: r(17e3, 1, "JSX_attributes_must_only_be_assigned_a_non_empty_expression_17000", "JSX attributes must only be assigned a non-empty 'expression'."),
	JSX_elements_cannot_have_multiple_attributes_with_the_same_name: r(17001, 1, "JSX_elements_cannot_have_multiple_attributes_with_the_same_name_17001", "JSX elements cannot have multiple attributes with the same name."),
	Expected_corresponding_JSX_closing_tag_for_0: r(17002, 1, "Expected_corresponding_JSX_closing_tag_for_0_17002", "Expected corresponding JSX closing tag for '{0}'."),
	Cannot_use_JSX_unless_the_jsx_flag_is_provided: r(17004, 1, "Cannot_use_JSX_unless_the_jsx_flag_is_provided_17004", "Cannot use JSX unless the '--jsx' flag is provided."),
	A_constructor_cannot_contain_a_super_call_when_its_class_extends_null: r(17005, 1, "A_constructor_cannot_contain_a_super_call_when_its_class_extends_null_17005", "A constructor cannot contain a 'super' call when its class extends 'null'."),
	An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses: r(17006, 1, "An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_ex_17006", "An unary expression with the '{0}' operator is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses."),
	A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses: r(17007, 1, "A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Con_17007", "A type assertion expression is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses."),
	JSX_element_0_has_no_corresponding_closing_tag: r(17008, 1, "JSX_element_0_has_no_corresponding_closing_tag_17008", "JSX element '{0}' has no corresponding closing tag."),
	super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class: r(17009, 1, "super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class_17009", "'super' must be called before accessing 'this' in the constructor of a derived class."),
	Unknown_type_acquisition_option_0: r(17010, 1, "Unknown_type_acquisition_option_0_17010", "Unknown type acquisition option '{0}'."),
	super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class: r(17011, 1, "super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class_17011", "'super' must be called before accessing a property of 'super' in the constructor of a derived class."),
	_0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2: r(17012, 1, "_0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2_17012", "'{0}' is not a valid meta-property for keyword '{1}'. Did you mean '{2}'?"),
	Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constructor: r(17013, 1, "Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constru_17013", "Meta-property '{0}' is only allowed in the body of a function declaration, function expression, or constructor."),
	JSX_fragment_has_no_corresponding_closing_tag: r(17014, 1, "JSX_fragment_has_no_corresponding_closing_tag_17014", "JSX fragment has no corresponding closing tag."),
	Expected_corresponding_closing_tag_for_JSX_fragment: r(17015, 1, "Expected_corresponding_closing_tag_for_JSX_fragment_17015", "Expected corresponding closing tag for JSX fragment."),
	The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_compiler_option: r(17016, 1, "The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_com_17016", "The 'jsxFragmentFactory' compiler option must be provided to use JSX fragments with the 'jsxFactory' compiler option."),
	An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments: r(17017, 1, "An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments_17017", "An @jsxFrag pragma is required when using an @jsx pragma with JSX fragments."),
	Unknown_type_acquisition_option_0_Did_you_mean_1: r(17018, 1, "Unknown_type_acquisition_option_0_Did_you_mean_1_17018", "Unknown type acquisition option '{0}'. Did you mean '{1}'?"),
	_0_at_the_end_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1: r(17019, 1, "_0_at_the_end_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1_17019", "'{0}' at the end of a type is not valid TypeScript syntax. Did you mean to write '{1}'?"),
	_0_at_the_start_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1: r(17020, 1, "_0_at_the_start_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1_17020", "'{0}' at the start of a type is not valid TypeScript syntax. Did you mean to write '{1}'?"),
	Unicode_escape_sequence_cannot_appear_here: r(17021, 1, "Unicode_escape_sequence_cannot_appear_here_17021", "Unicode escape sequence cannot appear here."),
	Circularity_detected_while_resolving_configuration_Colon_0: r(18e3, 1, "Circularity_detected_while_resolving_configuration_Colon_0_18000", "Circularity detected while resolving configuration: {0}"),
	The_files_list_in_config_file_0_is_empty: r(18002, 1, "The_files_list_in_config_file_0_is_empty_18002", "The 'files' list in config file '{0}' is empty."),
	No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2: r(18003, 1, "No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2_18003", "No inputs were found in config file '{0}'. Specified 'include' paths were '{1}' and 'exclude' paths were '{2}'."),
	File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module: r(80001, 2, "File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module_80001", "File is a CommonJS module; it may be converted to an ES module."),
	This_constructor_function_may_be_converted_to_a_class_declaration: r(80002, 2, "This_constructor_function_may_be_converted_to_a_class_declaration_80002", "This constructor function may be converted to a class declaration."),
	Import_may_be_converted_to_a_default_import: r(80003, 2, "Import_may_be_converted_to_a_default_import_80003", "Import may be converted to a default import."),
	JSDoc_types_may_be_moved_to_TypeScript_types: r(80004, 2, "JSDoc_types_may_be_moved_to_TypeScript_types_80004", "JSDoc types may be moved to TypeScript types."),
	require_call_may_be_converted_to_an_import: r(80005, 2, "require_call_may_be_converted_to_an_import_80005", "'require' call may be converted to an import."),
	This_may_be_converted_to_an_async_function: r(80006, 2, "This_may_be_converted_to_an_async_function_80006", "This may be converted to an async function."),
	await_has_no_effect_on_the_type_of_this_expression: r(80007, 2, "await_has_no_effect_on_the_type_of_this_expression_80007", "'await' has no effect on the type of this expression."),
	Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accurately_as_integers: r(80008, 2, "Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accur_80008", "Numeric literals with absolute values equal to 2^53 or greater are too large to be represented accurately as integers."),
	JSDoc_typedef_may_be_converted_to_TypeScript_type: r(80009, 2, "JSDoc_typedef_may_be_converted_to_TypeScript_type_80009", "JSDoc typedef may be converted to TypeScript type."),
	JSDoc_typedefs_may_be_converted_to_TypeScript_types: r(80010, 2, "JSDoc_typedefs_may_be_converted_to_TypeScript_types_80010", "JSDoc typedefs may be converted to TypeScript types."),
	Add_missing_super_call: r(90001, 3, "Add_missing_super_call_90001", "Add missing 'super()' call"),
	Make_super_call_the_first_statement_in_the_constructor: r(90002, 3, "Make_super_call_the_first_statement_in_the_constructor_90002", "Make 'super()' call the first statement in the constructor"),
	Change_extends_to_implements: r(90003, 3, "Change_extends_to_implements_90003", "Change 'extends' to 'implements'"),
	Remove_unused_declaration_for_Colon_0: r(90004, 3, "Remove_unused_declaration_for_Colon_0_90004", "Remove unused declaration for: '{0}'"),
	Remove_import_from_0: r(90005, 3, "Remove_import_from_0_90005", "Remove import from '{0}'"),
	Implement_interface_0: r(90006, 3, "Implement_interface_0_90006", "Implement interface '{0}'"),
	Implement_inherited_abstract_class: r(90007, 3, "Implement_inherited_abstract_class_90007", "Implement inherited abstract class"),
	Add_0_to_unresolved_variable: r(90008, 3, "Add_0_to_unresolved_variable_90008", "Add '{0}.' to unresolved variable"),
	Remove_variable_statement: r(90010, 3, "Remove_variable_statement_90010", "Remove variable statement"),
	Remove_template_tag: r(90011, 3, "Remove_template_tag_90011", "Remove template tag"),
	Remove_type_parameters: r(90012, 3, "Remove_type_parameters_90012", "Remove type parameters"),
	Import_0_from_1: r(90013, 3, "Import_0_from_1_90013", `Import '{0}' from "{1}"`),
	Change_0_to_1: r(90014, 3, "Change_0_to_1_90014", "Change '{0}' to '{1}'"),
	Declare_property_0: r(90016, 3, "Declare_property_0_90016", "Declare property '{0}'"),
	Add_index_signature_for_property_0: r(90017, 3, "Add_index_signature_for_property_0_90017", "Add index signature for property '{0}'"),
	Disable_checking_for_this_file: r(90018, 3, "Disable_checking_for_this_file_90018", "Disable checking for this file"),
	Ignore_this_error_message: r(90019, 3, "Ignore_this_error_message_90019", "Ignore this error message"),
	Initialize_property_0_in_the_constructor: r(90020, 3, "Initialize_property_0_in_the_constructor_90020", "Initialize property '{0}' in the constructor"),
	Initialize_static_property_0: r(90021, 3, "Initialize_static_property_0_90021", "Initialize static property '{0}'"),
	Change_spelling_to_0: r(90022, 3, "Change_spelling_to_0_90022", "Change spelling to '{0}'"),
	Declare_method_0: r(90023, 3, "Declare_method_0_90023", "Declare method '{0}'"),
	Declare_static_method_0: r(90024, 3, "Declare_static_method_0_90024", "Declare static method '{0}'"),
	Prefix_0_with_an_underscore: r(90025, 3, "Prefix_0_with_an_underscore_90025", "Prefix '{0}' with an underscore"),
	Rewrite_as_the_indexed_access_type_0: r(90026, 3, "Rewrite_as_the_indexed_access_type_0_90026", "Rewrite as the indexed access type '{0}'"),
	Declare_static_property_0: r(90027, 3, "Declare_static_property_0_90027", "Declare static property '{0}'"),
	Call_decorator_expression: r(90028, 3, "Call_decorator_expression_90028", "Call decorator expression"),
	Add_async_modifier_to_containing_function: r(90029, 3, "Add_async_modifier_to_containing_function_90029", "Add async modifier to containing function"),
	Replace_infer_0_with_unknown: r(90030, 3, "Replace_infer_0_with_unknown_90030", "Replace 'infer {0}' with 'unknown'"),
	Replace_all_unused_infer_with_unknown: r(90031, 3, "Replace_all_unused_infer_with_unknown_90031", "Replace all unused 'infer' with 'unknown'"),
	Add_parameter_name: r(90034, 3, "Add_parameter_name_90034", "Add parameter name"),
	Declare_private_property_0: r(90035, 3, "Declare_private_property_0_90035", "Declare private property '{0}'"),
	Replace_0_with_Promise_1: r(90036, 3, "Replace_0_with_Promise_1_90036", "Replace '{0}' with 'Promise<{1}>'"),
	Fix_all_incorrect_return_type_of_an_async_functions: r(90037, 3, "Fix_all_incorrect_return_type_of_an_async_functions_90037", "Fix all incorrect return type of an async functions"),
	Declare_private_method_0: r(90038, 3, "Declare_private_method_0_90038", "Declare private method '{0}'"),
	Remove_unused_destructuring_declaration: r(90039, 3, "Remove_unused_destructuring_declaration_90039", "Remove unused destructuring declaration"),
	Remove_unused_declarations_for_Colon_0: r(90041, 3, "Remove_unused_declarations_for_Colon_0_90041", "Remove unused declarations for: '{0}'"),
	Declare_a_private_field_named_0: r(90053, 3, "Declare_a_private_field_named_0_90053", "Declare a private field named '{0}'."),
	Includes_imports_of_types_referenced_by_0: r(90054, 3, "Includes_imports_of_types_referenced_by_0_90054", "Includes imports of types referenced by '{0}'"),
	Remove_type_from_import_declaration_from_0: r(90055, 3, "Remove_type_from_import_declaration_from_0_90055", `Remove 'type' from import declaration from "{0}"`),
	Remove_type_from_import_of_0_from_1: r(90056, 3, "Remove_type_from_import_of_0_from_1_90056", `Remove 'type' from import of '{0}' from "{1}"`),
	Add_import_from_0: r(90057, 3, "Add_import_from_0_90057", "Add import from \"{0}\""),
	Update_import_from_0: r(90058, 3, "Update_import_from_0_90058", "Update import from \"{0}\""),
	Export_0_from_module_1: r(90059, 3, "Export_0_from_module_1_90059", "Export '{0}' from module '{1}'"),
	Export_all_referenced_locals: r(90060, 3, "Export_all_referenced_locals_90060", "Export all referenced locals"),
	Update_modifiers_of_0: r(90061, 3, "Update_modifiers_of_0_90061", "Update modifiers of '{0}'"),
	Add_annotation_of_type_0: r(90062, 3, "Add_annotation_of_type_0_90062", "Add annotation of type '{0}'"),
	Add_return_type_0: r(90063, 3, "Add_return_type_0_90063", "Add return type '{0}'"),
	Extract_base_class_to_variable: r(90064, 3, "Extract_base_class_to_variable_90064", "Extract base class to variable"),
	Extract_default_export_to_variable: r(90065, 3, "Extract_default_export_to_variable_90065", "Extract default export to variable"),
	Extract_binding_expressions_to_variable: r(90066, 3, "Extract_binding_expressions_to_variable_90066", "Extract binding expressions to variable"),
	Add_all_missing_type_annotations: r(90067, 3, "Add_all_missing_type_annotations_90067", "Add all missing type annotations"),
	Add_satisfies_and_an_inline_type_assertion_with_0: r(90068, 3, "Add_satisfies_and_an_inline_type_assertion_with_0_90068", "Add satisfies and an inline type assertion with '{0}'"),
	Extract_to_variable_and_replace_with_0_as_typeof_0: r(90069, 3, "Extract_to_variable_and_replace_with_0_as_typeof_0_90069", "Extract to variable and replace with '{0} as typeof {0}'"),
	Mark_array_literal_as_const: r(90070, 3, "Mark_array_literal_as_const_90070", "Mark array literal as const"),
	Annotate_types_of_properties_expando_function_in_a_namespace: r(90071, 3, "Annotate_types_of_properties_expando_function_in_a_namespace_90071", "Annotate types of properties expando function in a namespace"),
	Convert_function_to_an_ES2015_class: r(95001, 3, "Convert_function_to_an_ES2015_class_95001", "Convert function to an ES2015 class"),
	Convert_0_to_1_in_0: r(95003, 3, "Convert_0_to_1_in_0_95003", "Convert '{0}' to '{1} in {0}'"),
	Extract_to_0_in_1: r(95004, 3, "Extract_to_0_in_1_95004", "Extract to {0} in {1}"),
	Extract_function: r(95005, 3, "Extract_function_95005", "Extract function"),
	Extract_constant: r(95006, 3, "Extract_constant_95006", "Extract constant"),
	Extract_to_0_in_enclosing_scope: r(95007, 3, "Extract_to_0_in_enclosing_scope_95007", "Extract to {0} in enclosing scope"),
	Extract_to_0_in_1_scope: r(95008, 3, "Extract_to_0_in_1_scope_95008", "Extract to {0} in {1} scope"),
	Annotate_with_type_from_JSDoc: r(95009, 3, "Annotate_with_type_from_JSDoc_95009", "Annotate with type from JSDoc"),
	Infer_type_of_0_from_usage: r(95011, 3, "Infer_type_of_0_from_usage_95011", "Infer type of '{0}' from usage"),
	Infer_parameter_types_from_usage: r(95012, 3, "Infer_parameter_types_from_usage_95012", "Infer parameter types from usage"),
	Convert_to_default_import: r(95013, 3, "Convert_to_default_import_95013", "Convert to default import"),
	Install_0: r(95014, 3, "Install_0_95014", "Install '{0}'"),
	Replace_import_with_0: r(95015, 3, "Replace_import_with_0_95015", "Replace import with '{0}'."),
	Use_synthetic_default_member: r(95016, 3, "Use_synthetic_default_member_95016", "Use synthetic 'default' member."),
	Convert_to_ES_module: r(95017, 3, "Convert_to_ES_module_95017", "Convert to ES module"),
	Add_undefined_type_to_property_0: r(95018, 3, "Add_undefined_type_to_property_0_95018", "Add 'undefined' type to property '{0}'"),
	Add_initializer_to_property_0: r(95019, 3, "Add_initializer_to_property_0_95019", "Add initializer to property '{0}'"),
	Add_definite_assignment_assertion_to_property_0: r(95020, 3, "Add_definite_assignment_assertion_to_property_0_95020", "Add definite assignment assertion to property '{0}'"),
	Convert_all_type_literals_to_mapped_type: r(95021, 3, "Convert_all_type_literals_to_mapped_type_95021", "Convert all type literals to mapped type"),
	Add_all_missing_members: r(95022, 3, "Add_all_missing_members_95022", "Add all missing members"),
	Infer_all_types_from_usage: r(95023, 3, "Infer_all_types_from_usage_95023", "Infer all types from usage"),
	Delete_all_unused_declarations: r(95024, 3, "Delete_all_unused_declarations_95024", "Delete all unused declarations"),
	Prefix_all_unused_declarations_with_where_possible: r(95025, 3, "Prefix_all_unused_declarations_with_where_possible_95025", "Prefix all unused declarations with '_' where possible"),
	Fix_all_detected_spelling_errors: r(95026, 3, "Fix_all_detected_spelling_errors_95026", "Fix all detected spelling errors"),
	Add_initializers_to_all_uninitialized_properties: r(95027, 3, "Add_initializers_to_all_uninitialized_properties_95027", "Add initializers to all uninitialized properties"),
	Add_definite_assignment_assertions_to_all_uninitialized_properties: r(95028, 3, "Add_definite_assignment_assertions_to_all_uninitialized_properties_95028", "Add definite assignment assertions to all uninitialized properties"),
	Add_undefined_type_to_all_uninitialized_properties: r(95029, 3, "Add_undefined_type_to_all_uninitialized_properties_95029", "Add undefined type to all uninitialized properties"),
	Change_all_jsdoc_style_types_to_TypeScript: r(95030, 3, "Change_all_jsdoc_style_types_to_TypeScript_95030", "Change all jsdoc-style types to TypeScript"),
	Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types: r(95031, 3, "Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types_95031", "Change all jsdoc-style types to TypeScript (and add '| undefined' to nullable types)"),
	Implement_all_unimplemented_interfaces: r(95032, 3, "Implement_all_unimplemented_interfaces_95032", "Implement all unimplemented interfaces"),
	Install_all_missing_types_packages: r(95033, 3, "Install_all_missing_types_packages_95033", "Install all missing types packages"),
	Rewrite_all_as_indexed_access_types: r(95034, 3, "Rewrite_all_as_indexed_access_types_95034", "Rewrite all as indexed access types"),
	Convert_all_to_default_imports: r(95035, 3, "Convert_all_to_default_imports_95035", "Convert all to default imports"),
	Make_all_super_calls_the_first_statement_in_their_constructor: r(95036, 3, "Make_all_super_calls_the_first_statement_in_their_constructor_95036", "Make all 'super()' calls the first statement in their constructor"),
	Add_qualifier_to_all_unresolved_variables_matching_a_member_name: r(95037, 3, "Add_qualifier_to_all_unresolved_variables_matching_a_member_name_95037", "Add qualifier to all unresolved variables matching a member name"),
	Change_all_extended_interfaces_to_implements: r(95038, 3, "Change_all_extended_interfaces_to_implements_95038", "Change all extended interfaces to 'implements'"),
	Add_all_missing_super_calls: r(95039, 3, "Add_all_missing_super_calls_95039", "Add all missing super calls"),
	Implement_all_inherited_abstract_classes: r(95040, 3, "Implement_all_inherited_abstract_classes_95040", "Implement all inherited abstract classes"),
	Add_all_missing_async_modifiers: r(95041, 3, "Add_all_missing_async_modifiers_95041", "Add all missing 'async' modifiers"),
	Add_ts_ignore_to_all_error_messages: r(95042, 3, "Add_ts_ignore_to_all_error_messages_95042", "Add '@ts-ignore' to all error messages"),
	Annotate_everything_with_types_from_JSDoc: r(95043, 3, "Annotate_everything_with_types_from_JSDoc_95043", "Annotate everything with types from JSDoc"),
	Add_to_all_uncalled_decorators: r(95044, 3, "Add_to_all_uncalled_decorators_95044", "Add '()' to all uncalled decorators"),
	Convert_all_constructor_functions_to_classes: r(95045, 3, "Convert_all_constructor_functions_to_classes_95045", "Convert all constructor functions to classes"),
	Generate_get_and_set_accessors: r(95046, 3, "Generate_get_and_set_accessors_95046", "Generate 'get' and 'set' accessors"),
	Convert_require_to_import: r(95047, 3, "Convert_require_to_import_95047", "Convert 'require' to 'import'"),
	Convert_all_require_to_import: r(95048, 3, "Convert_all_require_to_import_95048", "Convert all 'require' to 'import'"),
	Move_to_a_new_file: r(95049, 3, "Move_to_a_new_file_95049", "Move to a new file"),
	Remove_unreachable_code: r(95050, 3, "Remove_unreachable_code_95050", "Remove unreachable code"),
	Remove_all_unreachable_code: r(95051, 3, "Remove_all_unreachable_code_95051", "Remove all unreachable code"),
	Add_missing_typeof: r(95052, 3, "Add_missing_typeof_95052", "Add missing 'typeof'"),
	Remove_unused_label: r(95053, 3, "Remove_unused_label_95053", "Remove unused label"),
	Remove_all_unused_labels: r(95054, 3, "Remove_all_unused_labels_95054", "Remove all unused labels"),
	Convert_0_to_mapped_object_type: r(95055, 3, "Convert_0_to_mapped_object_type_95055", "Convert '{0}' to mapped object type"),
	Convert_namespace_import_to_named_imports: r(95056, 3, "Convert_namespace_import_to_named_imports_95056", "Convert namespace import to named imports"),
	Convert_named_imports_to_namespace_import: r(95057, 3, "Convert_named_imports_to_namespace_import_95057", "Convert named imports to namespace import"),
	Add_or_remove_braces_in_an_arrow_function: r(95058, 3, "Add_or_remove_braces_in_an_arrow_function_95058", "Add or remove braces in an arrow function"),
	Add_braces_to_arrow_function: r(95059, 3, "Add_braces_to_arrow_function_95059", "Add braces to arrow function"),
	Remove_braces_from_arrow_function: r(95060, 3, "Remove_braces_from_arrow_function_95060", "Remove braces from arrow function"),
	Convert_default_export_to_named_export: r(95061, 3, "Convert_default_export_to_named_export_95061", "Convert default export to named export"),
	Convert_named_export_to_default_export: r(95062, 3, "Convert_named_export_to_default_export_95062", "Convert named export to default export"),
	Add_missing_enum_member_0: r(95063, 3, "Add_missing_enum_member_0_95063", "Add missing enum member '{0}'"),
	Add_all_missing_imports: r(95064, 3, "Add_all_missing_imports_95064", "Add all missing imports"),
	Convert_to_async_function: r(95065, 3, "Convert_to_async_function_95065", "Convert to async function"),
	Convert_all_to_async_functions: r(95066, 3, "Convert_all_to_async_functions_95066", "Convert all to async functions"),
	Add_missing_call_parentheses: r(95067, 3, "Add_missing_call_parentheses_95067", "Add missing call parentheses"),
	Add_all_missing_call_parentheses: r(95068, 3, "Add_all_missing_call_parentheses_95068", "Add all missing call parentheses"),
	Add_unknown_conversion_for_non_overlapping_types: r(95069, 3, "Add_unknown_conversion_for_non_overlapping_types_95069", "Add 'unknown' conversion for non-overlapping types"),
	Add_unknown_to_all_conversions_of_non_overlapping_types: r(95070, 3, "Add_unknown_to_all_conversions_of_non_overlapping_types_95070", "Add 'unknown' to all conversions of non-overlapping types"),
	Add_missing_new_operator_to_call: r(95071, 3, "Add_missing_new_operator_to_call_95071", "Add missing 'new' operator to call"),
	Add_missing_new_operator_to_all_calls: r(95072, 3, "Add_missing_new_operator_to_all_calls_95072", "Add missing 'new' operator to all calls"),
	Add_names_to_all_parameters_without_names: r(95073, 3, "Add_names_to_all_parameters_without_names_95073", "Add names to all parameters without names"),
	Enable_the_experimentalDecorators_option_in_your_configuration_file: r(95074, 3, "Enable_the_experimentalDecorators_option_in_your_configuration_file_95074", "Enable the 'experimentalDecorators' option in your configuration file"),
	Convert_parameters_to_destructured_object: r(95075, 3, "Convert_parameters_to_destructured_object_95075", "Convert parameters to destructured object"),
	Extract_type: r(95077, 3, "Extract_type_95077", "Extract type"),
	Extract_to_type_alias: r(95078, 3, "Extract_to_type_alias_95078", "Extract to type alias"),
	Extract_to_typedef: r(95079, 3, "Extract_to_typedef_95079", "Extract to typedef"),
	Infer_this_type_of_0_from_usage: r(95080, 3, "Infer_this_type_of_0_from_usage_95080", "Infer 'this' type of '{0}' from usage"),
	Add_const_to_unresolved_variable: r(95081, 3, "Add_const_to_unresolved_variable_95081", "Add 'const' to unresolved variable"),
	Add_const_to_all_unresolved_variables: r(95082, 3, "Add_const_to_all_unresolved_variables_95082", "Add 'const' to all unresolved variables"),
	Add_await: r(95083, 3, "Add_await_95083", "Add 'await'"),
	Add_await_to_initializer_for_0: r(95084, 3, "Add_await_to_initializer_for_0_95084", "Add 'await' to initializer for '{0}'"),
	Fix_all_expressions_possibly_missing_await: r(95085, 3, "Fix_all_expressions_possibly_missing_await_95085", "Fix all expressions possibly missing 'await'"),
	Remove_unnecessary_await: r(95086, 3, "Remove_unnecessary_await_95086", "Remove unnecessary 'await'"),
	Remove_all_unnecessary_uses_of_await: r(95087, 3, "Remove_all_unnecessary_uses_of_await_95087", "Remove all unnecessary uses of 'await'"),
	Enable_the_jsx_flag_in_your_configuration_file: r(95088, 3, "Enable_the_jsx_flag_in_your_configuration_file_95088", "Enable the '--jsx' flag in your configuration file"),
	Add_await_to_initializers: r(95089, 3, "Add_await_to_initializers_95089", "Add 'await' to initializers"),
	Extract_to_interface: r(95090, 3, "Extract_to_interface_95090", "Extract to interface"),
	Convert_to_a_bigint_numeric_literal: r(95091, 3, "Convert_to_a_bigint_numeric_literal_95091", "Convert to a bigint numeric literal"),
	Convert_all_to_bigint_numeric_literals: r(95092, 3, "Convert_all_to_bigint_numeric_literals_95092", "Convert all to bigint numeric literals"),
	Convert_const_to_let: r(95093, 3, "Convert_const_to_let_95093", "Convert 'const' to 'let'"),
	Prefix_with_declare: r(95094, 3, "Prefix_with_declare_95094", "Prefix with 'declare'"),
	Prefix_all_incorrect_property_declarations_with_declare: r(95095, 3, "Prefix_all_incorrect_property_declarations_with_declare_95095", "Prefix all incorrect property declarations with 'declare'"),
	Convert_to_template_string: r(95096, 3, "Convert_to_template_string_95096", "Convert to template string"),
	Add_export_to_make_this_file_into_a_module: r(95097, 3, "Add_export_to_make_this_file_into_a_module_95097", "Add 'export {}' to make this file into a module"),
	Set_the_target_option_in_your_configuration_file_to_0: r(95098, 3, "Set_the_target_option_in_your_configuration_file_to_0_95098", "Set the 'target' option in your configuration file to '{0}'"),
	Set_the_module_option_in_your_configuration_file_to_0: r(95099, 3, "Set_the_module_option_in_your_configuration_file_to_0_95099", "Set the 'module' option in your configuration file to '{0}'"),
	Convert_invalid_character_to_its_html_entity_code: r(95100, 3, "Convert_invalid_character_to_its_html_entity_code_95100", "Convert invalid character to its html entity code"),
	Convert_all_invalid_characters_to_HTML_entity_code: r(95101, 3, "Convert_all_invalid_characters_to_HTML_entity_code_95101", "Convert all invalid characters to HTML entity code"),
	Convert_all_const_to_let: r(95102, 3, "Convert_all_const_to_let_95102", "Convert all 'const' to 'let'"),
	Convert_function_expression_0_to_arrow_function: r(95105, 3, "Convert_function_expression_0_to_arrow_function_95105", "Convert function expression '{0}' to arrow function"),
	Convert_function_declaration_0_to_arrow_function: r(95106, 3, "Convert_function_declaration_0_to_arrow_function_95106", "Convert function declaration '{0}' to arrow function"),
	Fix_all_implicit_this_errors: r(95107, 3, "Fix_all_implicit_this_errors_95107", "Fix all implicit-'this' errors"),
	Wrap_invalid_character_in_an_expression_container: r(95108, 3, "Wrap_invalid_character_in_an_expression_container_95108", "Wrap invalid character in an expression container"),
	Wrap_all_invalid_characters_in_an_expression_container: r(95109, 3, "Wrap_all_invalid_characters_in_an_expression_container_95109", "Wrap all invalid characters in an expression container"),
	Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_to_read_more_about_this_file: r(95110, 3, "Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_to_read_more_about_this_file_95110", "Visit https://aka.ms/tsconfig to read more about this file"),
	Add_a_return_statement: r(95111, 3, "Add_a_return_statement_95111", "Add a return statement"),
	Remove_braces_from_arrow_function_body: r(95112, 3, "Remove_braces_from_arrow_function_body_95112", "Remove braces from arrow function body"),
	Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal: r(95113, 3, "Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal_95113", "Wrap the following body with parentheses which should be an object literal"),
	Add_all_missing_return_statement: r(95114, 3, "Add_all_missing_return_statement_95114", "Add all missing return statement"),
	Remove_braces_from_all_arrow_function_bodies_with_relevant_issues: r(95115, 3, "Remove_braces_from_all_arrow_function_bodies_with_relevant_issues_95115", "Remove braces from all arrow function bodies with relevant issues"),
	Wrap_all_object_literal_with_parentheses: r(95116, 3, "Wrap_all_object_literal_with_parentheses_95116", "Wrap all object literal with parentheses"),
	Move_labeled_tuple_element_modifiers_to_labels: r(95117, 3, "Move_labeled_tuple_element_modifiers_to_labels_95117", "Move labeled tuple element modifiers to labels"),
	Convert_overload_list_to_single_signature: r(95118, 3, "Convert_overload_list_to_single_signature_95118", "Convert overload list to single signature"),
	Generate_get_and_set_accessors_for_all_overriding_properties: r(95119, 3, "Generate_get_and_set_accessors_for_all_overriding_properties_95119", "Generate 'get' and 'set' accessors for all overriding properties"),
	Wrap_in_JSX_fragment: r(95120, 3, "Wrap_in_JSX_fragment_95120", "Wrap in JSX fragment"),
	Wrap_all_unparented_JSX_in_JSX_fragment: r(95121, 3, "Wrap_all_unparented_JSX_in_JSX_fragment_95121", "Wrap all unparented JSX in JSX fragment"),
	Convert_arrow_function_or_function_expression: r(95122, 3, "Convert_arrow_function_or_function_expression_95122", "Convert arrow function or function expression"),
	Convert_to_anonymous_function: r(95123, 3, "Convert_to_anonymous_function_95123", "Convert to anonymous function"),
	Convert_to_named_function: r(95124, 3, "Convert_to_named_function_95124", "Convert to named function"),
	Convert_to_arrow_function: r(95125, 3, "Convert_to_arrow_function_95125", "Convert to arrow function"),
	Remove_parentheses: r(95126, 3, "Remove_parentheses_95126", "Remove parentheses"),
	Could_not_find_a_containing_arrow_function: r(95127, 3, "Could_not_find_a_containing_arrow_function_95127", "Could not find a containing arrow function"),
	Containing_function_is_not_an_arrow_function: r(95128, 3, "Containing_function_is_not_an_arrow_function_95128", "Containing function is not an arrow function"),
	Could_not_find_export_statement: r(95129, 3, "Could_not_find_export_statement_95129", "Could not find export statement"),
	This_file_already_has_a_default_export: r(95130, 3, "This_file_already_has_a_default_export_95130", "This file already has a default export"),
	Could_not_find_import_clause: r(95131, 3, "Could_not_find_import_clause_95131", "Could not find import clause"),
	Could_not_find_namespace_import_or_named_imports: r(95132, 3, "Could_not_find_namespace_import_or_named_imports_95132", "Could not find namespace import or named imports"),
	Selection_is_not_a_valid_type_node: r(95133, 3, "Selection_is_not_a_valid_type_node_95133", "Selection is not a valid type node"),
	No_type_could_be_extracted_from_this_type_node: r(95134, 3, "No_type_could_be_extracted_from_this_type_node_95134", "No type could be extracted from this type node"),
	Could_not_find_property_for_which_to_generate_accessor: r(95135, 3, "Could_not_find_property_for_which_to_generate_accessor_95135", "Could not find property for which to generate accessor"),
	Name_is_not_valid: r(95136, 3, "Name_is_not_valid_95136", "Name is not valid"),
	Can_only_convert_property_with_modifier: r(95137, 3, "Can_only_convert_property_with_modifier_95137", "Can only convert property with modifier"),
	Switch_each_misused_0_to_1: r(95138, 3, "Switch_each_misused_0_to_1_95138", "Switch each misused '{0}' to '{1}'"),
	Convert_to_optional_chain_expression: r(95139, 3, "Convert_to_optional_chain_expression_95139", "Convert to optional chain expression"),
	Could_not_find_convertible_access_expression: r(95140, 3, "Could_not_find_convertible_access_expression_95140", "Could not find convertible access expression"),
	Could_not_find_matching_access_expressions: r(95141, 3, "Could_not_find_matching_access_expressions_95141", "Could not find matching access expressions"),
	Can_only_convert_logical_AND_access_chains: r(95142, 3, "Can_only_convert_logical_AND_access_chains_95142", "Can only convert logical AND access chains"),
	Add_void_to_Promise_resolved_without_a_value: r(95143, 3, "Add_void_to_Promise_resolved_without_a_value_95143", "Add 'void' to Promise resolved without a value"),
	Add_void_to_all_Promises_resolved_without_a_value: r(95144, 3, "Add_void_to_all_Promises_resolved_without_a_value_95144", "Add 'void' to all Promises resolved without a value"),
	Use_element_access_for_0: r(95145, 3, "Use_element_access_for_0_95145", "Use element access for '{0}'"),
	Use_element_access_for_all_undeclared_properties: r(95146, 3, "Use_element_access_for_all_undeclared_properties_95146", "Use element access for all undeclared properties."),
	Delete_all_unused_imports: r(95147, 3, "Delete_all_unused_imports_95147", "Delete all unused imports"),
	Infer_function_return_type: r(95148, 3, "Infer_function_return_type_95148", "Infer function return type"),
	Return_type_must_be_inferred_from_a_function: r(95149, 3, "Return_type_must_be_inferred_from_a_function_95149", "Return type must be inferred from a function"),
	Could_not_determine_function_return_type: r(95150, 3, "Could_not_determine_function_return_type_95150", "Could not determine function return type"),
	Could_not_convert_to_arrow_function: r(95151, 3, "Could_not_convert_to_arrow_function_95151", "Could not convert to arrow function"),
	Could_not_convert_to_named_function: r(95152, 3, "Could_not_convert_to_named_function_95152", "Could not convert to named function"),
	Could_not_convert_to_anonymous_function: r(95153, 3, "Could_not_convert_to_anonymous_function_95153", "Could not convert to anonymous function"),
	Can_only_convert_string_concatenations_and_string_literals: r(95154, 3, "Can_only_convert_string_concatenations_and_string_literals_95154", "Can only convert string concatenations and string literals"),
	Selection_is_not_a_valid_statement_or_statements: r(95155, 3, "Selection_is_not_a_valid_statement_or_statements_95155", "Selection is not a valid statement or statements"),
	Add_missing_function_declaration_0: r(95156, 3, "Add_missing_function_declaration_0_95156", "Add missing function declaration '{0}'"),
	Add_all_missing_function_declarations: r(95157, 3, "Add_all_missing_function_declarations_95157", "Add all missing function declarations"),
	Method_not_implemented: r(95158, 3, "Method_not_implemented_95158", "Method not implemented."),
	Function_not_implemented: r(95159, 3, "Function_not_implemented_95159", "Function not implemented."),
	Add_override_modifier: r(95160, 3, "Add_override_modifier_95160", "Add 'override' modifier"),
	Remove_override_modifier: r(95161, 3, "Remove_override_modifier_95161", "Remove 'override' modifier"),
	Add_all_missing_override_modifiers: r(95162, 3, "Add_all_missing_override_modifiers_95162", "Add all missing 'override' modifiers"),
	Remove_all_unnecessary_override_modifiers: r(95163, 3, "Remove_all_unnecessary_override_modifiers_95163", "Remove all unnecessary 'override' modifiers"),
	Can_only_convert_named_export: r(95164, 3, "Can_only_convert_named_export_95164", "Can only convert named export"),
	Add_missing_properties: r(95165, 3, "Add_missing_properties_95165", "Add missing properties"),
	Add_all_missing_properties: r(95166, 3, "Add_all_missing_properties_95166", "Add all missing properties"),
	Add_missing_attributes: r(95167, 3, "Add_missing_attributes_95167", "Add missing attributes"),
	Add_all_missing_attributes: r(95168, 3, "Add_all_missing_attributes_95168", "Add all missing attributes"),
	Add_undefined_to_optional_property_type: r(95169, 3, "Add_undefined_to_optional_property_type_95169", "Add 'undefined' to optional property type"),
	Convert_named_imports_to_default_import: r(95170, 3, "Convert_named_imports_to_default_import_95170", "Convert named imports to default import"),
	Delete_unused_param_tag_0: r(95171, 3, "Delete_unused_param_tag_0_95171", "Delete unused '@param' tag '{0}'"),
	Delete_all_unused_param_tags: r(95172, 3, "Delete_all_unused_param_tags_95172", "Delete all unused '@param' tags"),
	Rename_param_tag_name_0_to_1: r(95173, 3, "Rename_param_tag_name_0_to_1_95173", "Rename '@param' tag name '{0}' to '{1}'"),
	Use_0: r(95174, 3, "Use_0_95174", "Use `{0}`."),
	Use_Number_isNaN_in_all_conditions: r(95175, 3, "Use_Number_isNaN_in_all_conditions_95175", "Use `Number.isNaN` in all conditions."),
	Convert_typedef_to_TypeScript_type: r(95176, 3, "Convert_typedef_to_TypeScript_type_95176", "Convert typedef to TypeScript type."),
	Convert_all_typedef_to_TypeScript_types: r(95177, 3, "Convert_all_typedef_to_TypeScript_types_95177", "Convert all typedef to TypeScript types."),
	Move_to_file: r(95178, 3, "Move_to_file_95178", "Move to file"),
	Cannot_move_to_file_selected_file_is_invalid: r(95179, 3, "Cannot_move_to_file_selected_file_is_invalid_95179", "Cannot move to file, selected file is invalid"),
	Use_import_type: r(95180, 3, "Use_import_type_95180", "Use 'import type'"),
	Use_type_0: r(95181, 3, "Use_type_0_95181", "Use 'type {0}'"),
	Fix_all_with_type_only_imports: r(95182, 3, "Fix_all_with_type_only_imports_95182", "Fix all with type-only imports"),
	Cannot_move_statements_to_the_selected_file: r(95183, 3, "Cannot_move_statements_to_the_selected_file_95183", "Cannot move statements to the selected file"),
	Inline_variable: r(95184, 3, "Inline_variable_95184", "Inline variable"),
	Could_not_find_variable_to_inline: r(95185, 3, "Could_not_find_variable_to_inline_95185", "Could not find variable to inline."),
	Variables_with_multiple_declarations_cannot_be_inlined: r(95186, 3, "Variables_with_multiple_declarations_cannot_be_inlined_95186", "Variables with multiple declarations cannot be inlined."),
	Add_missing_comma_for_object_member_completion_0: r(95187, 3, "Add_missing_comma_for_object_member_completion_0_95187", "Add missing comma for object member completion '{0}'."),
	Add_missing_parameter_to_0: r(95188, 3, "Add_missing_parameter_to_0_95188", "Add missing parameter to '{0}'"),
	Add_missing_parameters_to_0: r(95189, 3, "Add_missing_parameters_to_0_95189", "Add missing parameters to '{0}'"),
	Add_all_missing_parameters: r(95190, 3, "Add_all_missing_parameters_95190", "Add all missing parameters"),
	Add_optional_parameter_to_0: r(95191, 3, "Add_optional_parameter_to_0_95191", "Add optional parameter to '{0}'"),
	Add_optional_parameters_to_0: r(95192, 3, "Add_optional_parameters_to_0_95192", "Add optional parameters to '{0}'"),
	Add_all_optional_parameters: r(95193, 3, "Add_all_optional_parameters_95193", "Add all optional parameters"),
	Wrap_in_parentheses: r(95194, 3, "Wrap_in_parentheses_95194", "Wrap in parentheses"),
	Wrap_all_invalid_decorator_expressions_in_parentheses: r(95195, 3, "Wrap_all_invalid_decorator_expressions_in_parentheses_95195", "Wrap all invalid decorator expressions in parentheses"),
	Add_resolution_mode_import_attribute: r(95196, 3, "Add_resolution_mode_import_attribute_95196", "Add 'resolution-mode' import attribute"),
	Add_resolution_mode_import_attribute_to_all_type_only_imports_that_need_it: r(95197, 3, "Add_resolution_mode_import_attribute_to_all_type_only_imports_that_need_it_95197", "Add 'resolution-mode' import attribute to all type-only imports that need it"),
	No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer: r(18004, 1, "No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer_18004", "No value exists in scope for the shorthand property '{0}'. Either declare one or provide an initializer."),
	Classes_may_not_have_a_field_named_constructor: r(18006, 1, "Classes_may_not_have_a_field_named_constructor_18006", "Classes may not have a field named 'constructor'."),
	JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array: r(18007, 1, "JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array_18007", "JSX expressions may not use the comma operator. Did you mean to write an array?"),
	Private_identifiers_cannot_be_used_as_parameters: r(18009, 1, "Private_identifiers_cannot_be_used_as_parameters_18009", "Private identifiers cannot be used as parameters."),
	An_accessibility_modifier_cannot_be_used_with_a_private_identifier: r(18010, 1, "An_accessibility_modifier_cannot_be_used_with_a_private_identifier_18010", "An accessibility modifier cannot be used with a private identifier."),
	The_operand_of_a_delete_operator_cannot_be_a_private_identifier: r(18011, 1, "The_operand_of_a_delete_operator_cannot_be_a_private_identifier_18011", "The operand of a 'delete' operator cannot be a private identifier."),
	constructor_is_a_reserved_word: r(18012, 1, "constructor_is_a_reserved_word_18012", "'#constructor' is a reserved word."),
	Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier: r(18013, 1, "Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier_18013", "Property '{0}' is not accessible outside class '{1}' because it has a private identifier."),
	The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_private_identifier_with_the_same_spelling: r(18014, 1, "The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_priv_18014", "The property '{0}' cannot be accessed on type '{1}' within this class because it is shadowed by another private identifier with the same spelling."),
	Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2: r(18015, 1, "Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2_18015", "Property '{0}' in type '{1}' refers to a different member that cannot be accessed from within type '{2}'."),
	Private_identifiers_are_not_allowed_outside_class_bodies: r(18016, 1, "Private_identifiers_are_not_allowed_outside_class_bodies_18016", "Private identifiers are not allowed outside class bodies."),
	The_shadowing_declaration_of_0_is_defined_here: r(18017, 1, "The_shadowing_declaration_of_0_is_defined_here_18017", "The shadowing declaration of '{0}' is defined here"),
	The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here: r(18018, 1, "The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here_18018", "The declaration of '{0}' that you probably intended to use is defined here"),
	_0_modifier_cannot_be_used_with_a_private_identifier: r(18019, 1, "_0_modifier_cannot_be_used_with_a_private_identifier_18019", "'{0}' modifier cannot be used with a private identifier."),
	An_enum_member_cannot_be_named_with_a_private_identifier: r(18024, 1, "An_enum_member_cannot_be_named_with_a_private_identifier_18024", "An enum member cannot be named with a private identifier."),
	can_only_be_used_at_the_start_of_a_file: r(18026, 1, "can_only_be_used_at_the_start_of_a_file_18026", "'#!' can only be used at the start of a file."),
	Compiler_reserves_name_0_when_emitting_private_identifier_downlevel: r(18027, 1, "Compiler_reserves_name_0_when_emitting_private_identifier_downlevel_18027", "Compiler reserves name '{0}' when emitting private identifier downlevel."),
	Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher: r(18028, 1, "Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher_18028", "Private identifiers are only available when targeting ECMAScript 2015 and higher."),
	Private_identifiers_are_not_allowed_in_variable_declarations: r(18029, 1, "Private_identifiers_are_not_allowed_in_variable_declarations_18029", "Private identifiers are not allowed in variable declarations."),
	An_optional_chain_cannot_contain_private_identifiers: r(18030, 1, "An_optional_chain_cannot_contain_private_identifiers_18030", "An optional chain cannot contain private identifiers."),
	The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituents: r(18031, 1, "The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituent_18031", "The intersection '{0}' was reduced to 'never' because property '{1}' has conflicting types in some constituents."),
	The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_private_in_some: r(18032, 1, "The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_pr_18032", "The intersection '{0}' was reduced to 'never' because property '{1}' exists in multiple constituents and is private in some."),
	Type_0_is_not_assignable_to_type_1_as_required_for_computed_enum_member_values: r(18033, 1, "Type_0_is_not_assignable_to_type_1_as_required_for_computed_enum_member_values_18033", "Type '{0}' is not assignable to type '{1}' as required for computed enum member values."),
	Specify_the_JSX_fragment_factory_function_to_use_when_targeting_react_JSX_emit_with_jsxFactory_compiler_option_is_specified_e_g_Fragment: r(18034, 3, "Specify_the_JSX_fragment_factory_function_to_use_when_targeting_react_JSX_emit_with_jsxFactory_compi_18034", "Specify the JSX fragment factory function to use when targeting 'react' JSX emit with 'jsxFactory' compiler option is specified, e.g. 'Fragment'."),
	Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name: r(18035, 1, "Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name_18035", "Invalid value for 'jsxFragmentFactory'. '{0}' is not a valid identifier or qualified-name."),
	Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_decorator: r(18036, 1, "Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_dec_18036", "Class decorators can't be used with static private identifier. Consider removing the experimental decorator."),
	await_expression_cannot_be_used_inside_a_class_static_block: r(18037, 1, "await_expression_cannot_be_used_inside_a_class_static_block_18037", "'await' expression cannot be used inside a class static block."),
	for_await_loops_cannot_be_used_inside_a_class_static_block: r(18038, 1, "for_await_loops_cannot_be_used_inside_a_class_static_block_18038", "'for await' loops cannot be used inside a class static block."),
	Invalid_use_of_0_It_cannot_be_used_inside_a_class_static_block: r(18039, 1, "Invalid_use_of_0_It_cannot_be_used_inside_a_class_static_block_18039", "Invalid use of '{0}'. It cannot be used inside a class static block."),
	A_return_statement_cannot_be_used_inside_a_class_static_block: r(18041, 1, "A_return_statement_cannot_be_used_inside_a_class_static_block_18041", "A 'return' statement cannot be used inside a class static block."),
	_0_is_a_type_and_cannot_be_imported_in_JavaScript_files_Use_1_in_a_JSDoc_type_annotation: r(18042, 1, "_0_is_a_type_and_cannot_be_imported_in_JavaScript_files_Use_1_in_a_JSDoc_type_annotation_18042", "'{0}' is a type and cannot be imported in JavaScript files. Use '{1}' in a JSDoc type annotation."),
	Types_cannot_appear_in_export_declarations_in_JavaScript_files: r(18043, 1, "Types_cannot_appear_in_export_declarations_in_JavaScript_files_18043", "Types cannot appear in export declarations in JavaScript files."),
	_0_is_automatically_exported_here: r(18044, 3, "_0_is_automatically_exported_here_18044", "'{0}' is automatically exported here."),
	Properties_with_the_accessor_modifier_are_only_available_when_targeting_ECMAScript_2015_and_higher: r(18045, 1, "Properties_with_the_accessor_modifier_are_only_available_when_targeting_ECMAScript_2015_and_higher_18045", "Properties with the 'accessor' modifier are only available when targeting ECMAScript 2015 and higher."),
	_0_is_of_type_unknown: r(18046, 1, "_0_is_of_type_unknown_18046", "'{0}' is of type 'unknown'."),
	_0_is_possibly_null: r(18047, 1, "_0_is_possibly_null_18047", "'{0}' is possibly 'null'."),
	_0_is_possibly_undefined: r(18048, 1, "_0_is_possibly_undefined_18048", "'{0}' is possibly 'undefined'."),
	_0_is_possibly_null_or_undefined: r(18049, 1, "_0_is_possibly_null_or_undefined_18049", "'{0}' is possibly 'null' or 'undefined'."),
	The_value_0_cannot_be_used_here: r(18050, 1, "The_value_0_cannot_be_used_here_18050", "The value '{0}' cannot be used here."),
	Compiler_option_0_cannot_be_given_an_empty_string: r(18051, 1, "Compiler_option_0_cannot_be_given_an_empty_string_18051", "Compiler option '{0}' cannot be given an empty string."),
	Its_type_0_is_not_a_valid_JSX_element_type: r(18053, 1, "Its_type_0_is_not_a_valid_JSX_element_type_18053", "Its type '{0}' is not a valid JSX element type."),
	await_using_statements_cannot_be_used_inside_a_class_static_block: r(18054, 1, "await_using_statements_cannot_be_used_inside_a_class_static_block_18054", "'await using' statements cannot be used inside a class static block."),
	_0_has_a_string_type_but_must_have_syntactically_recognizable_string_syntax_when_isolatedModules_is_enabled: r(18055, 1, "_0_has_a_string_type_but_must_have_syntactically_recognizable_string_syntax_when_isolatedModules_is__18055", "'{0}' has a string type, but must have syntactically recognizable string syntax when 'isolatedModules' is enabled."),
	Enum_member_following_a_non_literal_numeric_member_must_have_an_initializer_when_isolatedModules_is_enabled: r(18056, 1, "Enum_member_following_a_non_literal_numeric_member_must_have_an_initializer_when_isolatedModules_is__18056", "Enum member following a non-literal numeric member must have an initializer when 'isolatedModules' is enabled."),
	String_literal_import_and_export_names_are_not_supported_when_the_module_flag_is_set_to_es2015_or_es2020: r(18057, 1, "String_literal_import_and_export_names_are_not_supported_when_the_module_flag_is_set_to_es2015_or_es_18057", "String literal import and export names are not supported when the '--module' flag is set to 'es2015' or 'es2020'."),
	Default_imports_are_not_allowed_in_a_deferred_import: r(18058, 1, "Default_imports_are_not_allowed_in_a_deferred_import_18058", "Default imports are not allowed in a deferred import."),
	Named_imports_are_not_allowed_in_a_deferred_import: r(18059, 1, "Named_imports_are_not_allowed_in_a_deferred_import_18059", "Named imports are not allowed in a deferred import."),
	Deferred_imports_are_only_supported_when_the_module_flag_is_set_to_esnext_or_preserve: r(18060, 1, "Deferred_imports_are_only_supported_when_the_module_flag_is_set_to_esnext_or_preserve_18060", "Deferred imports are only supported when the '--module' flag is set to 'esnext' or 'preserve'."),
	_0_is_not_a_valid_meta_property_for_keyword_import_Did_you_mean_meta_or_defer: r(18061, 1, "_0_is_not_a_valid_meta_property_for_keyword_import_Did_you_mean_meta_or_defer_18061", "'{0}' is not a valid meta-property for keyword 'import'. Did you mean 'meta' or 'defer'?")
};
function St(e) {
	return e >= 80;
}
function Vy(e) {
	return e === 32 || St(e);
}
var tf = {
	abstract: 128,
	accessor: 129,
	any: 133,
	as: 130,
	asserts: 131,
	assert: 132,
	bigint: 163,
	boolean: 136,
	break: 83,
	case: 84,
	catch: 85,
	class: 86,
	continue: 88,
	const: 87,
	constructor: 137,
	debugger: 89,
	declare: 138,
	default: 90,
	defer: 166,
	delete: 91,
	do: 92,
	else: 93,
	enum: 94,
	export: 95,
	extends: 96,
	false: 97,
	finally: 98,
	for: 99,
	from: 161,
	function: 100,
	get: 139,
	if: 101,
	implements: 119,
	import: 102,
	in: 103,
	infer: 140,
	instanceof: 104,
	interface: 120,
	intrinsic: 141,
	is: 142,
	keyof: 143,
	let: 121,
	module: 144,
	namespace: 145,
	never: 146,
	new: 105,
	null: 106,
	number: 150,
	object: 151,
	package: 122,
	private: 123,
	protected: 124,
	public: 125,
	override: 164,
	out: 147,
	readonly: 148,
	require: 149,
	global: 162,
	return: 107,
	satisfies: 152,
	set: 153,
	static: 126,
	string: 154,
	super: 108,
	switch: 109,
	symbol: 155,
	this: 110,
	throw: 111,
	true: 112,
	try: 113,
	type: 156,
	typeof: 114,
	undefined: 157,
	unique: 158,
	unknown: 159,
	using: 160,
	var: 115,
	void: 116,
	while: 117,
	with: 118,
	yield: 127,
	async: 134,
	await: 135,
	of: 165
}, Wy = new Map(Object.entries(tf)), Lm = new Map(Object.entries({
	...tf,
	"{": 19,
	"}": 20,
	"(": 21,
	")": 22,
	"[": 23,
	"]": 24,
	".": 25,
	"...": 26,
	";": 27,
	",": 28,
	"<": 30,
	">": 32,
	"<=": 33,
	">=": 34,
	"==": 35,
	"!=": 36,
	"===": 37,
	"!==": 38,
	"=>": 39,
	"+": 40,
	"-": 41,
	"**": 43,
	"*": 42,
	"/": 44,
	"%": 45,
	"++": 46,
	"--": 47,
	"<<": 48,
	"</": 31,
	">>": 49,
	">>>": 50,
	"&": 51,
	"|": 52,
	"^": 53,
	"!": 54,
	"~": 55,
	"&&": 56,
	"||": 57,
	"?": 58,
	"??": 61,
	"?.": 29,
	":": 59,
	"=": 64,
	"+=": 65,
	"-=": 66,
	"*=": 67,
	"**=": 68,
	"/=": 69,
	"%=": 70,
	"<<=": 71,
	">>=": 72,
	">>>=": 73,
	"&=": 74,
	"|=": 75,
	"^=": 79,
	"||=": 76,
	"&&=": 77,
	"??=": 78,
	"@": 60,
	"#": 63,
	"`": 62
})), Jm = new Map([
	[100, 1],
	[103, 2],
	[105, 4],
	[109, 8],
	[115, 16],
	[117, 32],
	[118, 64],
	[121, 128]
]), Gy = new Map([
	[1, $s.RegularExpressionFlagsHasIndices],
	[16, $s.RegularExpressionFlagsDotAll],
	[32, $s.RegularExpressionFlagsUnicode],
	[64, $s.RegularExpressionFlagsUnicodeSets],
	[128, $s.RegularExpressionFlagsSticky]
]), Yy = [
	170,
	170,
	181,
	181,
	186,
	186,
	192,
	214,
	216,
	246,
	248,
	705,
	710,
	721,
	736,
	740,
	748,
	748,
	750,
	750,
	880,
	884,
	886,
	887,
	890,
	893,
	902,
	902,
	904,
	906,
	908,
	908,
	910,
	929,
	931,
	1013,
	1015,
	1153,
	1162,
	1319,
	1329,
	1366,
	1369,
	1369,
	1377,
	1415,
	1488,
	1514,
	1520,
	1522,
	1568,
	1610,
	1646,
	1647,
	1649,
	1747,
	1749,
	1749,
	1765,
	1766,
	1774,
	1775,
	1786,
	1788,
	1791,
	1791,
	1808,
	1808,
	1810,
	1839,
	1869,
	1957,
	1969,
	1969,
	1994,
	2026,
	2036,
	2037,
	2042,
	2042,
	2048,
	2069,
	2074,
	2074,
	2084,
	2084,
	2088,
	2088,
	2112,
	2136,
	2208,
	2208,
	2210,
	2220,
	2308,
	2361,
	2365,
	2365,
	2384,
	2384,
	2392,
	2401,
	2417,
	2423,
	2425,
	2431,
	2437,
	2444,
	2447,
	2448,
	2451,
	2472,
	2474,
	2480,
	2482,
	2482,
	2486,
	2489,
	2493,
	2493,
	2510,
	2510,
	2524,
	2525,
	2527,
	2529,
	2544,
	2545,
	2565,
	2570,
	2575,
	2576,
	2579,
	2600,
	2602,
	2608,
	2610,
	2611,
	2613,
	2614,
	2616,
	2617,
	2649,
	2652,
	2654,
	2654,
	2674,
	2676,
	2693,
	2701,
	2703,
	2705,
	2707,
	2728,
	2730,
	2736,
	2738,
	2739,
	2741,
	2745,
	2749,
	2749,
	2768,
	2768,
	2784,
	2785,
	2821,
	2828,
	2831,
	2832,
	2835,
	2856,
	2858,
	2864,
	2866,
	2867,
	2869,
	2873,
	2877,
	2877,
	2908,
	2909,
	2911,
	2913,
	2929,
	2929,
	2947,
	2947,
	2949,
	2954,
	2958,
	2960,
	2962,
	2965,
	2969,
	2970,
	2972,
	2972,
	2974,
	2975,
	2979,
	2980,
	2984,
	2986,
	2990,
	3001,
	3024,
	3024,
	3077,
	3084,
	3086,
	3088,
	3090,
	3112,
	3114,
	3123,
	3125,
	3129,
	3133,
	3133,
	3160,
	3161,
	3168,
	3169,
	3205,
	3212,
	3214,
	3216,
	3218,
	3240,
	3242,
	3251,
	3253,
	3257,
	3261,
	3261,
	3294,
	3294,
	3296,
	3297,
	3313,
	3314,
	3333,
	3340,
	3342,
	3344,
	3346,
	3386,
	3389,
	3389,
	3406,
	3406,
	3424,
	3425,
	3450,
	3455,
	3461,
	3478,
	3482,
	3505,
	3507,
	3515,
	3517,
	3517,
	3520,
	3526,
	3585,
	3632,
	3634,
	3635,
	3648,
	3654,
	3713,
	3714,
	3716,
	3716,
	3719,
	3720,
	3722,
	3722,
	3725,
	3725,
	3732,
	3735,
	3737,
	3743,
	3745,
	3747,
	3749,
	3749,
	3751,
	3751,
	3754,
	3755,
	3757,
	3760,
	3762,
	3763,
	3773,
	3773,
	3776,
	3780,
	3782,
	3782,
	3804,
	3807,
	3840,
	3840,
	3904,
	3911,
	3913,
	3948,
	3976,
	3980,
	4096,
	4138,
	4159,
	4159,
	4176,
	4181,
	4186,
	4189,
	4193,
	4193,
	4197,
	4198,
	4206,
	4208,
	4213,
	4225,
	4238,
	4238,
	4256,
	4293,
	4295,
	4295,
	4301,
	4301,
	4304,
	4346,
	4348,
	4680,
	4682,
	4685,
	4688,
	4694,
	4696,
	4696,
	4698,
	4701,
	4704,
	4744,
	4746,
	4749,
	4752,
	4784,
	4786,
	4789,
	4792,
	4798,
	4800,
	4800,
	4802,
	4805,
	4808,
	4822,
	4824,
	4880,
	4882,
	4885,
	4888,
	4954,
	4992,
	5007,
	5024,
	5108,
	5121,
	5740,
	5743,
	5759,
	5761,
	5786,
	5792,
	5866,
	5870,
	5872,
	5888,
	5900,
	5902,
	5905,
	5920,
	5937,
	5952,
	5969,
	5984,
	5996,
	5998,
	6e3,
	6016,
	6067,
	6103,
	6103,
	6108,
	6108,
	6176,
	6263,
	6272,
	6312,
	6314,
	6314,
	6320,
	6389,
	6400,
	6428,
	6480,
	6509,
	6512,
	6516,
	6528,
	6571,
	6593,
	6599,
	6656,
	6678,
	6688,
	6740,
	6823,
	6823,
	6917,
	6963,
	6981,
	6987,
	7043,
	7072,
	7086,
	7087,
	7098,
	7141,
	7168,
	7203,
	7245,
	7247,
	7258,
	7293,
	7401,
	7404,
	7406,
	7409,
	7413,
	7414,
	7424,
	7615,
	7680,
	7957,
	7960,
	7965,
	7968,
	8005,
	8008,
	8013,
	8016,
	8023,
	8025,
	8025,
	8027,
	8027,
	8029,
	8029,
	8031,
	8061,
	8064,
	8116,
	8118,
	8124,
	8126,
	8126,
	8130,
	8132,
	8134,
	8140,
	8144,
	8147,
	8150,
	8155,
	8160,
	8172,
	8178,
	8180,
	8182,
	8188,
	8305,
	8305,
	8319,
	8319,
	8336,
	8348,
	8450,
	8450,
	8455,
	8455,
	8458,
	8467,
	8469,
	8469,
	8473,
	8477,
	8484,
	8484,
	8486,
	8486,
	8488,
	8488,
	8490,
	8493,
	8495,
	8505,
	8508,
	8511,
	8517,
	8521,
	8526,
	8526,
	8544,
	8584,
	11264,
	11310,
	11312,
	11358,
	11360,
	11492,
	11499,
	11502,
	11506,
	11507,
	11520,
	11557,
	11559,
	11559,
	11565,
	11565,
	11568,
	11623,
	11631,
	11631,
	11648,
	11670,
	11680,
	11686,
	11688,
	11694,
	11696,
	11702,
	11704,
	11710,
	11712,
	11718,
	11720,
	11726,
	11728,
	11734,
	11736,
	11742,
	11823,
	11823,
	12293,
	12295,
	12321,
	12329,
	12337,
	12341,
	12344,
	12348,
	12353,
	12438,
	12445,
	12447,
	12449,
	12538,
	12540,
	12543,
	12549,
	12589,
	12593,
	12686,
	12704,
	12730,
	12784,
	12799,
	13312,
	19893,
	19968,
	40908,
	40960,
	42124,
	42192,
	42237,
	42240,
	42508,
	42512,
	42527,
	42538,
	42539,
	42560,
	42606,
	42623,
	42647,
	42656,
	42735,
	42775,
	42783,
	42786,
	42888,
	42891,
	42894,
	42896,
	42899,
	42912,
	42922,
	43e3,
	43009,
	43011,
	43013,
	43015,
	43018,
	43020,
	43042,
	43072,
	43123,
	43138,
	43187,
	43250,
	43255,
	43259,
	43259,
	43274,
	43301,
	43312,
	43334,
	43360,
	43388,
	43396,
	43442,
	43471,
	43471,
	43520,
	43560,
	43584,
	43586,
	43588,
	43595,
	43616,
	43638,
	43642,
	43642,
	43648,
	43695,
	43697,
	43697,
	43701,
	43702,
	43705,
	43709,
	43712,
	43712,
	43714,
	43714,
	43739,
	43741,
	43744,
	43754,
	43762,
	43764,
	43777,
	43782,
	43785,
	43790,
	43793,
	43798,
	43808,
	43814,
	43816,
	43822,
	43968,
	44002,
	44032,
	55203,
	55216,
	55238,
	55243,
	55291,
	63744,
	64109,
	64112,
	64217,
	64256,
	64262,
	64275,
	64279,
	64285,
	64285,
	64287,
	64296,
	64298,
	64310,
	64312,
	64316,
	64318,
	64318,
	64320,
	64321,
	64323,
	64324,
	64326,
	64433,
	64467,
	64829,
	64848,
	64911,
	64914,
	64967,
	65008,
	65019,
	65136,
	65140,
	65142,
	65276,
	65313,
	65338,
	65345,
	65370,
	65382,
	65470,
	65474,
	65479,
	65482,
	65487,
	65490,
	65495,
	65498,
	65500
], Hy = [
	170,
	170,
	181,
	181,
	186,
	186,
	192,
	214,
	216,
	246,
	248,
	705,
	710,
	721,
	736,
	740,
	748,
	748,
	750,
	750,
	768,
	884,
	886,
	887,
	890,
	893,
	902,
	902,
	904,
	906,
	908,
	908,
	910,
	929,
	931,
	1013,
	1015,
	1153,
	1155,
	1159,
	1162,
	1319,
	1329,
	1366,
	1369,
	1369,
	1377,
	1415,
	1425,
	1469,
	1471,
	1471,
	1473,
	1474,
	1476,
	1477,
	1479,
	1479,
	1488,
	1514,
	1520,
	1522,
	1552,
	1562,
	1568,
	1641,
	1646,
	1747,
	1749,
	1756,
	1759,
	1768,
	1770,
	1788,
	1791,
	1791,
	1808,
	1866,
	1869,
	1969,
	1984,
	2037,
	2042,
	2042,
	2048,
	2093,
	2112,
	2139,
	2208,
	2208,
	2210,
	2220,
	2276,
	2302,
	2304,
	2403,
	2406,
	2415,
	2417,
	2423,
	2425,
	2431,
	2433,
	2435,
	2437,
	2444,
	2447,
	2448,
	2451,
	2472,
	2474,
	2480,
	2482,
	2482,
	2486,
	2489,
	2492,
	2500,
	2503,
	2504,
	2507,
	2510,
	2519,
	2519,
	2524,
	2525,
	2527,
	2531,
	2534,
	2545,
	2561,
	2563,
	2565,
	2570,
	2575,
	2576,
	2579,
	2600,
	2602,
	2608,
	2610,
	2611,
	2613,
	2614,
	2616,
	2617,
	2620,
	2620,
	2622,
	2626,
	2631,
	2632,
	2635,
	2637,
	2641,
	2641,
	2649,
	2652,
	2654,
	2654,
	2662,
	2677,
	2689,
	2691,
	2693,
	2701,
	2703,
	2705,
	2707,
	2728,
	2730,
	2736,
	2738,
	2739,
	2741,
	2745,
	2748,
	2757,
	2759,
	2761,
	2763,
	2765,
	2768,
	2768,
	2784,
	2787,
	2790,
	2799,
	2817,
	2819,
	2821,
	2828,
	2831,
	2832,
	2835,
	2856,
	2858,
	2864,
	2866,
	2867,
	2869,
	2873,
	2876,
	2884,
	2887,
	2888,
	2891,
	2893,
	2902,
	2903,
	2908,
	2909,
	2911,
	2915,
	2918,
	2927,
	2929,
	2929,
	2946,
	2947,
	2949,
	2954,
	2958,
	2960,
	2962,
	2965,
	2969,
	2970,
	2972,
	2972,
	2974,
	2975,
	2979,
	2980,
	2984,
	2986,
	2990,
	3001,
	3006,
	3010,
	3014,
	3016,
	3018,
	3021,
	3024,
	3024,
	3031,
	3031,
	3046,
	3055,
	3073,
	3075,
	3077,
	3084,
	3086,
	3088,
	3090,
	3112,
	3114,
	3123,
	3125,
	3129,
	3133,
	3140,
	3142,
	3144,
	3146,
	3149,
	3157,
	3158,
	3160,
	3161,
	3168,
	3171,
	3174,
	3183,
	3202,
	3203,
	3205,
	3212,
	3214,
	3216,
	3218,
	3240,
	3242,
	3251,
	3253,
	3257,
	3260,
	3268,
	3270,
	3272,
	3274,
	3277,
	3285,
	3286,
	3294,
	3294,
	3296,
	3299,
	3302,
	3311,
	3313,
	3314,
	3330,
	3331,
	3333,
	3340,
	3342,
	3344,
	3346,
	3386,
	3389,
	3396,
	3398,
	3400,
	3402,
	3406,
	3415,
	3415,
	3424,
	3427,
	3430,
	3439,
	3450,
	3455,
	3458,
	3459,
	3461,
	3478,
	3482,
	3505,
	3507,
	3515,
	3517,
	3517,
	3520,
	3526,
	3530,
	3530,
	3535,
	3540,
	3542,
	3542,
	3544,
	3551,
	3570,
	3571,
	3585,
	3642,
	3648,
	3662,
	3664,
	3673,
	3713,
	3714,
	3716,
	3716,
	3719,
	3720,
	3722,
	3722,
	3725,
	3725,
	3732,
	3735,
	3737,
	3743,
	3745,
	3747,
	3749,
	3749,
	3751,
	3751,
	3754,
	3755,
	3757,
	3769,
	3771,
	3773,
	3776,
	3780,
	3782,
	3782,
	3784,
	3789,
	3792,
	3801,
	3804,
	3807,
	3840,
	3840,
	3864,
	3865,
	3872,
	3881,
	3893,
	3893,
	3895,
	3895,
	3897,
	3897,
	3902,
	3911,
	3913,
	3948,
	3953,
	3972,
	3974,
	3991,
	3993,
	4028,
	4038,
	4038,
	4096,
	4169,
	4176,
	4253,
	4256,
	4293,
	4295,
	4295,
	4301,
	4301,
	4304,
	4346,
	4348,
	4680,
	4682,
	4685,
	4688,
	4694,
	4696,
	4696,
	4698,
	4701,
	4704,
	4744,
	4746,
	4749,
	4752,
	4784,
	4786,
	4789,
	4792,
	4798,
	4800,
	4800,
	4802,
	4805,
	4808,
	4822,
	4824,
	4880,
	4882,
	4885,
	4888,
	4954,
	4957,
	4959,
	4992,
	5007,
	5024,
	5108,
	5121,
	5740,
	5743,
	5759,
	5761,
	5786,
	5792,
	5866,
	5870,
	5872,
	5888,
	5900,
	5902,
	5908,
	5920,
	5940,
	5952,
	5971,
	5984,
	5996,
	5998,
	6e3,
	6002,
	6003,
	6016,
	6099,
	6103,
	6103,
	6108,
	6109,
	6112,
	6121,
	6155,
	6157,
	6160,
	6169,
	6176,
	6263,
	6272,
	6314,
	6320,
	6389,
	6400,
	6428,
	6432,
	6443,
	6448,
	6459,
	6470,
	6509,
	6512,
	6516,
	6528,
	6571,
	6576,
	6601,
	6608,
	6617,
	6656,
	6683,
	6688,
	6750,
	6752,
	6780,
	6783,
	6793,
	6800,
	6809,
	6823,
	6823,
	6912,
	6987,
	6992,
	7001,
	7019,
	7027,
	7040,
	7155,
	7168,
	7223,
	7232,
	7241,
	7245,
	7293,
	7376,
	7378,
	7380,
	7414,
	7424,
	7654,
	7676,
	7957,
	7960,
	7965,
	7968,
	8005,
	8008,
	8013,
	8016,
	8023,
	8025,
	8025,
	8027,
	8027,
	8029,
	8029,
	8031,
	8061,
	8064,
	8116,
	8118,
	8124,
	8126,
	8126,
	8130,
	8132,
	8134,
	8140,
	8144,
	8147,
	8150,
	8155,
	8160,
	8172,
	8178,
	8180,
	8182,
	8188,
	8204,
	8205,
	8255,
	8256,
	8276,
	8276,
	8305,
	8305,
	8319,
	8319,
	8336,
	8348,
	8400,
	8412,
	8417,
	8417,
	8421,
	8432,
	8450,
	8450,
	8455,
	8455,
	8458,
	8467,
	8469,
	8469,
	8473,
	8477,
	8484,
	8484,
	8486,
	8486,
	8488,
	8488,
	8490,
	8493,
	8495,
	8505,
	8508,
	8511,
	8517,
	8521,
	8526,
	8526,
	8544,
	8584,
	11264,
	11310,
	11312,
	11358,
	11360,
	11492,
	11499,
	11507,
	11520,
	11557,
	11559,
	11559,
	11565,
	11565,
	11568,
	11623,
	11631,
	11631,
	11647,
	11670,
	11680,
	11686,
	11688,
	11694,
	11696,
	11702,
	11704,
	11710,
	11712,
	11718,
	11720,
	11726,
	11728,
	11734,
	11736,
	11742,
	11744,
	11775,
	11823,
	11823,
	12293,
	12295,
	12321,
	12335,
	12337,
	12341,
	12344,
	12348,
	12353,
	12438,
	12441,
	12442,
	12445,
	12447,
	12449,
	12538,
	12540,
	12543,
	12549,
	12589,
	12593,
	12686,
	12704,
	12730,
	12784,
	12799,
	13312,
	19893,
	19968,
	40908,
	40960,
	42124,
	42192,
	42237,
	42240,
	42508,
	42512,
	42539,
	42560,
	42607,
	42612,
	42621,
	42623,
	42647,
	42655,
	42737,
	42775,
	42783,
	42786,
	42888,
	42891,
	42894,
	42896,
	42899,
	42912,
	42922,
	43e3,
	43047,
	43072,
	43123,
	43136,
	43204,
	43216,
	43225,
	43232,
	43255,
	43259,
	43259,
	43264,
	43309,
	43312,
	43347,
	43360,
	43388,
	43392,
	43456,
	43471,
	43481,
	43520,
	43574,
	43584,
	43597,
	43600,
	43609,
	43616,
	43638,
	43642,
	43643,
	43648,
	43714,
	43739,
	43741,
	43744,
	43759,
	43762,
	43766,
	43777,
	43782,
	43785,
	43790,
	43793,
	43798,
	43808,
	43814,
	43816,
	43822,
	43968,
	44010,
	44012,
	44013,
	44016,
	44025,
	44032,
	55203,
	55216,
	55238,
	55243,
	55291,
	63744,
	64109,
	64112,
	64217,
	64256,
	64262,
	64275,
	64279,
	64285,
	64296,
	64298,
	64310,
	64312,
	64316,
	64318,
	64318,
	64320,
	64321,
	64323,
	64324,
	64326,
	64433,
	64467,
	64829,
	64848,
	64911,
	64914,
	64967,
	65008,
	65019,
	65024,
	65039,
	65056,
	65062,
	65075,
	65076,
	65101,
	65103,
	65136,
	65140,
	65142,
	65276,
	65296,
	65305,
	65313,
	65338,
	65343,
	65343,
	65345,
	65370,
	65382,
	65470,
	65474,
	65479,
	65482,
	65487,
	65490,
	65495,
	65498,
	65500
], Xy = [
	65,
	90,
	97,
	122,
	170,
	170,
	181,
	181,
	186,
	186,
	192,
	214,
	216,
	246,
	248,
	705,
	710,
	721,
	736,
	740,
	748,
	748,
	750,
	750,
	880,
	884,
	886,
	887,
	890,
	893,
	895,
	895,
	902,
	902,
	904,
	906,
	908,
	908,
	910,
	929,
	931,
	1013,
	1015,
	1153,
	1162,
	1327,
	1329,
	1366,
	1369,
	1369,
	1376,
	1416,
	1488,
	1514,
	1519,
	1522,
	1568,
	1610,
	1646,
	1647,
	1649,
	1747,
	1749,
	1749,
	1765,
	1766,
	1774,
	1775,
	1786,
	1788,
	1791,
	1791,
	1808,
	1808,
	1810,
	1839,
	1869,
	1957,
	1969,
	1969,
	1994,
	2026,
	2036,
	2037,
	2042,
	2042,
	2048,
	2069,
	2074,
	2074,
	2084,
	2084,
	2088,
	2088,
	2112,
	2136,
	2144,
	2154,
	2160,
	2183,
	2185,
	2190,
	2208,
	2249,
	2308,
	2361,
	2365,
	2365,
	2384,
	2384,
	2392,
	2401,
	2417,
	2432,
	2437,
	2444,
	2447,
	2448,
	2451,
	2472,
	2474,
	2480,
	2482,
	2482,
	2486,
	2489,
	2493,
	2493,
	2510,
	2510,
	2524,
	2525,
	2527,
	2529,
	2544,
	2545,
	2556,
	2556,
	2565,
	2570,
	2575,
	2576,
	2579,
	2600,
	2602,
	2608,
	2610,
	2611,
	2613,
	2614,
	2616,
	2617,
	2649,
	2652,
	2654,
	2654,
	2674,
	2676,
	2693,
	2701,
	2703,
	2705,
	2707,
	2728,
	2730,
	2736,
	2738,
	2739,
	2741,
	2745,
	2749,
	2749,
	2768,
	2768,
	2784,
	2785,
	2809,
	2809,
	2821,
	2828,
	2831,
	2832,
	2835,
	2856,
	2858,
	2864,
	2866,
	2867,
	2869,
	2873,
	2877,
	2877,
	2908,
	2909,
	2911,
	2913,
	2929,
	2929,
	2947,
	2947,
	2949,
	2954,
	2958,
	2960,
	2962,
	2965,
	2969,
	2970,
	2972,
	2972,
	2974,
	2975,
	2979,
	2980,
	2984,
	2986,
	2990,
	3001,
	3024,
	3024,
	3077,
	3084,
	3086,
	3088,
	3090,
	3112,
	3114,
	3129,
	3133,
	3133,
	3160,
	3162,
	3165,
	3165,
	3168,
	3169,
	3200,
	3200,
	3205,
	3212,
	3214,
	3216,
	3218,
	3240,
	3242,
	3251,
	3253,
	3257,
	3261,
	3261,
	3293,
	3294,
	3296,
	3297,
	3313,
	3314,
	3332,
	3340,
	3342,
	3344,
	3346,
	3386,
	3389,
	3389,
	3406,
	3406,
	3412,
	3414,
	3423,
	3425,
	3450,
	3455,
	3461,
	3478,
	3482,
	3505,
	3507,
	3515,
	3517,
	3517,
	3520,
	3526,
	3585,
	3632,
	3634,
	3635,
	3648,
	3654,
	3713,
	3714,
	3716,
	3716,
	3718,
	3722,
	3724,
	3747,
	3749,
	3749,
	3751,
	3760,
	3762,
	3763,
	3773,
	3773,
	3776,
	3780,
	3782,
	3782,
	3804,
	3807,
	3840,
	3840,
	3904,
	3911,
	3913,
	3948,
	3976,
	3980,
	4096,
	4138,
	4159,
	4159,
	4176,
	4181,
	4186,
	4189,
	4193,
	4193,
	4197,
	4198,
	4206,
	4208,
	4213,
	4225,
	4238,
	4238,
	4256,
	4293,
	4295,
	4295,
	4301,
	4301,
	4304,
	4346,
	4348,
	4680,
	4682,
	4685,
	4688,
	4694,
	4696,
	4696,
	4698,
	4701,
	4704,
	4744,
	4746,
	4749,
	4752,
	4784,
	4786,
	4789,
	4792,
	4798,
	4800,
	4800,
	4802,
	4805,
	4808,
	4822,
	4824,
	4880,
	4882,
	4885,
	4888,
	4954,
	4992,
	5007,
	5024,
	5109,
	5112,
	5117,
	5121,
	5740,
	5743,
	5759,
	5761,
	5786,
	5792,
	5866,
	5870,
	5880,
	5888,
	5905,
	5919,
	5937,
	5952,
	5969,
	5984,
	5996,
	5998,
	6e3,
	6016,
	6067,
	6103,
	6103,
	6108,
	6108,
	6176,
	6264,
	6272,
	6312,
	6314,
	6314,
	6320,
	6389,
	6400,
	6430,
	6480,
	6509,
	6512,
	6516,
	6528,
	6571,
	6576,
	6601,
	6656,
	6678,
	6688,
	6740,
	6823,
	6823,
	6917,
	6963,
	6981,
	6988,
	7043,
	7072,
	7086,
	7087,
	7098,
	7141,
	7168,
	7203,
	7245,
	7247,
	7258,
	7293,
	7296,
	7304,
	7312,
	7354,
	7357,
	7359,
	7401,
	7404,
	7406,
	7411,
	7413,
	7414,
	7418,
	7418,
	7424,
	7615,
	7680,
	7957,
	7960,
	7965,
	7968,
	8005,
	8008,
	8013,
	8016,
	8023,
	8025,
	8025,
	8027,
	8027,
	8029,
	8029,
	8031,
	8061,
	8064,
	8116,
	8118,
	8124,
	8126,
	8126,
	8130,
	8132,
	8134,
	8140,
	8144,
	8147,
	8150,
	8155,
	8160,
	8172,
	8178,
	8180,
	8182,
	8188,
	8305,
	8305,
	8319,
	8319,
	8336,
	8348,
	8450,
	8450,
	8455,
	8455,
	8458,
	8467,
	8469,
	8469,
	8472,
	8477,
	8484,
	8484,
	8486,
	8486,
	8488,
	8488,
	8490,
	8505,
	8508,
	8511,
	8517,
	8521,
	8526,
	8526,
	8544,
	8584,
	11264,
	11492,
	11499,
	11502,
	11506,
	11507,
	11520,
	11557,
	11559,
	11559,
	11565,
	11565,
	11568,
	11623,
	11631,
	11631,
	11648,
	11670,
	11680,
	11686,
	11688,
	11694,
	11696,
	11702,
	11704,
	11710,
	11712,
	11718,
	11720,
	11726,
	11728,
	11734,
	11736,
	11742,
	12293,
	12295,
	12321,
	12329,
	12337,
	12341,
	12344,
	12348,
	12353,
	12438,
	12443,
	12447,
	12449,
	12538,
	12540,
	12543,
	12549,
	12591,
	12593,
	12686,
	12704,
	12735,
	12784,
	12799,
	13312,
	19903,
	19968,
	42124,
	42192,
	42237,
	42240,
	42508,
	42512,
	42527,
	42538,
	42539,
	42560,
	42606,
	42623,
	42653,
	42656,
	42735,
	42775,
	42783,
	42786,
	42888,
	42891,
	42954,
	42960,
	42961,
	42963,
	42963,
	42965,
	42969,
	42994,
	43009,
	43011,
	43013,
	43015,
	43018,
	43020,
	43042,
	43072,
	43123,
	43138,
	43187,
	43250,
	43255,
	43259,
	43259,
	43261,
	43262,
	43274,
	43301,
	43312,
	43334,
	43360,
	43388,
	43396,
	43442,
	43471,
	43471,
	43488,
	43492,
	43494,
	43503,
	43514,
	43518,
	43520,
	43560,
	43584,
	43586,
	43588,
	43595,
	43616,
	43638,
	43642,
	43642,
	43646,
	43695,
	43697,
	43697,
	43701,
	43702,
	43705,
	43709,
	43712,
	43712,
	43714,
	43714,
	43739,
	43741,
	43744,
	43754,
	43762,
	43764,
	43777,
	43782,
	43785,
	43790,
	43793,
	43798,
	43808,
	43814,
	43816,
	43822,
	43824,
	43866,
	43868,
	43881,
	43888,
	44002,
	44032,
	55203,
	55216,
	55238,
	55243,
	55291,
	63744,
	64109,
	64112,
	64217,
	64256,
	64262,
	64275,
	64279,
	64285,
	64285,
	64287,
	64296,
	64298,
	64310,
	64312,
	64316,
	64318,
	64318,
	64320,
	64321,
	64323,
	64324,
	64326,
	64433,
	64467,
	64829,
	64848,
	64911,
	64914,
	64967,
	65008,
	65019,
	65136,
	65140,
	65142,
	65276,
	65313,
	65338,
	65345,
	65370,
	65382,
	65470,
	65474,
	65479,
	65482,
	65487,
	65490,
	65495,
	65498,
	65500,
	65536,
	65547,
	65549,
	65574,
	65576,
	65594,
	65596,
	65597,
	65599,
	65613,
	65616,
	65629,
	65664,
	65786,
	65856,
	65908,
	66176,
	66204,
	66208,
	66256,
	66304,
	66335,
	66349,
	66378,
	66384,
	66421,
	66432,
	66461,
	66464,
	66499,
	66504,
	66511,
	66513,
	66517,
	66560,
	66717,
	66736,
	66771,
	66776,
	66811,
	66816,
	66855,
	66864,
	66915,
	66928,
	66938,
	66940,
	66954,
	66956,
	66962,
	66964,
	66965,
	66967,
	66977,
	66979,
	66993,
	66995,
	67001,
	67003,
	67004,
	67072,
	67382,
	67392,
	67413,
	67424,
	67431,
	67456,
	67461,
	67463,
	67504,
	67506,
	67514,
	67584,
	67589,
	67592,
	67592,
	67594,
	67637,
	67639,
	67640,
	67644,
	67644,
	67647,
	67669,
	67680,
	67702,
	67712,
	67742,
	67808,
	67826,
	67828,
	67829,
	67840,
	67861,
	67872,
	67897,
	67968,
	68023,
	68030,
	68031,
	68096,
	68096,
	68112,
	68115,
	68117,
	68119,
	68121,
	68149,
	68192,
	68220,
	68224,
	68252,
	68288,
	68295,
	68297,
	68324,
	68352,
	68405,
	68416,
	68437,
	68448,
	68466,
	68480,
	68497,
	68608,
	68680,
	68736,
	68786,
	68800,
	68850,
	68864,
	68899,
	69248,
	69289,
	69296,
	69297,
	69376,
	69404,
	69415,
	69415,
	69424,
	69445,
	69488,
	69505,
	69552,
	69572,
	69600,
	69622,
	69635,
	69687,
	69745,
	69746,
	69749,
	69749,
	69763,
	69807,
	69840,
	69864,
	69891,
	69926,
	69956,
	69956,
	69959,
	69959,
	69968,
	70002,
	70006,
	70006,
	70019,
	70066,
	70081,
	70084,
	70106,
	70106,
	70108,
	70108,
	70144,
	70161,
	70163,
	70187,
	70207,
	70208,
	70272,
	70278,
	70280,
	70280,
	70282,
	70285,
	70287,
	70301,
	70303,
	70312,
	70320,
	70366,
	70405,
	70412,
	70415,
	70416,
	70419,
	70440,
	70442,
	70448,
	70450,
	70451,
	70453,
	70457,
	70461,
	70461,
	70480,
	70480,
	70493,
	70497,
	70656,
	70708,
	70727,
	70730,
	70751,
	70753,
	70784,
	70831,
	70852,
	70853,
	70855,
	70855,
	71040,
	71086,
	71128,
	71131,
	71168,
	71215,
	71236,
	71236,
	71296,
	71338,
	71352,
	71352,
	71424,
	71450,
	71488,
	71494,
	71680,
	71723,
	71840,
	71903,
	71935,
	71942,
	71945,
	71945,
	71948,
	71955,
	71957,
	71958,
	71960,
	71983,
	71999,
	71999,
	72001,
	72001,
	72096,
	72103,
	72106,
	72144,
	72161,
	72161,
	72163,
	72163,
	72192,
	72192,
	72203,
	72242,
	72250,
	72250,
	72272,
	72272,
	72284,
	72329,
	72349,
	72349,
	72368,
	72440,
	72704,
	72712,
	72714,
	72750,
	72768,
	72768,
	72818,
	72847,
	72960,
	72966,
	72968,
	72969,
	72971,
	73008,
	73030,
	73030,
	73056,
	73061,
	73063,
	73064,
	73066,
	73097,
	73112,
	73112,
	73440,
	73458,
	73474,
	73474,
	73476,
	73488,
	73490,
	73523,
	73648,
	73648,
	73728,
	74649,
	74752,
	74862,
	74880,
	75075,
	77712,
	77808,
	77824,
	78895,
	78913,
	78918,
	82944,
	83526,
	92160,
	92728,
	92736,
	92766,
	92784,
	92862,
	92880,
	92909,
	92928,
	92975,
	92992,
	92995,
	93027,
	93047,
	93053,
	93071,
	93760,
	93823,
	93952,
	94026,
	94032,
	94032,
	94099,
	94111,
	94176,
	94177,
	94179,
	94179,
	94208,
	100343,
	100352,
	101589,
	101632,
	101640,
	110576,
	110579,
	110581,
	110587,
	110589,
	110590,
	110592,
	110882,
	110898,
	110898,
	110928,
	110930,
	110933,
	110933,
	110948,
	110951,
	110960,
	111355,
	113664,
	113770,
	113776,
	113788,
	113792,
	113800,
	113808,
	113817,
	119808,
	119892,
	119894,
	119964,
	119966,
	119967,
	119970,
	119970,
	119973,
	119974,
	119977,
	119980,
	119982,
	119993,
	119995,
	119995,
	119997,
	120003,
	120005,
	120069,
	120071,
	120074,
	120077,
	120084,
	120086,
	120092,
	120094,
	120121,
	120123,
	120126,
	120128,
	120132,
	120134,
	120134,
	120138,
	120144,
	120146,
	120485,
	120488,
	120512,
	120514,
	120538,
	120540,
	120570,
	120572,
	120596,
	120598,
	120628,
	120630,
	120654,
	120656,
	120686,
	120688,
	120712,
	120714,
	120744,
	120746,
	120770,
	120772,
	120779,
	122624,
	122654,
	122661,
	122666,
	122928,
	122989,
	123136,
	123180,
	123191,
	123197,
	123214,
	123214,
	123536,
	123565,
	123584,
	123627,
	124112,
	124139,
	124896,
	124902,
	124904,
	124907,
	124909,
	124910,
	124912,
	124926,
	124928,
	125124,
	125184,
	125251,
	125259,
	125259,
	126464,
	126467,
	126469,
	126495,
	126497,
	126498,
	126500,
	126500,
	126503,
	126503,
	126505,
	126514,
	126516,
	126519,
	126521,
	126521,
	126523,
	126523,
	126530,
	126530,
	126535,
	126535,
	126537,
	126537,
	126539,
	126539,
	126541,
	126543,
	126545,
	126546,
	126548,
	126548,
	126551,
	126551,
	126553,
	126553,
	126555,
	126555,
	126557,
	126557,
	126559,
	126559,
	126561,
	126562,
	126564,
	126564,
	126567,
	126570,
	126572,
	126578,
	126580,
	126583,
	126585,
	126588,
	126590,
	126590,
	126592,
	126601,
	126603,
	126619,
	126625,
	126627,
	126629,
	126633,
	126635,
	126651,
	131072,
	173791,
	173824,
	177977,
	177984,
	178205,
	178208,
	183969,
	183984,
	191456,
	191472,
	192093,
	194560,
	195101,
	196608,
	201546,
	201552,
	205743
], $y = [
	48,
	57,
	65,
	90,
	95,
	95,
	97,
	122,
	170,
	170,
	181,
	181,
	183,
	183,
	186,
	186,
	192,
	214,
	216,
	246,
	248,
	705,
	710,
	721,
	736,
	740,
	748,
	748,
	750,
	750,
	768,
	884,
	886,
	887,
	890,
	893,
	895,
	895,
	902,
	906,
	908,
	908,
	910,
	929,
	931,
	1013,
	1015,
	1153,
	1155,
	1159,
	1162,
	1327,
	1329,
	1366,
	1369,
	1369,
	1376,
	1416,
	1425,
	1469,
	1471,
	1471,
	1473,
	1474,
	1476,
	1477,
	1479,
	1479,
	1488,
	1514,
	1519,
	1522,
	1552,
	1562,
	1568,
	1641,
	1646,
	1747,
	1749,
	1756,
	1759,
	1768,
	1770,
	1788,
	1791,
	1791,
	1808,
	1866,
	1869,
	1969,
	1984,
	2037,
	2042,
	2042,
	2045,
	2045,
	2048,
	2093,
	2112,
	2139,
	2144,
	2154,
	2160,
	2183,
	2185,
	2190,
	2200,
	2273,
	2275,
	2403,
	2406,
	2415,
	2417,
	2435,
	2437,
	2444,
	2447,
	2448,
	2451,
	2472,
	2474,
	2480,
	2482,
	2482,
	2486,
	2489,
	2492,
	2500,
	2503,
	2504,
	2507,
	2510,
	2519,
	2519,
	2524,
	2525,
	2527,
	2531,
	2534,
	2545,
	2556,
	2556,
	2558,
	2558,
	2561,
	2563,
	2565,
	2570,
	2575,
	2576,
	2579,
	2600,
	2602,
	2608,
	2610,
	2611,
	2613,
	2614,
	2616,
	2617,
	2620,
	2620,
	2622,
	2626,
	2631,
	2632,
	2635,
	2637,
	2641,
	2641,
	2649,
	2652,
	2654,
	2654,
	2662,
	2677,
	2689,
	2691,
	2693,
	2701,
	2703,
	2705,
	2707,
	2728,
	2730,
	2736,
	2738,
	2739,
	2741,
	2745,
	2748,
	2757,
	2759,
	2761,
	2763,
	2765,
	2768,
	2768,
	2784,
	2787,
	2790,
	2799,
	2809,
	2815,
	2817,
	2819,
	2821,
	2828,
	2831,
	2832,
	2835,
	2856,
	2858,
	2864,
	2866,
	2867,
	2869,
	2873,
	2876,
	2884,
	2887,
	2888,
	2891,
	2893,
	2901,
	2903,
	2908,
	2909,
	2911,
	2915,
	2918,
	2927,
	2929,
	2929,
	2946,
	2947,
	2949,
	2954,
	2958,
	2960,
	2962,
	2965,
	2969,
	2970,
	2972,
	2972,
	2974,
	2975,
	2979,
	2980,
	2984,
	2986,
	2990,
	3001,
	3006,
	3010,
	3014,
	3016,
	3018,
	3021,
	3024,
	3024,
	3031,
	3031,
	3046,
	3055,
	3072,
	3084,
	3086,
	3088,
	3090,
	3112,
	3114,
	3129,
	3132,
	3140,
	3142,
	3144,
	3146,
	3149,
	3157,
	3158,
	3160,
	3162,
	3165,
	3165,
	3168,
	3171,
	3174,
	3183,
	3200,
	3203,
	3205,
	3212,
	3214,
	3216,
	3218,
	3240,
	3242,
	3251,
	3253,
	3257,
	3260,
	3268,
	3270,
	3272,
	3274,
	3277,
	3285,
	3286,
	3293,
	3294,
	3296,
	3299,
	3302,
	3311,
	3313,
	3315,
	3328,
	3340,
	3342,
	3344,
	3346,
	3396,
	3398,
	3400,
	3402,
	3406,
	3412,
	3415,
	3423,
	3427,
	3430,
	3439,
	3450,
	3455,
	3457,
	3459,
	3461,
	3478,
	3482,
	3505,
	3507,
	3515,
	3517,
	3517,
	3520,
	3526,
	3530,
	3530,
	3535,
	3540,
	3542,
	3542,
	3544,
	3551,
	3558,
	3567,
	3570,
	3571,
	3585,
	3642,
	3648,
	3662,
	3664,
	3673,
	3713,
	3714,
	3716,
	3716,
	3718,
	3722,
	3724,
	3747,
	3749,
	3749,
	3751,
	3773,
	3776,
	3780,
	3782,
	3782,
	3784,
	3790,
	3792,
	3801,
	3804,
	3807,
	3840,
	3840,
	3864,
	3865,
	3872,
	3881,
	3893,
	3893,
	3895,
	3895,
	3897,
	3897,
	3902,
	3911,
	3913,
	3948,
	3953,
	3972,
	3974,
	3991,
	3993,
	4028,
	4038,
	4038,
	4096,
	4169,
	4176,
	4253,
	4256,
	4293,
	4295,
	4295,
	4301,
	4301,
	4304,
	4346,
	4348,
	4680,
	4682,
	4685,
	4688,
	4694,
	4696,
	4696,
	4698,
	4701,
	4704,
	4744,
	4746,
	4749,
	4752,
	4784,
	4786,
	4789,
	4792,
	4798,
	4800,
	4800,
	4802,
	4805,
	4808,
	4822,
	4824,
	4880,
	4882,
	4885,
	4888,
	4954,
	4957,
	4959,
	4969,
	4977,
	4992,
	5007,
	5024,
	5109,
	5112,
	5117,
	5121,
	5740,
	5743,
	5759,
	5761,
	5786,
	5792,
	5866,
	5870,
	5880,
	5888,
	5909,
	5919,
	5940,
	5952,
	5971,
	5984,
	5996,
	5998,
	6e3,
	6002,
	6003,
	6016,
	6099,
	6103,
	6103,
	6108,
	6109,
	6112,
	6121,
	6155,
	6157,
	6159,
	6169,
	6176,
	6264,
	6272,
	6314,
	6320,
	6389,
	6400,
	6430,
	6432,
	6443,
	6448,
	6459,
	6470,
	6509,
	6512,
	6516,
	6528,
	6571,
	6576,
	6601,
	6608,
	6618,
	6656,
	6683,
	6688,
	6750,
	6752,
	6780,
	6783,
	6793,
	6800,
	6809,
	6823,
	6823,
	6832,
	6845,
	6847,
	6862,
	6912,
	6988,
	6992,
	7001,
	7019,
	7027,
	7040,
	7155,
	7168,
	7223,
	7232,
	7241,
	7245,
	7293,
	7296,
	7304,
	7312,
	7354,
	7357,
	7359,
	7376,
	7378,
	7380,
	7418,
	7424,
	7957,
	7960,
	7965,
	7968,
	8005,
	8008,
	8013,
	8016,
	8023,
	8025,
	8025,
	8027,
	8027,
	8029,
	8029,
	8031,
	8061,
	8064,
	8116,
	8118,
	8124,
	8126,
	8126,
	8130,
	8132,
	8134,
	8140,
	8144,
	8147,
	8150,
	8155,
	8160,
	8172,
	8178,
	8180,
	8182,
	8188,
	8204,
	8205,
	8255,
	8256,
	8276,
	8276,
	8305,
	8305,
	8319,
	8319,
	8336,
	8348,
	8400,
	8412,
	8417,
	8417,
	8421,
	8432,
	8450,
	8450,
	8455,
	8455,
	8458,
	8467,
	8469,
	8469,
	8472,
	8477,
	8484,
	8484,
	8486,
	8486,
	8488,
	8488,
	8490,
	8505,
	8508,
	8511,
	8517,
	8521,
	8526,
	8526,
	8544,
	8584,
	11264,
	11492,
	11499,
	11507,
	11520,
	11557,
	11559,
	11559,
	11565,
	11565,
	11568,
	11623,
	11631,
	11631,
	11647,
	11670,
	11680,
	11686,
	11688,
	11694,
	11696,
	11702,
	11704,
	11710,
	11712,
	11718,
	11720,
	11726,
	11728,
	11734,
	11736,
	11742,
	11744,
	11775,
	12293,
	12295,
	12321,
	12335,
	12337,
	12341,
	12344,
	12348,
	12353,
	12438,
	12441,
	12447,
	12449,
	12543,
	12549,
	12591,
	12593,
	12686,
	12704,
	12735,
	12784,
	12799,
	13312,
	19903,
	19968,
	42124,
	42192,
	42237,
	42240,
	42508,
	42512,
	42539,
	42560,
	42607,
	42612,
	42621,
	42623,
	42737,
	42775,
	42783,
	42786,
	42888,
	42891,
	42954,
	42960,
	42961,
	42963,
	42963,
	42965,
	42969,
	42994,
	43047,
	43052,
	43052,
	43072,
	43123,
	43136,
	43205,
	43216,
	43225,
	43232,
	43255,
	43259,
	43259,
	43261,
	43309,
	43312,
	43347,
	43360,
	43388,
	43392,
	43456,
	43471,
	43481,
	43488,
	43518,
	43520,
	43574,
	43584,
	43597,
	43600,
	43609,
	43616,
	43638,
	43642,
	43714,
	43739,
	43741,
	43744,
	43759,
	43762,
	43766,
	43777,
	43782,
	43785,
	43790,
	43793,
	43798,
	43808,
	43814,
	43816,
	43822,
	43824,
	43866,
	43868,
	43881,
	43888,
	44010,
	44012,
	44013,
	44016,
	44025,
	44032,
	55203,
	55216,
	55238,
	55243,
	55291,
	63744,
	64109,
	64112,
	64217,
	64256,
	64262,
	64275,
	64279,
	64285,
	64296,
	64298,
	64310,
	64312,
	64316,
	64318,
	64318,
	64320,
	64321,
	64323,
	64324,
	64326,
	64433,
	64467,
	64829,
	64848,
	64911,
	64914,
	64967,
	65008,
	65019,
	65024,
	65039,
	65056,
	65071,
	65075,
	65076,
	65101,
	65103,
	65136,
	65140,
	65142,
	65276,
	65296,
	65305,
	65313,
	65338,
	65343,
	65343,
	65345,
	65370,
	65381,
	65470,
	65474,
	65479,
	65482,
	65487,
	65490,
	65495,
	65498,
	65500,
	65536,
	65547,
	65549,
	65574,
	65576,
	65594,
	65596,
	65597,
	65599,
	65613,
	65616,
	65629,
	65664,
	65786,
	65856,
	65908,
	66045,
	66045,
	66176,
	66204,
	66208,
	66256,
	66272,
	66272,
	66304,
	66335,
	66349,
	66378,
	66384,
	66426,
	66432,
	66461,
	66464,
	66499,
	66504,
	66511,
	66513,
	66517,
	66560,
	66717,
	66720,
	66729,
	66736,
	66771,
	66776,
	66811,
	66816,
	66855,
	66864,
	66915,
	66928,
	66938,
	66940,
	66954,
	66956,
	66962,
	66964,
	66965,
	66967,
	66977,
	66979,
	66993,
	66995,
	67001,
	67003,
	67004,
	67072,
	67382,
	67392,
	67413,
	67424,
	67431,
	67456,
	67461,
	67463,
	67504,
	67506,
	67514,
	67584,
	67589,
	67592,
	67592,
	67594,
	67637,
	67639,
	67640,
	67644,
	67644,
	67647,
	67669,
	67680,
	67702,
	67712,
	67742,
	67808,
	67826,
	67828,
	67829,
	67840,
	67861,
	67872,
	67897,
	67968,
	68023,
	68030,
	68031,
	68096,
	68099,
	68101,
	68102,
	68108,
	68115,
	68117,
	68119,
	68121,
	68149,
	68152,
	68154,
	68159,
	68159,
	68192,
	68220,
	68224,
	68252,
	68288,
	68295,
	68297,
	68326,
	68352,
	68405,
	68416,
	68437,
	68448,
	68466,
	68480,
	68497,
	68608,
	68680,
	68736,
	68786,
	68800,
	68850,
	68864,
	68903,
	68912,
	68921,
	69248,
	69289,
	69291,
	69292,
	69296,
	69297,
	69373,
	69404,
	69415,
	69415,
	69424,
	69456,
	69488,
	69509,
	69552,
	69572,
	69600,
	69622,
	69632,
	69702,
	69734,
	69749,
	69759,
	69818,
	69826,
	69826,
	69840,
	69864,
	69872,
	69881,
	69888,
	69940,
	69942,
	69951,
	69956,
	69959,
	69968,
	70003,
	70006,
	70006,
	70016,
	70084,
	70089,
	70092,
	70094,
	70106,
	70108,
	70108,
	70144,
	70161,
	70163,
	70199,
	70206,
	70209,
	70272,
	70278,
	70280,
	70280,
	70282,
	70285,
	70287,
	70301,
	70303,
	70312,
	70320,
	70378,
	70384,
	70393,
	70400,
	70403,
	70405,
	70412,
	70415,
	70416,
	70419,
	70440,
	70442,
	70448,
	70450,
	70451,
	70453,
	70457,
	70459,
	70468,
	70471,
	70472,
	70475,
	70477,
	70480,
	70480,
	70487,
	70487,
	70493,
	70499,
	70502,
	70508,
	70512,
	70516,
	70656,
	70730,
	70736,
	70745,
	70750,
	70753,
	70784,
	70853,
	70855,
	70855,
	70864,
	70873,
	71040,
	71093,
	71096,
	71104,
	71128,
	71133,
	71168,
	71232,
	71236,
	71236,
	71248,
	71257,
	71296,
	71352,
	71360,
	71369,
	71424,
	71450,
	71453,
	71467,
	71472,
	71481,
	71488,
	71494,
	71680,
	71738,
	71840,
	71913,
	71935,
	71942,
	71945,
	71945,
	71948,
	71955,
	71957,
	71958,
	71960,
	71989,
	71991,
	71992,
	71995,
	72003,
	72016,
	72025,
	72096,
	72103,
	72106,
	72151,
	72154,
	72161,
	72163,
	72164,
	72192,
	72254,
	72263,
	72263,
	72272,
	72345,
	72349,
	72349,
	72368,
	72440,
	72704,
	72712,
	72714,
	72758,
	72760,
	72768,
	72784,
	72793,
	72818,
	72847,
	72850,
	72871,
	72873,
	72886,
	72960,
	72966,
	72968,
	72969,
	72971,
	73014,
	73018,
	73018,
	73020,
	73021,
	73023,
	73031,
	73040,
	73049,
	73056,
	73061,
	73063,
	73064,
	73066,
	73102,
	73104,
	73105,
	73107,
	73112,
	73120,
	73129,
	73440,
	73462,
	73472,
	73488,
	73490,
	73530,
	73534,
	73538,
	73552,
	73561,
	73648,
	73648,
	73728,
	74649,
	74752,
	74862,
	74880,
	75075,
	77712,
	77808,
	77824,
	78895,
	78912,
	78933,
	82944,
	83526,
	92160,
	92728,
	92736,
	92766,
	92768,
	92777,
	92784,
	92862,
	92864,
	92873,
	92880,
	92909,
	92912,
	92916,
	92928,
	92982,
	92992,
	92995,
	93008,
	93017,
	93027,
	93047,
	93053,
	93071,
	93760,
	93823,
	93952,
	94026,
	94031,
	94087,
	94095,
	94111,
	94176,
	94177,
	94179,
	94180,
	94192,
	94193,
	94208,
	100343,
	100352,
	101589,
	101632,
	101640,
	110576,
	110579,
	110581,
	110587,
	110589,
	110590,
	110592,
	110882,
	110898,
	110898,
	110928,
	110930,
	110933,
	110933,
	110948,
	110951,
	110960,
	111355,
	113664,
	113770,
	113776,
	113788,
	113792,
	113800,
	113808,
	113817,
	113821,
	113822,
	118528,
	118573,
	118576,
	118598,
	119141,
	119145,
	119149,
	119154,
	119163,
	119170,
	119173,
	119179,
	119210,
	119213,
	119362,
	119364,
	119808,
	119892,
	119894,
	119964,
	119966,
	119967,
	119970,
	119970,
	119973,
	119974,
	119977,
	119980,
	119982,
	119993,
	119995,
	119995,
	119997,
	120003,
	120005,
	120069,
	120071,
	120074,
	120077,
	120084,
	120086,
	120092,
	120094,
	120121,
	120123,
	120126,
	120128,
	120132,
	120134,
	120134,
	120138,
	120144,
	120146,
	120485,
	120488,
	120512,
	120514,
	120538,
	120540,
	120570,
	120572,
	120596,
	120598,
	120628,
	120630,
	120654,
	120656,
	120686,
	120688,
	120712,
	120714,
	120744,
	120746,
	120770,
	120772,
	120779,
	120782,
	120831,
	121344,
	121398,
	121403,
	121452,
	121461,
	121461,
	121476,
	121476,
	121499,
	121503,
	121505,
	121519,
	122624,
	122654,
	122661,
	122666,
	122880,
	122886,
	122888,
	122904,
	122907,
	122913,
	122915,
	122916,
	122918,
	122922,
	122928,
	122989,
	123023,
	123023,
	123136,
	123180,
	123184,
	123197,
	123200,
	123209,
	123214,
	123214,
	123536,
	123566,
	123584,
	123641,
	124112,
	124153,
	124896,
	124902,
	124904,
	124907,
	124909,
	124910,
	124912,
	124926,
	124928,
	125124,
	125136,
	125142,
	125184,
	125259,
	125264,
	125273,
	126464,
	126467,
	126469,
	126495,
	126497,
	126498,
	126500,
	126500,
	126503,
	126503,
	126505,
	126514,
	126516,
	126519,
	126521,
	126521,
	126523,
	126523,
	126530,
	126530,
	126535,
	126535,
	126537,
	126537,
	126539,
	126539,
	126541,
	126543,
	126545,
	126546,
	126548,
	126548,
	126551,
	126551,
	126553,
	126553,
	126555,
	126555,
	126557,
	126557,
	126559,
	126559,
	126561,
	126562,
	126564,
	126564,
	126567,
	126570,
	126572,
	126578,
	126580,
	126583,
	126585,
	126588,
	126590,
	126590,
	126592,
	126601,
	126603,
	126619,
	126625,
	126627,
	126629,
	126633,
	126635,
	126651,
	130032,
	130041,
	131072,
	173791,
	173824,
	177977,
	177984,
	178205,
	178208,
	183969,
	183984,
	191456,
	191472,
	192093,
	194560,
	195101,
	196608,
	201546,
	201552,
	205743,
	917760,
	917999
], Qy = /^\/\/\/?\s*@(ts-expect-error|ts-ignore)/, Ky = /^(?:\/|\*)*\s*@(ts-expect-error|ts-ignore)/, Zy = /@(?:see|link)/i;
function yl(e, t) {
	if (e < t[0]) return !1;
	let a = 0, _ = t.length, f;
	for (; a + 1 < _;) {
		if (f = a + (_ - a) / 2, f -= f % 2, t[f] <= e && e <= t[f + 1]) return !0;
		e < t[f] ? _ = f : a = f + 2;
	}
	return !1;
}
function eg(e, t) {
	return t >= 2 ? yl(e, Xy) : yl(e, Yy);
}
function tg(e, t) {
	return t >= 2 ? yl(e, $y) : yl(e, Hy);
}
function jm(e) {
	let t = [];
	return e.forEach((a, _) => {
		t[a] = _;
	}), t;
}
var ng = jm(Lm);
function nt(e) {
	return ng[e];
}
function Rm(e) {
	return Lm.get(e);
}
jm(Jm);
function wd(e) {
	return Jm.get(e);
}
function Um(e) {
	let t = [], a = 0, _ = 0;
	for (; a < e.length;) {
		let f = e.charCodeAt(a);
		switch (a++, f) {
			case 13: e.charCodeAt(a) === 10 && a++;
			case 10:
				t.push(_), _ = a;
				break;
			default:
				f > 127 && kn(f) && (t.push(_), _ = a);
				break;
		}
	}
	return t.push(_), t;
}
function rg(e, t, a, _, f) {
	(t < 0 || t >= e.length) && (f ? t = t < 0 ? 0 : t >= e.length ? e.length - 1 : t : q.fail(`Bad line number. Line: ${t}, lineStarts.length: ${e.length} , line map is correct? ${_ !== void 0 ? ly(e, Um(_)) : "unknown"}`));
	let h = e[t] + a;
	return f ? h > e[t + 1] ? e[t + 1] : typeof _ == "string" && h > _.length ? _.length : h : (t < e.length - 1 ? q.assert(h < e[t + 1]) : _ !== void 0 && q.assert(h <= _.length), h);
}
function Mp(e) {
	return e.lineMap || (e.lineMap = Um(e.text));
}
function ig(e, t) {
	let a = ag(e, t);
	return {
		line: a,
		character: t - e[a]
	};
}
function ag(e, t, a) {
	let _ = hy(e, t, bt, Sm, a);
	return _ < 0 && (_ = ~_ - 1, q.assert(_ !== -1, "position cannot precede the beginning of the file")), _;
}
function Bm(e, t) {
	return ig(Mp(e), t);
}
function qa(e) {
	return n_(e) || kn(e);
}
function n_(e) {
	return e === 32 || e === 9 || e === 11 || e === 12 || e === 160 || e === 133 || e === 5760 || e >= 8192 && e <= 8203 || e === 8239 || e === 8287 || e === 12288 || e === 65279;
}
function kn(e) {
	return e === 10 || e === 13 || e === 8232 || e === 8233;
}
function fi(e) {
	return e >= 48 && e <= 57;
}
function vp(e) {
	return fi(e) || e >= 65 && e <= 70 || e >= 97 && e <= 102;
}
function nf(e) {
	return e >= 65 && e <= 90 || e >= 97 && e <= 122;
}
function qm(e) {
	return nf(e) || fi(e) || e === 95;
}
function Tp(e) {
	return e >= 48 && e <= 55;
}
function Cr(e, t, a, _, f) {
	if (d_(t)) return t;
	let h = !1;
	for (;;) {
		let T = e.charCodeAt(t);
		switch (T) {
			case 13: e.charCodeAt(t + 1) === 10 && t++;
			case 10:
				if (t++, a) return t;
				h = !!f;
				continue;
			case 9:
			case 11:
			case 12:
			case 32:
				t++;
				continue;
			case 47:
				if (_) break;
				if (e.charCodeAt(t + 1) === 47) {
					for (t += 2; t < e.length && !kn(e.charCodeAt(t));) t++;
					h = !1;
					continue;
				}
				if (e.charCodeAt(t + 1) === 42) {
					for (t += 2; t < e.length;) {
						if (e.charCodeAt(t) === 42 && e.charCodeAt(t + 1) === 47) {
							t += 2;
							break;
						}
						t++;
					}
					h = !1;
					continue;
				}
				break;
			case 60:
			case 124:
			case 61:
			case 62:
				if ($i(e, t)) {
					t = Ma(e, t), h = !1;
					continue;
				}
				break;
			case 35:
				if (t === 0 && Fm(e, t)) {
					t = zm(e, t), h = !1;
					continue;
				}
				break;
			case 42:
				if (h) {
					t++, h = !1;
					continue;
				}
				break;
			default:
				if (T > 127 && qa(T)) {
					t++;
					continue;
				}
				break;
		}
		return t;
	}
}
var ul = 7;
function $i(e, t) {
	if (q.assert(t >= 0), t === 0 || kn(e.charCodeAt(t - 1))) {
		let a = e.charCodeAt(t);
		if (t + ul < e.length) {
			for (let _ = 0; _ < ul; _++) if (e.charCodeAt(t + _) !== a) return !1;
			return a === 61 || e.charCodeAt(t + ul) === 32;
		}
	}
	return !1;
}
function Ma(e, t, a) {
	a && a(A.Merge_conflict_marker_encountered, t, ul);
	let _ = e.charCodeAt(t), f = e.length;
	if (_ === 60 || _ === 62) for (; t < f && !kn(e.charCodeAt(t));) t++;
	else for (q.assert(_ === 124 || _ === 61); t < f;) {
		let h = e.charCodeAt(t);
		if ((h === 61 || h === 62) && h !== _ && $i(e, t)) break;
		t++;
	}
	return t;
}
var rf = /^#!.*/;
function Fm(e, t) {
	return q.assert(t === 0), rf.test(e);
}
function zm(e, t) {
	let a = rf.exec(e)[0];
	return t = t + a.length, t;
}
function kl(e, t, a, _, f, h, T) {
	let k, c, W, y, G = !1, E = _, D = T;
	if (a === 0) {
		E = !0;
		let R = af(t);
		R && (a = R.length);
	}
	e: for (; a >= 0 && a < t.length;) {
		let R = t.charCodeAt(a);
		switch (R) {
			case 13: t.charCodeAt(a + 1) === 10 && a++;
			case 10:
				if (a++, _) break e;
				E = !0, G && (y = !0);
				continue;
			case 9:
			case 11:
			case 12:
			case 32:
				a++;
				continue;
			case 47:
				let ue = t.charCodeAt(a + 1), be = !1;
				if (ue === 47 || ue === 42) {
					let he = ue === 47 ? 2 : 3, de = a;
					if (a += 2, ue === 47) for (; a < t.length;) {
						if (kn(t.charCodeAt(a))) {
							be = !0;
							break;
						}
						a++;
					}
					else for (; a < t.length;) {
						if (t.charCodeAt(a) === 42 && t.charCodeAt(a + 1) === 47) {
							a += 2;
							break;
						}
						a++;
					}
					if (E) {
						if (G && (D = f(k, c, W, y, h, D), !e && D)) return D;
						k = de, c = a, W = he, y = be, G = !0;
					}
					continue;
				}
				break e;
			default:
				if (R > 127 && qa(R)) {
					G && kn(R) && (y = !0), a++;
					continue;
				}
				break e;
		}
	}
	return G && (D = f(k, c, W, y, h, D)), D;
}
function Vm(e, t, a, _) {
	return kl(!1, e, t, !1, a, _);
}
function Wm(e, t, a, _) {
	return kl(!1, e, t, !0, a, _);
}
function sg(e, t, a, _, f) {
	return kl(!0, e, t, !1, a, _, f);
}
function _g(e, t, a, _, f) {
	return kl(!0, e, t, !0, a, _, f);
}
function Gm(e, t, a, _, f, h = []) {
	return h.push({
		kind: a,
		pos: e,
		end: t,
		hasTrailingNewLine: _
	}), h;
}
function Lp(e, t) {
	return sg(e, t, Gm, void 0, void 0);
}
function og(e, t) {
	return _g(e, t, Gm, void 0, void 0);
}
function af(e) {
	let t = rf.exec(e);
	if (t) return t[0];
}
function Zn(e, t) {
	return nf(e) || e === 36 || e === 95 || e > 127 && eg(e, t);
}
function Ar(e, t, a) {
	return qm(e) || e === 36 || (a === 1 ? e === 45 || e === 58 : !1) || e > 127 && tg(e, t);
}
function cg(e, t, a) {
	let _ = Qi(e, 0);
	if (!Zn(_, t)) return !1;
	for (let f = Vt(_); f < e.length; f += Vt(_)) if (!Ar(_ = Qi(e, f), t, a)) return !1;
	return !0;
}
function sf(e, t, a = 0, _, f, h, T) {
	var k = _, c, W, y, G, E, D, R, ue, be = 0, he = 0, de = 0;
	Ct(k, h, T);
	var O = {
		getTokenFullStart: () => y,
		getStartPos: () => y,
		getTokenEnd: () => c,
		getTextPos: () => c,
		getToken: () => E,
		getTokenStart: () => G,
		getTokenPos: () => G,
		getTokenText: () => k.substring(G, c),
		getTokenValue: () => D,
		hasUnicodeEscape: () => (R & 1024) !== 0,
		hasExtendedUnicodeEscape: () => (R & 8) !== 0,
		hasPrecedingLineBreak: () => (R & 1) !== 0,
		hasPrecedingJSDocComment: () => (R & 2) !== 0,
		hasPrecedingJSDocLeadingAsterisks: () => (R & 32768) !== 0,
		isIdentifier: () => E === 80 || E > 118,
		isReservedWord: () => E >= 83 && E <= 118,
		isUnterminated: () => (R & 4) !== 0,
		getCommentDirectives: () => ue,
		getNumericLiteralFlags: () => R & 25584,
		getTokenFlags: () => R,
		reScanGreaterToken: ct,
		reScanAsteriskEqualsToken: ar,
		reScanSlashToken: dt,
		reScanTemplateToken: qt,
		reScanTemplateHeadOrNoSubstitutionTemplate: tn,
		scanJsxIdentifier: Or,
		scanJsxAttributeValue: Vn,
		reScanJsxAttributeValue: Ce,
		reScanJsxToken: sr,
		reScanLessThanToken: mr,
		reScanHashToken: hr,
		reScanQuestionToken: Fn,
		reScanInvalidIdentifier: Bt,
		scanJsxToken: zn,
		scanJsDocToken: L,
		scanJSDocCommentTextToken: yr,
		scan: ot,
		getText: Qe,
		clearCommentDirectives: st,
		setText: Ct,
		setScriptTarget: lt,
		setLanguageVariant: Mr,
		setScriptKind: gr,
		setJSDocParsingMode: Nn,
		setOnError: Tt,
		resetTokenState: Wn,
		setTextPos: Wn,
		setSkipJsDocLeadingAsterisks: wi,
		tryScan: He,
		lookAhead: Te,
		scanRange: fe
	};
	return q.isDebugging && Object.defineProperty(O, "__debugShowCurrentPositionInText", { get: () => {
		let U = O.getText();
		return U.slice(0, O.getTokenFullStart()) + "║" + U.slice(O.getTokenFullStart());
	} }), O;
	function ae(U) {
		return Qi(k, U);
	}
	function Oe(U) {
		return U >= 0 && U < W ? ae(U) : -1;
	}
	function V(U) {
		return k.charCodeAt(U);
	}
	function oe(U) {
		return U >= 0 && U < W ? V(U) : -1;
	}
	function Y(U, K = c, Z, xe) {
		if (f) {
			let Se = c;
			c = K, f(U, Z || 0, xe), c = Se;
		}
	}
	function ft() {
		let U = c, K = !1, Z = !1, xe = "";
		for (;;) {
			let Se = V(c);
			if (Se === 95) {
				R |= 512, K ? (K = !1, Z = !0, xe += k.substring(U, c)) : (R |= 16384, Y(Z ? A.Multiple_consecutive_numeric_separators_are_not_permitted : A.Numeric_separators_are_not_allowed_here, c, 1)), c++, U = c;
				continue;
			}
			if (fi(Se)) {
				K = !0, Z = !1, c++;
				continue;
			}
			break;
		}
		return V(c - 1) === 95 && (R |= 16384, Y(A.Numeric_separators_are_not_allowed_here, c - 1, 1)), xe + k.substring(U, c);
	}
	function nr() {
		let U = c, K;
		if (V(c) === 48) if (c++, V(c) === 95) R |= 16896, Y(A.Numeric_separators_are_not_allowed_here, c, 1), c--, K = ft();
		else if (!rr()) R |= 8192, K = "" + +D;
		else if (!D) K = "0";
		else {
			D = "" + parseInt(D, 8), R |= 32;
			let me = E === 41, Ve = (me ? "-" : "") + "0o" + (+D).toString(8);
			return me && U--, Y(A.Octal_literals_are_not_allowed_Use_the_syntax_0, U, c - U, Ve), 9;
		}
		else K = ft();
		let Z, xe;
		V(c) === 46 && (c++, Z = ft());
		let Se = c;
		if (V(c) === 69 || V(c) === 101) {
			c++, R |= 16, (V(c) === 43 || V(c) === 45) && c++;
			let me = c, Ve = ft();
			Ve ? (xe = k.substring(Se, me) + Ve, Se = c) : Y(A.Digit_expected);
		}
		let we;
		if (R & 512 ? (we = K, Z && (we += "." + Z), xe && (we += xe)) : we = k.substring(U, Se), R & 8192) return Y(A.Decimals_with_leading_zeros_are_not_allowed, U, Se - U), D = "" + +we, 9;
		if (Z !== void 0 || R & 16) return mn(U, Z === void 0 && !!(R & 16)), D = "" + +we, 9;
		{
			D = we;
			let me = $t();
			return mn(U), me;
		}
	}
	function mn(U, K) {
		if (!Zn(ae(c), e)) return;
		let Z = c, { length: xe } = ht();
		xe === 1 && k[Z] === "n" ? Y(K ? A.A_bigint_literal_cannot_use_exponential_notation : A.A_bigint_literal_must_be_an_integer, U, Z - U + 1) : (Y(A.An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal, Z, xe), c = Z);
	}
	function rr() {
		let U = c, K = !0;
		for (; fi(oe(c));) Tp(V(c)) || (K = !1), c++;
		return D = k.substring(U, c), K;
	}
	function hn(U, K) {
		let Z = We(U, !1, K);
		return Z ? parseInt(Z, 16) : -1;
	}
	function Dn(U, K) {
		return We(U, !0, K);
	}
	function We(U, K, Z) {
		let xe = [], Se = !1, we = !1;
		for (; xe.length < U || K;) {
			let me = V(c);
			if (Z && me === 95) {
				R |= 512, Se ? (Se = !1, we = !0) : Y(we ? A.Multiple_consecutive_numeric_separators_are_not_permitted : A.Numeric_separators_are_not_allowed_here, c, 1), c++;
				continue;
			}
			if (Se = Z, me >= 65 && me <= 70) me += 32;
			else if (!(me >= 48 && me <= 57 || me >= 97 && me <= 102)) break;
			xe.push(me), c++, we = !1;
		}
		return xe.length < U && (xe = []), V(c - 1) === 95 && Y(A.Numeric_separators_are_not_allowed_here, c - 1, 1), String.fromCharCode(...xe);
	}
	function ir(U = !1) {
		let K = V(c);
		c++;
		let Z = "", xe = c;
		for (;;) {
			if (c >= W) {
				Z += k.substring(xe, c), R |= 4, Y(A.Unterminated_string_literal);
				break;
			}
			let Se = V(c);
			if (Se === K) {
				Z += k.substring(xe, c), c++;
				break;
			}
			if (Se === 92 && !U) {
				Z += k.substring(xe, c), Z += Ot(3), xe = c;
				continue;
			}
			if ((Se === 10 || Se === 13) && !U) {
				Z += k.substring(xe, c), R |= 4, Y(A.Unterminated_string_literal);
				break;
			}
			c++;
		}
		return Z;
	}
	function Ir(U) {
		let K = V(c) === 96;
		c++;
		let Z = c, xe = "", Se;
		for (;;) {
			if (c >= W) {
				xe += k.substring(Z, c), R |= 4, Y(A.Unterminated_template_literal), Se = K ? 15 : 18;
				break;
			}
			let we = V(c);
			if (we === 96) {
				xe += k.substring(Z, c), c++, Se = K ? 15 : 18;
				break;
			}
			if (we === 36 && c + 1 < W && V(c + 1) === 123) {
				xe += k.substring(Z, c), c += 2, Se = K ? 16 : 17;
				break;
			}
			if (we === 92) {
				xe += k.substring(Z, c), xe += Ot(1 | (U ? 2 : 0)), Z = c;
				continue;
			}
			if (we === 13) {
				xe += k.substring(Z, c), c++, c < W && V(c) === 10 && c++, xe += `
`, Z = c;
				continue;
			}
			c++;
		}
		return q.assert(Se !== void 0), D = xe, Se;
	}
	function Ot(U) {
		let K = c;
		if (c++, c >= W) return Y(A.Unexpected_end_of_text), "";
		let Z = V(c);
		switch (c++, Z) {
			case 48: if (c >= W || !fi(V(c))) return "\0";
			case 49:
			case 50:
			case 51: c < W && Tp(V(c)) && c++;
			case 52:
			case 53:
			case 54:
			case 55:
				if (c < W && Tp(V(c)) && c++, R |= 2048, U & 6) {
					let we = parseInt(k.substring(K + 1, c), 8);
					return U & 4 && !(U & 32) && Z !== 48 ? Y(A.Octal_escape_sequences_and_backreferences_are_not_allowed_in_a_character_class_If_this_was_intended_as_an_escape_sequence_use_the_syntax_0_instead, K, c - K, "\\x" + we.toString(16).padStart(2, "0")) : Y(A.Octal_escape_sequences_are_not_allowed_Use_the_syntax_0, K, c - K, "\\x" + we.toString(16).padStart(2, "0")), String.fromCharCode(we);
				}
				return k.substring(K, c);
			case 56:
			case 57: return R |= 2048, U & 6 ? (U & 4 && !(U & 32) ? Y(A.Decimal_escape_sequences_and_backreferences_are_not_allowed_in_a_character_class, K, c - K) : Y(A.Escape_sequence_0_is_not_allowed, K, c - K, k.substring(K, c)), String.fromCharCode(Z)) : k.substring(K, c);
			case 98: return "\b";
			case 116: return "	";
			case 110: return `
`;
			case 118: return "\v";
			case 102: return "\f";
			case 114: return "\r";
			case 39: return "'";
			case 34: return "\"";
			case 117:
				if (c < W && V(c) === 123) {
					c -= 2;
					let we = Bn(!!(U & 6));
					return U & 17 || (R |= 2048, U & 6 && Y(A.Unicode_escape_sequences_are_only_available_when_the_Unicode_u_flag_or_the_Unicode_Sets_v_flag_is_set, K, c - K)), we;
				}
				for (; c < K + 6; c++) if (!(c < W && vp(V(c)))) return R |= 2048, U & 6 && Y(A.Hexadecimal_digit_expected), k.substring(K, c);
				R |= 1024;
				let xe = parseInt(k.substring(K + 2, c), 16), Se = String.fromCharCode(xe);
				if (U & 16 && xe >= 55296 && xe <= 56319 && c + 6 < W && k.substring(c, c + 2) === "\\u" && V(c + 2) !== 123) {
					let we = c, me = c + 2;
					for (; me < we + 6; me++) if (!vp(V(me))) return Se;
					let Ve = parseInt(k.substring(we + 2, me), 16);
					if (Ve >= 56320 && Ve <= 57343) return c = me, Se + String.fromCharCode(Ve);
				}
				return Se;
			case 120:
				for (; c < K + 4; c++) if (!(c < W && vp(V(c)))) return R |= 2048, U & 6 && Y(A.Hexadecimal_digit_expected), k.substring(K, c);
				return R |= 4096, String.fromCharCode(parseInt(k.substring(K + 2, c), 16));
			case 13: c < W && V(c) === 10 && c++;
			case 10:
			case 8232:
			case 8233: return "";
			default: return (U & 16 || U & 4 && !(U & 8) && Ar(Z, e)) && Y(A.This_character_cannot_be_escaped_in_a_regular_expression, c - 2, 2), String.fromCharCode(Z);
		}
	}
	function Bn(U) {
		let K = c;
		c += 3;
		let Z = c, xe = Dn(1, !1), Se = xe ? parseInt(xe, 16) : -1, we = !1;
		return Se < 0 ? (U && Y(A.Hexadecimal_digit_expected), we = !0) : Se > 1114111 && (U && Y(A.An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive, Z, c - Z), we = !0), c >= W ? (U && Y(A.Unexpected_end_of_text), we = !0) : V(c) === 125 ? c++ : (U && Y(A.Unterminated_Unicode_escape_sequence), we = !0), we ? (R |= 2048, k.substring(K, c)) : (R |= 8, kd(Se));
	}
	function Pn() {
		if (c + 5 < W && V(c + 1) === 117) {
			let U = c;
			c += 2;
			let K = hn(4, !1);
			return c = U, K;
		}
		return -1;
	}
	function Mt() {
		if (ae(c + 1) === 117 && ae(c + 2) === 123) {
			let U = c;
			c += 3;
			let K = Dn(1, !1), Z = K ? parseInt(K, 16) : -1;
			return c = U, Z;
		}
		return -1;
	}
	function ht() {
		let U = "", K = c;
		for (; c < W;) {
			let Z = ae(c);
			if (Ar(Z, e)) c += Vt(Z);
			else if (Z === 92) {
				if (Z = Mt(), Z >= 0 && Ar(Z, e)) {
					U += Bn(!0), K = c;
					continue;
				}
				if (Z = Pn(), !(Z >= 0 && Ar(Z, e))) break;
				R |= 1024, U += k.substring(K, c), U += kd(Z), c += 6, K = c;
			} else break;
		}
		return U += k.substring(K, c), U;
	}
	function $e() {
		let U = D.length;
		if (U >= 2 && U <= 12) {
			let K = D.charCodeAt(0);
			if (K >= 97 && K <= 122) {
				let Z = Wy.get(D);
				if (Z !== void 0) return E = Z;
			}
		}
		return E = 80;
	}
	function qn(U) {
		let K = "", Z = !1, xe = !1;
		for (;;) {
			let Se = V(c);
			if (Se === 95) {
				R |= 512, Z ? (Z = !1, xe = !0) : Y(xe ? A.Multiple_consecutive_numeric_separators_are_not_permitted : A.Numeric_separators_are_not_allowed_here, c, 1), c++;
				continue;
			}
			if (Z = !0, !fi(Se) || Se - 48 >= U) break;
			K += k[c], c++, xe = !1;
		}
		return V(c - 1) === 95 && Y(A.Numeric_separators_are_not_allowed_here, c - 1, 1), K;
	}
	function $t() {
		return V(c) === 110 ? (D += "n", R & 384 && (D = vb(D) + "n"), c++, 10) : (D = "" + (R & 128 ? parseInt(D.slice(2), 2) : R & 256 ? parseInt(D.slice(2), 8) : +D), 9);
	}
	function ot() {
		for (y = c, R = 0;;) {
			if (G = c, c >= W) return E = 1;
			let U = ae(c);
			if (c === 0 && U === 35 && Fm(k, c)) {
				if (c = zm(k, c), t) continue;
				return E = 6;
			}
			switch (U) {
				case 10:
				case 13: if (R |= 1, t) {
					c++;
					continue;
				} else return U === 13 && c + 1 < W && V(c + 1) === 10 ? c += 2 : c++, E = 4;
				case 9:
				case 11:
				case 12:
				case 32:
				case 160:
				case 5760:
				case 8192:
				case 8193:
				case 8194:
				case 8195:
				case 8196:
				case 8197:
				case 8198:
				case 8199:
				case 8200:
				case 8201:
				case 8202:
				case 8203:
				case 8239:
				case 8287:
				case 12288:
				case 65279: if (t) {
					c++;
					continue;
				} else {
					for (; c < W && n_(V(c));) c++;
					return E = 5;
				}
				case 33: return V(c + 1) === 61 ? V(c + 2) === 61 ? (c += 3, E = 38) : (c += 2, E = 36) : (c++, E = 54);
				case 34:
				case 39: return D = ir(), E = 11;
				case 96: return E = Ir(!1);
				case 37: return V(c + 1) === 61 ? (c += 2, E = 70) : (c++, E = 45);
				case 38: return V(c + 1) === 38 ? V(c + 2) === 61 ? (c += 3, E = 77) : (c += 2, E = 56) : V(c + 1) === 61 ? (c += 2, E = 74) : (c++, E = 51);
				case 40: return c++, E = 21;
				case 41: return c++, E = 22;
				case 42:
					if (V(c + 1) === 61) return c += 2, E = 67;
					if (V(c + 1) === 42) return V(c + 2) === 61 ? (c += 3, E = 68) : (c += 2, E = 43);
					if (c++, be && (R & 32768) === 0 && R & 1) {
						R |= 32768;
						continue;
					}
					return E = 42;
				case 43: return V(c + 1) === 43 ? (c += 2, E = 46) : V(c + 1) === 61 ? (c += 2, E = 65) : (c++, E = 40);
				case 44: return c++, E = 28;
				case 45: return V(c + 1) === 45 ? (c += 2, E = 47) : V(c + 1) === 61 ? (c += 2, E = 66) : (c++, E = 41);
				case 46: return fi(V(c + 1)) ? (nr(), E = 9) : V(c + 1) === 46 && V(c + 2) === 46 ? (c += 3, E = 26) : (c++, E = 25);
				case 47:
					if (V(c + 1) === 47) {
						for (c += 2; c < W && !kn(V(c));) c++;
						if (ue = _n(ue, k.slice(G, c), Qy, G), t) continue;
						return E = 2;
					}
					if (V(c + 1) === 42) {
						c += 2;
						let me = V(c) === 42 && V(c + 1) !== 47, Ve = !1, Ze = G;
						for (; c < W;) {
							let Ye = V(c);
							if (Ye === 42 && V(c + 1) === 47) {
								c += 2, Ve = !0;
								break;
							}
							c++, kn(Ye) && (Ze = c, R |= 1);
						}
						if (me && at() && (R |= 2), ue = _n(ue, k.slice(Ze, c), Ky, Ze), Ve || Y(A.Asterisk_Slash_expected), t) continue;
						return Ve || (R |= 4), E = 3;
					}
					return V(c + 1) === 61 ? (c += 2, E = 69) : (c++, E = 44);
				case 48:
					if (c + 2 < W && (V(c + 1) === 88 || V(c + 1) === 120)) return c += 2, D = Dn(1, !0), D || (Y(A.Hexadecimal_digit_expected), D = "0"), D = "0x" + D, R |= 64, E = $t();
					if (c + 2 < W && (V(c + 1) === 66 || V(c + 1) === 98)) return c += 2, D = qn(2), D || (Y(A.Binary_digit_expected), D = "0"), D = "0b" + D, R |= 128, E = $t();
					if (c + 2 < W && (V(c + 1) === 79 || V(c + 1) === 111)) return c += 2, D = qn(8), D || (Y(A.Octal_digit_expected), D = "0"), D = "0o" + D, R |= 256, E = $t();
				case 49:
				case 50:
				case 51:
				case 52:
				case 53:
				case 54:
				case 55:
				case 56:
				case 57: return E = nr();
				case 58: return c++, E = 59;
				case 59: return c++, E = 27;
				case 60:
					if ($i(k, c)) {
						if (c = Ma(k, c, Y), t) continue;
						return E = 7;
					}
					return V(c + 1) === 60 ? V(c + 2) === 61 ? (c += 3, E = 71) : (c += 2, E = 48) : V(c + 1) === 61 ? (c += 2, E = 33) : a === 1 && V(c + 1) === 47 && V(c + 2) !== 42 ? (c += 2, E = 31) : (c++, E = 30);
				case 61:
					if ($i(k, c)) {
						if (c = Ma(k, c, Y), t) continue;
						return E = 7;
					}
					return V(c + 1) === 61 ? V(c + 2) === 61 ? (c += 3, E = 37) : (c += 2, E = 35) : V(c + 1) === 62 ? (c += 2, E = 39) : (c++, E = 64);
				case 62:
					if ($i(k, c)) {
						if (c = Ma(k, c, Y), t) continue;
						return E = 7;
					}
					return c++, E = 32;
				case 63: return V(c + 1) === 46 && !fi(V(c + 2)) ? (c += 2, E = 29) : V(c + 1) === 63 ? V(c + 2) === 61 ? (c += 3, E = 78) : (c += 2, E = 61) : (c++, E = 58);
				case 91: return c++, E = 23;
				case 93: return c++, E = 24;
				case 94: return V(c + 1) === 61 ? (c += 2, E = 79) : (c++, E = 53);
				case 123: return c++, E = 19;
				case 124:
					if ($i(k, c)) {
						if (c = Ma(k, c, Y), t) continue;
						return E = 7;
					}
					return V(c + 1) === 124 ? V(c + 2) === 61 ? (c += 3, E = 76) : (c += 2, E = 57) : V(c + 1) === 61 ? (c += 2, E = 75) : (c++, E = 52);
				case 125: return c++, E = 20;
				case 126: return c++, E = 55;
				case 64: return c++, E = 60;
				case 92:
					let K = Mt();
					if (K >= 0 && Zn(K, e)) return D = Bn(!0) + ht(), E = $e();
					let Z = Pn();
					return Z >= 0 && Zn(Z, e) ? (c += 6, R |= 1024, D = String.fromCharCode(Z) + ht(), E = $e()) : (Y(A.Invalid_character), c++, E = 0);
				case 35:
					if (c !== 0 && k[c + 1] === "!") return Y(A.can_only_be_used_at_the_start_of_a_file, c, 2), c++, E = 0;
					let xe = ae(c + 1);
					if (xe === 92) {
						c++;
						let me = Mt();
						if (me >= 0 && Zn(me, e)) return D = "#" + Bn(!0) + ht(), E = 81;
						let Ve = Pn();
						if (Ve >= 0 && Zn(Ve, e)) return c += 6, R |= 1024, D = "#" + String.fromCharCode(Ve) + ht(), E = 81;
						c--;
					}
					return Zn(xe, e) ? (c++, Lt(xe, e)) : (D = "#", Y(A.Invalid_character, c++, Vt(U))), E = 81;
				case 65533: return Y(A.File_appears_to_be_binary, 0, 0), c = W, E = 8;
				default:
					let Se = Lt(U, e);
					if (Se) return E = Se;
					if (n_(U)) {
						c += Vt(U);
						continue;
					} else if (kn(U)) {
						R |= 1, c += Vt(U);
						continue;
					}
					let we = Vt(U);
					return Y(A.Invalid_character, c, we), c += we, E = 0;
			}
		}
	}
	function at() {
		switch (de) {
			case 0: return !0;
			case 1: return !1;
		}
		return he !== 3 && he !== 4 ? !0 : de === 3 ? !1 : Zy.test(k.slice(y, c));
	}
	function Bt() {
		q.assert(E === 0, "'reScanInvalidIdentifier' should only be called when the current token is 'SyntaxKind.Unknown'."), c = G = y, R = 0;
		let U = ae(c), K = Lt(U, 99);
		return K ? E = K : (c += Vt(U), E);
	}
	function Lt(U, K) {
		let Z = U;
		if (Zn(Z, K)) {
			for (c += Vt(Z); c < W && Ar(Z = ae(c), K);) c += Vt(Z);
			return D = k.substring(G, c), Z === 92 && (D += ht()), $e();
		}
	}
	function ct() {
		if (E === 32) {
			if (V(c) === 62) return V(c + 1) === 62 ? V(c + 2) === 61 ? (c += 3, E = 73) : (c += 2, E = 50) : V(c + 1) === 61 ? (c += 2, E = 72) : (c++, E = 49);
			if (V(c) === 61) return c++, E = 34;
		}
		return E;
	}
	function ar() {
		return q.assert(E === 67, "'reScanAsteriskEqualsToken' should only be called on a '*='"), c = G + 1, E = 64;
	}
	function dt(U) {
		if (E === 44 || E === 69) {
			let K = G + 1;
			c = K;
			let Z = !1, xe = !1, Se = !1;
			for (;;) {
				let me = oe(c);
				if (me === -1 || kn(me)) {
					R |= 4;
					break;
				}
				if (Z) Z = !1;
				else {
					if (me === 47 && !Se) break;
					me === 91 ? Se = !0 : me === 92 ? Z = !0 : me === 93 ? Se = !1 : !Se && me === 40 && oe(c + 1) === 63 && oe(c + 2) === 60 && oe(c + 3) !== 61 && oe(c + 3) !== 33 && (xe = !0);
				}
				c++;
			}
			let we = c;
			if (R & 4) {
				c = K, Z = !1;
				let me = 0, Ve = !1, Ze = 0;
				for (; c < we;) {
					let Ye = V(c);
					if (Z) Z = !1;
					else if (Ye === 92) Z = !0;
					else if (Ye === 91) me++;
					else if (Ye === 93 && me) me--;
					else if (!me) {
						if (Ye === 123) Ve = !0;
						else if (Ye === 125 && Ve) Ve = !1;
						else if (!Ve) {
							if (Ye === 40) Ze++;
							else if (Ye === 41 && Ze) Ze--;
							else if (Ye === 41 || Ye === 93 || Ye === 125) break;
						}
					}
					c++;
				}
				for (; qa(oe(c - 1)) || oe(c - 1) === 59;) c--;
				Y(A.Unterminated_regular_expression_literal, G, c - G);
			} else {
				c++;
				let me = 0;
				for (;;) {
					let Ve = Oe(c);
					if (Ve === -1 || !Ar(Ve, e)) break;
					let Ze = Vt(Ve);
					if (U) {
						let Ye = wd(Ve);
						Ye === void 0 ? Y(A.Unknown_regular_expression_flag, c, Ze) : me & Ye ? Y(A.Duplicate_regular_expression_flag, c, Ze) : ((me | Ye) & 96) === 96 ? Y(A.The_Unicode_u_flag_and_the_Unicode_Sets_v_flag_cannot_be_set_simultaneously, c, Ze) : (me |= Ye, yt(Ye, Ze));
					}
					c += Ze;
				}
				U && fe(K, we - K, () => {
					yn(me, !0, xe);
				});
			}
			D = k.substring(G, c), E = 14;
		}
		return E;
	}
	function yn(U, K, Z) {
		var xe = !!(U & 64), Se = !!(U & 96), we = Se || !K, me = !1, Ve = 0, Ze, Ye, Ee, gn = [], rt;
		function on(H) {
			for (;;) {
				if (gn.push(rt), rt = void 0, Zr(H), rt = gn.pop(), oe(c) !== 124) return;
				c++;
			}
		}
		function Zr(H) {
			let le = !1;
			for (;;) {
				let qe = c, ve = oe(c);
				switch (ve) {
					case -1: return;
					case 94:
					case 36:
						c++, le = !1;
						break;
					case 92:
						switch (c++, oe(c)) {
							case 98:
							case 66:
								c++, le = !1;
								break;
							default:
								Ue(), le = !0;
								break;
						}
						break;
					case 40:
						if (c++, oe(c) === 63) switch (c++, oe(c)) {
							case 61:
							case 33:
								c++, le = !we;
								break;
							case 60:
								let xt = c;
								switch (c++, oe(c)) {
									case 61:
									case 33:
										c++, le = !1;
										break;
									default:
										Me(!1), cn(62), e < 5 && Y(A.Named_capturing_groups_are_only_available_when_targeting_ES2018_or_later, xt, c - xt), Ve++, le = !0;
										break;
								}
								break;
							default:
								let Jt = c, ln = M(0);
								oe(c) === 45 && (c++, M(ln), c === Jt + 1 && Y(A.Subpattern_flags_must_be_present_when_there_is_a_minus_sign, Jt, c - Jt)), cn(58), le = !0;
								break;
						}
						else Ve++, le = !0;
						on(!0), cn(41);
						break;
					case 123:
						c++;
						let J = c;
						rr();
						let mt = D;
						if (!we && !mt) {
							le = !0;
							break;
						}
						if (oe(c) === 44) {
							c++, rr();
							let xt = D;
							if (mt) xt && Number.parseInt(mt) > Number.parseInt(xt) && (we || oe(c) === 125) && Y(A.Numbers_out_of_order_in_quantifier, J, c - J);
							else if (xt || oe(c) === 125) Y(A.Incomplete_quantifier_Digit_expected, J, 0);
							else {
								Y(A.Unexpected_0_Did_you_mean_to_escape_it_with_backslash, qe, 1, String.fromCharCode(ve)), le = !0;
								break;
							}
						} else if (!mt) {
							we && Y(A.Unexpected_0_Did_you_mean_to_escape_it_with_backslash, qe, 1, String.fromCharCode(ve)), le = !0;
							break;
						}
						if (oe(c) !== 125) if (we) Y(A._0_expected, c, 0, "}"), c--;
						else {
							le = !0;
							break;
						}
					case 42:
					case 43:
					case 63:
						c++, oe(c) === 63 && c++, le || Y(A.There_is_nothing_available_for_repetition, qe, c - qe), le = !1;
						break;
					case 46:
						c++, le = !0;
						break;
					case 91:
						c++, xe ? nn() : Be(), cn(93), le = !0;
						break;
					case 41: if (H) return;
					case 93:
					case 125:
						(we || ve === 41) && Y(A.Unexpected_0_Did_you_mean_to_escape_it_with_backslash, c, 1, String.fromCharCode(ve)), c++, le = !0;
						break;
					case 47:
					case 124: return;
					default:
						ki(), le = !0;
						break;
				}
			}
		}
		function M(H) {
			for (;;) {
				let le = Oe(c);
				if (le === -1 || !Ar(le, e)) break;
				let qe = Vt(le), ve = wd(le);
				ve === void 0 ? Y(A.Unknown_regular_expression_flag, c, qe) : H & ve ? Y(A.Duplicate_regular_expression_flag, c, qe) : ve & 28 ? (H |= ve, yt(ve, qe)) : Y(A.This_regular_expression_flag_cannot_be_toggled_within_a_subpattern, c, qe), c += qe;
			}
			return H;
		}
		function Ue() {
			switch (q.assertEqual(V(c - 1), 92), oe(c)) {
				case 107:
					c++, oe(c) === 60 ? (c++, Me(!0), cn(62)) : (we || Z) && Y(A.k_must_be_followed_by_a_capturing_group_name_enclosed_in_angle_brackets, c - 2, 2);
					break;
				case 113: if (xe) {
					c++, Y(A.q_is_only_available_inside_character_class, c - 2, 2);
					break;
				}
				default:
					q.assert(Ft() || u() || Ie(!0));
					break;
			}
		}
		function u() {
			q.assertEqual(V(c - 1), 92);
			let H = oe(c);
			if (H >= 49 && H <= 57) {
				let le = c;
				return rr(), Ee = wn(Ee, {
					pos: le,
					end: c,
					value: +D
				}), !0;
			}
			return !1;
		}
		function Ie(H) {
			q.assertEqual(V(c - 1), 92);
			let le = oe(c);
			switch (le) {
				case -1: return Y(A.Undetermined_character_escape, c - 1, 1), "\\";
				case 99:
					if (c++, le = oe(c), nf(le)) return c++, String.fromCharCode(le & 31);
					if (we) Y(A.c_must_be_followed_by_an_ASCII_letter, c - 2, 2);
					else if (H) return c--, "\\";
					return String.fromCharCode(le);
				case 94:
				case 36:
				case 47:
				case 92:
				case 46:
				case 42:
				case 43:
				case 63:
				case 40:
				case 41:
				case 91:
				case 93:
				case 123:
				case 125:
				case 124: return c++, String.fromCharCode(le);
				default: return c--, Ot(4 | (K ? 8 : 0) | (Se ? 16 : 0) | (H ? 32 : 0));
			}
		}
		function Me(H) {
			q.assertEqual(V(c - 1), 60), G = c, Lt(Oe(c), e), c === G ? Y(A.Expected_a_capturing_group_name) : H ? Ye = wn(Ye, {
				pos: G,
				end: c,
				name: D
			}) : rt?.has(D) || gn.some((le) => le?.has(D)) ? Y(A.Named_capturing_groups_with_the_same_name_must_be_mutually_exclusive_to_each_other, G, c - G) : (rt ?? (rt = /* @__PURE__ */ new Set()), rt.add(D), Ze ?? (Ze = /* @__PURE__ */ new Set()), Ze.add(D));
		}
		function B(H) {
			return H === 93 || H === -1 || c >= W;
		}
		function Be() {
			for (q.assertEqual(V(c - 1), 91), oe(c) === 94 && c++;;) {
				if (B(oe(c))) return;
				let le = c, qe = Pt();
				if (oe(c) === 45) {
					c++;
					if (B(oe(c))) return;
					!qe && we && Y(A.A_character_class_range_must_not_be_bounded_by_another_character_class, le, c - 1 - le);
					let J = c, mt = Pt();
					if (!mt && we) {
						Y(A.A_character_class_range_must_not_be_bounded_by_another_character_class, J, c - J);
						continue;
					}
					if (!qe) continue;
					let xt = Qi(qe, 0), Jt = Qi(mt, 0);
					qe.length === Vt(xt) && mt.length === Vt(Jt) && xt > Jt && Y(A.Range_out_of_order_in_character_class, le, c - le);
				}
			}
		}
		function nn() {
			q.assertEqual(V(c - 1), 91);
			let H = !1;
			oe(c) === 94 && (c++, H = !0);
			let le = !1, qe = oe(c);
			if (B(qe)) return;
			let ve = c, J;
			switch (k.slice(c, c + 2)) {
				case "--":
				case "&&":
					Y(A.Expected_a_class_set_operand), me = !1;
					break;
				default:
					J = Xe();
					break;
			}
			switch (oe(c)) {
				case 45:
					if (oe(c + 1) === 45) {
						H && me && Y(A.Anything_that_would_possibly_match_more_than_a_single_character_is_invalid_inside_a_negated_character_class, ve, c - ve), le = me, ze(3), me = !H && le;
						return;
					}
					break;
				case 38:
					if (oe(c + 1) === 38) {
						ze(2), H && me && Y(A.Anything_that_would_possibly_match_more_than_a_single_character_is_invalid_inside_a_negated_character_class, ve, c - ve), le = me, me = !H && le;
						return;
					} else Y(A.Unexpected_0_Did_you_mean_to_escape_it_with_backslash, c, 1, String.fromCharCode(qe));
					break;
				default:
					H && me && Y(A.Anything_that_would_possibly_match_more_than_a_single_character_is_invalid_inside_a_negated_character_class, ve, c - ve), le = me;
					break;
			}
			for (; qe = oe(c), qe !== -1;) {
				switch (qe) {
					case 45:
						if (c++, qe = oe(c), B(qe)) {
							me = !H && le;
							return;
						}
						if (qe === 45) {
							c++, Y(A.Operators_must_not_be_mixed_within_a_character_class_Wrap_it_in_a_nested_class_instead, c - 2, 2), ve = c - 2, J = k.slice(ve, c);
							continue;
						} else {
							J || Y(A.A_character_class_range_must_not_be_bounded_by_another_character_class, ve, c - 1 - ve);
							let mt = c, xt = Xe();
							if (H && me && Y(A.Anything_that_would_possibly_match_more_than_a_single_character_is_invalid_inside_a_negated_character_class, mt, c - mt), le || (le = me), !xt) {
								Y(A.A_character_class_range_must_not_be_bounded_by_another_character_class, mt, c - mt);
								break;
							}
							if (!J) break;
							let Jt = Qi(J, 0), ln = Qi(xt, 0);
							J.length === Vt(Jt) && xt.length === Vt(ln) && Jt > ln && Y(A.Range_out_of_order_in_character_class, ve, c - ve);
						}
						break;
					case 38:
						ve = c, c++, oe(c) === 38 ? (c++, Y(A.Operators_must_not_be_mixed_within_a_character_class_Wrap_it_in_a_nested_class_instead, c - 2, 2), oe(c) === 38 && (Y(A.Unexpected_0_Did_you_mean_to_escape_it_with_backslash, c, 1, String.fromCharCode(qe)), c++)) : Y(A.Unexpected_0_Did_you_mean_to_escape_it_with_backslash, c - 1, 1, String.fromCharCode(qe)), J = k.slice(ve, c);
						continue;
				}
				if (B(oe(c))) break;
				switch (ve = c, k.slice(c, c + 2)) {
					case "--":
					case "&&":
						Y(A.Operators_must_not_be_mixed_within_a_character_class_Wrap_it_in_a_nested_class_instead, c, 2), c += 2, J = k.slice(ve, c);
						break;
					default:
						J = Xe();
						break;
				}
			}
			me = !H && le;
		}
		function ze(H) {
			let le = me;
			for (;;) {
				let qe = oe(c);
				if (B(qe)) break;
				switch (qe) {
					case 45:
						c++, oe(c) === 45 ? (c++, H !== 3 && Y(A.Operators_must_not_be_mixed_within_a_character_class_Wrap_it_in_a_nested_class_instead, c - 2, 2)) : Y(A.Operators_must_not_be_mixed_within_a_character_class_Wrap_it_in_a_nested_class_instead, c - 1, 1);
						break;
					case 38:
						c++, oe(c) === 38 ? (c++, H !== 2 && Y(A.Operators_must_not_be_mixed_within_a_character_class_Wrap_it_in_a_nested_class_instead, c - 2, 2), oe(c) === 38 && (Y(A.Unexpected_0_Did_you_mean_to_escape_it_with_backslash, c, 1, String.fromCharCode(qe)), c++)) : Y(A.Unexpected_0_Did_you_mean_to_escape_it_with_backslash, c - 1, 1, String.fromCharCode(qe));
						break;
					default:
						switch (H) {
							case 3:
								Y(A._0_expected, c, 0, "--");
								break;
							case 2:
								Y(A._0_expected, c, 0, "&&");
								break;
							default: break;
						}
						break;
				}
				if (qe = oe(c), B(qe)) {
					Y(A.Expected_a_class_set_operand);
					break;
				}
				Xe(), le && (le = me);
			}
			me = le;
		}
		function Xe() {
			switch (me = !1, oe(c)) {
				case -1: return "";
				case 91: return c++, nn(), cn(93), "";
				case 92:
					if (c++, Ft()) return "";
					if (oe(c) === 113) return c++, oe(c) === 123 ? (c++, Dt(), cn(125), "") : (Y(A.q_must_be_followed_by_string_alternatives_enclosed_in_braces, c - 2, 2), "q");
					c--;
				default: return wt();
			}
		}
		function Dt() {
			q.assertEqual(V(c - 1), 123);
			let H = 0;
			for (;;) switch (oe(c)) {
				case -1: return;
				case 125:
					H !== 1 && (me = !0);
					return;
				case 124:
					H !== 1 && (me = !0), c++, h = c, H = 0;
					break;
				default:
					wt(), H++;
					break;
			}
		}
		function wt() {
			let H = oe(c);
			if (H === -1) return "";
			if (H === 92) {
				c++;
				let le = oe(c);
				switch (le) {
					case 98: return c++, "\b";
					case 38:
					case 45:
					case 33:
					case 35:
					case 37:
					case 44:
					case 58:
					case 59:
					case 60:
					case 61:
					case 62:
					case 64:
					case 96:
					case 126: return c++, String.fromCharCode(le);
					default: return Ie(!1);
				}
			} else if (H === oe(c + 1)) switch (H) {
				case 38:
				case 33:
				case 35:
				case 37:
				case 42:
				case 43:
				case 44:
				case 46:
				case 58:
				case 59:
				case 60:
				case 61:
				case 62:
				case 63:
				case 64:
				case 96:
				case 126: return Y(A.A_character_class_must_not_contain_a_reserved_double_punctuator_Did_you_mean_to_escape_it_with_backslash, c, 2), c += 2, k.substring(c - 2, c);
			}
			switch (H) {
				case 47:
				case 40:
				case 41:
				case 91:
				case 93:
				case 123:
				case 125:
				case 45:
				case 124: return Y(A.Unexpected_0_Did_you_mean_to_escape_it_with_backslash, c, 1, String.fromCharCode(H)), c++, String.fromCharCode(H);
			}
			return ki();
		}
		function Pt() {
			if (oe(c) === 92) {
				c++;
				let H = oe(c);
				switch (H) {
					case 98: return c++, "\b";
					case 45: return c++, String.fromCharCode(H);
					default: return Ft() ? "" : Ie(!1);
				}
			} else return ki();
		}
		function Ft() {
			q.assertEqual(V(c - 1), 92);
			let H = !1, le = c - 1, qe = oe(c);
			switch (qe) {
				case 100:
				case 68:
				case 115:
				case 83:
				case 119:
				case 87: return c++, !0;
				case 80: H = !0;
				case 112:
					if (c++, oe(c) === 123) {
						c++;
						let ve = c, J = Gn();
						if (oe(c) === 61) {
							let mt = Ed.get(J);
							if (c === ve) Y(A.Expected_a_Unicode_property_name);
							else if (mt === void 0) {
								Y(A.Unknown_Unicode_property_name, ve, c - ve);
								let ln = t_(J, Ed.keys(), bt);
								ln && Y(A.Did_you_mean_0, ve, c - ve, ln);
							}
							c++;
							let xt = c, Jt = Gn();
							if (c === xt) Y(A.Expected_a_Unicode_property_value);
							else if (mt !== void 0 && !Ra[mt].has(Jt)) {
								Y(A.Unknown_Unicode_property_value, xt, c - xt);
								let ln = t_(Jt, Ra[mt], bt);
								ln && Y(A.Did_you_mean_0, xt, c - xt, ln);
							}
						} else if (c === ve) Y(A.Expected_a_Unicode_property_name_or_value);
						else if (Cd.has(J)) xe ? H ? Y(A.Anything_that_would_possibly_match_more_than_a_single_character_is_invalid_inside_a_negated_character_class, ve, c - ve) : me = !0 : Y(A.Any_Unicode_property_that_would_possibly_match_more_than_a_single_character_is_only_available_when_the_Unicode_Sets_v_flag_is_set, ve, c - ve);
						else if (!Ra.General_Category.has(J) && !Ad.has(J)) {
							Y(A.Unknown_Unicode_property_name_or_value, ve, c - ve);
							let mt = t_(J, [
								...Ra.General_Category,
								...Ad,
								...Cd
							], bt);
							mt && Y(A.Did_you_mean_0, ve, c - ve, mt);
						}
						cn(125), Se || Y(A.Unicode_property_value_expressions_are_only_available_when_the_Unicode_u_flag_or_the_Unicode_Sets_v_flag_is_set, le, c - le);
					} else if (we) Y(A._0_must_be_followed_by_a_Unicode_property_value_expression_enclosed_in_braces, c - 2, 2, String.fromCharCode(qe));
					else return c--, !1;
					return !0;
			}
			return !1;
		}
		function Gn() {
			let H = "";
			for (;;) {
				let le = oe(c);
				if (le === -1 || !qm(le)) break;
				H += String.fromCharCode(le), c++;
			}
			return H;
		}
		function ki() {
			let H = Se ? Vt(Oe(c)) : 1;
			return c += H, H > 0 ? k.substring(c - H, c) : "";
		}
		function cn(H) {
			oe(c) === H ? c++ : Y(A._0_expected, c, 0, String.fromCharCode(H));
		}
		on(!1), jn(Ye, (H) => {
			if (!Ze?.has(H.name) && (Y(A.There_is_no_capturing_group_named_0_in_this_regular_expression, H.pos, H.end - H.pos, H.name), Ze)) {
				let le = t_(H.name, Ze, bt);
				le && Y(A.Did_you_mean_0, H.pos, H.end - H.pos, le);
			}
		}), jn(Ee, (H) => {
			H.value > Ve && (Ve ? Y(A.This_backreference_refers_to_a_group_that_does_not_exist_There_are_only_0_capturing_groups_in_this_regular_expression, H.pos, H.end - H.pos, Ve) : Y(A.This_backreference_refers_to_a_group_that_does_not_exist_There_are_no_capturing_groups_in_this_regular_expression, H.pos, H.end - H.pos));
		});
	}
	function yt(U, K) {
		let Z = Gy.get(U);
		Z && e < Z && Y(A.This_regular_expression_flag_is_only_available_when_targeting_0_or_later, c, K, ub(Z));
	}
	function _n(U, K, Z, xe) {
		let Se = tt(K.trimStart(), Z);
		return Se === void 0 ? U : wn(U, {
			range: {
				pos: xe,
				end: c
			},
			type: Se
		});
	}
	function tt(U, K) {
		let Z = K.exec(U);
		if (Z) switch (Z[1]) {
			case "ts-expect-error": return 0;
			case "ts-ignore": return 1;
		}
	}
	function qt(U) {
		return c = G, E = Ir(!U);
	}
	function tn() {
		return c = G, E = Ir(!0);
	}
	function sr(U = !0) {
		return c = G = y, E = zn(U);
	}
	function mr() {
		return E === 48 ? (c = G + 1, E = 30) : E;
	}
	function hr() {
		return E === 81 ? (c = G + 1, E = 63) : E;
	}
	function Fn() {
		return q.assert(E === 61, "'reScanQuestionToken' should only be called on a '??'"), c = G + 1, E = 58;
	}
	function zn(U = !0) {
		if (y = G = c, c >= W) return E = 1;
		let K = V(c);
		if (K === 60) return V(c + 1) === 47 ? (c += 2, E = 31) : (c++, E = 30);
		if (K === 123) return c++, E = 19;
		let Z = 0;
		for (; c < W && (K = V(c), K !== 123);) {
			if (K === 60) {
				if ($i(k, c)) return c = Ma(k, c, Y), E = 7;
				break;
			}
			if (K === 62 && Y(A.Unexpected_token_Did_you_mean_or_gt, c, 1), K === 125 && Y(A.Unexpected_token_Did_you_mean_or_rbrace, c, 1), kn(K) && Z === 0) Z = -1;
			else {
				if (!U && kn(K) && Z > 0) break;
				qa(K) || (Z = c);
			}
			c++;
		}
		return D = k.substring(y, c), Z === -1 ? 13 : 12;
	}
	function Or() {
		if (St(E)) {
			for (; c < W;) {
				if (V(c) === 45) {
					D += "-", c++;
					continue;
				}
				let K = c;
				if (D += ht(), c === K) break;
			}
			return $e();
		}
		return E;
	}
	function Vn() {
		switch (y = c, V(c)) {
			case 34:
			case 39: return D = ir(!0), E = 11;
			default: return ot();
		}
	}
	function Ce() {
		return c = G = y, Vn();
	}
	function yr(U) {
		if (y = G = c, R = 0, c >= W) return E = 1;
		for (let K = V(c); c < W && !kn(K) && K !== 96; K = ae(++c)) if (!U) {
			if (K === 123) break;
			if (K === 64 && c - 1 >= 0 && n_(V(c - 1)) && !(c + 1 < W && qa(V(c + 1)))) break;
		}
		return c === G ? L() : (D = k.substring(G, c), E = 82);
	}
	function L() {
		if (y = G = c, R = 0, c >= W) return E = 1;
		let U = ae(c);
		switch (c += Vt(U), U) {
			case 9:
			case 11:
			case 12:
			case 32:
				for (; c < W && n_(V(c));) c++;
				return E = 5;
			case 64: return E = 60;
			case 13: V(c) === 10 && c++;
			case 10: return R |= 1, E = 4;
			case 42: return E = 42;
			case 123: return E = 19;
			case 125: return E = 20;
			case 91: return E = 23;
			case 93: return E = 24;
			case 40: return E = 21;
			case 41: return E = 22;
			case 60: return E = 30;
			case 62: return E = 32;
			case 61: return E = 64;
			case 44: return E = 28;
			case 46: return E = 25;
			case 96: return E = 62;
			case 35: return E = 63;
			case 92:
				c--;
				let K = Mt();
				if (K >= 0 && Zn(K, e)) return D = Bn(!0) + ht(), E = $e();
				let Z = Pn();
				return Z >= 0 && Zn(Z, e) ? (c += 6, R |= 1024, D = String.fromCharCode(Z) + ht(), E = $e()) : (c++, E = 0);
		}
		if (Zn(U, e)) {
			let K = U;
			for (; c < W && Ar(K = ae(c), e) || K === 45;) c += Vt(K);
			return D = k.substring(G, c), K === 92 && (D += ht()), E = $e();
		} else return E = 0;
	}
	function se(U, K) {
		let Z = c, xe = y, Se = G, we = E, me = D, Ve = R, Ze = U();
		return (!Ze || K) && (c = Z, y = xe, G = Se, E = we, D = me, R = Ve), Ze;
	}
	function fe(U, K, Z) {
		let xe = W, Se = c, we = y, me = G, Ve = E, Ze = D, Ye = R, Ee = ue;
		Ct(k, U, K);
		let gn = Z();
		return W = xe, c = Se, y = we, G = me, E = Ve, D = Ze, R = Ye, ue = Ee, gn;
	}
	function Te(U) {
		return se(U, !0);
	}
	function He(U) {
		return se(U, !1);
	}
	function Qe() {
		return k;
	}
	function st() {
		ue = void 0;
	}
	function Ct(U, K, Z) {
		k = U || "", W = Z === void 0 ? k.length : K + Z, Wn(K || 0);
	}
	function Tt(U) {
		f = U;
	}
	function lt(U) {
		e = U;
	}
	function Mr(U) {
		a = U;
	}
	function gr(U) {
		he = U;
	}
	function Nn(U) {
		de = U;
	}
	function Wn(U) {
		q.assert(U >= 0), c = U, y = U, G = U, E = 0, D = void 0, R = 0;
	}
	function wi(U) {
		be += U ? 1 : -1;
	}
}
function Qi(e, t) {
	return e.codePointAt(t);
}
function Vt(e) {
	return e >= 65536 ? 2 : e === -1 ? 0 : 1;
}
function lg(e) {
	if (q.assert(0 <= e && e <= 1114111), e <= 65535) return String.fromCharCode(e);
	let t = Math.floor((e - 65536) / 1024) + 55296, a = (e - 65536) % 1024 + 56320;
	return String.fromCharCode(t, a);
}
var ug = String.fromCodePoint ? (e) => String.fromCodePoint(e) : lg;
function kd(e) {
	return ug(e);
}
var Ed = new Map(Object.entries({
	General_Category: "General_Category",
	gc: "General_Category",
	Script: "Script",
	sc: "Script",
	Script_Extensions: "Script_Extensions",
	scx: "Script_Extensions"
})), Ad = new Set([
	"ASCII",
	"ASCII_Hex_Digit",
	"AHex",
	"Alphabetic",
	"Alpha",
	"Any",
	"Assigned",
	"Bidi_Control",
	"Bidi_C",
	"Bidi_Mirrored",
	"Bidi_M",
	"Case_Ignorable",
	"CI",
	"Cased",
	"Changes_When_Casefolded",
	"CWCF",
	"Changes_When_Casemapped",
	"CWCM",
	"Changes_When_Lowercased",
	"CWL",
	"Changes_When_NFKC_Casefolded",
	"CWKCF",
	"Changes_When_Titlecased",
	"CWT",
	"Changes_When_Uppercased",
	"CWU",
	"Dash",
	"Default_Ignorable_Code_Point",
	"DI",
	"Deprecated",
	"Dep",
	"Diacritic",
	"Dia",
	"Emoji",
	"Emoji_Component",
	"EComp",
	"Emoji_Modifier",
	"EMod",
	"Emoji_Modifier_Base",
	"EBase",
	"Emoji_Presentation",
	"EPres",
	"Extended_Pictographic",
	"ExtPict",
	"Extender",
	"Ext",
	"Grapheme_Base",
	"Gr_Base",
	"Grapheme_Extend",
	"Gr_Ext",
	"Hex_Digit",
	"Hex",
	"IDS_Binary_Operator",
	"IDSB",
	"IDS_Trinary_Operator",
	"IDST",
	"ID_Continue",
	"IDC",
	"ID_Start",
	"IDS",
	"Ideographic",
	"Ideo",
	"Join_Control",
	"Join_C",
	"Logical_Order_Exception",
	"LOE",
	"Lowercase",
	"Lower",
	"Math",
	"Noncharacter_Code_Point",
	"NChar",
	"Pattern_Syntax",
	"Pat_Syn",
	"Pattern_White_Space",
	"Pat_WS",
	"Quotation_Mark",
	"QMark",
	"Radical",
	"Regional_Indicator",
	"RI",
	"Sentence_Terminal",
	"STerm",
	"Soft_Dotted",
	"SD",
	"Terminal_Punctuation",
	"Term",
	"Unified_Ideograph",
	"UIdeo",
	"Uppercase",
	"Upper",
	"Variation_Selector",
	"VS",
	"White_Space",
	"space",
	"XID_Continue",
	"XIDC",
	"XID_Start",
	"XIDS"
]), Cd = new Set([
	"Basic_Emoji",
	"Emoji_Keycap_Sequence",
	"RGI_Emoji_Modifier_Sequence",
	"RGI_Emoji_Flag_Sequence",
	"RGI_Emoji_Tag_Sequence",
	"RGI_Emoji_ZWJ_Sequence",
	"RGI_Emoji"
]), Ra = {
	General_Category: new Set([
		"C",
		"Other",
		"Cc",
		"Control",
		"cntrl",
		"Cf",
		"Format",
		"Cn",
		"Unassigned",
		"Co",
		"Private_Use",
		"Cs",
		"Surrogate",
		"L",
		"Letter",
		"LC",
		"Cased_Letter",
		"Ll",
		"Lowercase_Letter",
		"Lm",
		"Modifier_Letter",
		"Lo",
		"Other_Letter",
		"Lt",
		"Titlecase_Letter",
		"Lu",
		"Uppercase_Letter",
		"M",
		"Mark",
		"Combining_Mark",
		"Mc",
		"Spacing_Mark",
		"Me",
		"Enclosing_Mark",
		"Mn",
		"Nonspacing_Mark",
		"N",
		"Number",
		"Nd",
		"Decimal_Number",
		"digit",
		"Nl",
		"Letter_Number",
		"No",
		"Other_Number",
		"P",
		"Punctuation",
		"punct",
		"Pc",
		"Connector_Punctuation",
		"Pd",
		"Dash_Punctuation",
		"Pe",
		"Close_Punctuation",
		"Pf",
		"Final_Punctuation",
		"Pi",
		"Initial_Punctuation",
		"Po",
		"Other_Punctuation",
		"Ps",
		"Open_Punctuation",
		"S",
		"Symbol",
		"Sc",
		"Currency_Symbol",
		"Sk",
		"Modifier_Symbol",
		"Sm",
		"Math_Symbol",
		"So",
		"Other_Symbol",
		"Z",
		"Separator",
		"Zl",
		"Line_Separator",
		"Zp",
		"Paragraph_Separator",
		"Zs",
		"Space_Separator"
	]),
	Script: new Set([
		"Adlm",
		"Adlam",
		"Aghb",
		"Caucasian_Albanian",
		"Ahom",
		"Arab",
		"Arabic",
		"Armi",
		"Imperial_Aramaic",
		"Armn",
		"Armenian",
		"Avst",
		"Avestan",
		"Bali",
		"Balinese",
		"Bamu",
		"Bamum",
		"Bass",
		"Bassa_Vah",
		"Batk",
		"Batak",
		"Beng",
		"Bengali",
		"Bhks",
		"Bhaiksuki",
		"Bopo",
		"Bopomofo",
		"Brah",
		"Brahmi",
		"Brai",
		"Braille",
		"Bugi",
		"Buginese",
		"Buhd",
		"Buhid",
		"Cakm",
		"Chakma",
		"Cans",
		"Canadian_Aboriginal",
		"Cari",
		"Carian",
		"Cham",
		"Cher",
		"Cherokee",
		"Chrs",
		"Chorasmian",
		"Copt",
		"Coptic",
		"Qaac",
		"Cpmn",
		"Cypro_Minoan",
		"Cprt",
		"Cypriot",
		"Cyrl",
		"Cyrillic",
		"Deva",
		"Devanagari",
		"Diak",
		"Dives_Akuru",
		"Dogr",
		"Dogra",
		"Dsrt",
		"Deseret",
		"Dupl",
		"Duployan",
		"Egyp",
		"Egyptian_Hieroglyphs",
		"Elba",
		"Elbasan",
		"Elym",
		"Elymaic",
		"Ethi",
		"Ethiopic",
		"Geor",
		"Georgian",
		"Glag",
		"Glagolitic",
		"Gong",
		"Gunjala_Gondi",
		"Gonm",
		"Masaram_Gondi",
		"Goth",
		"Gothic",
		"Gran",
		"Grantha",
		"Grek",
		"Greek",
		"Gujr",
		"Gujarati",
		"Guru",
		"Gurmukhi",
		"Hang",
		"Hangul",
		"Hani",
		"Han",
		"Hano",
		"Hanunoo",
		"Hatr",
		"Hatran",
		"Hebr",
		"Hebrew",
		"Hira",
		"Hiragana",
		"Hluw",
		"Anatolian_Hieroglyphs",
		"Hmng",
		"Pahawh_Hmong",
		"Hmnp",
		"Nyiakeng_Puachue_Hmong",
		"Hrkt",
		"Katakana_Or_Hiragana",
		"Hung",
		"Old_Hungarian",
		"Ital",
		"Old_Italic",
		"Java",
		"Javanese",
		"Kali",
		"Kayah_Li",
		"Kana",
		"Katakana",
		"Kawi",
		"Khar",
		"Kharoshthi",
		"Khmr",
		"Khmer",
		"Khoj",
		"Khojki",
		"Kits",
		"Khitan_Small_Script",
		"Knda",
		"Kannada",
		"Kthi",
		"Kaithi",
		"Lana",
		"Tai_Tham",
		"Laoo",
		"Lao",
		"Latn",
		"Latin",
		"Lepc",
		"Lepcha",
		"Limb",
		"Limbu",
		"Lina",
		"Linear_A",
		"Linb",
		"Linear_B",
		"Lisu",
		"Lyci",
		"Lycian",
		"Lydi",
		"Lydian",
		"Mahj",
		"Mahajani",
		"Maka",
		"Makasar",
		"Mand",
		"Mandaic",
		"Mani",
		"Manichaean",
		"Marc",
		"Marchen",
		"Medf",
		"Medefaidrin",
		"Mend",
		"Mende_Kikakui",
		"Merc",
		"Meroitic_Cursive",
		"Mero",
		"Meroitic_Hieroglyphs",
		"Mlym",
		"Malayalam",
		"Modi",
		"Mong",
		"Mongolian",
		"Mroo",
		"Mro",
		"Mtei",
		"Meetei_Mayek",
		"Mult",
		"Multani",
		"Mymr",
		"Myanmar",
		"Nagm",
		"Nag_Mundari",
		"Nand",
		"Nandinagari",
		"Narb",
		"Old_North_Arabian",
		"Nbat",
		"Nabataean",
		"Newa",
		"Nkoo",
		"Nko",
		"Nshu",
		"Nushu",
		"Ogam",
		"Ogham",
		"Olck",
		"Ol_Chiki",
		"Orkh",
		"Old_Turkic",
		"Orya",
		"Oriya",
		"Osge",
		"Osage",
		"Osma",
		"Osmanya",
		"Ougr",
		"Old_Uyghur",
		"Palm",
		"Palmyrene",
		"Pauc",
		"Pau_Cin_Hau",
		"Perm",
		"Old_Permic",
		"Phag",
		"Phags_Pa",
		"Phli",
		"Inscriptional_Pahlavi",
		"Phlp",
		"Psalter_Pahlavi",
		"Phnx",
		"Phoenician",
		"Plrd",
		"Miao",
		"Prti",
		"Inscriptional_Parthian",
		"Rjng",
		"Rejang",
		"Rohg",
		"Hanifi_Rohingya",
		"Runr",
		"Runic",
		"Samr",
		"Samaritan",
		"Sarb",
		"Old_South_Arabian",
		"Saur",
		"Saurashtra",
		"Sgnw",
		"SignWriting",
		"Shaw",
		"Shavian",
		"Shrd",
		"Sharada",
		"Sidd",
		"Siddham",
		"Sind",
		"Khudawadi",
		"Sinh",
		"Sinhala",
		"Sogd",
		"Sogdian",
		"Sogo",
		"Old_Sogdian",
		"Sora",
		"Sora_Sompeng",
		"Soyo",
		"Soyombo",
		"Sund",
		"Sundanese",
		"Sylo",
		"Syloti_Nagri",
		"Syrc",
		"Syriac",
		"Tagb",
		"Tagbanwa",
		"Takr",
		"Takri",
		"Tale",
		"Tai_Le",
		"Talu",
		"New_Tai_Lue",
		"Taml",
		"Tamil",
		"Tang",
		"Tangut",
		"Tavt",
		"Tai_Viet",
		"Telu",
		"Telugu",
		"Tfng",
		"Tifinagh",
		"Tglg",
		"Tagalog",
		"Thaa",
		"Thaana",
		"Thai",
		"Tibt",
		"Tibetan",
		"Tirh",
		"Tirhuta",
		"Tnsa",
		"Tangsa",
		"Toto",
		"Ugar",
		"Ugaritic",
		"Vaii",
		"Vai",
		"Vith",
		"Vithkuqi",
		"Wara",
		"Warang_Citi",
		"Wcho",
		"Wancho",
		"Xpeo",
		"Old_Persian",
		"Xsux",
		"Cuneiform",
		"Yezi",
		"Yezidi",
		"Yiii",
		"Yi",
		"Zanb",
		"Zanabazar_Square",
		"Zinh",
		"Inherited",
		"Qaai",
		"Zyyy",
		"Common",
		"Zzzz",
		"Unknown"
	]),
	Script_Extensions: void 0
};
Ra.Script_Extensions = Ra.Script;
function kr(e) {
	return e.start + e.length;
}
function pg(e) {
	return e.length === 0;
}
function _f(e, t) {
	if (e < 0) throw new Error("start < 0");
	if (t < 0) throw new Error("length < 0");
	return {
		start: e,
		length: t
	};
}
function fg(e, t) {
	return _f(e, t - e);
}
function Qs(e) {
	return _f(e.span.start, e.newLength);
}
function dg(e) {
	return pg(e.span) && e.newLength === 0;
}
function Ym(e, t) {
	if (t < 0) throw new Error("newLength < 0");
	return {
		span: e,
		newLength: t
	};
}
Ym(_f(0, 0), 0);
function of(e, t) {
	for (; e;) {
		let a = t(e);
		if (a === "quit") return;
		if (a) return e;
		e = e.parent;
	}
}
function gl(e) {
	return (e.flags & 16) === 0;
}
function mg(e, t) {
	if (e === void 0 || gl(e)) return e;
	for (e = e.original; e;) {
		if (gl(e)) return !t || t(e) ? e : void 0;
		e = e.original;
	}
}
function La(e) {
	return e.length >= 2 && e.charCodeAt(0) === 95 && e.charCodeAt(1) === 95 ? "_" + e : e;
}
function l_(e) {
	let t = e;
	return t.length >= 3 && t.charCodeAt(0) === 95 && t.charCodeAt(1) === 95 && t.charCodeAt(2) === 95 ? t.substr(1) : t;
}
function An(e) {
	return l_(e.escapedText);
}
function cf(e) {
	let t = Rm(e.escapedText);
	return t ? Sy(t, di) : void 0;
}
function Jp(e) {
	return e.valueDeclaration && jg(e.valueDeclaration) ? An(e.valueDeclaration.name) : l_(e.escapedName);
}
function Hm(e) {
	let t = e.parent.parent;
	if (t) {
		if (Nd(t)) return rl(t);
		switch (t.kind) {
			case 244:
				if (t.declarationList && t.declarationList.declarations[0]) return rl(t.declarationList.declarations[0]);
				break;
			case 245:
				let a = t.expression;
				switch (a.kind === 227 && a.operatorToken.kind === 64 && (a = a.left), a.kind) {
					case 212: return a.name;
					case 213:
						let _ = a.argumentExpression;
						if (Ke(_)) return _;
				}
				break;
			case 218: return rl(t.expression);
			case 257:
				if (Nd(t.statement) || _1(t.statement)) return rl(t.statement);
				break;
		}
	}
}
function rl(e) {
	let t = Xm(e);
	return t && Ke(t) ? t : void 0;
}
function hg(e) {
	return e.name || Hm(e);
}
function yg(e) {
	return !!e.name;
}
function lf(e) {
	switch (e.kind) {
		case 80: return e;
		case 349:
		case 342: {
			let { name: a } = e;
			if (a.kind === 167) return a.right;
			break;
		}
		case 214:
		case 227: {
			let a = e;
			switch (yf(a)) {
				case 1:
				case 4:
				case 5:
				case 3: return gf(a.left);
				case 7:
				case 8:
				case 9: return a.arguments[1];
				default: return;
			}
		}
		case 347: return hg(e);
		case 341: return Hm(e);
		case 278: {
			let { expression: a } = e;
			return Ke(a) ? a : void 0;
		}
		case 213:
			let t = e;
			if (d1(t)) return t.argumentExpression;
	}
	return e.name;
}
function Xm(e) {
	if (e !== void 0) return lf(e) || (Mf(e) || Lf(e) || xl(e) ? gg(e) : void 0);
}
function gg(e) {
	if (e.parent) {
		if (K1(e.parent) || B1(e.parent)) return e.parent.name;
		if (na(e.parent) && e === e.parent.right) {
			if (Ke(e.parent.left)) return e.parent.left;
			if (v1(e.parent.left)) return gf(e.parent.left);
		} else if (Jf(e.parent) && Ke(e.parent.name)) return e.parent.name;
	} else return;
}
function uf(e) {
	if (F2(e)) return Hr(e.modifiers, Cl);
}
function $m(e) {
	if (v_(e, 98303)) return Hr(e.modifiers, Bg);
}
function Qm(e, t) {
	if (e.name) if (Ke(e.name)) {
		let a = e.name.escapedText;
		return u_(e.parent, t).filter((_) => zp(_) && Ke(_.name) && _.name.escapedText === a);
	} else {
		let a = e.parent.parameters.indexOf(e);
		q.assert(a > -1, "Parameters should always be in their parents' parameter list");
		let _ = u_(e.parent, t).filter(zp);
		if (a < _.length) return [_[a]];
	}
	return vt;
}
function bg(e) {
	return Qm(e, !1);
}
function vg(e) {
	return Qm(e, !0);
}
function Km(e, t) {
	let a = e.name.escapedText;
	return u_(e.parent, t).filter((_) => ih(_) && _.typeParameters.some((f) => f.name.escapedText === a));
}
function Tg(e) {
	return Km(e, !1);
}
function xg(e) {
	return Km(e, !0);
}
function Sg(e) {
	return bi(e, a6);
}
function wg(e) {
	return Ig(e, d6);
}
function kg(e) {
	return bi(e, s6, !0);
}
function Eg(e) {
	return bi(e, _6, !0);
}
function Ag(e) {
	return bi(e, o6, !0);
}
function Cg(e) {
	return bi(e, c6, !0);
}
function Dg(e) {
	return bi(e, l6, !0);
}
function Pg(e) {
	return bi(e, p6, !0);
}
function Ng(e) {
	let t = bi(e, zf);
	if (t && t.typeExpression && t.typeExpression.type) return t;
}
function u_(e, t) {
	var a;
	if (!bf(e)) return vt;
	let _ = (a = e.jsDoc) == null ? void 0 : a.jsDocCache;
	if (_ === void 0 || t) {
		let f = E2(e, t);
		q.assert(f.length < 2 || f[0] !== f[1]), _ = Tm(f, (h) => rh(h) ? h.tags : h), t || (e.jsDoc ?? (e.jsDoc = []), e.jsDoc.jsDocCache = _);
	}
	return _;
}
function Zm(e) {
	return u_(e, !1);
}
function bi(e, t, a) {
	return bm(u_(e, a), t);
}
function Ig(e, t) {
	return Zm(e).filter(t);
}
function jp(e) {
	return e.kind === 80 || e.kind === 81;
}
function Og(e) {
	return dr(e) && !!(e.flags & 64);
}
function Mg(e) {
	return Ha(e) && !!(e.flags & 64);
}
function Dd(e) {
	return Of(e) && !!(e.flags & 64);
}
function e1(e) {
	let t = e.kind;
	return !!(e.flags & 64) && (t === 212 || t === 213 || t === 214 || t === 236);
}
function pf(e) {
	return Vf(e, 8);
}
function Lg(e) {
	return fl(e) && !!(e.flags & 64);
}
function ff(e) {
	return e >= 167;
}
function df(e) {
	return e >= 0 && e <= 166;
}
function t1(e) {
	return df(e.kind);
}
function mi(e) {
	return Dr(e, "pos") && Dr(e, "end");
}
function Jg(e) {
	return 9 <= e && e <= 15;
}
function Pd(e) {
	return 15 <= e && e <= 18;
}
function Ua(e) {
	var t;
	return Ke(e) && ((t = e.emitNode) == null ? void 0 : t.autoGenerate) !== void 0;
}
function n1(e) {
	var t;
	return gi(e) && ((t = e.emitNode) == null ? void 0 : t.autoGenerate) !== void 0;
}
function jg(e) {
	return (Wa(e) || zg(e)) && gi(e.name);
}
function Yr(e) {
	switch (e) {
		case 128:
		case 129:
		case 134:
		case 87:
		case 138:
		case 90:
		case 95:
		case 103:
		case 125:
		case 123:
		case 124:
		case 148:
		case 126:
		case 147:
		case 164: return !0;
	}
	return !1;
}
function Rg(e) {
	return !!(g1(e) & 31);
}
function Ug(e) {
	return Rg(e) || e === 126 || e === 164 || e === 129;
}
function Bg(e) {
	return Yr(e.kind);
}
function r1(e) {
	let t = e.kind;
	return t === 80 || t === 81 || t === 11 || t === 9 || t === 168;
}
function mf(e) {
	return !!e && Fg(e.kind);
}
function qg(e) {
	switch (e) {
		case 263:
		case 175:
		case 177:
		case 178:
		case 179:
		case 219:
		case 220: return !0;
		default: return !1;
	}
}
function Fg(e) {
	switch (e) {
		case 174:
		case 180:
		case 324:
		case 181:
		case 182:
		case 185:
		case 318:
		case 186: return !0;
		default: return qg(e);
	}
}
function ra(e) {
	return e && (e.kind === 264 || e.kind === 232);
}
function zg(e) {
	switch (e.kind) {
		case 175:
		case 178:
		case 179: return !0;
		default: return !1;
	}
}
function Vg(e) {
	let t = e.kind;
	return t === 304 || t === 305 || t === 306 || t === 175 || t === 178 || t === 179;
}
function i1(e) {
	return Z2(e.kind);
}
function Wg(e) {
	if (e) {
		let t = e.kind;
		return t === 208 || t === 207;
	}
	return !1;
}
function Gg(e) {
	let t = e.kind;
	return t === 210 || t === 211;
}
function Yg(e) {
	switch (e.kind) {
		case 261:
		case 170:
		case 209: return !0;
	}
	return !1;
}
function Fa(e) {
	return a1(pf(e).kind);
}
function a1(e) {
	switch (e) {
		case 212:
		case 213:
		case 215:
		case 214:
		case 285:
		case 286:
		case 289:
		case 216:
		case 210:
		case 218:
		case 211:
		case 232:
		case 219:
		case 80:
		case 81:
		case 14:
		case 9:
		case 10:
		case 11:
		case 15:
		case 229:
		case 97:
		case 106:
		case 110:
		case 112:
		case 108:
		case 236:
		case 234:
		case 237:
		case 102:
		case 283: return !0;
		default: return !1;
	}
}
function Hg(e) {
	return s1(pf(e).kind);
}
function s1(e) {
	switch (e) {
		case 225:
		case 226:
		case 221:
		case 222:
		case 223:
		case 224:
		case 217: return !0;
		default: return a1(e);
	}
}
function _1(e) {
	return Xg(pf(e).kind);
}
function Xg(e) {
	switch (e) {
		case 228:
		case 230:
		case 220:
		case 227:
		case 231:
		case 235:
		case 233:
		case 357:
		case 356:
		case 239: return !0;
		default: return s1(e);
	}
}
function $g(e) {
	return e === 220 || e === 209 || e === 264 || e === 232 || e === 176 || e === 177 || e === 267 || e === 307 || e === 282 || e === 263 || e === 219 || e === 178 || e === 274 || e === 272 || e === 277 || e === 265 || e === 292 || e === 175 || e === 174 || e === 268 || e === 271 || e === 275 || e === 281 || e === 170 || e === 304 || e === 173 || e === 172 || e === 179 || e === 305 || e === 266 || e === 169 || e === 261 || e === 347 || e === 339 || e === 349 || e === 203;
}
function o1(e) {
	return e === 263 || e === 283 || e === 264 || e === 265 || e === 266 || e === 267 || e === 268 || e === 273 || e === 272 || e === 279 || e === 278 || e === 271;
}
function c1(e) {
	return e === 253 || e === 252 || e === 260 || e === 247 || e === 245 || e === 243 || e === 250 || e === 251 || e === 249 || e === 246 || e === 257 || e === 254 || e === 256 || e === 258 || e === 259 || e === 244 || e === 248 || e === 255 || e === 354;
}
function Nd(e) {
	return e.kind === 169 ? e.parent && e.parent.kind !== 346 || ia(e) : $g(e.kind);
}
function Qg(e) {
	let t = e.kind;
	return c1(t) || o1(t) || Kg(e);
}
function Kg(e) {
	return e.kind !== 242 || e.parent !== void 0 && (e.parent.kind === 259 || e.parent.kind === 300) ? !1 : !f2(e);
}
function Zg(e) {
	let t = e.kind;
	return c1(t) || o1(t) || t === 242;
}
function l1(e) {
	return e.kind >= 310 && e.kind <= 352;
}
function e2(e) {
	return e.kind === 321 || e.kind === 320 || e.kind === 322 || r2(e) || t2(e) || i6(e) || Il(e);
}
function t2(e) {
	return e.kind >= 328 && e.kind <= 352;
}
function il(e) {
	return e.kind === 179;
}
function al(e) {
	return e.kind === 178;
}
function Ki(e) {
	if (!bf(e)) return !1;
	let { jsDoc: t } = e;
	return !!t && t.length > 0;
}
function n2(e) {
	return !!e.initializer;
}
function El(e) {
	return e.kind === 11 || e.kind === 15;
}
function r2(e) {
	return e.kind === 325 || e.kind === 326 || e.kind === 327;
}
function Id(e) {
	return (e.flags & 33554432) !== 0;
}
i2();
function i2() {
	var e = "";
	let t = (a) => e += a;
	return {
		getText: () => e,
		write: t,
		rawWrite: t,
		writeKeyword: t,
		writeOperator: t,
		writePunctuation: t,
		writeSpace: t,
		writeStringLiteral: t,
		writeLiteral: t,
		writeParameter: t,
		writeProperty: t,
		writeSymbol: (a, _) => t(a),
		writeTrailingSemicolon: t,
		writeComment: t,
		getTextPos: () => e.length,
		getLine: () => 0,
		getColumn: () => 0,
		getIndent: () => 0,
		isAtStartOfLine: () => !1,
		hasTrailingComment: () => !1,
		hasTrailingWhitespace: () => !!e.length && qa(e.charCodeAt(e.length - 1)),
		writeLine: () => e += " ",
		increaseIndent: Va,
		decreaseIndent: Va,
		clear: () => e = ""
	};
}
function a2(e, t) {
	let a = e.entries();
	for (let [_, f] of a) {
		let h = t(f, _);
		if (h) return h;
	}
}
function s2(e) {
	return e.end - e.pos;
}
function u1(e) {
	return _2(e), (e.flags & 1048576) !== 0;
}
function _2(e) {
	e.flags & 2097152 || ((e.flags & 262144 || Xt(e, u1)) && (e.flags |= 1048576), e.flags |= 2097152);
}
function hi(e) {
	for (; e && e.kind !== 308;) e = e.parent;
	return e;
}
function Zi(e) {
	return e === void 0 ? !0 : e.pos === e.end && e.pos >= 0 && e.kind !== 1;
}
function Rp(e) {
	return !Zi(e);
}
function bl(e, t, a) {
	if (Zi(e)) return e.pos;
	if (l1(e) || e.kind === 12) return Cr((t ?? hi(e)).text, e.pos, !1, !0);
	if (a && Ki(e)) return bl(e.jsDoc[0], t);
	if (e.kind === 353) {
		t ?? (t = hi(e));
		let _ = Hp(ah(e, t));
		if (_) return bl(_, t, a);
	}
	return Cr((t ?? hi(e)).text, e.pos, !1, !1, d2(e));
}
function Od(e, t, a = !1) {
	return r_(e.text, t, a);
}
function o2(e) {
	return !!of(e, eh);
}
function r_(e, t, a = !1) {
	if (Zi(t)) return "";
	let _ = e.substring(a ? t.pos : Cr(e, t.pos), t.end);
	return o2(t) && (_ = _.split(/\r\n|\n|\r/).map((f) => f.replace(/^\s*\*/, "").trimStart()).join(`
`)), _;
}
function za(e) {
	let t = e.emitNode;
	return t && t.flags || 0;
}
function c2(e, t, a) {
	q.assertGreaterThanOrEqual(t, 0), q.assertGreaterThanOrEqual(a, 0), q.assertLessThanOrEqual(t, e.length), q.assertLessThanOrEqual(t + a, e.length);
}
function pl(e) {
	return e.kind === 245 && e.expression.kind === 11;
}
function hf(e) {
	return !!(za(e) & 2097152);
}
function Md(e) {
	return hf(e) && jf(e);
}
function l2(e) {
	return Ke(e.name) && !e.initializer;
}
function Ld(e) {
	return hf(e) && Xa(e) && Gp(e.declarationList.declarations, l2);
}
function u2(e, t) {
	return Hr(e.kind === 170 || e.kind === 169 || e.kind === 219 || e.kind === 220 || e.kind === 218 || e.kind === 261 || e.kind === 282 ? Yp(og(t, e.pos), Lp(t, e.pos)) : Lp(t, e.pos), (_) => _.end <= e.end && t.charCodeAt(_.pos + 1) === 42 && t.charCodeAt(_.pos + 2) === 42 && t.charCodeAt(_.pos + 3) !== 47);
}
function p2(e) {
	if (e) switch (e.kind) {
		case 209:
		case 307:
		case 170:
		case 304:
		case 173:
		case 172:
		case 305:
		case 261: return !0;
	}
	return !1;
}
function f2(e) {
	return e && e.kind === 242 && mf(e.parent);
}
function Jd(e) {
	let t = e.kind;
	return (t === 212 || t === 213) && e.expression.kind === 108;
}
function ia(e) {
	return !!e && !!(e.flags & 524288);
}
function d2(e) {
	return !!e && !!(e.flags & 16777216);
}
function m2(e) {
	for (; vl(e, !0);) e = e.right;
	return e;
}
function h2(e) {
	return Ke(e) && e.escapedText === "exports";
}
function y2(e) {
	return Ke(e) && e.escapedText === "module";
}
function p1(e) {
	return (dr(e) || f1(e)) && y2(e.expression) && f_(e) === "exports";
}
function yf(e) {
	let t = b2(e);
	return t === 5 || ia(e) ? t : 0;
}
function g2(e) {
	return e_(e.arguments) === 3 && dr(e.expression) && Ke(e.expression.expression) && An(e.expression.expression) === "Object" && An(e.expression.name) === "defineProperty" && Al(e.arguments[1]) && p_(e.arguments[0], !0);
}
function f1(e) {
	return Ha(e) && Al(e.argumentExpression);
}
function b_(e, t) {
	return dr(e) && (!t && e.expression.kind === 110 || Ke(e.name) && p_(e.expression, !0)) || d1(e, t);
}
function d1(e, t) {
	return f1(e) && (!t && e.expression.kind === 110 || xf(e.expression) || b_(e.expression, !0));
}
function p_(e, t) {
	return xf(e) || b_(e, t);
}
function b2(e) {
	if (Of(e)) {
		if (!g2(e)) return 0;
		let t = e.arguments[0];
		return h2(t) || p1(t) ? 8 : b_(t) && f_(t) === "prototype" ? 9 : 7;
	}
	return e.operatorToken.kind !== 64 || !v1(e.left) || v2(m2(e)) ? 0 : p_(e.left.expression, !0) && f_(e.left) === "prototype" && If(x2(e)) ? 6 : T2(e.left);
}
function v2(e) {
	return Kb(e) && aa(e.expression) && e.expression.text === "0";
}
function gf(e) {
	if (dr(e)) return e.name;
	let t = vf(e.argumentExpression);
	return aa(t) || El(t) ? t : e;
}
function f_(e) {
	let t = gf(e);
	if (t) {
		if (Ke(t)) return t.escapedText;
		if (El(t) || aa(t)) return La(t.text);
	}
}
function T2(e) {
	if (e.expression.kind === 110) return 4;
	if (p1(e)) return 2;
	if (p_(e.expression, !0)) {
		if (Q2(e.expression)) return 3;
		let t = e;
		for (; !Ke(t.expression);) t = t.expression;
		let a = t.expression;
		if ((a.escapedText === "exports" || a.escapedText === "module" && f_(t) === "exports") && b_(e)) return 1;
		if (p_(e, !0) || Ha(e) && J2(e)) return 5;
	}
	return 0;
}
function x2(e) {
	for (; na(e.right);) e = e.right;
	return e.right;
}
function S2(e) {
	return Pl(e) && na(e.expression) && yf(e.expression) !== 0 && na(e.expression.right) && (e.expression.right.operatorToken.kind === 57 || e.expression.right.operatorToken.kind === 61) ? e.expression.right.right : void 0;
}
function w2(e) {
	switch (e.kind) {
		case 244:
			let t = Up(e);
			return t && t.initializer;
		case 173: return e.initializer;
		case 304: return e.initializer;
	}
}
function Up(e) {
	return Xa(e) ? Hp(e.declarationList.declarations) : void 0;
}
function k2(e) {
	return Ti(e) && e.body && e.body.kind === 268 ? e.body : void 0;
}
function bf(e) {
	switch (e.kind) {
		case 220:
		case 227:
		case 242:
		case 253:
		case 180:
		case 297:
		case 264:
		case 232:
		case 176:
		case 177:
		case 186:
		case 181:
		case 252:
		case 260:
		case 247:
		case 213:
		case 243:
		case 1:
		case 267:
		case 307:
		case 278:
		case 279:
		case 282:
		case 245:
		case 250:
		case 251:
		case 249:
		case 263:
		case 219:
		case 185:
		case 178:
		case 80:
		case 246:
		case 273:
		case 272:
		case 182:
		case 265:
		case 318:
		case 324:
		case 257:
		case 175:
		case 174:
		case 268:
		case 203:
		case 271:
		case 211:
		case 170:
		case 218:
		case 212:
		case 304:
		case 173:
		case 172:
		case 254:
		case 241:
		case 179:
		case 305:
		case 306:
		case 256:
		case 258:
		case 259:
		case 266:
		case 169:
		case 261:
		case 244:
		case 248:
		case 255: return !0;
		default: return !1;
	}
}
function E2(e, t) {
	let a;
	p2(e) && n2(e) && Ki(e.initializer) && (a = En(a, jd(e, e.initializer.jsDoc)));
	let _ = e;
	for (; _ && _.parent;) {
		if (Ki(_) && (a = En(a, jd(e, _.jsDoc))), _.kind === 170) {
			a = En(a, (t ? vg : bg)(_));
			break;
		}
		if (_.kind === 169) {
			a = En(a, (t ? xg : Tg)(_));
			break;
		}
		_ = C2(_);
	}
	return a || vt;
}
function jd(e, t) {
	let a = dy(t);
	return Tm(t, (_) => {
		if (_ === a) {
			let f = Hr(_.tags, (h) => A2(e, h));
			return _.tags === f ? [_] : f;
		} else return Hr(_.tags, u6);
	});
}
function A2(e, t) {
	return !(zf(t) || m6(t)) || !t.parent || !rh(t.parent) || !Dl(t.parent.parent) || t.parent.parent === e;
}
function C2(e) {
	let t = e.parent;
	if (t.kind === 304 || t.kind === 278 || t.kind === 173 || t.kind === 245 && e.kind === 212 || t.kind === 254 || k2(t) || vl(e)) return t;
	if (t.parent && (Up(t.parent) === e || vl(t))) return t.parent;
	if (t.parent && t.parent.parent && (Up(t.parent.parent) || w2(t.parent.parent) === e || S2(t.parent.parent))) return t.parent.parent;
}
function vf(e, t) {
	return Vf(e, t ? -2147483647 : 1);
}
function D2(e) {
	let t = P2(e);
	if (t && ia(e)) {
		let a = Sg(e);
		if (a) return a.class;
	}
	return t;
}
function P2(e) {
	let t = Tf(e.heritageClauses, 96);
	return t && t.types.length > 0 ? t.types[0] : void 0;
}
function N2(e) {
	if (ia(e)) return wg(e).map((t) => t.class);
	return Tf(e.heritageClauses, 119)?.types;
}
function I2(e) {
	return T_(e) ? O2(e) || vt : ra(e) && Yp(Ip(D2(e)), N2(e)) || vt;
}
function O2(e) {
	let t = Tf(e.heritageClauses, 96);
	return t ? t.types : void 0;
}
function Tf(e, t) {
	if (e) {
		for (let a of e) if (a.token === t) return a;
	}
}
function di(e) {
	return 83 <= e && e <= 166;
}
function M2(e) {
	return 19 <= e && e <= 79;
}
function xp(e) {
	return di(e) || M2(e);
}
function Al(e) {
	return El(e) || aa(e);
}
function L2(e) {
	return z1(e) && (e.operator === 40 || e.operator === 41) && aa(e.operand);
}
function J2(e) {
	if (!(e.kind === 168 || e.kind === 213)) return !1;
	let t = Ha(e) ? vf(e.argumentExpression) : e.expression;
	return !Al(t) && !L2(t);
}
function j2(e) {
	return jp(e) ? An(e) : Q1(e) ? Eb(e) : e.text;
}
function Ja(e) {
	return d_(e.pos) || d_(e.end);
}
function Sp(e) {
	switch (e) {
		case 61: return 5;
		case 57: return 5;
		case 56: return 6;
		case 52: return 7;
		case 53: return 8;
		case 51: return 9;
		case 35:
		case 36:
		case 37:
		case 38: return 10;
		case 30:
		case 32:
		case 33:
		case 34:
		case 104:
		case 103:
		case 130:
		case 152: return 11;
		case 48:
		case 49:
		case 50: return 12;
		case 40:
		case 41: return 13;
		case 42:
		case 44:
		case 45: return 14;
		case 43: return 15;
	}
	return -1;
}
function wp(e) {
	return !!((e.templateFlags || 0) & 2048);
}
function R2(e) {
	return e && !!(E1(e) ? wp(e) : wp(e.head) || Zt(e.templateSpans, (t) => wp(t.literal)));
}
new Map(Object.entries({
	"	": "\\t",
	"\v": "\\v",
	"\f": "\\f",
	"\b": "\\b",
	"\r": "\\r",
	"\n": "\\n",
	"\\": "\\\\",
	"\"": "\\\"",
	"'": "\\'",
	"`": "\\`",
	"\u2028": "\\u2028",
	"\u2029": "\\u2029",
	"": "\\u0085",
	"\r\n": "\\r\\n"
}));
new Map(Object.entries({
	"\"": "&quot;",
	"'": "&apos;"
}));
function U2(e) {
	return !!e && e.kind === 80 && B2(e);
}
function B2(e) {
	return e.escapedText === "this";
}
function v_(e, t) {
	return !!z2(e, t);
}
function q2(e) {
	return v_(e, 256);
}
function F2(e) {
	return v_(e, 32768);
}
function z2(e, t) {
	return W2(e) & t;
}
function V2(e, t, a) {
	return e.kind >= 0 && e.kind <= 166 ? 0 : (e.modifierFlagsCache & 536870912 || (e.modifierFlagsCache = y1(e) | 536870912), a || t && ia(e) ? (!(e.modifierFlagsCache & 268435456) && e.parent && (e.modifierFlagsCache |= m1(e) | 268435456), h1(e.modifierFlagsCache)) : G2(e.modifierFlagsCache));
}
function W2(e) {
	return V2(e, !1);
}
function m1(e) {
	let t = 0;
	return e.parent && !m_(e) && (ia(e) && (kg(e) && (t |= 8388608), Eg(e) && (t |= 16777216), Ag(e) && (t |= 33554432), Cg(e) && (t |= 67108864), Dg(e) && (t |= 134217728)), Pg(e) && (t |= 65536)), t;
}
function G2(e) {
	return e & 65535;
}
function h1(e) {
	return e & 131071 | (e & 260046848) >>> 23;
}
function Y2(e) {
	return h1(m1(e));
}
function H2(e) {
	return y1(e) | Y2(e);
}
function y1(e) {
	let t = Ol(e) ? Jn(e.modifiers) : 0;
	return (e.flags & 8 || e.kind === 80 && e.flags & 4096) && (t |= 32), t;
}
function Jn(e) {
	let t = 0;
	if (e) for (let a of e) t |= g1(a.kind);
	return t;
}
function g1(e) {
	switch (e) {
		case 126: return 256;
		case 125: return 1;
		case 124: return 4;
		case 123: return 2;
		case 128: return 64;
		case 129: return 512;
		case 95: return 32;
		case 138: return 128;
		case 87: return 4096;
		case 90: return 2048;
		case 134: return 1024;
		case 148: return 8;
		case 164: return 16;
		case 103: return 8192;
		case 147: return 16384;
		case 171: return 32768;
	}
	return 0;
}
function X2(e) {
	return e === 76 || e === 77 || e === 78;
}
function b1(e) {
	return e >= 64 && e <= 79;
}
function vl(e, t) {
	return na(e) && (t ? e.operatorToken.kind === 64 : b1(e.operatorToken.kind)) && Fa(e.left);
}
function xf(e) {
	return e.kind === 80 || $2(e);
}
function $2(e) {
	return dr(e) && Ke(e.name) && xf(e.expression);
}
function Q2(e) {
	return b_(e) && f_(e) === "prototype";
}
function kp(e) {
	return e.flags & 3899393 ? e.objectFlags : 0;
}
function K2(e) {
	let t;
	return Xt(e, (a) => {
		Rp(a) && (t = a);
	}, (a) => {
		for (let _ = a.length - 1; _ >= 0; _--) if (Rp(a[_])) {
			t = a[_];
			break;
		}
	}), t;
}
function Z2(e) {
	return e >= 183 && e <= 206 || e === 133 || e === 159 || e === 150 || e === 163 || e === 151 || e === 136 || e === 154 || e === 155 || e === 116 || e === 157 || e === 146 || e === 141 || e === 234 || e === 313 || e === 314 || e === 315 || e === 316 || e === 317 || e === 318 || e === 319;
}
function v1(e) {
	return e.kind === 212 || e.kind === 213;
}
function eb(e, t) {
	this.flags = e, this.escapedName = t, this.declarations = void 0, this.valueDeclaration = void 0, this.id = 0, this.mergeId = 0, this.parent = void 0, this.members = void 0, this.exports = void 0, this.exportSymbol = void 0, this.constEnumOnlyModule = void 0, this.isReferenced = void 0, this.lastAssignmentPos = void 0, this.links = void 0;
}
function tb(e, t) {
	this.flags = t, (q.isDebugging || ll) && (this.checker = e);
}
function nb(e, t) {
	this.flags = t, q.isDebugging && (this.checker = e);
}
function Ep(e, t, a) {
	this.pos = t, this.end = a, this.kind = e, this.id = 0, this.flags = 0, this.modifierFlagsCache = 0, this.transformFlags = 0, this.parent = void 0, this.original = void 0, this.emitNode = void 0;
}
function rb(e, t, a) {
	this.pos = t, this.end = a, this.kind = e, this.id = 0, this.flags = 0, this.transformFlags = 0, this.parent = void 0, this.emitNode = void 0;
}
function ib(e, t, a) {
	this.pos = t, this.end = a, this.kind = e, this.id = 0, this.flags = 0, this.transformFlags = 0, this.parent = void 0, this.original = void 0, this.emitNode = void 0;
}
function ab(e, t, a) {
	this.fileName = e, this.text = t, this.skipTrivia = a || ((_) => _);
}
var Et = {
	getNodeConstructor: () => Ep,
	getTokenConstructor: () => rb,
	getIdentifierConstructor: () => ib,
	getPrivateIdentifierConstructor: () => Ep,
	getSourceFileConstructor: () => Ep,
	getSymbolConstructor: () => eb,
	getTypeConstructor: () => tb,
	getSignatureConstructor: () => nb,
	getSourceMapSourceConstructor: () => ab
}, sb = [];
function _b(e) {
	Object.assign(Et, e), jn(sb, (t) => t(Et));
}
function ob(e, t) {
	return e.replace(/\{(\d+)\}/g, (a, _) => "" + q.checkDefined(t[+_]));
}
var Rd;
function cb(e) {
	return Rd && Rd[e.key] || e.message;
}
function Oa(e, t, a, _, f, ...h) {
	a + _ > t.length && (_ = t.length - a), c2(t, a, _);
	let T = cb(f);
	return Zt(h) && (T = ob(T, h)), {
		file: void 0,
		start: a,
		length: _,
		messageText: T,
		category: f.category,
		code: f.code,
		reportsUnnecessary: f.reportsUnnecessary,
		fileName: e
	};
}
function lb(e) {
	return e.file === void 0 && e.start !== void 0 && e.length !== void 0 && typeof e.fileName == "string";
}
function T1(e, t) {
	let a = t.fileName || "", _ = t.text.length;
	q.assertEqual(e.fileName, a), q.assertLessThanOrEqual(e.start, _), q.assertLessThanOrEqual(e.start + e.length, _);
	let f = {
		file: t,
		start: e.start,
		length: e.length,
		messageText: e.messageText,
		category: e.category,
		code: e.code,
		reportsUnnecessary: e.reportsUnnecessary
	};
	if (e.relatedInformation) {
		f.relatedInformation = [];
		for (let h of e.relatedInformation) lb(h) && h.fileName === a ? (q.assertLessThanOrEqual(h.start, _), q.assertLessThanOrEqual(h.start + h.length, _), f.relatedInformation.push(T1(h, t))) : f.relatedInformation.push(h);
	}
	return f;
}
function Yi(e, t) {
	let a = [];
	for (let _ of e) a.push(T1(_, t));
	return a;
}
function Ud(e) {
	return e === 4 || e === 2 || e === 1 || e === 6 ? 1 : 0;
}
var it = {
	allowImportingTsExtensions: {
		dependencies: ["rewriteRelativeImportExtensions"],
		computeValue: (e) => !!(e.allowImportingTsExtensions || e.rewriteRelativeImportExtensions)
	},
	target: {
		dependencies: ["module"],
		computeValue: (e) => (e.target === 0 ? void 0 : e.target) ?? (e.module === 100 && 9 || e.module === 101 && 9 || e.module === 102 && 10 || e.module === 199 && 99 || 1)
	},
	module: {
		dependencies: ["target"],
		computeValue: (e) => typeof e.module == "number" ? e.module : it.target.computeValue(e) >= 2 ? 5 : 1
	},
	moduleResolution: {
		dependencies: ["module", "target"],
		computeValue: (e) => {
			let t = e.moduleResolution;
			if (t === void 0) switch (it.module.computeValue(e)) {
				case 1:
					t = 2;
					break;
				case 100:
				case 101:
				case 102:
					t = 3;
					break;
				case 199:
					t = 99;
					break;
				case 200:
					t = 100;
					break;
				default:
					t = 1;
					break;
			}
			return t;
		}
	},
	moduleDetection: {
		dependencies: ["module", "target"],
		computeValue: (e) => {
			if (e.moduleDetection !== void 0) return e.moduleDetection;
			let t = it.module.computeValue(e);
			return 100 <= t && t <= 199 ? 3 : 2;
		}
	},
	isolatedModules: {
		dependencies: ["verbatimModuleSyntax"],
		computeValue: (e) => !!(e.isolatedModules || e.verbatimModuleSyntax)
	},
	esModuleInterop: {
		dependencies: ["module", "target"],
		computeValue: (e) => {
			if (e.esModuleInterop !== void 0) return e.esModuleInterop;
			switch (it.module.computeValue(e)) {
				case 100:
				case 101:
				case 102:
				case 199:
				case 200: return !0;
			}
			return !1;
		}
	},
	allowSyntheticDefaultImports: {
		dependencies: [
			"module",
			"target",
			"moduleResolution"
		],
		computeValue: (e) => e.allowSyntheticDefaultImports !== void 0 ? e.allowSyntheticDefaultImports : it.esModuleInterop.computeValue(e) || it.module.computeValue(e) === 4 || it.moduleResolution.computeValue(e) === 100
	},
	resolvePackageJsonExports: {
		dependencies: ["moduleResolution"],
		computeValue: (e) => {
			let t = it.moduleResolution.computeValue(e);
			if (!Bd(t)) return !1;
			if (e.resolvePackageJsonExports !== void 0) return e.resolvePackageJsonExports;
			switch (t) {
				case 3:
				case 99:
				case 100: return !0;
			}
			return !1;
		}
	},
	resolvePackageJsonImports: {
		dependencies: ["moduleResolution", "resolvePackageJsonExports"],
		computeValue: (e) => {
			let t = it.moduleResolution.computeValue(e);
			if (!Bd(t)) return !1;
			if (e.resolvePackageJsonImports !== void 0) return e.resolvePackageJsonImports;
			switch (t) {
				case 3:
				case 99:
				case 100: return !0;
			}
			return !1;
		}
	},
	resolveJsonModule: {
		dependencies: [
			"moduleResolution",
			"module",
			"target"
		],
		computeValue: (e) => {
			if (e.resolveJsonModule !== void 0) return e.resolveJsonModule;
			switch (it.module.computeValue(e)) {
				case 102:
				case 199: return !0;
			}
			return it.moduleResolution.computeValue(e) === 100;
		}
	},
	declaration: {
		dependencies: ["composite"],
		computeValue: (e) => !!(e.declaration || e.composite)
	},
	preserveConstEnums: {
		dependencies: ["isolatedModules", "verbatimModuleSyntax"],
		computeValue: (e) => !!(e.preserveConstEnums || it.isolatedModules.computeValue(e))
	},
	incremental: {
		dependencies: ["composite"],
		computeValue: (e) => !!(e.incremental || e.composite)
	},
	declarationMap: {
		dependencies: ["declaration", "composite"],
		computeValue: (e) => !!(e.declarationMap && it.declaration.computeValue(e))
	},
	allowJs: {
		dependencies: ["checkJs"],
		computeValue: (e) => e.allowJs === void 0 ? !!e.checkJs : e.allowJs
	},
	useDefineForClassFields: {
		dependencies: ["target", "module"],
		computeValue: (e) => e.useDefineForClassFields === void 0 ? it.target.computeValue(e) >= 9 : e.useDefineForClassFields
	},
	noImplicitAny: {
		dependencies: ["strict"],
		computeValue: (e) => Gr(e, "noImplicitAny")
	},
	noImplicitThis: {
		dependencies: ["strict"],
		computeValue: (e) => Gr(e, "noImplicitThis")
	},
	strictNullChecks: {
		dependencies: ["strict"],
		computeValue: (e) => Gr(e, "strictNullChecks")
	},
	strictFunctionTypes: {
		dependencies: ["strict"],
		computeValue: (e) => Gr(e, "strictFunctionTypes")
	},
	strictBindCallApply: {
		dependencies: ["strict"],
		computeValue: (e) => Gr(e, "strictBindCallApply")
	},
	strictPropertyInitialization: {
		dependencies: ["strict"],
		computeValue: (e) => Gr(e, "strictPropertyInitialization")
	},
	strictBuiltinIteratorReturn: {
		dependencies: ["strict"],
		computeValue: (e) => Gr(e, "strictBuiltinIteratorReturn")
	},
	alwaysStrict: {
		dependencies: ["strict"],
		computeValue: (e) => Gr(e, "alwaysStrict")
	},
	useUnknownInCatchVariables: {
		dependencies: ["strict"],
		computeValue: (e) => Gr(e, "useUnknownInCatchVariables")
	}
};
it.allowImportingTsExtensions.computeValue;
it.target.computeValue;
it.module.computeValue;
it.moduleResolution.computeValue;
it.moduleDetection.computeValue;
it.isolatedModules.computeValue;
it.esModuleInterop.computeValue;
it.allowSyntheticDefaultImports.computeValue;
it.resolvePackageJsonExports.computeValue;
it.resolvePackageJsonImports.computeValue;
it.resolveJsonModule.computeValue;
it.declaration.computeValue;
it.preserveConstEnums.computeValue;
it.incremental.computeValue;
it.declarationMap.computeValue;
it.allowJs.computeValue;
it.useDefineForClassFields.computeValue;
function Bd(e) {
	return e >= 3 && e <= 99 || e === 100;
}
function Gr(e, t) {
	return e[t] === void 0 ? !!e.strict : !!e[t];
}
function ub(e) {
	return a2(targetOptionDeclaration.type, (t, a) => t === e ? a : void 0);
}
var x1 = `(?!(?:${[
	"node_modules",
	"bower_components",
	"jspm_packages"
].join("|")})(?:/|$))`, fb = {
	singleAsteriskRegexFragment: "(?:[^./]|(?:\\.(?!min\\.js$))?)*",
	doubleAsteriskRegexFragment: `(?:/${x1}[^/.][^/]*)*?`,
	replaceWildcardCharacter: (e) => S1(e, fb.singleAsteriskRegexFragment)
}, db = {
	singleAsteriskRegexFragment: "[^/]*",
	doubleAsteriskRegexFragment: `(?:/${x1}[^/.][^/]*)*?`,
	replaceWildcardCharacter: (e) => S1(e, db.singleAsteriskRegexFragment)
};
function S1(e, t) {
	return e === "*" ? t : e === "?" ? "[^/]" : "\\" + e;
}
function mb(e, t) {
	return t || hb(e) || 3;
}
function hb(e) {
	switch (e.substr(e.lastIndexOf(".")).toLowerCase()) {
		case ".js":
		case ".cjs":
		case ".mjs": return 1;
		case ".jsx": return 2;
		case ".ts":
		case ".cts":
		case ".mts": return 3;
		case ".tsx": return 4;
		case ".json": return 6;
		default: return 0;
	}
}
var w1 = [
	[
		".ts",
		".tsx",
		".d.ts"
	],
	[".cts", ".d.cts"],
	[".mts", ".d.mts"]
];
vm(w1);
[...w1];
vm([
	[".js", ".jsx"],
	[".mjs"],
	[".cjs"]
]);
var bb = [
	".d.ts",
	".d.cts",
	".d.mts"
];
function d_(e) {
	return !(e >= 0);
}
function sl(e, ...t) {
	return t.length && (e.relatedInformation || (e.relatedInformation = []), q.assert(e.relatedInformation !== vt, "Diagnostic had empty array singleton for related info, but is still being constructed!"), e.relatedInformation.push(...t)), e;
}
function vb(e) {
	let t;
	switch (e.charCodeAt(1)) {
		case 98:
		case 66:
			t = 1;
			break;
		case 111:
		case 79:
			t = 3;
			break;
		case 120:
		case 88:
			t = 4;
			break;
		default:
			let W = e.length - 1, y = 0;
			for (; e.charCodeAt(y) === 48;) y++;
			return e.slice(y, W) || "0";
	}
	let a = 2, _ = e.length - 1, f = (_ - a) * t, h = new Uint16Array((f >>> 4) + (f & 15 ? 1 : 0));
	for (let W = _ - 1, y = 0; W >= a; W--, y += t) {
		let G = y >>> 4, E = e.charCodeAt(W), R = (E <= 57 ? E - 48 : 10 + E - (E <= 70 ? 65 : 97)) << (y & 15);
		h[G] |= R;
		let ue = R >>> 16;
		ue && (h[G + 1] |= ue);
	}
	let T = "", k = h.length - 1, c = !0;
	for (; c;) {
		let W = 0;
		c = !1;
		for (let y = k; y >= 0; y--) {
			let G = W << 16 | h[y], E = G / 10 | 0;
			h[y] = E, W = G - E * 10, E && !c && (k = y, c = !0);
		}
		T = W + T;
	}
	return T;
}
function Tb({ negative: e, base10Value: t }) {
	return (e && t !== "0" ? "-" : "") + t;
}
function Bp(e, t) {
	return e.pos = t, e;
}
function xb(e, t) {
	return e.end = t, e;
}
function yi(e, t, a) {
	return xb(Bp(e, t), a);
}
function qd(e, t, a) {
	return yi(e, t, t + a);
}
function Sf(e, t) {
	return e && t && (e.parent = t), e;
}
function Sb(e, t) {
	if (!e) return e;
	return dm(e, l1(e) ? a : f), e;
	function a(h, T) {
		if (t && h.parent === T) return "skip";
		Sf(h, T);
	}
	function _(h) {
		if (Ki(h)) for (let T of h.jsDoc) a(T, h), dm(T, a);
	}
	function f(h, T) {
		return a(h, T) || _(h);
	}
}
function wb(e) {
	return !!(e.flags & 262144 && e.isThisType);
}
function kb(e) {
	var t;
	return ((t = getSnippetElement(e)) == null ? void 0 : t.kind) === 0;
}
function Eb(e) {
	return `${An(e.namespace)}:${An(e.name)}`;
}
String.prototype.replace;
var qp = [
	"assert",
	"assert/strict",
	"async_hooks",
	"buffer",
	"child_process",
	"cluster",
	"console",
	"constants",
	"crypto",
	"dgram",
	"diagnostics_channel",
	"dns",
	"dns/promises",
	"domain",
	"events",
	"fs",
	"fs/promises",
	"http",
	"http2",
	"https",
	"inspector",
	"inspector/promises",
	"module",
	"net",
	"os",
	"path",
	"path/posix",
	"path/win32",
	"perf_hooks",
	"process",
	"punycode",
	"querystring",
	"readline",
	"readline/promises",
	"repl",
	"stream",
	"stream/consumers",
	"stream/promises",
	"stream/web",
	"string_decoder",
	"sys",
	"test/mock_loader",
	"timers",
	"timers/promises",
	"tls",
	"trace_events",
	"tty",
	"url",
	"util",
	"util/types",
	"v8",
	"vm",
	"wasi",
	"worker_threads",
	"zlib"
];
new Set(qp);
var Ab = new Set([
	"node:sea",
	"node:sqlite",
	"node:test",
	"node:test/reporters"
]);
new Set([
	...qp,
	...qp.map((e) => `node:${e}`),
	...Ab
]);
function Cb() {
	let e, t, a, _, f;
	return {
		createBaseSourceFileNode: h,
		createBaseIdentifierNode: T,
		createBasePrivateIdentifierNode: k,
		createBaseTokenNode: c,
		createBaseNode: W
	};
	function h(y) {
		return new (f || (f = (Et.getSourceFileConstructor())))(y, -1, -1);
	}
	function T(y) {
		return new (a || (a = (Et.getIdentifierConstructor())))(y, -1, -1);
	}
	function k(y) {
		return new (_ || (_ = (Et.getPrivateIdentifierConstructor())))(y, -1, -1);
	}
	function c(y) {
		return new (t || (t = (Et.getTokenConstructor())))(y, -1, -1);
	}
	function W(y) {
		return new (e || (e = (Et.getNodeConstructor())))(y, -1, -1);
	}
}
var Db = {
	getParenthesizeLeftSideOfBinaryForOperator: (e) => bt,
	getParenthesizeRightSideOfBinaryForOperator: (e) => bt,
	parenthesizeLeftSideOfBinary: (e, t) => t,
	parenthesizeRightSideOfBinary: (e, t, a) => a,
	parenthesizeExpressionOfComputedPropertyName: bt,
	parenthesizeConditionOfConditionalExpression: bt,
	parenthesizeBranchOfConditionalExpression: bt,
	parenthesizeExpressionOfExportDefault: bt,
	parenthesizeExpressionOfNew: (e) => Er(e, Fa),
	parenthesizeLeftSideOfAccess: (e) => Er(e, Fa),
	parenthesizeOperandOfPostfixUnary: (e) => Er(e, Fa),
	parenthesizeOperandOfPrefixUnary: (e) => Er(e, Hg),
	parenthesizeExpressionsOfCommaDelimitedList: (e) => Er(e, mi),
	parenthesizeExpressionForDisallowedComma: bt,
	parenthesizeExpressionOfExpressionStatement: bt,
	parenthesizeConciseBodyOfArrowFunction: bt,
	parenthesizeCheckTypeOfConditionalType: bt,
	parenthesizeExtendsTypeOfConditionalType: bt,
	parenthesizeConstituentTypesOfUnionType: (e) => Er(e, mi),
	parenthesizeConstituentTypeOfUnionType: bt,
	parenthesizeConstituentTypesOfIntersectionType: (e) => Er(e, mi),
	parenthesizeConstituentTypeOfIntersectionType: bt,
	parenthesizeOperandOfTypeOperator: bt,
	parenthesizeOperandOfReadonlyTypeOperator: bt,
	parenthesizeNonArrayTypeOfPostfixType: bt,
	parenthesizeElementTypesOfTupleType: (e) => Er(e, mi),
	parenthesizeElementTypeOfTupleType: bt,
	parenthesizeTypeOfOptionalType: bt,
	parenthesizeTypeArguments: (e) => e && Er(e, mi),
	parenthesizeLeadingTypeArgument: bt
}, _l = 0;
var Pb = [];
function wf(e, t) {
	let a = e & 8 ? bt : Lb, _ = gd(() => e & 1 ? Db : createParenthesizerRules(he)), f = gd(() => e & 2 ? nullNodeConverters : createNodeConverters(he)), h = Kn((n) => (i, s) => da(i, n, s)), T = Kn((n) => (i) => Ur(n, i)), k = Kn((n) => (i) => ni(i, n)), c = Kn((n) => () => Qo(n)), W = Kn((n) => (i) => Cs(n, i)), y = Kn((n) => (i, s) => wu(n, i, s)), G = Kn((n) => (i, s) => Ko(n, i, s)), E = Kn((n) => (i, s) => Su(n, i, s)), D = Kn((n) => (i, s) => hc(n, i, s)), R = Kn((n) => (i, s, l) => Lu(n, i, s, l)), ue = Kn((n) => (i, s, l) => yc(n, i, s, l)), be = Kn((n) => (i, s, l, d) => Ju(n, i, s, l, d)), he = {
		get parenthesizer() {
			return _();
		},
		get converters() {
			return f();
		},
		baseFactory: t,
		flags: e,
		createNodeArray: de,
		createNumericLiteral: V,
		createBigIntLiteral: oe,
		createStringLiteral: ft,
		createStringLiteralFromNode: nr,
		createRegularExpressionLiteral: mn,
		createLiteralLikeNode: rr,
		createIdentifier: We,
		createTempVariable: ir,
		createLoopVariable: Ir,
		createUniqueName: Ot,
		getGeneratedNameForNode: Bn,
		createPrivateIdentifier: Mt,
		createUniquePrivateName: $e,
		getGeneratedPrivateNameForNode: qn,
		createToken: ot,
		createSuper: at,
		createThis: Bt,
		createNull: Lt,
		createTrue: ct,
		createFalse: ar,
		createModifier: dt,
		createModifiersFromModifierFlags: yn,
		createQualifiedName: yt,
		updateQualifiedName: _n,
		createComputedPropertyName: tt,
		updateComputedPropertyName: qt,
		createTypeParameterDeclaration: tn,
		updateTypeParameterDeclaration: sr,
		createParameterDeclaration: mr,
		updateParameterDeclaration: hr,
		createDecorator: Fn,
		updateDecorator: zn,
		createPropertySignature: Or,
		updatePropertySignature: Vn,
		createPropertyDeclaration: yr,
		updatePropertyDeclaration: L,
		createMethodSignature: se,
		updateMethodSignature: fe,
		createMethodDeclaration: Te,
		updateMethodDeclaration: He,
		createConstructorDeclaration: lt,
		updateConstructorDeclaration: Mr,
		createGetAccessorDeclaration: Nn,
		updateGetAccessorDeclaration: Wn,
		createSetAccessorDeclaration: U,
		updateSetAccessorDeclaration: K,
		createCallSignature: xe,
		updateCallSignature: Se,
		createConstructSignature: we,
		updateConstructSignature: me,
		createIndexSignature: Ve,
		updateIndexSignature: Ze,
		createClassStaticBlockDeclaration: st,
		updateClassStaticBlockDeclaration: Ct,
		createTemplateLiteralTypeSpan: Ye,
		updateTemplateLiteralTypeSpan: Ee,
		createKeywordTypeNode: gn,
		createTypePredicateNode: rt,
		updateTypePredicateNode: on,
		createTypeReferenceNode: Zr,
		updateTypeReferenceNode: M,
		createFunctionTypeNode: Ue,
		updateFunctionTypeNode: u,
		createConstructorTypeNode: Me,
		updateConstructorTypeNode: nn,
		createTypeQueryNode: Dt,
		updateTypeQueryNode: wt,
		createTypeLiteralNode: Pt,
		updateTypeLiteralNode: Ft,
		createArrayTypeNode: Gn,
		updateArrayTypeNode: ki,
		createTupleTypeNode: cn,
		updateTupleTypeNode: H,
		createNamedTupleMember: le,
		updateNamedTupleMember: qe,
		createOptionalTypeNode: ve,
		updateOptionalTypeNode: J,
		createRestTypeNode: mt,
		updateRestTypeNode: xt,
		createUnionTypeNode: ql,
		updateUnionTypeNode: C_,
		createIntersectionTypeNode: Lr,
		updateIntersectionTypeNode: Le,
		createConditionalTypeNode: pt,
		updateConditionalTypeNode: Fl,
		createInferTypeNode: Yn,
		updateInferTypeNode: zl,
		createImportTypeNode: _r,
		updateImportTypeNode: oa,
		createParenthesizedType: Qt,
		updateParenthesizedType: At,
		createThisTypeNode: P,
		createTypeOperatorNode: Gt,
		updateTypeOperatorNode: Jr,
		createIndexedAccessTypeNode: or,
		updateIndexedAccessTypeNode: Ka,
		createMappedTypeNode: gt,
		updateMappedTypeNode: jt,
		createLiteralTypeNode: ei,
		updateLiteralTypeNode: br,
		createTemplateLiteralType: Wt,
		updateTemplateLiteralType: Vl,
		createObjectBindingPattern: D_,
		updateObjectBindingPattern: Wl,
		createArrayBindingPattern: jr,
		updateArrayBindingPattern: Gl,
		createBindingElement: ca,
		updateBindingElement: ti,
		createArrayLiteralExpression: Za,
		updateArrayLiteralExpression: P_,
		createObjectLiteralExpression: Ei,
		updateObjectLiteralExpression: Yl,
		createPropertyAccessExpression: e & 4 ? (n, i) => setEmitFlags(cr(n, i), 262144) : cr,
		updatePropertyAccessExpression: Hl,
		createPropertyAccessChain: e & 4 ? (n, i, s) => setEmitFlags(Ai(n, i, s), 262144) : Ai,
		updatePropertyAccessChain: la,
		createElementAccessExpression: Ci,
		updateElementAccessExpression: Xl,
		createElementAccessChain: O_,
		updateElementAccessChain: es,
		createCallExpression: Di,
		updateCallExpression: ua,
		createCallChain: ts,
		updateCallChain: L_,
		createNewExpression: bn,
		updateNewExpression: ns,
		createTaggedTemplateExpression: pa,
		updateTaggedTemplateExpression: J_,
		createTypeAssertion: j_,
		updateTypeAssertion: R_,
		createParenthesizedExpression: rs,
		updateParenthesizedExpression: U_,
		createFunctionExpression: is,
		updateFunctionExpression: B_,
		createArrowFunction: as,
		updateArrowFunction: q_,
		createDeleteExpression: F_,
		updateDeleteExpression: z_,
		createTypeOfExpression: fa,
		updateTypeOfExpression: un,
		createVoidExpression: ss,
		updateVoidExpression: lr,
		createAwaitExpression: V_,
		updateAwaitExpression: Rr,
		createPrefixUnaryExpression: Ur,
		updatePrefixUnaryExpression: $l,
		createPostfixUnaryExpression: ni,
		updatePostfixUnaryExpression: Ql,
		createBinaryExpression: da,
		updateBinaryExpression: Kl,
		createConditionalExpression: G_,
		updateConditionalExpression: Y_,
		createTemplateExpression: H_,
		updateTemplateExpression: Hn,
		createTemplateHead: $_,
		createTemplateMiddle: ma,
		createTemplateTail: _s,
		createNoSubstitutionTemplateLiteral: eu,
		createTemplateLiteralLikeNode: ii,
		createYieldExpression: os,
		updateYieldExpression: tu,
		createSpreadElement: Q_,
		updateSpreadElement: nu,
		createClassExpression: K_,
		updateClassExpression: cs,
		createOmittedExpression: ls,
		createExpressionWithTypeArguments: Z_,
		updateExpressionWithTypeArguments: eo,
		createAsExpression: pn,
		updateAsExpression: ha,
		createNonNullExpression: to,
		updateNonNullExpression: no,
		createSatisfiesExpression: us,
		updateSatisfiesExpression: ro,
		createNonNullChain: ps,
		updateNonNullChain: In,
		createMetaProperty: io,
		updateMetaProperty: fs,
		createTemplateSpan: Xn,
		updateTemplateSpan: ya,
		createSemicolonClassElement: ao,
		createBlock: Br,
		updateBlock: ru,
		createVariableStatement: ds,
		updateVariableStatement: so,
		createEmptyStatement: _o,
		createExpressionStatement: Ni,
		updateExpressionStatement: oo,
		createIfStatement: co,
		updateIfStatement: lo,
		createDoStatement: uo,
		updateDoStatement: po,
		createWhileStatement: fo,
		updateWhileStatement: iu,
		createForStatement: mo,
		updateForStatement: ho,
		createForInStatement: ms,
		updateForInStatement: au,
		createForOfStatement: yo,
		updateForOfStatement: su,
		createContinueStatement: go,
		updateContinueStatement: _u,
		createBreakStatement: hs,
		updateBreakStatement: bo,
		createReturnStatement: ys,
		updateReturnStatement: ou,
		createWithStatement: gs,
		updateWithStatement: vo,
		createSwitchStatement: bs,
		updateSwitchStatement: ai,
		createLabeledStatement: To,
		updateLabeledStatement: xo,
		createThrowStatement: So,
		updateThrowStatement: cu,
		createTryStatement: wo,
		updateTryStatement: lu,
		createDebuggerStatement: ko,
		createVariableDeclaration: ga,
		updateVariableDeclaration: Eo,
		createVariableDeclarationList: vs,
		updateVariableDeclarationList: uu,
		createFunctionDeclaration: Ao,
		updateFunctionDeclaration: Ts,
		createClassDeclaration: Co,
		updateClassDeclaration: ba,
		createInterfaceDeclaration: Do,
		updateInterfaceDeclaration: Po,
		createTypeAliasDeclaration: _t,
		updateTypeAliasDeclaration: vr,
		createEnumDeclaration: xs,
		updateEnumDeclaration: Tr,
		createModuleDeclaration: No,
		updateModuleDeclaration: kt,
		createModuleBlock: xr,
		updateModuleBlock: zt,
		createCaseBlock: Io,
		updateCaseBlock: fu,
		createNamespaceExportDeclaration: Oo,
		updateNamespaceExportDeclaration: Mo,
		createImportEqualsDeclaration: Lo,
		updateImportEqualsDeclaration: Jo,
		createImportDeclaration: jo,
		updateImportDeclaration: Ro,
		createImportClause: Uo,
		updateImportClause: Bo,
		createAssertClause: Ss,
		updateAssertClause: mu,
		createAssertEntry: Ii,
		updateAssertEntry: qo,
		createImportTypeAssertionContainer: ws,
		updateImportTypeAssertionContainer: Fo,
		createImportAttributes: zo,
		updateImportAttributes: ks,
		createImportAttribute: Vo,
		updateImportAttribute: Wo,
		createNamespaceImport: Go,
		updateNamespaceImport: hu,
		createNamespaceExport: Yo,
		updateNamespaceExport: yu,
		createNamedImports: Ho,
		updateNamedImports: Xo,
		createImportSpecifier: Sr,
		updateImportSpecifier: gu,
		createExportAssignment: va,
		updateExportAssignment: Oi,
		createExportDeclaration: Ta,
		updateExportDeclaration: $o,
		createNamedExports: Es,
		updateNamedExports: bu,
		createExportSpecifier: xa,
		updateExportSpecifier: vu,
		createMissingDeclaration: Tu,
		createExternalModuleReference: As,
		updateExternalModuleReference: xu,
		get createJSDocAllType() {
			return c(313);
		},
		get createJSDocUnknownType() {
			return c(314);
		},
		get createJSDocNonNullableType() {
			return G(316);
		},
		get updateJSDocNonNullableType() {
			return E(316);
		},
		get createJSDocNullableType() {
			return G(315);
		},
		get updateJSDocNullableType() {
			return E(315);
		},
		get createJSDocOptionalType() {
			return W(317);
		},
		get updateJSDocOptionalType() {
			return y(317);
		},
		get createJSDocVariadicType() {
			return W(319);
		},
		get updateJSDocVariadicType() {
			return y(319);
		},
		get createJSDocNamepathType() {
			return W(320);
		},
		get updateJSDocNamepathType() {
			return y(320);
		},
		createJSDocFunctionType: Zo,
		updateJSDocFunctionType: ku,
		createJSDocTypeLiteral: ec,
		updateJSDocTypeLiteral: Eu,
		createJSDocTypeExpression: tc,
		updateJSDocTypeExpression: Ds,
		createJSDocSignature: nc,
		updateJSDocSignature: Au,
		createJSDocTemplateTag: Ps,
		updateJSDocTemplateTag: rc,
		createJSDocTypedefTag: Sa,
		updateJSDocTypedefTag: Cu,
		createJSDocParameterTag: Ns,
		updateJSDocParameterTag: Du,
		createJSDocPropertyTag: ic,
		updateJSDocPropertyTag: ac,
		createJSDocCallbackTag: sc,
		updateJSDocCallbackTag: _c,
		createJSDocOverloadTag: oc,
		updateJSDocOverloadTag: Is,
		createJSDocAugmentsTag: Os,
		updateJSDocAugmentsTag: Li,
		createJSDocImplementsTag: cc,
		updateJSDocImplementsTag: Mu,
		createJSDocSeeTag: Fr,
		updateJSDocSeeTag: wa,
		createJSDocImportTag: vc,
		updateJSDocImportTag: Tc,
		createJSDocNameReference: lc,
		updateJSDocNameReference: Pu,
		createJSDocMemberName: uc,
		updateJSDocMemberName: Nu,
		createJSDocLink: pc,
		updateJSDocLink: fc,
		createJSDocLinkCode: dc,
		updateJSDocLinkCode: Iu,
		createJSDocLinkPlain: mc,
		updateJSDocLinkPlain: Ou,
		get createJSDocTypeTag() {
			return ue(345);
		},
		get updateJSDocTypeTag() {
			return be(345);
		},
		get createJSDocReturnTag() {
			return ue(343);
		},
		get updateJSDocReturnTag() {
			return be(343);
		},
		get createJSDocThisTag() {
			return ue(344);
		},
		get updateJSDocThisTag() {
			return be(344);
		},
		get createJSDocAuthorTag() {
			return D(331);
		},
		get updateJSDocAuthorTag() {
			return R(331);
		},
		get createJSDocClassTag() {
			return D(333);
		},
		get updateJSDocClassTag() {
			return R(333);
		},
		get createJSDocPublicTag() {
			return D(334);
		},
		get updateJSDocPublicTag() {
			return R(334);
		},
		get createJSDocPrivateTag() {
			return D(335);
		},
		get updateJSDocPrivateTag() {
			return R(335);
		},
		get createJSDocProtectedTag() {
			return D(336);
		},
		get updateJSDocProtectedTag() {
			return R(336);
		},
		get createJSDocReadonlyTag() {
			return D(337);
		},
		get updateJSDocReadonlyTag() {
			return R(337);
		},
		get createJSDocOverrideTag() {
			return D(338);
		},
		get updateJSDocOverrideTag() {
			return R(338);
		},
		get createJSDocDeprecatedTag() {
			return D(332);
		},
		get updateJSDocDeprecatedTag() {
			return R(332);
		},
		get createJSDocThrowsTag() {
			return ue(350);
		},
		get updateJSDocThrowsTag() {
			return be(350);
		},
		get createJSDocSatisfiesTag() {
			return ue(351);
		},
		get updateJSDocSatisfiesTag() {
			return be(351);
		},
		createJSDocEnumTag: bc,
		updateJSDocEnumTag: Ms,
		createJSDocUnknownTag: gc,
		updateJSDocUnknownTag: ju,
		createJSDocText: Ls,
		updateJSDocText: Ru,
		createJSDocComment: Ji,
		updateJSDocComment: xc,
		createJsxElement: Sc,
		updateJsxElement: Uu,
		createJsxSelfClosingElement: wc,
		updateJsxSelfClosingElement: Bu,
		createJsxOpeningElement: ka,
		updateJsxOpeningElement: kc,
		createJsxClosingElement: Js,
		updateJsxClosingElement: js,
		createJsxFragment: Yt,
		createJsxText: ji,
		updateJsxText: qu,
		createJsxOpeningFragment: Ac,
		createJsxJsxClosingFragment: Cc,
		updateJsxFragment: Ec,
		createJsxAttribute: Dc,
		updateJsxAttribute: Fu,
		createJsxAttributes: Ri,
		updateJsxAttributes: zu,
		createJsxSpreadAttribute: Pc,
		updateJsxSpreadAttribute: Vu,
		createJsxExpression: Nc,
		updateJsxExpression: Rs,
		createJsxNamespacedName: si,
		updateJsxNamespacedName: Wu,
		createCaseClause: Ea,
		updateCaseClause: Ic,
		createDefaultClause: Oc,
		updateDefaultClause: Ui,
		createHeritageClause: Us,
		updateHeritageClause: Gu,
		createCatchClause: Mc,
		updateCatchClause: Lc,
		createPropertyAssignment: Aa,
		updatePropertyAssignment: Bs,
		createShorthandPropertyAssignment: Jc,
		updateShorthandPropertyAssignment: Yu,
		createSpreadAssignment: jc,
		updateSpreadAssignment: Rc,
		createEnumMember: qs,
		updateEnumMember: On,
		createSourceFile: Uc,
		updateSourceFile: Qu,
		createRedirectedSourceFile: Bc,
		createBundle: qc,
		updateBundle: Fc,
		createSyntheticExpression: Ku,
		createSyntaxList: Zu,
		createNotEmittedStatement: Ca,
		createNotEmittedTypeElement: ep,
		createPartiallyEmittedExpression: Vs,
		updatePartiallyEmittedExpression: zc,
		createCommaListExpression: Ws,
		updateCommaListExpression: np,
		createSyntheticReferenceExpression: Gs,
		updateSyntheticReferenceExpression: Vc,
		cloneNode: Da,
		get createComma() {
			return h(28);
		},
		get createAssignment() {
			return h(64);
		},
		get createLogicalOr() {
			return h(57);
		},
		get createLogicalAnd() {
			return h(56);
		},
		get createBitwiseOr() {
			return h(52);
		},
		get createBitwiseXor() {
			return h(53);
		},
		get createBitwiseAnd() {
			return h(51);
		},
		get createStrictEquality() {
			return h(37);
		},
		get createStrictInequality() {
			return h(38);
		},
		get createEquality() {
			return h(35);
		},
		get createInequality() {
			return h(36);
		},
		get createLessThan() {
			return h(30);
		},
		get createLessThanEquals() {
			return h(33);
		},
		get createGreaterThan() {
			return h(32);
		},
		get createGreaterThanEquals() {
			return h(34);
		},
		get createLeftShift() {
			return h(48);
		},
		get createRightShift() {
			return h(49);
		},
		get createUnsignedRightShift() {
			return h(50);
		},
		get createAdd() {
			return h(40);
		},
		get createSubtract() {
			return h(41);
		},
		get createMultiply() {
			return h(42);
		},
		get createDivide() {
			return h(44);
		},
		get createModulo() {
			return h(45);
		},
		get createExponent() {
			return h(43);
		},
		get createPrefixPlus() {
			return T(40);
		},
		get createPrefixMinus() {
			return T(41);
		},
		get createPrefixIncrement() {
			return T(46);
		},
		get createPrefixDecrement() {
			return T(47);
		},
		get createBitwiseNot() {
			return T(55);
		},
		get createLogicalNot() {
			return T(54);
		},
		get createPostfixIncrement() {
			return k(46);
		},
		get createPostfixDecrement() {
			return k(47);
		},
		createImmediatelyInvokedFunctionExpression: ap,
		createImmediatelyInvokedArrowFunction: sp,
		createVoidZero: Bi,
		createExportDefault: Yc,
		createExternalModuleExport: Hc,
		createTypeCheck: _p,
		createIsNotTypeCheck: Ys,
		createMethodCall: zr,
		createGlobalMethodCall: qi,
		createFunctionBindCall: op,
		createFunctionCallCall: cp,
		createFunctionApplyCall: lp,
		createArraySliceCall: up,
		createArrayConcatCall: Fi,
		createObjectDefinePropertyCall: pp,
		createObjectGetOwnPropertyDescriptorCall: Hs,
		createReflectGetCall: oi,
		createReflectSetCall: Xc,
		createPropertyDescriptor: fp,
		createCallBinding: Zc,
		createAssignmentTargetWrapper: el,
		inlineExpressions: o,
		getInternalName: m,
		getLocalName: g,
		getExportName: b,
		getDeclarationName: N,
		getNamespaceMemberName: Q,
		getExternalModuleOrNamespaceExportName: _e,
		restoreOuterExpressions: Qc,
		restoreEnclosingLabel: Kc,
		createUseStrictPrologue: ce,
		copyPrologue: ee,
		copyStandardPrologue: je,
		copyCustomPrologue: Je,
		ensureUseStrict: De,
		liftToBlock: Ht,
		mergeLexicalEnvironment: ur,
		replaceModifiers: pr,
		replaceDecoratorsAndModifiers: Mn,
		replacePropertyName: Vr
	};
	return jn(Pb, (n) => n(he)), he;
	function de(n, i) {
		if (n === void 0 || n === vt) n = [];
		else if (mi(n)) {
			if (i === void 0 || n.hasTrailingComma === i) return n.transformFlags === void 0 && zd(n), q.attachNodeArrayDebugInfo(n), n;
			let d = n.slice();
			return d.pos = n.pos, d.end = n.end, d.hasTrailingComma = i, d.transformFlags = n.transformFlags, q.attachNodeArrayDebugInfo(d), d;
		}
		let s = n.length, l = s >= 1 && s <= 4 ? n.slice() : n;
		return l.pos = -1, l.end = -1, l.hasTrailingComma = !!i, l.transformFlags = 0, zd(l), q.attachNodeArrayDebugInfo(l), l;
	}
	function O(n) {
		return t.createBaseNode(n);
	}
	function ae(n) {
		let i = O(n);
		return i.symbol = void 0, i.localSymbol = void 0, i;
	}
	function Oe(n, i) {
		return n !== i && (n.typeArguments = i.typeArguments), j(n, i);
	}
	function V(n, i = 0) {
		let s = typeof n == "number" ? n + "" : n;
		q.assert(s.charCodeAt(0) !== 45, "Negative numbers should be created in combination with createPrefixUnaryExpression");
		let l = ae(9);
		return l.text = s, l.numericLiteralFlags = i, i & 384 && (l.transformFlags |= 1024), l;
	}
	function oe(n) {
		let i = $t(10);
		return i.text = typeof n == "string" ? n : Tb(n) + "n", i.transformFlags |= 32, i;
	}
	function Y(n, i) {
		let s = ae(11);
		return s.text = n, s.singleQuote = i, s;
	}
	function ft(n, i, s) {
		let l = Y(n, i);
		return l.hasExtendedUnicodeEscape = s, s && (l.transformFlags |= 1024), l;
	}
	function nr(n) {
		let i = Y(j2(n), void 0);
		return i.textSourceNode = n, i;
	}
	function mn(n) {
		let i = $t(14);
		return i.text = n, i;
	}
	function rr(n, i) {
		switch (n) {
			case 9: return V(i, 0);
			case 10: return oe(i);
			case 11: return ft(i, void 0);
			case 12: return ji(i, !1);
			case 13: return ji(i, !0);
			case 14: return mn(i);
			case 15: return ii(n, i, void 0, 0);
		}
	}
	function hn(n) {
		let i = t.createBaseIdentifierNode(80);
		return i.escapedText = n, i.jsDoc = void 0, i.flowNode = void 0, i.symbol = void 0, i;
	}
	function Dn(n, i, s, l) {
		let d = hn(La(n));
		return setIdentifierAutoGenerate(d, {
			flags: i,
			id: _l,
			prefix: s,
			suffix: l
		}), _l++, d;
	}
	function We(n, i, s) {
		i === void 0 && n && (i = Rm(n)), i === 80 && (i = void 0);
		let l = hn(La(n));
		return s && (l.flags |= 256), l.escapedText === "await" && (l.transformFlags |= 67108864), l.flags & 256 && (l.transformFlags |= 1024), l;
	}
	function ir(n, i, s, l) {
		let d = 1;
		i && (d |= 8);
		let v = Dn("", d, s, l);
		return n && n(v), v;
	}
	function Ir(n) {
		let i = 2;
		return n && (i |= 8), Dn("", i, void 0, void 0);
	}
	function Ot(n, i = 0, s, l) {
		return q.assert(!(i & 7), "Argument out of range: flags"), q.assert((i & 48) !== 32, "GeneratedIdentifierFlags.FileLevel cannot be set without also setting GeneratedIdentifierFlags.Optimistic"), Dn(n, 3 | i, s, l);
	}
	function Bn(n, i = 0, s, l) {
		q.assert(!(i & 7), "Argument out of range: flags");
		let d = n ? jp(n) ? Vp(!1, s, n, l, An) : `generated@${getNodeId(n)}` : "";
		(s || l) && (i |= 16);
		let v = Dn(d, 4 | i, s, l);
		return v.original = n, v;
	}
	function Pn(n) {
		let i = t.createBasePrivateIdentifierNode(81);
		return i.escapedText = n, i.transformFlags |= 16777216, i;
	}
	function Mt(n) {
		return ml(n, "#") || q.fail("First character of private identifier must be #: " + n), Pn(La(n));
	}
	function ht(n, i, s, l) {
		let d = Pn(La(n));
		return setIdentifierAutoGenerate(d, {
			flags: i,
			id: _l,
			prefix: s,
			suffix: l
		}), _l++, d;
	}
	function $e(n, i, s) {
		n && !ml(n, "#") && q.fail("First character of private identifier must be #: " + n);
		return ht(n ?? "", 8 | (n ? 3 : 1), i, s);
	}
	function qn(n, i, s) {
		let v = ht(jp(n) ? Vp(!0, i, n, s, An) : `#generated@${getNodeId(n)}`, 4 | (i || s ? 16 : 0), i, s);
		return v.original = n, v;
	}
	function $t(n) {
		return t.createBaseTokenNode(n);
	}
	function ot(n) {
		q.assert(n >= 0 && n <= 166, "Invalid token"), q.assert(n <= 15 || n >= 18, "Invalid token. Use 'createTemplateLiteralLikeNode' to create template literals."), q.assert(n <= 9 || n >= 15, "Invalid token. Use 'createLiteralLikeNode' to create literals."), q.assert(n !== 80, "Invalid token. Use 'createIdentifier' to create identifiers");
		let i = $t(n), s = 0;
		switch (n) {
			case 134:
				s = 384;
				break;
			case 160:
				s = 4;
				break;
			case 125:
			case 123:
			case 124:
			case 148:
			case 128:
			case 138:
			case 87:
			case 133:
			case 150:
			case 163:
			case 146:
			case 151:
			case 103:
			case 147:
			case 164:
			case 154:
			case 136:
			case 155:
			case 116:
			case 159:
			case 157:
				s = 1;
				break;
			case 108:
				s = 134218752, i.flowNode = void 0;
				break;
			case 126:
				s = 1024;
				break;
			case 129:
				s = 16777216;
				break;
			case 110:
				s = 16384, i.flowNode = void 0;
				break;
		}
		return s && (i.transformFlags |= s), i;
	}
	function at() {
		return ot(108);
	}
	function Bt() {
		return ot(110);
	}
	function Lt() {
		return ot(106);
	}
	function ct() {
		return ot(112);
	}
	function ar() {
		return ot(97);
	}
	function dt(n) {
		return ot(n);
	}
	function yn(n) {
		let i = [];
		return n & 32 && i.push(dt(95)), n & 128 && i.push(dt(138)), n & 2048 && i.push(dt(90)), n & 4096 && i.push(dt(87)), n & 1 && i.push(dt(125)), n & 2 && i.push(dt(123)), n & 4 && i.push(dt(124)), n & 64 && i.push(dt(128)), n & 256 && i.push(dt(126)), n & 16 && i.push(dt(164)), n & 8 && i.push(dt(148)), n & 512 && i.push(dt(129)), n & 1024 && i.push(dt(134)), n & 8192 && i.push(dt(103)), n & 16384 && i.push(dt(147)), i.length ? i : void 0;
	}
	function yt(n, i) {
		let s = O(167);
		return s.left = n, s.right = et(i), s.transformFlags |= z(s.left) | ja(s.right), s.flowNode = void 0, s;
	}
	function _n(n, i, s) {
		return n.left !== i || n.right !== s ? j(yt(i, s), n) : n;
	}
	function tt(n) {
		let i = O(168);
		return i.expression = _().parenthesizeExpressionOfComputedPropertyName(n), i.transformFlags |= z(i.expression) | 132096, i;
	}
	function qt(n, i) {
		return n.expression !== i ? j(tt(i), n) : n;
	}
	function tn(n, i, s, l) {
		let d = ae(169);
		return d.modifiers = Pe(n), d.name = et(i), d.constraint = s, d.default = l, d.transformFlags = 1, d.expression = void 0, d.jsDoc = void 0, d;
	}
	function sr(n, i, s, l, d) {
		return n.modifiers !== i || n.name !== s || n.constraint !== l || n.default !== d ? j(tn(i, s, l, d), n) : n;
	}
	function mr(n, i, s, l, d, v) {
		let F = ae(170);
		return F.modifiers = Pe(n), F.dotDotDotToken = i, F.name = et(s), F.questionToken = l, F.type = d, F.initializer = zi(v), U2(F.name) ? F.transformFlags = 1 : F.transformFlags = ke(F.modifiers) | z(F.dotDotDotToken) | Ln(F.name) | z(F.questionToken) | z(F.initializer) | (F.questionToken ?? F.type ? 1 : 0) | (F.dotDotDotToken ?? F.initializer ? 1024 : 0) | (Jn(F.modifiers) & 31 ? 8192 : 0), F.jsDoc = void 0, F;
	}
	function hr(n, i, s, l, d, v, F) {
		return n.modifiers !== i || n.dotDotDotToken !== s || n.name !== l || n.questionToken !== d || n.type !== v || n.initializer !== F ? j(mr(i, s, l, d, v, F), n) : n;
	}
	function Fn(n) {
		let i = O(171);
		return i.expression = _().parenthesizeLeftSideOfAccess(n, !1), i.transformFlags |= z(i.expression) | 33562625, i;
	}
	function zn(n, i) {
		return n.expression !== i ? j(Fn(i), n) : n;
	}
	function Or(n, i, s, l) {
		let d = ae(172);
		return d.modifiers = Pe(n), d.name = et(i), d.type = l, d.questionToken = s, d.transformFlags = 1, d.initializer = void 0, d.jsDoc = void 0, d;
	}
	function Vn(n, i, s, l, d) {
		return n.modifiers !== i || n.name !== s || n.questionToken !== l || n.type !== d ? Ce(Or(i, s, l, d), n) : n;
	}
	function Ce(n, i) {
		return n !== i && (n.initializer = i.initializer), j(n, i);
	}
	function yr(n, i, s, l, d) {
		let v = ae(173);
		v.modifiers = Pe(n), v.name = et(i), v.questionToken = s && Wd(s) ? s : void 0, v.exclamationToken = s && Vd(s) ? s : void 0, v.type = l, v.initializer = zi(d);
		let F = v.flags & 33554432 || Jn(v.modifiers) & 128;
		return v.transformFlags = ke(v.modifiers) | Ln(v.name) | z(v.initializer) | (F || v.questionToken || v.exclamationToken || v.type ? 1 : 0) | (kf(v.name) || Jn(v.modifiers) & 256 && v.initializer ? 8192 : 0) | 16777216, v.jsDoc = void 0, v;
	}
	function L(n, i, s, l, d, v) {
		return n.modifiers !== i || n.name !== s || n.questionToken !== (l !== void 0 && Wd(l) ? l : void 0) || n.exclamationToken !== (l !== void 0 && Vd(l) ? l : void 0) || n.type !== d || n.initializer !== v ? j(yr(i, s, l, d, v), n) : n;
	}
	function se(n, i, s, l, d, v) {
		let F = ae(174);
		return F.modifiers = Pe(n), F.name = et(i), F.questionToken = s, F.typeParameters = Pe(l), F.parameters = Pe(d), F.type = v, F.transformFlags = 1, F.jsDoc = void 0, F.locals = void 0, F.nextContainer = void 0, F.typeArguments = void 0, F;
	}
	function fe(n, i, s, l, d, v, F) {
		return n.modifiers !== i || n.name !== s || n.questionToken !== l || n.typeParameters !== d || n.parameters !== v || n.type !== F ? Oe(se(i, s, l, d, v, F), n) : n;
	}
	function Te(n, i, s, l, d, v, F, pe) {
		let Fe = ae(175);
		if (Fe.modifiers = Pe(n), Fe.asteriskToken = i, Fe.name = et(s), Fe.questionToken = l, Fe.exclamationToken = void 0, Fe.typeParameters = Pe(d), Fe.parameters = de(v), Fe.type = F, Fe.body = pe, !Fe.body) Fe.transformFlags = 1;
		else {
			let It = Jn(Fe.modifiers) & 1024, fr = !!Fe.asteriskToken, xn = It && fr;
			Fe.transformFlags = ke(Fe.modifiers) | z(Fe.asteriskToken) | Ln(Fe.name) | z(Fe.questionToken) | ke(Fe.typeParameters) | ke(Fe.parameters) | z(Fe.type) | z(Fe.body) & -67108865 | (xn ? 128 : It ? 256 : fr ? 2048 : 0) | (Fe.questionToken || Fe.typeParameters || Fe.type ? 1 : 0) | 1024;
		}
		return Fe.typeArguments = void 0, Fe.jsDoc = void 0, Fe.locals = void 0, Fe.nextContainer = void 0, Fe.flowNode = void 0, Fe.endFlowNode = void 0, Fe.returnFlowNode = void 0, Fe;
	}
	function He(n, i, s, l, d, v, F, pe, Fe) {
		return n.modifiers !== i || n.asteriskToken !== s || n.name !== l || n.questionToken !== d || n.typeParameters !== v || n.parameters !== F || n.type !== pe || n.body !== Fe ? Qe(Te(i, s, l, d, v, F, pe, Fe), n) : n;
	}
	function Qe(n, i) {
		return n !== i && (n.exclamationToken = i.exclamationToken), j(n, i);
	}
	function st(n) {
		let i = ae(176);
		return i.body = n, i.transformFlags = z(n) | 16777216, i.modifiers = void 0, i.jsDoc = void 0, i.locals = void 0, i.nextContainer = void 0, i.endFlowNode = void 0, i.returnFlowNode = void 0, i;
	}
	function Ct(n, i) {
		return n.body !== i ? Tt(st(i), n) : n;
	}
	function Tt(n, i) {
		return n !== i && (n.modifiers = i.modifiers), j(n, i);
	}
	function lt(n, i, s) {
		let l = ae(177);
		return l.modifiers = Pe(n), l.parameters = de(i), l.body = s, l.body ? l.transformFlags = ke(l.modifiers) | ke(l.parameters) | z(l.body) & -67108865 | 1024 : l.transformFlags = 1, l.typeParameters = void 0, l.type = void 0, l.typeArguments = void 0, l.jsDoc = void 0, l.locals = void 0, l.nextContainer = void 0, l.endFlowNode = void 0, l.returnFlowNode = void 0, l;
	}
	function Mr(n, i, s, l) {
		return n.modifiers !== i || n.parameters !== s || n.body !== l ? gr(lt(i, s, l), n) : n;
	}
	function gr(n, i) {
		return n !== i && (n.typeParameters = i.typeParameters, n.type = i.type), Oe(n, i);
	}
	function Nn(n, i, s, l, d) {
		let v = ae(178);
		return v.modifiers = Pe(n), v.name = et(i), v.parameters = de(s), v.type = l, v.body = d, v.body ? v.transformFlags = ke(v.modifiers) | Ln(v.name) | ke(v.parameters) | z(v.type) | z(v.body) & -67108865 | (v.type ? 1 : 0) : v.transformFlags = 1, v.typeArguments = void 0, v.typeParameters = void 0, v.jsDoc = void 0, v.locals = void 0, v.nextContainer = void 0, v.flowNode = void 0, v.endFlowNode = void 0, v.returnFlowNode = void 0, v;
	}
	function Wn(n, i, s, l, d, v) {
		return n.modifiers !== i || n.name !== s || n.parameters !== l || n.type !== d || n.body !== v ? wi(Nn(i, s, l, d, v), n) : n;
	}
	function wi(n, i) {
		return n !== i && (n.typeParameters = i.typeParameters), Oe(n, i);
	}
	function U(n, i, s, l) {
		let d = ae(179);
		return d.modifiers = Pe(n), d.name = et(i), d.parameters = de(s), d.body = l, d.body ? d.transformFlags = ke(d.modifiers) | Ln(d.name) | ke(d.parameters) | z(d.body) & -67108865 | (d.type ? 1 : 0) : d.transformFlags = 1, d.typeArguments = void 0, d.typeParameters = void 0, d.type = void 0, d.jsDoc = void 0, d.locals = void 0, d.nextContainer = void 0, d.flowNode = void 0, d.endFlowNode = void 0, d.returnFlowNode = void 0, d;
	}
	function K(n, i, s, l, d) {
		return n.modifiers !== i || n.name !== s || n.parameters !== l || n.body !== d ? Z(U(i, s, l, d), n) : n;
	}
	function Z(n, i) {
		return n !== i && (n.typeParameters = i.typeParameters, n.type = i.type), Oe(n, i);
	}
	function xe(n, i, s) {
		let l = ae(180);
		return l.typeParameters = Pe(n), l.parameters = Pe(i), l.type = s, l.transformFlags = 1, l.jsDoc = void 0, l.locals = void 0, l.nextContainer = void 0, l.typeArguments = void 0, l;
	}
	function Se(n, i, s, l) {
		return n.typeParameters !== i || n.parameters !== s || n.type !== l ? Oe(xe(i, s, l), n) : n;
	}
	function we(n, i, s) {
		let l = ae(181);
		return l.typeParameters = Pe(n), l.parameters = Pe(i), l.type = s, l.transformFlags = 1, l.jsDoc = void 0, l.locals = void 0, l.nextContainer = void 0, l.typeArguments = void 0, l;
	}
	function me(n, i, s, l) {
		return n.typeParameters !== i || n.parameters !== s || n.type !== l ? Oe(we(i, s, l), n) : n;
	}
	function Ve(n, i, s) {
		let l = ae(182);
		return l.modifiers = Pe(n), l.parameters = Pe(i), l.type = s, l.transformFlags = 1, l.jsDoc = void 0, l.locals = void 0, l.nextContainer = void 0, l.typeArguments = void 0, l;
	}
	function Ze(n, i, s, l) {
		return n.parameters !== s || n.type !== l || n.modifiers !== i ? Oe(Ve(i, s, l), n) : n;
	}
	function Ye(n, i) {
		let s = O(205);
		return s.type = n, s.literal = i, s.transformFlags = 1, s;
	}
	function Ee(n, i, s) {
		return n.type !== i || n.literal !== s ? j(Ye(i, s), n) : n;
	}
	function gn(n) {
		return ot(n);
	}
	function rt(n, i, s) {
		let l = O(183);
		return l.assertsModifier = n, l.parameterName = et(i), l.type = s, l.transformFlags = 1, l;
	}
	function on(n, i, s, l) {
		return n.assertsModifier !== i || n.parameterName !== s || n.type !== l ? j(rt(i, s, l), n) : n;
	}
	function Zr(n, i) {
		let s = O(184);
		return s.typeName = et(n), s.typeArguments = i && _().parenthesizeTypeArguments(de(i)), s.transformFlags = 1, s;
	}
	function M(n, i, s) {
		return n.typeName !== i || n.typeArguments !== s ? j(Zr(i, s), n) : n;
	}
	function Ue(n, i, s) {
		let l = ae(185);
		return l.typeParameters = Pe(n), l.parameters = Pe(i), l.type = s, l.transformFlags = 1, l.modifiers = void 0, l.jsDoc = void 0, l.locals = void 0, l.nextContainer = void 0, l.typeArguments = void 0, l;
	}
	function u(n, i, s, l) {
		return n.typeParameters !== i || n.parameters !== s || n.type !== l ? Ie(Ue(i, s, l), n) : n;
	}
	function Ie(n, i) {
		return n !== i && (n.modifiers = i.modifiers), Oe(n, i);
	}
	function Me(...n) {
		return n.length === 4 ? B(...n) : n.length === 3 ? Be(...n) : q.fail("Incorrect number of arguments specified.");
	}
	function B(n, i, s, l) {
		let d = ae(186);
		return d.modifiers = Pe(n), d.typeParameters = Pe(i), d.parameters = Pe(s), d.type = l, d.transformFlags = 1, d.jsDoc = void 0, d.locals = void 0, d.nextContainer = void 0, d.typeArguments = void 0, d;
	}
	function Be(n, i, s) {
		return B(void 0, n, i, s);
	}
	function nn(...n) {
		return n.length === 5 ? ze(...n) : n.length === 4 ? Xe(...n) : q.fail("Incorrect number of arguments specified.");
	}
	function ze(n, i, s, l, d) {
		return n.modifiers !== i || n.typeParameters !== s || n.parameters !== l || n.type !== d ? Oe(Me(i, s, l, d), n) : n;
	}
	function Xe(n, i, s, l) {
		return ze(n, n.modifiers, i, s, l);
	}
	function Dt(n, i) {
		let s = O(187);
		return s.exprName = n, s.typeArguments = i && _().parenthesizeTypeArguments(i), s.transformFlags = 1, s;
	}
	function wt(n, i, s) {
		return n.exprName !== i || n.typeArguments !== s ? j(Dt(i, s), n) : n;
	}
	function Pt(n) {
		let i = ae(188);
		return i.members = de(n), i.transformFlags = 1, i;
	}
	function Ft(n, i) {
		return n.members !== i ? j(Pt(i), n) : n;
	}
	function Gn(n) {
		let i = O(189);
		return i.elementType = _().parenthesizeNonArrayTypeOfPostfixType(n), i.transformFlags = 1, i;
	}
	function ki(n, i) {
		return n.elementType !== i ? j(Gn(i), n) : n;
	}
	function cn(n) {
		let i = O(190);
		return i.elements = de(_().parenthesizeElementTypesOfTupleType(n)), i.transformFlags = 1, i;
	}
	function H(n, i) {
		return n.elements !== i ? j(cn(i), n) : n;
	}
	function le(n, i, s, l) {
		let d = ae(203);
		return d.dotDotDotToken = n, d.name = i, d.questionToken = s, d.type = l, d.transformFlags = 1, d.jsDoc = void 0, d;
	}
	function qe(n, i, s, l, d) {
		return n.dotDotDotToken !== i || n.name !== s || n.questionToken !== l || n.type !== d ? j(le(i, s, l, d), n) : n;
	}
	function ve(n) {
		let i = O(191);
		return i.type = _().parenthesizeTypeOfOptionalType(n), i.transformFlags = 1, i;
	}
	function J(n, i) {
		return n.type !== i ? j(ve(i), n) : n;
	}
	function mt(n) {
		let i = O(192);
		return i.type = n, i.transformFlags = 1, i;
	}
	function xt(n, i) {
		return n.type !== i ? j(mt(i), n) : n;
	}
	function Jt(n, i, s) {
		let l = O(n);
		return l.types = he.createNodeArray(s(i)), l.transformFlags = 1, l;
	}
	function ln(n, i, s) {
		return n.types !== i ? j(Jt(n.kind, i, s), n) : n;
	}
	function ql(n) {
		return Jt(193, n, _().parenthesizeConstituentTypesOfUnionType);
	}
	function C_(n, i) {
		return ln(n, i, _().parenthesizeConstituentTypesOfUnionType);
	}
	function Lr(n) {
		return Jt(194, n, _().parenthesizeConstituentTypesOfIntersectionType);
	}
	function Le(n, i) {
		return ln(n, i, _().parenthesizeConstituentTypesOfIntersectionType);
	}
	function pt(n, i, s, l) {
		let d = O(195);
		return d.checkType = _().parenthesizeCheckTypeOfConditionalType(n), d.extendsType = _().parenthesizeExtendsTypeOfConditionalType(i), d.trueType = s, d.falseType = l, d.transformFlags = 1, d.locals = void 0, d.nextContainer = void 0, d;
	}
	function Fl(n, i, s, l, d) {
		return n.checkType !== i || n.extendsType !== s || n.trueType !== l || n.falseType !== d ? j(pt(i, s, l, d), n) : n;
	}
	function Yn(n) {
		let i = O(196);
		return i.typeParameter = n, i.transformFlags = 1, i;
	}
	function zl(n, i) {
		return n.typeParameter !== i ? j(Yn(i), n) : n;
	}
	function Wt(n, i) {
		let s = O(204);
		return s.head = n, s.templateSpans = de(i), s.transformFlags = 1, s;
	}
	function Vl(n, i, s) {
		return n.head !== i || n.templateSpans !== s ? j(Wt(i, s), n) : n;
	}
	function _r(n, i, s, l, d = !1) {
		let v = O(206);
		return v.argument = n, v.attributes = i, v.assertions && v.assertions.assertClause && v.attributes && (v.assertions.assertClause = v.attributes), v.qualifier = s, v.typeArguments = l && _().parenthesizeTypeArguments(l), v.isTypeOf = d, v.transformFlags = 1, v;
	}
	function oa(n, i, s, l, d, v = n.isTypeOf) {
		return n.argument !== i || n.attributes !== s || n.qualifier !== l || n.typeArguments !== d || n.isTypeOf !== v ? j(_r(i, s, l, d, v), n) : n;
	}
	function Qt(n) {
		let i = O(197);
		return i.type = n, i.transformFlags = 1, i;
	}
	function At(n, i) {
		return n.type !== i ? j(Qt(i), n) : n;
	}
	function P() {
		let n = O(198);
		return n.transformFlags = 1, n;
	}
	function Gt(n, i) {
		let s = O(199);
		return s.operator = n, s.type = n === 148 ? _().parenthesizeOperandOfReadonlyTypeOperator(i) : _().parenthesizeOperandOfTypeOperator(i), s.transformFlags = 1, s;
	}
	function Jr(n, i) {
		return n.type !== i ? j(Gt(n.operator, i), n) : n;
	}
	function or(n, i) {
		let s = O(200);
		return s.objectType = _().parenthesizeNonArrayTypeOfPostfixType(n), s.indexType = i, s.transformFlags = 1, s;
	}
	function Ka(n, i, s) {
		return n.objectType !== i || n.indexType !== s ? j(or(i, s), n) : n;
	}
	function gt(n, i, s, l, d, v) {
		let F = ae(201);
		return F.readonlyToken = n, F.typeParameter = i, F.nameType = s, F.questionToken = l, F.type = d, F.members = v && de(v), F.transformFlags = 1, F.locals = void 0, F.nextContainer = void 0, F;
	}
	function jt(n, i, s, l, d, v, F) {
		return n.readonlyToken !== i || n.typeParameter !== s || n.nameType !== l || n.questionToken !== d || n.type !== v || n.members !== F ? j(gt(i, s, l, d, v, F), n) : n;
	}
	function ei(n) {
		let i = O(202);
		return i.literal = n, i.transformFlags = 1, i;
	}
	function br(n, i) {
		return n.literal !== i ? j(ei(i), n) : n;
	}
	function D_(n) {
		let i = O(207);
		return i.elements = de(n), i.transformFlags |= ke(i.elements) | 525312, i.transformFlags & 32768 && (i.transformFlags |= 65664), i;
	}
	function Wl(n, i) {
		return n.elements !== i ? j(D_(i), n) : n;
	}
	function jr(n) {
		let i = O(208);
		return i.elements = de(n), i.transformFlags |= ke(i.elements) | 525312, i;
	}
	function Gl(n, i) {
		return n.elements !== i ? j(jr(i), n) : n;
	}
	function ca(n, i, s, l) {
		let d = ae(209);
		return d.dotDotDotToken = n, d.propertyName = et(i), d.name = et(s), d.initializer = zi(l), d.transformFlags |= z(d.dotDotDotToken) | Ln(d.propertyName) | Ln(d.name) | z(d.initializer) | (d.dotDotDotToken ? 32768 : 0) | 1024, d.flowNode = void 0, d;
	}
	function ti(n, i, s, l, d) {
		return n.propertyName !== s || n.dotDotDotToken !== i || n.name !== l || n.initializer !== d ? j(ca(i, s, l, d), n) : n;
	}
	function Za(n, i) {
		let s = O(210), l = n && Ba(n), d = de(n, l && W1(l) ? !0 : void 0);
		return s.elements = _().parenthesizeExpressionsOfCommaDelimitedList(d), s.multiLine = i, s.transformFlags |= ke(s.elements), s;
	}
	function P_(n, i) {
		return n.elements !== i ? j(Za(i, n.multiLine), n) : n;
	}
	function Ei(n, i) {
		let s = ae(211);
		return s.properties = de(n), s.multiLine = i, s.transformFlags |= ke(s.properties), s.jsDoc = void 0, s;
	}
	function Yl(n, i) {
		return n.properties !== i ? j(Ei(i, n.multiLine), n) : n;
	}
	function N_(n, i, s) {
		let l = ae(212);
		return l.expression = n, l.questionDotToken = i, l.name = s, l.transformFlags = z(l.expression) | z(l.questionDotToken) | (Ke(l.name) ? ja(l.name) : z(l.name) | 536870912), l.jsDoc = void 0, l.flowNode = void 0, l;
	}
	function cr(n, i) {
		let s = N_(_().parenthesizeLeftSideOfAccess(n, !1), void 0, et(i));
		return Ap(n) && (s.transformFlags |= 384), s;
	}
	function Hl(n, i, s) {
		return Og(n) ? la(n, i, n.questionDotToken, Er(s, Ke)) : n.expression !== i || n.name !== s ? j(cr(i, s), n) : n;
	}
	function Ai(n, i, s) {
		let l = N_(_().parenthesizeLeftSideOfAccess(n, !0), i, et(s));
		return l.flags |= 64, l.transformFlags |= 32, l;
	}
	function la(n, i, s, l) {
		return q.assert(!!(n.flags & 64), "Cannot update a PropertyAccessExpression using updatePropertyAccessChain. Use updatePropertyAccess instead."), n.expression !== i || n.questionDotToken !== s || n.name !== l ? j(Ai(i, s, l), n) : n;
	}
	function I_(n, i, s) {
		let l = ae(213);
		return l.expression = n, l.questionDotToken = i, l.argumentExpression = s, l.transformFlags |= z(l.expression) | z(l.questionDotToken) | z(l.argumentExpression), l.jsDoc = void 0, l.flowNode = void 0, l;
	}
	function Ci(n, i) {
		let s = I_(_().parenthesizeLeftSideOfAccess(n, !1), void 0, wr(i));
		return Ap(n) && (s.transformFlags |= 384), s;
	}
	function Xl(n, i, s) {
		return Mg(n) ? es(n, i, n.questionDotToken, s) : n.expression !== i || n.argumentExpression !== s ? j(Ci(i, s), n) : n;
	}
	function O_(n, i, s) {
		let l = I_(_().parenthesizeLeftSideOfAccess(n, !0), i, wr(s));
		return l.flags |= 64, l.transformFlags |= 32, l;
	}
	function es(n, i, s, l) {
		return q.assert(!!(n.flags & 64), "Cannot update a ElementAccessExpression using updateElementAccessChain. Use updateElementAccess instead."), n.expression !== i || n.questionDotToken !== s || n.argumentExpression !== l ? j(O_(i, s, l), n) : n;
	}
	function M_(n, i, s, l) {
		let d = ae(214);
		return d.expression = n, d.questionDotToken = i, d.typeArguments = s, d.arguments = l, d.transformFlags |= z(d.expression) | z(d.questionDotToken) | ke(d.typeArguments) | ke(d.arguments), d.typeArguments && (d.transformFlags |= 1), Jd(d.expression) && (d.transformFlags |= 16384), d;
	}
	function Di(n, i, s) {
		let l = M_(_().parenthesizeLeftSideOfAccess(n, !1), void 0, Pe(i), _().parenthesizeExpressionsOfCommaDelimitedList(de(s)));
		return Bb(l.expression) && (l.transformFlags |= 8388608), l;
	}
	function ua(n, i, s, l) {
		return Dd(n) ? L_(n, i, n.questionDotToken, s, l) : n.expression !== i || n.typeArguments !== s || n.arguments !== l ? j(Di(i, s, l), n) : n;
	}
	function ts(n, i, s, l) {
		let d = M_(_().parenthesizeLeftSideOfAccess(n, !0), i, Pe(s), _().parenthesizeExpressionsOfCommaDelimitedList(de(l)));
		return d.flags |= 64, d.transformFlags |= 32, d;
	}
	function L_(n, i, s, l, d) {
		return q.assert(!!(n.flags & 64), "Cannot update a CallExpression using updateCallChain. Use updateCall instead."), n.expression !== i || n.questionDotToken !== s || n.typeArguments !== l || n.arguments !== d ? j(ts(i, s, l, d), n) : n;
	}
	function bn(n, i, s) {
		let l = ae(215);
		return l.expression = _().parenthesizeExpressionOfNew(n), l.typeArguments = Pe(i), l.arguments = s ? _().parenthesizeExpressionsOfCommaDelimitedList(s) : void 0, l.transformFlags |= z(l.expression) | ke(l.typeArguments) | ke(l.arguments) | 32, l.typeArguments && (l.transformFlags |= 1), l;
	}
	function ns(n, i, s, l) {
		return n.expression !== i || n.typeArguments !== s || n.arguments !== l ? j(bn(i, s, l), n) : n;
	}
	function pa(n, i, s) {
		let l = O(216);
		return l.tag = _().parenthesizeLeftSideOfAccess(n, !1), l.typeArguments = Pe(i), l.template = s, l.transformFlags |= z(l.tag) | ke(l.typeArguments) | z(l.template) | 1024, l.typeArguments && (l.transformFlags |= 1), R2(l.template) && (l.transformFlags |= 128), l;
	}
	function J_(n, i, s, l) {
		return n.tag !== i || n.typeArguments !== s || n.template !== l ? j(pa(i, s, l), n) : n;
	}
	function j_(n, i) {
		let s = O(217);
		return s.expression = _().parenthesizeOperandOfPrefixUnary(i), s.type = n, s.transformFlags |= z(s.expression) | z(s.type) | 1, s;
	}
	function R_(n, i, s) {
		return n.type !== i || n.expression !== s ? j(j_(i, s), n) : n;
	}
	function rs(n) {
		let i = O(218);
		return i.expression = n, i.transformFlags = z(i.expression), i.jsDoc = void 0, i;
	}
	function U_(n, i) {
		return n.expression !== i ? j(rs(i), n) : n;
	}
	function is(n, i, s, l, d, v, F) {
		let pe = ae(219);
		pe.modifiers = Pe(n), pe.asteriskToken = i, pe.name = et(s), pe.typeParameters = Pe(l), pe.parameters = de(d), pe.type = v, pe.body = F;
		let Fe = Jn(pe.modifiers) & 1024, It = !!pe.asteriskToken, fr = Fe && It;
		return pe.transformFlags = ke(pe.modifiers) | z(pe.asteriskToken) | Ln(pe.name) | ke(pe.typeParameters) | ke(pe.parameters) | z(pe.type) | z(pe.body) & -67108865 | (fr ? 128 : Fe ? 256 : It ? 2048 : 0) | (pe.typeParameters || pe.type ? 1 : 0) | 4194304, pe.typeArguments = void 0, pe.jsDoc = void 0, pe.locals = void 0, pe.nextContainer = void 0, pe.flowNode = void 0, pe.endFlowNode = void 0, pe.returnFlowNode = void 0, pe;
	}
	function B_(n, i, s, l, d, v, F, pe) {
		return n.name !== l || n.modifiers !== i || n.asteriskToken !== s || n.typeParameters !== d || n.parameters !== v || n.type !== F || n.body !== pe ? Oe(is(i, s, l, d, v, F, pe), n) : n;
	}
	function as(n, i, s, l, d, v) {
		let F = ae(220);
		F.modifiers = Pe(n), F.typeParameters = Pe(i), F.parameters = de(s), F.type = l, F.equalsGreaterThanToken = d ?? ot(39), F.body = _().parenthesizeConciseBodyOfArrowFunction(v);
		let pe = Jn(F.modifiers) & 1024;
		return F.transformFlags = ke(F.modifiers) | ke(F.typeParameters) | ke(F.parameters) | z(F.type) | z(F.equalsGreaterThanToken) | z(F.body) & -67108865 | (F.typeParameters || F.type ? 1 : 0) | (pe ? 16640 : 0) | 1024, F.typeArguments = void 0, F.jsDoc = void 0, F.locals = void 0, F.nextContainer = void 0, F.flowNode = void 0, F.endFlowNode = void 0, F.returnFlowNode = void 0, F;
	}
	function q_(n, i, s, l, d, v, F) {
		return n.modifiers !== i || n.typeParameters !== s || n.parameters !== l || n.type !== d || n.equalsGreaterThanToken !== v || n.body !== F ? Oe(as(i, s, l, d, v, F), n) : n;
	}
	function F_(n) {
		let i = O(221);
		return i.expression = _().parenthesizeOperandOfPrefixUnary(n), i.transformFlags |= z(i.expression), i;
	}
	function z_(n, i) {
		return n.expression !== i ? j(F_(i), n) : n;
	}
	function fa(n) {
		let i = O(222);
		return i.expression = _().parenthesizeOperandOfPrefixUnary(n), i.transformFlags |= z(i.expression), i;
	}
	function un(n, i) {
		return n.expression !== i ? j(fa(i), n) : n;
	}
	function ss(n) {
		let i = O(223);
		return i.expression = _().parenthesizeOperandOfPrefixUnary(n), i.transformFlags |= z(i.expression), i;
	}
	function lr(n, i) {
		return n.expression !== i ? j(ss(i), n) : n;
	}
	function V_(n) {
		let i = O(224);
		return i.expression = _().parenthesizeOperandOfPrefixUnary(n), i.transformFlags |= z(i.expression) | 2097536, i;
	}
	function Rr(n, i) {
		return n.expression !== i ? j(V_(i), n) : n;
	}
	function Ur(n, i) {
		let s = O(225);
		return s.operator = n, s.operand = _().parenthesizeOperandOfPrefixUnary(i), s.transformFlags |= z(s.operand), (n === 46 || n === 47) && Ke(s.operand) && !Ua(s.operand) && !Yd(s.operand) && (s.transformFlags |= 268435456), s;
	}
	function $l(n, i) {
		return n.operand !== i ? j(Ur(n.operator, i), n) : n;
	}
	function ni(n, i) {
		let s = O(226);
		return s.operator = i, s.operand = _().parenthesizeOperandOfPostfixUnary(n), s.transformFlags |= z(s.operand), Ke(s.operand) && !Ua(s.operand) && !Yd(s.operand) && (s.transformFlags |= 268435456), s;
	}
	function Ql(n, i) {
		return n.operand !== i ? j(ni(i, n.operator), n) : n;
	}
	function da(n, i, s) {
		let l = ae(227), d = mp(i), v = d.kind;
		return l.left = _().parenthesizeLeftSideOfBinary(v, n), l.operatorToken = d, l.right = _().parenthesizeRightSideOfBinary(v, l.left, s), l.transformFlags |= z(l.left) | z(l.operatorToken) | z(l.right), v === 61 ? l.transformFlags |= 32 : v === 64 ? If(l.left) ? l.transformFlags |= 5248 | W_(l.left) : q1(l.left) && (l.transformFlags |= 5120 | W_(l.left)) : v === 43 || v === 68 ? l.transformFlags |= 512 : X2(v) && (l.transformFlags |= 16), v === 103 && gi(l.left) && (l.transformFlags |= 536870912), l.jsDoc = void 0, l;
	}
	function W_(n) {
		return _h(n) ? 65536 : 0;
	}
	function Kl(n, i, s, l) {
		return n.left !== i || n.operatorToken !== s || n.right !== l ? j(da(i, s, l), n) : n;
	}
	function G_(n, i, s, l, d) {
		let v = O(228);
		return v.condition = _().parenthesizeConditionOfConditionalExpression(n), v.questionToken = i ?? ot(58), v.whenTrue = _().parenthesizeBranchOfConditionalExpression(s), v.colonToken = l ?? ot(59), v.whenFalse = _().parenthesizeBranchOfConditionalExpression(d), v.transformFlags |= z(v.condition) | z(v.questionToken) | z(v.whenTrue) | z(v.colonToken) | z(v.whenFalse), v.flowNodeWhenFalse = void 0, v.flowNodeWhenTrue = void 0, v;
	}
	function Y_(n, i, s, l, d, v) {
		return n.condition !== i || n.questionToken !== s || n.whenTrue !== l || n.colonToken !== d || n.whenFalse !== v ? j(G_(i, s, l, d, v), n) : n;
	}
	function H_(n, i) {
		let s = O(229);
		return s.head = n, s.templateSpans = de(i), s.transformFlags |= z(s.head) | ke(s.templateSpans) | 1024, s;
	}
	function Hn(n, i, s) {
		return n.head !== i || n.templateSpans !== s ? j(H_(i, s), n) : n;
	}
	function Pi(n, i, s, l = 0) {
		q.assert(!(l & -7177), "Unsupported template flags.");
		let d;
		if (s !== void 0 && s !== i && (d = Nb(n, s), typeof d == "object")) return q.fail("Invalid raw text");
		if (i === void 0) {
			if (d === void 0) return q.fail("Arguments 'text' and 'rawText' may not both be undefined.");
			i = d;
		} else d !== void 0 && q.assert(i === d, "Expected argument 'text' to be the normalized (i.e. 'cooked') version of argument 'rawText'.");
		return i;
	}
	function X_(n) {
		let i = 1024;
		return n && (i |= 128), i;
	}
	function Zl(n, i, s, l) {
		let d = $t(n);
		return d.text = i, d.rawText = s, d.templateFlags = l & 7176, d.transformFlags = X_(d.templateFlags), d;
	}
	function ri(n, i, s, l) {
		let d = ae(n);
		return d.text = i, d.rawText = s, d.templateFlags = l & 7176, d.transformFlags = X_(d.templateFlags), d;
	}
	function ii(n, i, s, l) {
		return n === 15 ? ri(n, i, s, l) : Zl(n, i, s, l);
	}
	function $_(n, i, s) {
		return n = Pi(16, n, i, s), ii(16, n, i, s);
	}
	function ma(n, i, s) {
		return n = Pi(16, n, i, s), ii(17, n, i, s);
	}
	function _s(n, i, s) {
		return n = Pi(16, n, i, s), ii(18, n, i, s);
	}
	function eu(n, i, s) {
		return n = Pi(16, n, i, s), ri(15, n, i, s);
	}
	function os(n, i) {
		q.assert(!n || !!i, "A `YieldExpression` with an asteriskToken must have an expression.");
		let s = O(230);
		return s.expression = i && _().parenthesizeExpressionForDisallowedComma(i), s.asteriskToken = n, s.transformFlags |= z(s.expression) | z(s.asteriskToken) | 1049728, s;
	}
	function tu(n, i, s) {
		return n.expression !== s || n.asteriskToken !== i ? j(os(i, s), n) : n;
	}
	function Q_(n) {
		let i = O(231);
		return i.expression = _().parenthesizeExpressionForDisallowedComma(n), i.transformFlags |= z(i.expression) | 33792, i;
	}
	function nu(n, i) {
		return n.expression !== i ? j(Q_(i), n) : n;
	}
	function K_(n, i, s, l, d) {
		let v = ae(232);
		return v.modifiers = Pe(n), v.name = et(i), v.typeParameters = Pe(s), v.heritageClauses = Pe(l), v.members = de(d), v.transformFlags |= ke(v.modifiers) | Ln(v.name) | ke(v.typeParameters) | ke(v.heritageClauses) | ke(v.members) | (v.typeParameters ? 1 : 0) | 1024, v.jsDoc = void 0, v;
	}
	function cs(n, i, s, l, d, v) {
		return n.modifiers !== i || n.name !== s || n.typeParameters !== l || n.heritageClauses !== d || n.members !== v ? j(K_(i, s, l, d, v), n) : n;
	}
	function ls() {
		return O(233);
	}
	function Z_(n, i) {
		let s = O(234);
		return s.expression = _().parenthesizeLeftSideOfAccess(n, !1), s.typeArguments = i && _().parenthesizeTypeArguments(i), s.transformFlags |= z(s.expression) | ke(s.typeArguments) | 1024, s;
	}
	function eo(n, i, s) {
		return n.expression !== i || n.typeArguments !== s ? j(Z_(i, s), n) : n;
	}
	function pn(n, i) {
		let s = O(235);
		return s.expression = n, s.type = i, s.transformFlags |= z(s.expression) | z(s.type) | 1, s;
	}
	function ha(n, i, s) {
		return n.expression !== i || n.type !== s ? j(pn(i, s), n) : n;
	}
	function to(n) {
		let i = O(236);
		return i.expression = _().parenthesizeLeftSideOfAccess(n, !1), i.transformFlags |= z(i.expression) | 1, i;
	}
	function no(n, i) {
		return Lg(n) ? In(n, i) : n.expression !== i ? j(to(i), n) : n;
	}
	function us(n, i) {
		let s = O(239);
		return s.expression = n, s.type = i, s.transformFlags |= z(s.expression) | z(s.type) | 1, s;
	}
	function ro(n, i, s) {
		return n.expression !== i || n.type !== s ? j(us(i, s), n) : n;
	}
	function ps(n) {
		let i = O(236);
		return i.flags |= 64, i.expression = _().parenthesizeLeftSideOfAccess(n, !0), i.transformFlags |= z(i.expression) | 1, i;
	}
	function In(n, i) {
		return q.assert(!!(n.flags & 64), "Cannot update a NonNullExpression using updateNonNullChain. Use updateNonNullExpression instead."), n.expression !== i ? j(ps(i), n) : n;
	}
	function io(n, i) {
		let s = O(237);
		switch (s.keywordToken = n, s.name = i, s.transformFlags |= z(s.name), n) {
			case 105:
				s.transformFlags |= 1024;
				break;
			case 102:
				s.transformFlags |= 32;
				break;
			default: return q.assertNever(n);
		}
		return s.flowNode = void 0, s;
	}
	function fs(n, i) {
		return n.name !== i ? j(io(n.keywordToken, i), n) : n;
	}
	function Xn(n, i) {
		let s = O(240);
		return s.expression = n, s.literal = i, s.transformFlags |= z(s.expression) | z(s.literal) | 1024, s;
	}
	function ya(n, i, s) {
		return n.expression !== i || n.literal !== s ? j(Xn(i, s), n) : n;
	}
	function ao() {
		let n = O(241);
		return n.transformFlags |= 1024, n;
	}
	function Br(n, i) {
		let s = O(242);
		return s.statements = de(n), s.multiLine = i, s.transformFlags |= ke(s.statements), s.jsDoc = void 0, s.locals = void 0, s.nextContainer = void 0, s;
	}
	function ru(n, i) {
		return n.statements !== i ? j(Br(i, n.multiLine), n) : n;
	}
	function ds(n, i) {
		let s = O(244);
		return s.modifiers = Pe(n), s.declarationList = $r(i) ? vs(i) : i, s.transformFlags |= ke(s.modifiers) | z(s.declarationList), Jn(s.modifiers) & 128 && (s.transformFlags = 1), s.jsDoc = void 0, s.flowNode = void 0, s;
	}
	function so(n, i, s) {
		return n.modifiers !== i || n.declarationList !== s ? j(ds(i, s), n) : n;
	}
	function _o() {
		let n = O(243);
		return n.jsDoc = void 0, n;
	}
	function Ni(n) {
		let i = O(245);
		return i.expression = _().parenthesizeExpressionOfExpressionStatement(n), i.transformFlags |= z(i.expression), i.jsDoc = void 0, i.flowNode = void 0, i;
	}
	function oo(n, i) {
		return n.expression !== i ? j(Ni(i), n) : n;
	}
	function co(n, i, s) {
		let l = O(246);
		return l.expression = n, l.thenStatement = $n(i), l.elseStatement = $n(s), l.transformFlags |= z(l.expression) | z(l.thenStatement) | z(l.elseStatement), l.jsDoc = void 0, l.flowNode = void 0, l;
	}
	function lo(n, i, s, l) {
		return n.expression !== i || n.thenStatement !== s || n.elseStatement !== l ? j(co(i, s, l), n) : n;
	}
	function uo(n, i) {
		let s = O(247);
		return s.statement = $n(n), s.expression = i, s.transformFlags |= z(s.statement) | z(s.expression), s.jsDoc = void 0, s.flowNode = void 0, s;
	}
	function po(n, i, s) {
		return n.statement !== i || n.expression !== s ? j(uo(i, s), n) : n;
	}
	function fo(n, i) {
		let s = O(248);
		return s.expression = n, s.statement = $n(i), s.transformFlags |= z(s.expression) | z(s.statement), s.jsDoc = void 0, s.flowNode = void 0, s;
	}
	function iu(n, i, s) {
		return n.expression !== i || n.statement !== s ? j(fo(i, s), n) : n;
	}
	function mo(n, i, s, l) {
		let d = O(249);
		return d.initializer = n, d.condition = i, d.incrementor = s, d.statement = $n(l), d.transformFlags |= z(d.initializer) | z(d.condition) | z(d.incrementor) | z(d.statement), d.jsDoc = void 0, d.locals = void 0, d.nextContainer = void 0, d.flowNode = void 0, d;
	}
	function ho(n, i, s, l, d) {
		return n.initializer !== i || n.condition !== s || n.incrementor !== l || n.statement !== d ? j(mo(i, s, l, d), n) : n;
	}
	function ms(n, i, s) {
		let l = O(250);
		return l.initializer = n, l.expression = i, l.statement = $n(s), l.transformFlags |= z(l.initializer) | z(l.expression) | z(l.statement), l.jsDoc = void 0, l.locals = void 0, l.nextContainer = void 0, l.flowNode = void 0, l;
	}
	function au(n, i, s, l) {
		return n.initializer !== i || n.expression !== s || n.statement !== l ? j(ms(i, s, l), n) : n;
	}
	function yo(n, i, s, l) {
		let d = O(251);
		return d.awaitModifier = n, d.initializer = i, d.expression = _().parenthesizeExpressionForDisallowedComma(s), d.statement = $n(l), d.transformFlags |= z(d.awaitModifier) | z(d.initializer) | z(d.expression) | z(d.statement) | 1024, n && (d.transformFlags |= 128), d.jsDoc = void 0, d.locals = void 0, d.nextContainer = void 0, d.flowNode = void 0, d;
	}
	function su(n, i, s, l, d) {
		return n.awaitModifier !== i || n.initializer !== s || n.expression !== l || n.statement !== d ? j(yo(i, s, l, d), n) : n;
	}
	function go(n) {
		let i = O(252);
		return i.label = et(n), i.transformFlags |= z(i.label) | 4194304, i.jsDoc = void 0, i.flowNode = void 0, i;
	}
	function _u(n, i) {
		return n.label !== i ? j(go(i), n) : n;
	}
	function hs(n) {
		let i = O(253);
		return i.label = et(n), i.transformFlags |= z(i.label) | 4194304, i.jsDoc = void 0, i.flowNode = void 0, i;
	}
	function bo(n, i) {
		return n.label !== i ? j(hs(i), n) : n;
	}
	function ys(n) {
		let i = O(254);
		return i.expression = n, i.transformFlags |= z(i.expression) | 4194432, i.jsDoc = void 0, i.flowNode = void 0, i;
	}
	function ou(n, i) {
		return n.expression !== i ? j(ys(i), n) : n;
	}
	function gs(n, i) {
		let s = O(255);
		return s.expression = n, s.statement = $n(i), s.transformFlags |= z(s.expression) | z(s.statement), s.jsDoc = void 0, s.flowNode = void 0, s;
	}
	function vo(n, i, s) {
		return n.expression !== i || n.statement !== s ? j(gs(i, s), n) : n;
	}
	function bs(n, i) {
		let s = O(256);
		return s.expression = _().parenthesizeExpressionForDisallowedComma(n), s.caseBlock = i, s.transformFlags |= z(s.expression) | z(s.caseBlock), s.jsDoc = void 0, s.flowNode = void 0, s.possiblyExhaustive = !1, s;
	}
	function ai(n, i, s) {
		return n.expression !== i || n.caseBlock !== s ? j(bs(i, s), n) : n;
	}
	function To(n, i) {
		let s = O(257);
		return s.label = et(n), s.statement = $n(i), s.transformFlags |= z(s.label) | z(s.statement), s.jsDoc = void 0, s.flowNode = void 0, s;
	}
	function xo(n, i, s) {
		return n.label !== i || n.statement !== s ? j(To(i, s), n) : n;
	}
	function So(n) {
		let i = O(258);
		return i.expression = n, i.transformFlags |= z(i.expression), i.jsDoc = void 0, i.flowNode = void 0, i;
	}
	function cu(n, i) {
		return n.expression !== i ? j(So(i), n) : n;
	}
	function wo(n, i, s) {
		let l = O(259);
		return l.tryBlock = n, l.catchClause = i, l.finallyBlock = s, l.transformFlags |= z(l.tryBlock) | z(l.catchClause) | z(l.finallyBlock), l.jsDoc = void 0, l.flowNode = void 0, l;
	}
	function lu(n, i, s, l) {
		return n.tryBlock !== i || n.catchClause !== s || n.finallyBlock !== l ? j(wo(i, s, l), n) : n;
	}
	function ko() {
		let n = O(260);
		return n.jsDoc = void 0, n.flowNode = void 0, n;
	}
	function ga(n, i, s, l) {
		let d = ae(261);
		return d.name = et(n), d.exclamationToken = i, d.type = s, d.initializer = zi(l), d.transformFlags |= Ln(d.name) | z(d.initializer) | (d.exclamationToken ?? d.type ? 1 : 0), d.jsDoc = void 0, d;
	}
	function Eo(n, i, s, l, d) {
		return n.name !== i || n.type !== l || n.exclamationToken !== s || n.initializer !== d ? j(ga(i, s, l, d), n) : n;
	}
	function vs(n, i = 0) {
		let s = O(262);
		return s.flags |= i & 7, s.declarations = de(n), s.transformFlags |= ke(s.declarations) | 4194304, i & 7 && (s.transformFlags |= 263168), i & 4 && (s.transformFlags |= 4), s;
	}
	function uu(n, i) {
		return n.declarations !== i ? j(vs(i, n.flags), n) : n;
	}
	function Ao(n, i, s, l, d, v, F) {
		let pe = ae(263);
		if (pe.modifiers = Pe(n), pe.asteriskToken = i, pe.name = et(s), pe.typeParameters = Pe(l), pe.parameters = de(d), pe.type = v, pe.body = F, !pe.body || Jn(pe.modifiers) & 128) pe.transformFlags = 1;
		else {
			let Fe = Jn(pe.modifiers) & 1024, It = !!pe.asteriskToken, fr = Fe && It;
			pe.transformFlags = ke(pe.modifiers) | z(pe.asteriskToken) | Ln(pe.name) | ke(pe.typeParameters) | ke(pe.parameters) | z(pe.type) | z(pe.body) & -67108865 | (fr ? 128 : Fe ? 256 : It ? 2048 : 0) | (pe.typeParameters || pe.type ? 1 : 0) | 4194304;
		}
		return pe.typeArguments = void 0, pe.jsDoc = void 0, pe.locals = void 0, pe.nextContainer = void 0, pe.endFlowNode = void 0, pe.returnFlowNode = void 0, pe;
	}
	function Ts(n, i, s, l, d, v, F, pe) {
		return n.modifiers !== i || n.asteriskToken !== s || n.name !== l || n.typeParameters !== d || n.parameters !== v || n.type !== F || n.body !== pe ? pu(Ao(i, s, l, d, v, F, pe), n) : n;
	}
	function pu(n, i) {
		return n !== i && n.modifiers === i.modifiers && (n.modifiers = i.modifiers), Oe(n, i);
	}
	function Co(n, i, s, l, d) {
		let v = ae(264);
		return v.modifiers = Pe(n), v.name = et(i), v.typeParameters = Pe(s), v.heritageClauses = Pe(l), v.members = de(d), Jn(v.modifiers) & 128 ? v.transformFlags = 1 : (v.transformFlags |= ke(v.modifiers) | Ln(v.name) | ke(v.typeParameters) | ke(v.heritageClauses) | ke(v.members) | (v.typeParameters ? 1 : 0) | 1024, v.transformFlags & 8192 && (v.transformFlags |= 1)), v.jsDoc = void 0, v;
	}
	function ba(n, i, s, l, d, v) {
		return n.modifiers !== i || n.name !== s || n.typeParameters !== l || n.heritageClauses !== d || n.members !== v ? j(Co(i, s, l, d, v), n) : n;
	}
	function Do(n, i, s, l, d) {
		let v = ae(265);
		return v.modifiers = Pe(n), v.name = et(i), v.typeParameters = Pe(s), v.heritageClauses = Pe(l), v.members = de(d), v.transformFlags = 1, v.jsDoc = void 0, v;
	}
	function Po(n, i, s, l, d, v) {
		return n.modifiers !== i || n.name !== s || n.typeParameters !== l || n.heritageClauses !== d || n.members !== v ? j(Do(i, s, l, d, v), n) : n;
	}
	function _t(n, i, s, l) {
		let d = ae(266);
		return d.modifiers = Pe(n), d.name = et(i), d.typeParameters = Pe(s), d.type = l, d.transformFlags = 1, d.jsDoc = void 0, d.locals = void 0, d.nextContainer = void 0, d;
	}
	function vr(n, i, s, l, d) {
		return n.modifiers !== i || n.name !== s || n.typeParameters !== l || n.type !== d ? j(_t(i, s, l, d), n) : n;
	}
	function xs(n, i, s) {
		let l = ae(267);
		return l.modifiers = Pe(n), l.name = et(i), l.members = de(s), l.transformFlags |= ke(l.modifiers) | z(l.name) | ke(l.members) | 1, l.transformFlags &= -67108865, l.jsDoc = void 0, l;
	}
	function Tr(n, i, s, l) {
		return n.modifiers !== i || n.name !== s || n.members !== l ? j(xs(i, s, l), n) : n;
	}
	function No(n, i, s, l = 0) {
		let d = ae(268);
		return d.modifiers = Pe(n), d.flags |= l & 2088, d.name = i, d.body = s, Jn(d.modifiers) & 128 ? d.transformFlags = 1 : d.transformFlags |= ke(d.modifiers) | z(d.name) | z(d.body) | 1, d.transformFlags &= -67108865, d.jsDoc = void 0, d.locals = void 0, d.nextContainer = void 0, d;
	}
	function kt(n, i, s, l) {
		return n.modifiers !== i || n.name !== s || n.body !== l ? j(No(i, s, l, n.flags), n) : n;
	}
	function xr(n) {
		let i = O(269);
		return i.statements = de(n), i.transformFlags |= ke(i.statements), i.jsDoc = void 0, i;
	}
	function zt(n, i) {
		return n.statements !== i ? j(xr(i), n) : n;
	}
	function Io(n) {
		let i = O(270);
		return i.clauses = de(n), i.transformFlags |= ke(i.clauses), i.locals = void 0, i.nextContainer = void 0, i;
	}
	function fu(n, i) {
		return n.clauses !== i ? j(Io(i), n) : n;
	}
	function Oo(n) {
		let i = ae(271);
		return i.name = et(n), i.transformFlags |= ja(i.name) | 1, i.modifiers = void 0, i.jsDoc = void 0, i;
	}
	function Mo(n, i) {
		return n.name !== i ? du(Oo(i), n) : n;
	}
	function du(n, i) {
		return n !== i && (n.modifiers = i.modifiers), j(n, i);
	}
	function Lo(n, i, s, l) {
		let d = ae(272);
		return d.modifiers = Pe(n), d.name = et(s), d.isTypeOnly = i, d.moduleReference = l, d.transformFlags |= ke(d.modifiers) | ja(d.name) | z(d.moduleReference), Ff(d.moduleReference) || (d.transformFlags |= 1), d.transformFlags &= -67108865, d.jsDoc = void 0, d;
	}
	function Jo(n, i, s, l, d) {
		return n.modifiers !== i || n.isTypeOnly !== s || n.name !== l || n.moduleReference !== d ? j(Lo(i, s, l, d), n) : n;
	}
	function jo(n, i, s, l) {
		let d = O(273);
		return d.modifiers = Pe(n), d.importClause = i, d.moduleSpecifier = s, d.attributes = d.assertClause = l, d.transformFlags |= z(d.importClause) | z(d.moduleSpecifier), d.transformFlags &= -67108865, d.jsDoc = void 0, d;
	}
	function Ro(n, i, s, l, d) {
		return n.modifiers !== i || n.importClause !== s || n.moduleSpecifier !== l || n.attributes !== d ? j(jo(i, s, l, d), n) : n;
	}
	function Uo(n, i, s) {
		let l = ae(274);
		return typeof n == "boolean" && (n = n ? 156 : void 0), l.isTypeOnly = n === 156, l.phaseModifier = n, l.name = i, l.namedBindings = s, l.transformFlags |= z(l.name) | z(l.namedBindings), n === 156 && (l.transformFlags |= 1), l.transformFlags &= -67108865, l;
	}
	function Bo(n, i, s, l) {
		return typeof i == "boolean" && (i = i ? 156 : void 0), n.phaseModifier !== i || n.name !== s || n.namedBindings !== l ? j(Uo(i, s, l), n) : n;
	}
	function Ss(n, i) {
		let s = O(301);
		return s.elements = de(n), s.multiLine = i, s.token = 132, s.transformFlags |= 4, s;
	}
	function mu(n, i, s) {
		return n.elements !== i || n.multiLine !== s ? j(Ss(i, s), n) : n;
	}
	function Ii(n, i) {
		let s = O(302);
		return s.name = n, s.value = i, s.transformFlags |= 4, s;
	}
	function qo(n, i, s) {
		return n.name !== i || n.value !== s ? j(Ii(i, s), n) : n;
	}
	function ws(n, i) {
		let s = O(303);
		return s.assertClause = n, s.multiLine = i, s;
	}
	function Fo(n, i, s) {
		return n.assertClause !== i || n.multiLine !== s ? j(ws(i, s), n) : n;
	}
	function zo(n, i, s) {
		let l = O(301);
		return l.token = s ?? 118, l.elements = de(n), l.multiLine = i, l.transformFlags |= 4, l;
	}
	function ks(n, i, s) {
		return n.elements !== i || n.multiLine !== s ? j(zo(i, s, n.token), n) : n;
	}
	function Vo(n, i) {
		let s = O(302);
		return s.name = n, s.value = i, s.transformFlags |= 4, s;
	}
	function Wo(n, i, s) {
		return n.name !== i || n.value !== s ? j(Vo(i, s), n) : n;
	}
	function Go(n) {
		let i = ae(275);
		return i.name = n, i.transformFlags |= z(i.name), i.transformFlags &= -67108865, i;
	}
	function hu(n, i) {
		return n.name !== i ? j(Go(i), n) : n;
	}
	function Yo(n) {
		let i = ae(281);
		return i.name = n, i.transformFlags |= z(i.name) | 32, i.transformFlags &= -67108865, i;
	}
	function yu(n, i) {
		return n.name !== i ? j(Yo(i), n) : n;
	}
	function Ho(n) {
		let i = O(276);
		return i.elements = de(n), i.transformFlags |= ke(i.elements), i.transformFlags &= -67108865, i;
	}
	function Xo(n, i) {
		return n.elements !== i ? j(Ho(i), n) : n;
	}
	function Sr(n, i, s) {
		let l = ae(277);
		return l.isTypeOnly = n, l.propertyName = i, l.name = s, l.transformFlags |= z(l.propertyName) | z(l.name), l.transformFlags &= -67108865, l;
	}
	function gu(n, i, s, l) {
		return n.isTypeOnly !== i || n.propertyName !== s || n.name !== l ? j(Sr(i, s, l), n) : n;
	}
	function va(n, i, s) {
		let l = ae(278);
		return l.modifiers = Pe(n), l.isExportEquals = i, l.expression = i ? _().parenthesizeRightSideOfBinary(64, void 0, s) : _().parenthesizeExpressionOfExportDefault(s), l.transformFlags |= ke(l.modifiers) | z(l.expression), l.transformFlags &= -67108865, l.jsDoc = void 0, l;
	}
	function Oi(n, i, s) {
		return n.modifiers !== i || n.expression !== s ? j(va(i, n.isExportEquals, s), n) : n;
	}
	function Ta(n, i, s, l, d) {
		let v = ae(279);
		return v.modifiers = Pe(n), v.isTypeOnly = i, v.exportClause = s, v.moduleSpecifier = l, v.attributes = v.assertClause = d, v.transformFlags |= ke(v.modifiers) | z(v.exportClause) | z(v.moduleSpecifier), v.transformFlags &= -67108865, v.jsDoc = void 0, v;
	}
	function $o(n, i, s, l, d, v) {
		return n.modifiers !== i || n.isTypeOnly !== s || n.exportClause !== l || n.moduleSpecifier !== d || n.attributes !== v ? Mi(Ta(i, s, l, d, v), n) : n;
	}
	function Mi(n, i) {
		return n !== i && n.modifiers === i.modifiers && (n.modifiers = i.modifiers), j(n, i);
	}
	function Es(n) {
		let i = O(280);
		return i.elements = de(n), i.transformFlags |= ke(i.elements), i.transformFlags &= -67108865, i;
	}
	function bu(n, i) {
		return n.elements !== i ? j(Es(i), n) : n;
	}
	function xa(n, i, s) {
		let l = O(282);
		return l.isTypeOnly = n, l.propertyName = et(i), l.name = et(s), l.transformFlags |= z(l.propertyName) | z(l.name), l.transformFlags &= -67108865, l.jsDoc = void 0, l;
	}
	function vu(n, i, s, l) {
		return n.isTypeOnly !== i || n.propertyName !== s || n.name !== l ? j(xa(i, s, l), n) : n;
	}
	function Tu() {
		let n = ae(283);
		return n.jsDoc = void 0, n;
	}
	function As(n) {
		let i = O(284);
		return i.expression = n, i.transformFlags |= z(i.expression), i.transformFlags &= -67108865, i;
	}
	function xu(n, i) {
		return n.expression !== i ? j(As(i), n) : n;
	}
	function Qo(n) {
		return O(n);
	}
	function Ko(n, i, s = !1) {
		let l = Cs(n, s ? i && _().parenthesizeNonArrayTypeOfPostfixType(i) : i);
		return l.postfix = s, l;
	}
	function Cs(n, i) {
		let s = O(n);
		return s.type = i, s;
	}
	function Su(n, i, s) {
		return i.type !== s ? j(Ko(n, s, i.postfix), i) : i;
	}
	function wu(n, i, s) {
		return i.type !== s ? j(Cs(n, s), i) : i;
	}
	function Zo(n, i) {
		let s = ae(318);
		return s.parameters = Pe(n), s.type = i, s.transformFlags = ke(s.parameters) | (s.type ? 1 : 0), s.jsDoc = void 0, s.locals = void 0, s.nextContainer = void 0, s.typeArguments = void 0, s;
	}
	function ku(n, i, s) {
		return n.parameters !== i || n.type !== s ? j(Zo(i, s), n) : n;
	}
	function ec(n, i = !1) {
		let s = ae(323);
		return s.jsDocPropertyTags = Pe(n), s.isArrayType = i, s;
	}
	function Eu(n, i, s) {
		return n.jsDocPropertyTags !== i || n.isArrayType !== s ? j(ec(i, s), n) : n;
	}
	function tc(n) {
		let i = O(310);
		return i.type = n, i;
	}
	function Ds(n, i) {
		return n.type !== i ? j(tc(i), n) : n;
	}
	function nc(n, i, s) {
		let l = ae(324);
		return l.typeParameters = Pe(n), l.parameters = de(i), l.type = s, l.jsDoc = void 0, l.locals = void 0, l.nextContainer = void 0, l;
	}
	function Au(n, i, s, l) {
		return n.typeParameters !== i || n.parameters !== s || n.type !== l ? j(nc(i, s, l), n) : n;
	}
	function rn(n) {
		let i = ol(n.kind);
		return n.tagName.escapedText === La(i) ? n.tagName : We(i);
	}
	function vn(n, i, s) {
		let l = O(n);
		return l.tagName = i, l.comment = s, l;
	}
	function qr(n, i, s) {
		let l = ae(n);
		return l.tagName = i, l.comment = s, l;
	}
	function Ps(n, i, s, l) {
		let d = vn(346, n ?? We("template"), l);
		return d.constraint = i, d.typeParameters = de(s), d;
	}
	function rc(n, i = rn(n), s, l, d) {
		return n.tagName !== i || n.constraint !== s || n.typeParameters !== l || n.comment !== d ? j(Ps(i, s, l, d), n) : n;
	}
	function Sa(n, i, s, l) {
		let d = qr(347, n ?? We("typedef"), l);
		return d.typeExpression = i, d.fullName = s, d.name = Hd(s), d.locals = void 0, d.nextContainer = void 0, d;
	}
	function Cu(n, i = rn(n), s, l, d) {
		return n.tagName !== i || n.typeExpression !== s || n.fullName !== l || n.comment !== d ? j(Sa(i, s, l, d), n) : n;
	}
	function Ns(n, i, s, l, d, v) {
		let F = qr(342, n ?? We("param"), v);
		return F.typeExpression = l, F.name = i, F.isNameFirst = !!d, F.isBracketed = s, F;
	}
	function Du(n, i = rn(n), s, l, d, v, F) {
		return n.tagName !== i || n.name !== s || n.isBracketed !== l || n.typeExpression !== d || n.isNameFirst !== v || n.comment !== F ? j(Ns(i, s, l, d, v, F), n) : n;
	}
	function ic(n, i, s, l, d, v) {
		let F = qr(349, n ?? We("prop"), v);
		return F.typeExpression = l, F.name = i, F.isNameFirst = !!d, F.isBracketed = s, F;
	}
	function ac(n, i = rn(n), s, l, d, v, F) {
		return n.tagName !== i || n.name !== s || n.isBracketed !== l || n.typeExpression !== d || n.isNameFirst !== v || n.comment !== F ? j(ic(i, s, l, d, v, F), n) : n;
	}
	function sc(n, i, s, l) {
		let d = qr(339, n ?? We("callback"), l);
		return d.typeExpression = i, d.fullName = s, d.name = Hd(s), d.locals = void 0, d.nextContainer = void 0, d;
	}
	function _c(n, i = rn(n), s, l, d) {
		return n.tagName !== i || n.typeExpression !== s || n.fullName !== l || n.comment !== d ? j(sc(i, s, l, d), n) : n;
	}
	function oc(n, i, s) {
		let l = vn(340, n ?? We("overload"), s);
		return l.typeExpression = i, l;
	}
	function Is(n, i = rn(n), s, l) {
		return n.tagName !== i || n.typeExpression !== s || n.comment !== l ? j(oc(i, s, l), n) : n;
	}
	function Os(n, i, s) {
		let l = vn(329, n ?? We("augments"), s);
		return l.class = i, l;
	}
	function Li(n, i = rn(n), s, l) {
		return n.tagName !== i || n.class !== s || n.comment !== l ? j(Os(i, s, l), n) : n;
	}
	function cc(n, i, s) {
		let l = vn(330, n ?? We("implements"), s);
		return l.class = i, l;
	}
	function Fr(n, i, s) {
		let l = vn(348, n ?? We("see"), s);
		return l.name = i, l;
	}
	function wa(n, i, s, l) {
		return n.tagName !== i || n.name !== s || n.comment !== l ? j(Fr(i, s, l), n) : n;
	}
	function lc(n) {
		let i = O(311);
		return i.name = n, i;
	}
	function Pu(n, i) {
		return n.name !== i ? j(lc(i), n) : n;
	}
	function uc(n, i) {
		let s = O(312);
		return s.left = n, s.right = i, s.transformFlags |= z(s.left) | z(s.right), s;
	}
	function Nu(n, i, s) {
		return n.left !== i || n.right !== s ? j(uc(i, s), n) : n;
	}
	function pc(n, i) {
		let s = O(325);
		return s.name = n, s.text = i, s;
	}
	function fc(n, i, s) {
		return n.name !== i ? j(pc(i, s), n) : n;
	}
	function dc(n, i) {
		let s = O(326);
		return s.name = n, s.text = i, s;
	}
	function Iu(n, i, s) {
		return n.name !== i ? j(dc(i, s), n) : n;
	}
	function mc(n, i) {
		let s = O(327);
		return s.name = n, s.text = i, s;
	}
	function Ou(n, i, s) {
		return n.name !== i ? j(mc(i, s), n) : n;
	}
	function Mu(n, i = rn(n), s, l) {
		return n.tagName !== i || n.class !== s || n.comment !== l ? j(cc(i, s, l), n) : n;
	}
	function hc(n, i, s) {
		return vn(n, i ?? We(ol(n)), s);
	}
	function Lu(n, i, s = rn(i), l) {
		return i.tagName !== s || i.comment !== l ? j(hc(n, s, l), i) : i;
	}
	function yc(n, i, s, l) {
		let d = vn(n, i ?? We(ol(n)), l);
		return d.typeExpression = s, d;
	}
	function Ju(n, i, s = rn(i), l, d) {
		return i.tagName !== s || i.typeExpression !== l || i.comment !== d ? j(yc(n, s, l, d), i) : i;
	}
	function gc(n, i) {
		return vn(328, n, i);
	}
	function ju(n, i, s) {
		return n.tagName !== i || n.comment !== s ? j(gc(i, s), n) : n;
	}
	function bc(n, i, s) {
		let l = qr(341, n ?? We(ol(341)), s);
		return l.typeExpression = i, l.locals = void 0, l.nextContainer = void 0, l;
	}
	function Ms(n, i = rn(n), s, l) {
		return n.tagName !== i || n.typeExpression !== s || n.comment !== l ? j(bc(i, s, l), n) : n;
	}
	function vc(n, i, s, l, d) {
		let v = vn(352, n ?? We("import"), d);
		return v.importClause = i, v.moduleSpecifier = s, v.attributes = l, v.comment = d, v;
	}
	function Tc(n, i, s, l, d, v) {
		return n.tagName !== i || n.comment !== v || n.importClause !== s || n.moduleSpecifier !== l || n.attributes !== d ? j(vc(i, s, l, d, v), n) : n;
	}
	function Ls(n) {
		let i = O(322);
		return i.text = n, i;
	}
	function Ru(n, i) {
		return n.text !== i ? j(Ls(i), n) : n;
	}
	function Ji(n, i) {
		let s = O(321);
		return s.comment = n, s.tags = Pe(i), s;
	}
	function xc(n, i, s) {
		return n.comment !== i || n.tags !== s ? j(Ji(i, s), n) : n;
	}
	function Sc(n, i, s) {
		let l = O(285);
		return l.openingElement = n, l.children = de(i), l.closingElement = s, l.transformFlags |= z(l.openingElement) | ke(l.children) | z(l.closingElement) | 2, l;
	}
	function Uu(n, i, s, l) {
		return n.openingElement !== i || n.children !== s || n.closingElement !== l ? j(Sc(i, s, l), n) : n;
	}
	function wc(n, i, s) {
		let l = O(286);
		return l.tagName = n, l.typeArguments = Pe(i), l.attributes = s, l.transformFlags |= z(l.tagName) | ke(l.typeArguments) | z(l.attributes) | 2, l.typeArguments && (l.transformFlags |= 1), l;
	}
	function Bu(n, i, s, l) {
		return n.tagName !== i || n.typeArguments !== s || n.attributes !== l ? j(wc(i, s, l), n) : n;
	}
	function ka(n, i, s) {
		let l = O(287);
		return l.tagName = n, l.typeArguments = Pe(i), l.attributes = s, l.transformFlags |= z(l.tagName) | ke(l.typeArguments) | z(l.attributes) | 2, i && (l.transformFlags |= 1), l;
	}
	function kc(n, i, s, l) {
		return n.tagName !== i || n.typeArguments !== s || n.attributes !== l ? j(ka(i, s, l), n) : n;
	}
	function Js(n) {
		let i = O(288);
		return i.tagName = n, i.transformFlags |= z(i.tagName) | 2, i;
	}
	function js(n, i) {
		return n.tagName !== i ? j(Js(i), n) : n;
	}
	function Yt(n, i, s) {
		let l = O(289);
		return l.openingFragment = n, l.children = de(i), l.closingFragment = s, l.transformFlags |= z(l.openingFragment) | ke(l.children) | z(l.closingFragment) | 2, l;
	}
	function Ec(n, i, s, l) {
		return n.openingFragment !== i || n.children !== s || n.closingFragment !== l ? j(Yt(i, s, l), n) : n;
	}
	function ji(n, i) {
		let s = O(12);
		return s.text = n, s.containsOnlyTriviaWhiteSpaces = !!i, s.transformFlags |= 2, s;
	}
	function qu(n, i, s) {
		return n.text !== i || n.containsOnlyTriviaWhiteSpaces !== s ? j(ji(i, s), n) : n;
	}
	function Ac() {
		let n = O(290);
		return n.transformFlags |= 2, n;
	}
	function Cc() {
		let n = O(291);
		return n.transformFlags |= 2, n;
	}
	function Dc(n, i) {
		let s = ae(292);
		return s.name = n, s.initializer = i, s.transformFlags |= z(s.name) | z(s.initializer) | 2, s;
	}
	function Fu(n, i, s) {
		return n.name !== i || n.initializer !== s ? j(Dc(i, s), n) : n;
	}
	function Ri(n) {
		let i = ae(293);
		return i.properties = de(n), i.transformFlags |= ke(i.properties) | 2, i;
	}
	function zu(n, i) {
		return n.properties !== i ? j(Ri(i), n) : n;
	}
	function Pc(n) {
		let i = O(294);
		return i.expression = n, i.transformFlags |= z(i.expression) | 2, i;
	}
	function Vu(n, i) {
		return n.expression !== i ? j(Pc(i), n) : n;
	}
	function Nc(n, i) {
		let s = O(295);
		return s.dotDotDotToken = n, s.expression = i, s.transformFlags |= z(s.dotDotDotToken) | z(s.expression) | 2, s;
	}
	function Rs(n, i) {
		return n.expression !== i ? j(Nc(n.dotDotDotToken, i), n) : n;
	}
	function si(n, i) {
		let s = O(296);
		return s.namespace = n, s.name = i, s.transformFlags |= z(s.namespace) | z(s.name) | 2, s;
	}
	function Wu(n, i, s) {
		return n.namespace !== i || n.name !== s ? j(si(i, s), n) : n;
	}
	function Ea(n, i) {
		let s = O(297);
		return s.expression = _().parenthesizeExpressionForDisallowedComma(n), s.statements = de(i), s.transformFlags |= z(s.expression) | ke(s.statements), s.jsDoc = void 0, s;
	}
	function Ic(n, i, s) {
		return n.expression !== i || n.statements !== s ? j(Ea(i, s), n) : n;
	}
	function Oc(n) {
		let i = O(298);
		return i.statements = de(n), i.transformFlags = ke(i.statements), i;
	}
	function Ui(n, i) {
		return n.statements !== i ? j(Oc(i), n) : n;
	}
	function Us(n, i) {
		let s = O(299);
		switch (s.token = n, s.types = de(i), s.transformFlags |= ke(s.types), n) {
			case 96:
				s.transformFlags |= 1024;
				break;
			case 119:
				s.transformFlags |= 1;
				break;
			default: return q.assertNever(n);
		}
		return s;
	}
	function Gu(n, i) {
		return n.types !== i ? j(Us(n.token, i), n) : n;
	}
	function Mc(n, i) {
		let s = O(300);
		return s.variableDeclaration = Tn(n), s.block = i, s.transformFlags |= z(s.variableDeclaration) | z(s.block) | (n ? 0 : 64), s.locals = void 0, s.nextContainer = void 0, s;
	}
	function Lc(n, i, s) {
		return n.variableDeclaration !== i || n.block !== s ? j(Mc(i, s), n) : n;
	}
	function Aa(n, i) {
		let s = ae(304);
		return s.name = et(n), s.initializer = _().parenthesizeExpressionForDisallowedComma(i), s.transformFlags |= Ln(s.name) | z(s.initializer), s.modifiers = void 0, s.questionToken = void 0, s.exclamationToken = void 0, s.jsDoc = void 0, s;
	}
	function Bs(n, i, s) {
		return n.name !== i || n.initializer !== s ? _i(Aa(i, s), n) : n;
	}
	function _i(n, i) {
		return n !== i && (n.modifiers = i.modifiers, n.questionToken = i.questionToken, n.exclamationToken = i.exclamationToken), j(n, i);
	}
	function Jc(n, i) {
		let s = ae(305);
		return s.name = et(n), s.objectAssignmentInitializer = i && _().parenthesizeExpressionForDisallowedComma(i), s.transformFlags |= ja(s.name) | z(s.objectAssignmentInitializer) | 1024, s.equalsToken = void 0, s.modifiers = void 0, s.questionToken = void 0, s.exclamationToken = void 0, s.jsDoc = void 0, s;
	}
	function Yu(n, i, s) {
		return n.name !== i || n.objectAssignmentInitializer !== s ? Hu(Jc(i, s), n) : n;
	}
	function Hu(n, i) {
		return n !== i && (n.modifiers = i.modifiers, n.questionToken = i.questionToken, n.exclamationToken = i.exclamationToken, n.equalsToken = i.equalsToken), j(n, i);
	}
	function jc(n) {
		let i = ae(306);
		return i.expression = _().parenthesizeExpressionForDisallowedComma(n), i.transformFlags |= z(i.expression) | 65664, i.jsDoc = void 0, i;
	}
	function Rc(n, i) {
		return n.expression !== i ? j(jc(i), n) : n;
	}
	function qs(n, i) {
		let s = ae(307);
		return s.name = et(n), s.initializer = i && _().parenthesizeExpressionForDisallowedComma(i), s.transformFlags |= z(s.name) | z(s.initializer) | 1, s.jsDoc = void 0, s;
	}
	function On(n, i, s) {
		return n.name !== i || n.initializer !== s ? j(qs(i, s), n) : n;
	}
	function Uc(n, i, s) {
		let l = t.createBaseSourceFileNode(308);
		return l.statements = de(n), l.endOfFileToken = i, l.flags |= s, l.text = "", l.fileName = "", l.path = "", l.resolvedPath = "", l.originalFileName = "", l.languageVersion = 1, l.languageVariant = 0, l.scriptKind = 0, l.isDeclarationFile = !1, l.hasNoDefaultLib = !1, l.transformFlags |= ke(l.statements) | z(l.endOfFileToken), l.locals = void 0, l.nextContainer = void 0, l.endFlowNode = void 0, l.nodeCount = 0, l.identifierCount = 0, l.symbolCount = 0, l.parseDiagnostics = void 0, l.bindDiagnostics = void 0, l.bindSuggestionDiagnostics = void 0, l.lineMap = void 0, l.externalModuleIndicator = void 0, l.setExternalModuleIndicator = void 0, l.pragmas = void 0, l.checkJsDirective = void 0, l.referencedFiles = void 0, l.typeReferenceDirectives = void 0, l.libReferenceDirectives = void 0, l.amdDependencies = void 0, l.commentDirectives = void 0, l.identifiers = void 0, l.packageJsonLocations = void 0, l.packageJsonScope = void 0, l.imports = void 0, l.moduleAugmentations = void 0, l.ambientModuleNames = void 0, l.classifiableNames = void 0, l.impliedNodeFormat = void 0, l;
	}
	function Bc(n) {
		let i = Object.create(n.redirectTarget);
		return Object.defineProperties(i, {
			id: {
				get() {
					return this.redirectInfo.redirectTarget.id;
				},
				set(s) {
					this.redirectInfo.redirectTarget.id = s;
				}
			},
			symbol: {
				get() {
					return this.redirectInfo.redirectTarget.symbol;
				},
				set(s) {
					this.redirectInfo.redirectTarget.symbol = s;
				}
			}
		}), i.redirectInfo = n, i;
	}
	function Xu(n) {
		let i = Bc(n.redirectInfo);
		return i.flags |= n.flags & -17, i.fileName = n.fileName, i.path = n.path, i.resolvedPath = n.resolvedPath, i.originalFileName = n.originalFileName, i.packageJsonLocations = n.packageJsonLocations, i.packageJsonScope = n.packageJsonScope, i.emitNode = void 0, i;
	}
	function $u(n) {
		let i = t.createBaseSourceFileNode(308);
		i.flags |= n.flags & -17;
		for (let s in n) if (!(Dr(i, s) || !Dr(n, s))) {
			if (s === "emitNode") {
				i.emitNode = void 0;
				continue;
			}
			i[s] = n[s];
		}
		return i;
	}
	function Fs(n) {
		let i = n.redirectInfo ? Xu(n) : $u(n);
		return a(i, n), i;
	}
	function zs(n, i, s, l, d, v, F) {
		let pe = Fs(n);
		return pe.statements = de(i), pe.isDeclarationFile = s, pe.referencedFiles = l, pe.typeReferenceDirectives = d, pe.hasNoDefaultLib = v, pe.libReferenceDirectives = F, pe.transformFlags = ke(pe.statements) | z(pe.endOfFileToken), pe;
	}
	function Qu(n, i, s = n.isDeclarationFile, l = n.referencedFiles, d = n.typeReferenceDirectives, v = n.hasNoDefaultLib, F = n.libReferenceDirectives) {
		return n.statements !== i || n.isDeclarationFile !== s || n.referencedFiles !== l || n.typeReferenceDirectives !== d || n.hasNoDefaultLib !== v || n.libReferenceDirectives !== F ? j(zs(n, i, s, l, d, v, F), n) : n;
	}
	function qc(n) {
		let i = O(309);
		return i.sourceFiles = n, i.syntheticFileReferences = void 0, i.syntheticTypeReferences = void 0, i.syntheticLibReferences = void 0, i.hasNoDefaultLib = void 0, i;
	}
	function Fc(n, i) {
		return n.sourceFiles !== i ? j(qc(i), n) : n;
	}
	function Ku(n, i = !1, s) {
		let l = O(238);
		return l.type = n, l.isSpread = i, l.tupleNameSource = s, l;
	}
	function Zu(n) {
		let i = O(353);
		return i._children = n, i;
	}
	function Ca(n) {
		let i = O(354);
		return i.original = n, dn(i, n), i;
	}
	function Vs(n, i) {
		let s = O(356);
		return s.expression = n, s.original = i, s.transformFlags |= z(s.expression) | 1, dn(s, i), s;
	}
	function zc(n, i) {
		return n.expression !== i ? j(Vs(i, n.original), n) : n;
	}
	function ep() {
		return O(355);
	}
	function tp(n) {
		if (Ja(n) && !gl(n) && !n.original && !n.emitNode && !n.id) {
			if (e6(n)) return n.elements;
			if (na(n) && Rb(n.operatorToken)) return [n.left, n.right];
		}
		return n;
	}
	function Ws(n) {
		let i = O(357);
		return i.elements = de(oy(n, tp)), i.transformFlags |= ke(i.elements), i;
	}
	function np(n, i) {
		return n.elements !== i ? j(Ws(i), n) : n;
	}
	function Gs(n, i) {
		let s = O(358);
		return s.expression = n, s.thisArg = i, s.transformFlags |= z(s.expression) | z(s.thisArg), s;
	}
	function Vc(n, i, s) {
		return n.expression !== i || n.thisArg !== s ? j(Gs(i, s), n) : n;
	}
	function Wc(n) {
		let i = hn(n.escapedText);
		return i.flags |= n.flags & -17, i.transformFlags = n.transformFlags, a(i, n), setIdentifierAutoGenerate(i, { ...n.emitNode.autoGenerate }), i;
	}
	function rp(n) {
		let i = hn(n.escapedText);
		i.flags |= n.flags & -17, i.jsDoc = n.jsDoc, i.flowNode = n.flowNode, i.symbol = n.symbol, i.transformFlags = n.transformFlags, a(i, n);
		let s = getIdentifierTypeArguments(n);
		return s && setIdentifierTypeArguments(i, s), i;
	}
	function ip(n) {
		let i = Pn(n.escapedText);
		return i.flags |= n.flags & -17, i.transformFlags = n.transformFlags, a(i, n), setIdentifierAutoGenerate(i, { ...n.emitNode.autoGenerate }), i;
	}
	function Gc(n) {
		let i = Pn(n.escapedText);
		return i.flags |= n.flags & -17, i.transformFlags = n.transformFlags, a(i, n), i;
	}
	function Da(n) {
		if (n === void 0) return n;
		if (Z1(n)) return Fs(n);
		if (Ua(n)) return Wc(n);
		if (Ke(n)) return rp(n);
		if (n1(n)) return ip(n);
		if (gi(n)) return Gc(n);
		let i = ff(n.kind) ? t.createBaseNode(n.kind) : t.createBaseTokenNode(n.kind);
		i.flags |= n.flags & -17, i.transformFlags = n.transformFlags, a(i, n);
		for (let s in n) Dr(i, s) || !Dr(n, s) || (i[s] = n[s]);
		return i;
	}
	function ap(n, i, s) {
		return Di(is(void 0, void 0, void 0, void 0, i ? [i] : [], void 0, Br(n, !0)), void 0, s ? [s] : []);
	}
	function sp(n, i, s) {
		return Di(as(void 0, void 0, i ? [i] : [], void 0, void 0, Br(n, !0)), void 0, s ? [s] : []);
	}
	function Bi() {
		return ss(V("0"));
	}
	function Yc(n) {
		return va(void 0, !1, n);
	}
	function Hc(n) {
		return Ta(void 0, !1, Es([xa(!1, void 0, n)]));
	}
	function _p(n, i) {
		return i === "null" ? he.createStrictEquality(n, Lt()) : i === "undefined" ? he.createStrictEquality(n, Bi()) : he.createStrictEquality(fa(n), ft(i));
	}
	function Ys(n, i) {
		return i === "null" ? he.createStrictInequality(n, Lt()) : i === "undefined" ? he.createStrictInequality(n, Bi()) : he.createStrictInequality(fa(n), ft(i));
	}
	function zr(n, i, s) {
		return Dd(n) ? ts(Ai(n, void 0, i), void 0, void 0, s) : Di(cr(n, i), void 0, s);
	}
	function op(n, i, s) {
		return zr(n, "bind", [i, ...s]);
	}
	function cp(n, i, s) {
		return zr(n, "call", [i, ...s]);
	}
	function lp(n, i, s) {
		return zr(n, "apply", [i, s]);
	}
	function qi(n, i, s) {
		return zr(We(n), i, s);
	}
	function up(n, i) {
		return zr(n, "slice", i === void 0 ? [] : [wr(i)]);
	}
	function Fi(n, i) {
		return zr(n, "concat", i);
	}
	function pp(n, i, s) {
		return qi("Object", "defineProperty", [
			n,
			wr(i),
			s
		]);
	}
	function Hs(n, i) {
		return qi("Object", "getOwnPropertyDescriptor", [n, wr(i)]);
	}
	function oi(n, i, s) {
		return qi("Reflect", "get", s ? [
			n,
			i,
			s
		] : [n, i]);
	}
	function Xc(n, i, s, l) {
		return qi("Reflect", "set", l ? [
			n,
			i,
			s,
			l
		] : [
			n,
			i,
			s
		]);
	}
	function ci(n, i, s) {
		return s ? (n.push(Aa(i, s)), !0) : !1;
	}
	function fp(n, i) {
		let s = [];
		ci(s, "enumerable", wr(n.enumerable)), ci(s, "configurable", wr(n.configurable));
		let l = ci(s, "writable", wr(n.writable));
		l = ci(s, "value", n.value) || l;
		let d = ci(s, "get", n.get);
		return d = ci(s, "set", n.set) || d, q.assert(!(l && d), "A PropertyDescriptor may not be both an accessor descriptor and a data descriptor."), Ei(s, !i);
	}
	function $c(n, i) {
		switch (n.kind) {
			case 218: return U_(n, i);
			case 217: return R_(n, n.type, i);
			case 235: return ha(n, i, n.type);
			case 239: return ro(n, i, n.type);
			case 236: return no(n, i);
			case 234: return eo(n, i, n.typeArguments);
			case 356: return zc(n, i);
		}
	}
	function dp(n) {
		return Dl(n) && Ja(n) && Ja(getSourceMapRange(n)) && Ja(getCommentRange(n)) && !Zt(getSyntheticLeadingComments(n)) && !Zt(getSyntheticTrailingComments(n));
	}
	function Qc(n, i, s = 63) {
		return n && sh(n, s) && !dp(n) ? $c(n, Qc(n.expression, i)) : i;
	}
	function Kc(n, i, s) {
		if (!i) return n;
		let l = xo(i, i.label, Y1(i.statement) ? Kc(n, i.statement) : n);
		return s && s(i), l;
	}
	function Xs(n, i) {
		let s = vf(n);
		switch (s.kind) {
			case 80: return i;
			case 110:
			case 9:
			case 10:
			case 11: return !1;
			case 210: return s.elements.length !== 0;
			case 211: return s.properties.length > 0;
			default: return !0;
		}
	}
	function Zc(n, i, s, l = !1) {
		let d = Vf(n, 63), v, F;
		return Jd(d) ? (v = Bt(), F = d) : Ap(d) ? (v = Bt(), F = s !== void 0 && s < 2 ? dn(We("_super"), d) : d) : za(d) & 8192 ? (v = Bi(), F = _().parenthesizeLeftSideOfAccess(d, !1)) : dr(d) ? Xs(d.expression, l) ? (v = ir(i), F = cr(dn(he.createAssignment(v, d.expression), d.expression), d.name), dn(F, d)) : (v = d.expression, F = d) : Ha(d) ? Xs(d.expression, l) ? (v = ir(i), F = Ci(dn(he.createAssignment(v, d.expression), d.expression), d.argumentExpression), dn(F, d)) : (v = d.expression, F = d) : (v = Bi(), F = _().parenthesizeLeftSideOfAccess(n, !1)), {
			target: F,
			thisArg: v
		};
	}
	function el(n, i) {
		return cr(rs(Ei([U(void 0, "value", [mr(void 0, void 0, n, void 0, void 0, void 0)], Br([Ni(i)]))])), "value");
	}
	function o(n) {
		return n.length > 10 ? Ws(n) : gy(n, he.createComma);
	}
	function p(n, i, s, l = 0, d) {
		let v = d ? n && lf(n) : Xm(n);
		if (v && Ke(v) && !Ua(v)) {
			let F = Sf(dn(Da(v), v), v.parent);
			return l |= za(v), s || (l |= 96), i || (l |= 3072), l && setEmitFlags(F, l), F;
		}
		return Bn(n);
	}
	function m(n, i, s) {
		return p(n, i, s, 98304);
	}
	function g(n, i, s, l) {
		return p(n, i, s, 32768, l);
	}
	function b(n, i, s) {
		return p(n, i, s, 16384);
	}
	function N(n, i, s) {
		return p(n, i, s);
	}
	function Q(n, i, s, l) {
		let d = cr(n, Ja(i) ? i : Da(i));
		dn(d, i);
		let v = 0;
		return l || (v |= 96), s || (v |= 3072), v && setEmitFlags(d, v), d;
	}
	function _e(n, i, s, l) {
		return n && v_(i, 32) ? Q(n, p(i), s, l) : b(i, s, l);
	}
	function ee(n, i, s, l) {
		return Je(n, i, je(n, i, 0, s), l);
	}
	function te(n) {
		return vi(n.expression) && n.expression.text === "use strict";
	}
	function ce() {
		return T6(Ni(ft("use strict")));
	}
	function je(n, i, s = 0, l) {
		q.assert(i.length === 0, "Prologue directives should be at the first statement in the target statements array");
		let d = !1, v = n.length;
		for (; s < v;) {
			let F = n[s];
			if (pl(F)) te(F) && (d = !0), i.push(F);
			else break;
			s++;
		}
		return l && !d && i.push(ce()), s;
	}
	function Je(n, i, s, l, d = wy) {
		let v = n.length;
		for (; s !== void 0 && s < v;) {
			let F = n[s];
			if (za(F) & 2097152 && d(F)) wn(i, l ? visitNode(F, l, Qg) : F);
			else break;
			s++;
		}
		return s;
	}
	function De(n) {
		return b6(n) ? n : dn(de([ce(), ...n]), n);
	}
	function Ht(n) {
		return q.assert(Gp(n, Zg), "Cannot lift nodes to a Block."), my(n) || Br(n);
	}
	function Nt(n, i, s) {
		let l = s;
		for (; l < n.length && i(n[l]);) l++;
		return l;
	}
	function ur(n, i) {
		if (!Zt(i)) return n;
		let s = Nt(n, pl, 0), l = Nt(n, Md, s), d = Nt(n, Ld, l), v = Nt(i, pl, 0), F = Nt(i, Md, v), pe = Nt(i, Ld, F), Fe = Nt(i, hf, pe);
		q.assert(Fe === i.length, "Expected declarations to be valid standard or custom prologues");
		let It = mi(n) ? n.slice() : n;
		if (Fe > pe && It.splice(d, 0, ...i.slice(pe, Fe)), pe > F && It.splice(l, 0, ...i.slice(F, pe)), F > v && It.splice(s, 0, ...i.slice(v, F)), v > 0) if (s === 0) It.splice(0, 0, ...i.slice(0, v));
		else {
			let fr = /* @__PURE__ */ new Map();
			for (let xn = 0; xn < s; xn++) {
				let Vi = n[xn];
				fr.set(Vi.expression.text, !0);
			}
			for (let xn = v - 1; xn >= 0; xn--) {
				let Vi = i[xn];
				fr.has(Vi.expression.text) || It.unshift(Vi);
			}
		}
		return mi(n) ? dn(de(It, n.hasTrailingComma), n) : n;
	}
	function pr(n, i) {
		let s;
		return typeof i == "number" ? s = yn(i) : s = i, Ef(n) ? sr(n, s, n.name, n.constraint, n.default) : m_(n) ? hr(n, s, n.dotDotDotToken, n.name, n.questionToken, n.type, n.initializer) : Nf(n) ? ze(n, s, n.typeParameters, n.parameters, n.type) : C1(n) ? Vn(n, s, n.name, n.questionToken, n.type) : Wa(n) ? L(n, s, n.name, n.questionToken ?? n.exclamationToken, n.type, n.initializer) : D1(n) ? fe(n, s, n.name, n.questionToken, n.typeParameters, n.parameters, n.type) : h_(n) ? He(n, s, n.asteriskToken, n.name, n.questionToken, n.typeParameters, n.parameters, n.type, n.body) : Af(n) ? Mr(n, s, n.parameters, n.body) : Tl(n) ? Wn(n, s, n.name, n.parameters, n.type, n.body) : y_(n) ? K(n, s, n.name, n.parameters, n.body) : Cf(n) ? Ze(n, s, n.parameters, n.type) : Mf(n) ? B_(n, s, n.asteriskToken, n.name, n.typeParameters, n.parameters, n.type, n.body) : Lf(n) ? q_(n, s, n.typeParameters, n.parameters, n.type, n.equalsGreaterThanToken, n.body) : xl(n) ? cs(n, s, n.name, n.typeParameters, n.heritageClauses, n.members) : Xa(n) ? so(n, s, n.declarationList) : jf(n) ? Ts(n, s, n.asteriskToken, n.name, n.typeParameters, n.parameters, n.type, n.body) : Ga(n) ? ba(n, s, n.name, n.typeParameters, n.heritageClauses, n.members) : T_(n) ? Po(n, s, n.name, n.typeParameters, n.heritageClauses, n.members) : Nl(n) ? vr(n, s, n.name, n.typeParameters, n.type) : X1(n) ? Tr(n, s, n.name, n.members) : Ti(n) ? kt(n, s, n.name, n.body) : Rf(n) ? Jo(n, s, n.isTypeOnly, n.name, n.moduleReference) : Uf(n) ? Ro(n, s, n.importClause, n.moduleSpecifier, n.attributes) : Bf(n) ? Oi(n, s, n.expression) : qf(n) ? $o(n, s, n.isTypeOnly, n.exportClause, n.moduleSpecifier, n.attributes) : q.assertNever(n);
	}
	function Mn(n, i) {
		return m_(n) ? hr(n, i, n.dotDotDotToken, n.name, n.questionToken, n.type, n.initializer) : Wa(n) ? L(n, i, n.name, n.questionToken ?? n.exclamationToken, n.type, n.initializer) : h_(n) ? He(n, i, n.asteriskToken, n.name, n.questionToken, n.typeParameters, n.parameters, n.type, n.body) : Tl(n) ? Wn(n, i, n.name, n.parameters, n.type, n.body) : y_(n) ? K(n, i, n.name, n.parameters, n.body) : xl(n) ? cs(n, i, n.name, n.typeParameters, n.heritageClauses, n.members) : Ga(n) ? ba(n, i, n.name, n.typeParameters, n.heritageClauses, n.members) : q.assertNever(n);
	}
	function Vr(n, i) {
		switch (n.kind) {
			case 178: return Wn(n, n.modifiers, i, n.parameters, n.type, n.body);
			case 179: return K(n, n.modifiers, i, n.parameters, n.body);
			case 175: return He(n, n.modifiers, n.asteriskToken, i, n.questionToken, n.typeParameters, n.parameters, n.type, n.body);
			case 174: return fe(n, n.modifiers, i, n.questionToken, n.typeParameters, n.parameters, n.type);
			case 173: return L(n, n.modifiers, i, n.questionToken ?? n.exclamationToken, n.type, n.initializer);
			case 172: return Vn(n, n.modifiers, i, n.questionToken, n.type);
			case 304: return Bs(n, i, n.initializer);
		}
	}
	function Pe(n) {
		return n ? de(n) : void 0;
	}
	function et(n) {
		return typeof n == "string" ? We(n) : n;
	}
	function wr(n) {
		return typeof n == "string" ? ft(n) : typeof n == "number" ? V(n) : typeof n == "boolean" ? n ? ct() : ar() : n;
	}
	function zi(n) {
		return n && _().parenthesizeExpressionForDisallowedComma(n);
	}
	function mp(n) {
		return typeof n == "number" ? ot(n) : n;
	}
	function $n(n) {
		return n && t6(n) ? dn(a(_o(), n), n) : n;
	}
	function Tn(n) {
		return typeof n == "string" || n && !Jf(n) ? ga(n, void 0, void 0, void 0) : n;
	}
	function j(n, i) {
		return n !== i && (a(n, i), dn(n, i)), n;
	}
}
function ol(e) {
	switch (e) {
		case 345: return "type";
		case 343: return "returns";
		case 344: return "this";
		case 341: return "enum";
		case 331: return "author";
		case 333: return "class";
		case 334: return "public";
		case 335: return "private";
		case 336: return "protected";
		case 337: return "readonly";
		case 338: return "override";
		case 346: return "template";
		case 347: return "typedef";
		case 342: return "param";
		case 349: return "prop";
		case 339: return "callback";
		case 340: return "overload";
		case 329: return "augments";
		case 330: return "implements";
		case 352: return "import";
		default: return q.fail(`Unsupported kind: ${q.formatSyntaxKind(e)}`);
	}
}
var Sn, Fd = {};
function Nb(e, t) {
	switch (Sn || (Sn = sf(99, !1, 0)), e) {
		case 15:
			Sn.setText("`" + t + "`");
			break;
		case 16:
			Sn.setText("`" + t + "${");
			break;
		case 17:
			Sn.setText("}" + t + "${");
			break;
		case 18:
			Sn.setText("}" + t + "`");
			break;
	}
	let a = Sn.scan();
	if (a === 20 && (a = Sn.reScanTemplateToken(!1)), Sn.isUnterminated()) return Sn.setText(void 0), Fd;
	let _;
	switch (a) {
		case 15:
		case 16:
		case 17:
		case 18:
			_ = Sn.getTokenValue();
			break;
	}
	return _ === void 0 || Sn.scan() !== 1 ? (Sn.setText(void 0), Fd) : (Sn.setText(void 0), _);
}
function Ln(e) {
	return e && Ke(e) ? ja(e) : z(e);
}
function ja(e) {
	return z(e) & -67108865;
}
function Ib(e, t) {
	return t | e.transformFlags & 134234112;
}
function z(e) {
	if (!e) return 0;
	let t = e.transformFlags & ~Ob(e.kind);
	return yg(e) && r1(e.name) ? Ib(e.name, t) : t;
}
function ke(e) {
	return e ? e.transformFlags : 0;
}
function zd(e) {
	let t = 0;
	for (let a of e) t |= z(a);
	e.transformFlags = t;
}
function Ob(e) {
	if (e >= 183 && e <= 206) return -2;
	switch (e) {
		case 214:
		case 215:
		case 210: return -2147450880;
		case 268: return -1941676032;
		case 170: return -2147483648;
		case 220: return -2072174592;
		case 219:
		case 263: return -1937940480;
		case 262: return -2146893824;
		case 264:
		case 232: return -2147344384;
		case 177: return -1937948672;
		case 173: return -2013249536;
		case 175:
		case 178:
		case 179: return -2005057536;
		case 133:
		case 150:
		case 163:
		case 146:
		case 154:
		case 151:
		case 136:
		case 155:
		case 116:
		case 169:
		case 172:
		case 174:
		case 180:
		case 181:
		case 182:
		case 265:
		case 266: return -2;
		case 211: return -2147278848;
		case 300: return -2147418112;
		case 207:
		case 208: return -2147450880;
		case 217:
		case 239:
		case 235:
		case 356:
		case 218:
		case 108: return -2147483648;
		case 212:
		case 213: return -2147483648;
		default: return -2147483648;
	}
}
var Ks = Cb();
function Zs(e) {
	return e.flags |= 16, e;
}
wf(4, {
	createBaseSourceFileNode: (e) => Zs(Ks.createBaseSourceFileNode(e)),
	createBaseIdentifierNode: (e) => Zs(Ks.createBaseIdentifierNode(e)),
	createBasePrivateIdentifierNode: (e) => Zs(Ks.createBasePrivateIdentifierNode(e)),
	createBaseTokenNode: (e) => Zs(Ks.createBaseTokenNode(e)),
	createBaseNode: (e) => Zs(Ks.createBaseNode(e))
});
function Lb(e, t) {
	if (e.original !== t && (e.original = t, t)) {
		let a = t.emitNode;
		a && (e.emitNode = Jb(a, e.emitNode));
	}
	return e;
}
function Jb(e, t) {
	let { flags: a, internalFlags: _, leadingComments: f, trailingComments: h, commentRange: T, sourceMapRange: k, tokenSourceMapRanges: c, constantValue: W, helpers: y, startsOnNewLine: G, snippetElement: E, classThis: D, assignedName: R } = e;
	if (t || (t = {}), a && (t.flags = a), _ && (t.internalFlags = _ & -9), f && (t.leadingComments = En(f.slice(), t.leadingComments)), h && (t.trailingComments = En(h.slice(), t.trailingComments)), T && (t.commentRange = T), k && (t.sourceMapRange = k), c && (t.tokenSourceMapRanges = jb(c, t.tokenSourceMapRanges)), W !== void 0 && (t.constantValue = W), y) for (let ue of y) t.helpers = py(t.helpers, ue);
	return G !== void 0 && (t.startsOnNewLine = G), E !== void 0 && (t.snippetElement = E), D && (t.classThis = D), R && (t.assignedName = R), t;
}
function jb(e, t) {
	t || (t = []);
	for (let a in e) t[a] = e[a];
	return t;
}
function aa(e) {
	return e.kind === 9;
}
function k1(e) {
	return e.kind === 10;
}
function vi(e) {
	return e.kind === 11;
}
function E1(e) {
	return e.kind === 15;
}
function Rb(e) {
	return e.kind === 28;
}
function Vd(e) {
	return e.kind === 54;
}
function Wd(e) {
	return e.kind === 58;
}
function Ke(e) {
	return e.kind === 80;
}
function gi(e) {
	return e.kind === 81;
}
function Ub(e) {
	return e.kind === 95;
}
function cl(e) {
	return e.kind === 134;
}
function Ap(e) {
	return e.kind === 108;
}
function Bb(e) {
	return e.kind === 102;
}
function A1(e) {
	return e.kind === 167;
}
function kf(e) {
	return e.kind === 168;
}
function Ef(e) {
	return e.kind === 169;
}
function m_(e) {
	return e.kind === 170;
}
function Cl(e) {
	return e.kind === 171;
}
function C1(e) {
	return e.kind === 172;
}
function Wa(e) {
	return e.kind === 173;
}
function D1(e) {
	return e.kind === 174;
}
function h_(e) {
	return e.kind === 175;
}
function Af(e) {
	return e.kind === 177;
}
function Tl(e) {
	return e.kind === 178;
}
function y_(e) {
	return e.kind === 179;
}
function P1(e) {
	return e.kind === 180;
}
function N1(e) {
	return e.kind === 181;
}
function Cf(e) {
	return e.kind === 182;
}
function I1(e) {
	return e.kind === 183;
}
function Df(e) {
	return e.kind === 184;
}
function Pf(e) {
	return e.kind === 185;
}
function Nf(e) {
	return e.kind === 186;
}
function qb(e) {
	return e.kind === 187;
}
function O1(e) {
	return e.kind === 188;
}
function Fb(e) {
	return e.kind === 189;
}
function zb(e) {
	return e.kind === 190;
}
function M1(e) {
	return e.kind === 203;
}
function Vb(e) {
	return e.kind === 191;
}
function Wb(e) {
	return e.kind === 192;
}
function L1(e) {
	return e.kind === 193;
}
function J1(e) {
	return e.kind === 194;
}
function Gb(e) {
	return e.kind === 195;
}
function Yb(e) {
	return e.kind === 196;
}
function j1(e) {
	return e.kind === 197;
}
function Hb(e) {
	return e.kind === 198;
}
function R1(e) {
	return e.kind === 199;
}
function Xb(e) {
	return e.kind === 200;
}
function U1(e) {
	return e.kind === 201;
}
function $b(e) {
	return e.kind === 202;
}
function Qb(e) {
	return e.kind === 206;
}
function B1(e) {
	return e.kind === 209;
}
function q1(e) {
	return e.kind === 210;
}
function If(e) {
	return e.kind === 211;
}
function dr(e) {
	return e.kind === 212;
}
function Ha(e) {
	return e.kind === 213;
}
function Of(e) {
	return e.kind === 214;
}
function F1(e) {
	return e.kind === 216;
}
function Dl(e) {
	return e.kind === 218;
}
function Mf(e) {
	return e.kind === 219;
}
function Lf(e) {
	return e.kind === 220;
}
function Kb(e) {
	return e.kind === 223;
}
function z1(e) {
	return e.kind === 225;
}
function na(e) {
	return e.kind === 227;
}
function V1(e) {
	return e.kind === 231;
}
function xl(e) {
	return e.kind === 232;
}
function W1(e) {
	return e.kind === 233;
}
function G1(e) {
	return e.kind === 234;
}
function fl(e) {
	return e.kind === 236;
}
function Zb(e) {
	return e.kind === 237;
}
function e6(e) {
	return e.kind === 357;
}
function Xa(e) {
	return e.kind === 244;
}
function Pl(e) {
	return e.kind === 245;
}
function Y1(e) {
	return e.kind === 257;
}
function Jf(e) {
	return e.kind === 261;
}
function H1(e) {
	return e.kind === 262;
}
function jf(e) {
	return e.kind === 263;
}
function Ga(e) {
	return e.kind === 264;
}
function T_(e) {
	return e.kind === 265;
}
function Nl(e) {
	return e.kind === 266;
}
function X1(e) {
	return e.kind === 267;
}
function Ti(e) {
	return e.kind === 268;
}
function Rf(e) {
	return e.kind === 272;
}
function Uf(e) {
	return e.kind === 273;
}
function Bf(e) {
	return e.kind === 278;
}
function qf(e) {
	return e.kind === 279;
}
function $1(e) {
	return e.kind === 280;
}
function t6(e) {
	return e.kind === 354;
}
function Ff(e) {
	return e.kind === 284;
}
function Fp(e) {
	return e.kind === 287;
}
function n6(e) {
	return e.kind === 290;
}
function Q1(e) {
	return e.kind === 296;
}
function r6(e) {
	return e.kind === 298;
}
function K1(e) {
	return e.kind === 304;
}
function Z1(e) {
	return e.kind === 308;
}
function eh(e) {
	return e.kind === 310;
}
function th(e) {
	return e.kind === 315;
}
function nh(e) {
	return e.kind === 318;
}
function rh(e) {
	return e.kind === 321;
}
function i6(e) {
	return e.kind === 323;
}
function Il(e) {
	return e.kind === 324;
}
function a6(e) {
	return e.kind === 329;
}
function s6(e) {
	return e.kind === 334;
}
function _6(e) {
	return e.kind === 335;
}
function o6(e) {
	return e.kind === 336;
}
function c6(e) {
	return e.kind === 337;
}
function l6(e) {
	return e.kind === 338;
}
function u6(e) {
	return e.kind === 340;
}
function p6(e) {
	return e.kind === 332;
}
function zp(e) {
	return e.kind === 342;
}
function f6(e) {
	return e.kind === 343;
}
function zf(e) {
	return e.kind === 345;
}
function ih(e) {
	return e.kind === 346;
}
function d6(e) {
	return e.kind === 330;
}
function m6(e) {
	return e.kind === 351;
}
var ea = /* @__PURE__ */ new WeakMap();
function ah(e, t) {
	var a;
	let _ = e.kind;
	return ff(_) ? _ === 353 ? e._children : (a = ea.get(t)) == null ? void 0 : a.get(e) : vt;
}
function h6(e, t, a) {
	e.kind === 353 && q.fail("Should not need to re-set the children of a SyntaxList.");
	let _ = ea.get(t);
	return _ === void 0 && (_ = /* @__PURE__ */ new WeakMap(), ea.set(t, _)), _.set(e, a), a;
}
function Gd(e, t) {
	var a;
	e.kind === 353 && q.fail("Did not expect to unset the children of a SyntaxList."), (a = ea.get(t)) == null || a.delete(e);
}
function y6(e, t) {
	let a = ea.get(e);
	a !== void 0 && (ea.delete(e), ea.set(t, a));
}
function Yd(e) {
	return (za(e) & 32768) !== 0;
}
function g6(e) {
	return vi(e.expression) && e.expression.text === "use strict";
}
function b6(e) {
	for (let t of e) if (pl(t)) {
		if (g6(t)) return t;
	} else break;
}
function v6(e) {
	return Dl(e) && ia(e) && !!Ng(e);
}
function sh(e, t = 63) {
	switch (e.kind) {
		case 218: return t & -2147483648 && v6(e) ? !1 : (t & 1) !== 0;
		case 217:
		case 235: return (t & 2) !== 0;
		case 239: return (t & 34) !== 0;
		case 234: return (t & 16) !== 0;
		case 236: return (t & 4) !== 0;
		case 356: return (t & 8) !== 0;
	}
	return !1;
}
function Vf(e, t = 63) {
	for (; sh(e, t);) e = e.expression;
	return e;
}
function T6(e) {
	return setStartsOnNewLine(e, !0);
}
function i_(e) {
	if (Yg(e)) return e.name;
	if (Vg(e)) {
		switch (e.kind) {
			case 304: return i_(e.initializer);
			case 305: return e.name;
			case 306: return i_(e.expression);
		}
		return;
	}
	return vl(e, !0) ? i_(e.left) : V1(e) ? i_(e.expression) : e;
}
function x6(e) {
	switch (e.kind) {
		case 207:
		case 208:
		case 210: return e.elements;
		case 211: return e.properties;
	}
}
function Hd(e) {
	if (e) {
		let t = e;
		for (;;) {
			if (Ke(t) || !t.body) return Ke(t) ? t : t.name;
			t = t.body;
		}
	}
}
var Xd;
((e) => {
	function t(y, G, E, D, R, ue, be) {
		let he = G > 0 ? R[G - 1] : void 0;
		return q.assertEqual(E[G], t), R[G] = y.onEnter(D[G], he, be), E[G] = k(y, t), G;
	}
	e.enter = t;
	function a(y, G, E, D, R, ue, be) {
		q.assertEqual(E[G], a), q.assertIsDefined(y.onLeft), E[G] = k(y, a);
		let he = y.onLeft(D[G].left, R[G], D[G]);
		return he ? (W(G, D, he), c(G, E, D, R, he)) : G;
	}
	e.left = a;
	function _(y, G, E, D, R, ue, be) {
		return q.assertEqual(E[G], _), q.assertIsDefined(y.onOperator), E[G] = k(y, _), y.onOperator(D[G].operatorToken, R[G], D[G]), G;
	}
	e.operator = _;
	function f(y, G, E, D, R, ue, be) {
		q.assertEqual(E[G], f), q.assertIsDefined(y.onRight), E[G] = k(y, f);
		let he = y.onRight(D[G].right, R[G], D[G]);
		return he ? (W(G, D, he), c(G, E, D, R, he)) : G;
	}
	e.right = f;
	function h(y, G, E, D, R, ue, be) {
		q.assertEqual(E[G], h), E[G] = k(y, h);
		let he = y.onExit(D[G], R[G]);
		if (G > 0) {
			if (G--, y.foldState) {
				let de = E[G] === h ? "right" : "left";
				R[G] = y.foldState(R[G], he, de);
			}
		} else ue.value = he;
		return G;
	}
	e.exit = h;
	function T(y, G, E, D, R, ue, be) {
		return q.assertEqual(E[G], T), G;
	}
	e.done = T;
	function k(y, G) {
		switch (G) {
			case t: if (y.onLeft) return a;
			case a: if (y.onOperator) return _;
			case _: if (y.onRight) return f;
			case f: return h;
			case h: return T;
			case T: return T;
			default: q.fail("Invalid state");
		}
	}
	e.nextState = k;
	function c(y, G, E, D, R) {
		return y++, G[y] = t, E[y] = R, D[y] = void 0, y;
	}
	function W(y, G, E) {
		if (q.shouldAssert(2)) for (; y >= 0;) q.assert(G[y] !== E, "Circular traversal detected."), y--;
	}
})(Xd || (Xd = {}));
function $d(e, t) {
	return typeof e == "object" ? Vp(!1, e.prefix, e.node, e.suffix, t) : typeof e == "string" ? e.length > 0 && e.charCodeAt(0) === 35 ? e.slice(1) : e : "";
}
function S6(e, t) {
	return typeof e == "string" ? e : w6(e, q.checkDefined(t));
}
function w6(e, t) {
	return n1(e) ? t(e).slice(1) : Ua(e) ? t(e) : gi(e) ? e.escapedText.slice(1) : An(e);
}
function Vp(e, t, a, _, f) {
	return t = $d(t, f), _ = $d(_, f), a = S6(a, f), `${e ? "#" : ""}${t}${a}${_}`;
}
function _h(e) {
	if (e.transformFlags & 65536) return !0;
	if (e.transformFlags & 128) for (let t of x6(e)) {
		let a = i_(t);
		if (a && Gg(a) && (a.transformFlags & 65536 || a.transformFlags & 128 && _h(a))) return !0;
	}
	return !1;
}
function dn(e, t) {
	return t ? yi(e, t.pos, t.end) : e;
}
function Ol(e) {
	let t = e.kind;
	return t === 169 || t === 170 || t === 172 || t === 173 || t === 174 || t === 175 || t === 177 || t === 178 || t === 179 || t === 182 || t === 186 || t === 219 || t === 220 || t === 232 || t === 244 || t === 263 || t === 264 || t === 265 || t === 266 || t === 267 || t === 268 || t === 272 || t === 273 || t === 278 || t === 279;
}
function Wf(e) {
	let t = e.kind;
	return t === 170 || t === 173 || t === 175 || t === 178 || t === 179 || t === 232 || t === 264;
}
var Qd, Kd, Zd, em, tm;
wf(1, {
	createBaseSourceFileNode: (e) => new (tm || (tm = (Et.getSourceFileConstructor())))(e, -1, -1),
	createBaseIdentifierNode: (e) => new (Zd || (Zd = (Et.getIdentifierConstructor())))(e, -1, -1),
	createBasePrivateIdentifierNode: (e) => new (em || (em = (Et.getPrivateIdentifierConstructor())))(e, -1, -1),
	createBaseTokenNode: (e) => new (Kd || (Kd = (Et.getTokenConstructor())))(e, -1, -1),
	createBaseNode: (e) => new (Qd || (Qd = (Et.getNodeConstructor())))(e, -1, -1)
});
function S(e, t) {
	return t && e(t);
}
function ie(e, t, a) {
	if (a) {
		if (t) return t(a);
		for (let _ of a) {
			let f = e(_);
			if (f) return f;
		}
	}
}
function E6(e, t) {
	return e.charCodeAt(t + 1) === 42 && e.charCodeAt(t + 2) === 42 && e.charCodeAt(t + 3) !== 47;
}
function A6(e) {
	return jn(e.statements, C6) || D6(e);
}
function C6(e) {
	return Ol(e) && P6(e, 95) || Rf(e) && Ff(e.moduleReference) || Uf(e) || Bf(e) || qf(e) ? e : void 0;
}
function D6(e) {
	return e.flags & 8388608 ? oh(e) : void 0;
}
function oh(e) {
	return N6(e) ? e : Xt(e, oh);
}
function P6(e, t) {
	return Zt(e.modifiers, (a) => a.kind === t);
}
function N6(e) {
	return Zb(e) && e.keywordToken === 102 && e.name.escapedText === "meta";
}
var I6 = {
	167: function(t, a, _) {
		return S(a, t.left) || S(a, t.right);
	},
	169: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || S(a, t.constraint) || S(a, t.default) || S(a, t.expression);
	},
	305: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || S(a, t.questionToken) || S(a, t.exclamationToken) || S(a, t.equalsToken) || S(a, t.objectAssignmentInitializer);
	},
	306: function(t, a, _) {
		return S(a, t.expression);
	},
	170: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.dotDotDotToken) || S(a, t.name) || S(a, t.questionToken) || S(a, t.type) || S(a, t.initializer);
	},
	173: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || S(a, t.questionToken) || S(a, t.exclamationToken) || S(a, t.type) || S(a, t.initializer);
	},
	172: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || S(a, t.questionToken) || S(a, t.type) || S(a, t.initializer);
	},
	304: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || S(a, t.questionToken) || S(a, t.exclamationToken) || S(a, t.initializer);
	},
	261: function(t, a, _) {
		return S(a, t.name) || S(a, t.exclamationToken) || S(a, t.type) || S(a, t.initializer);
	},
	209: function(t, a, _) {
		return S(a, t.dotDotDotToken) || S(a, t.propertyName) || S(a, t.name) || S(a, t.initializer);
	},
	182: function(t, a, _) {
		return ie(a, _, t.modifiers) || ie(a, _, t.typeParameters) || ie(a, _, t.parameters) || S(a, t.type);
	},
	186: function(t, a, _) {
		return ie(a, _, t.modifiers) || ie(a, _, t.typeParameters) || ie(a, _, t.parameters) || S(a, t.type);
	},
	185: function(t, a, _) {
		return ie(a, _, t.modifiers) || ie(a, _, t.typeParameters) || ie(a, _, t.parameters) || S(a, t.type);
	},
	180: nm,
	181: nm,
	175: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.asteriskToken) || S(a, t.name) || S(a, t.questionToken) || S(a, t.exclamationToken) || ie(a, _, t.typeParameters) || ie(a, _, t.parameters) || S(a, t.type) || S(a, t.body);
	},
	174: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || S(a, t.questionToken) || ie(a, _, t.typeParameters) || ie(a, _, t.parameters) || S(a, t.type);
	},
	177: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || ie(a, _, t.typeParameters) || ie(a, _, t.parameters) || S(a, t.type) || S(a, t.body);
	},
	178: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || ie(a, _, t.typeParameters) || ie(a, _, t.parameters) || S(a, t.type) || S(a, t.body);
	},
	179: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || ie(a, _, t.typeParameters) || ie(a, _, t.parameters) || S(a, t.type) || S(a, t.body);
	},
	263: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.asteriskToken) || S(a, t.name) || ie(a, _, t.typeParameters) || ie(a, _, t.parameters) || S(a, t.type) || S(a, t.body);
	},
	219: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.asteriskToken) || S(a, t.name) || ie(a, _, t.typeParameters) || ie(a, _, t.parameters) || S(a, t.type) || S(a, t.body);
	},
	220: function(t, a, _) {
		return ie(a, _, t.modifiers) || ie(a, _, t.typeParameters) || ie(a, _, t.parameters) || S(a, t.type) || S(a, t.equalsGreaterThanToken) || S(a, t.body);
	},
	176: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.body);
	},
	184: function(t, a, _) {
		return S(a, t.typeName) || ie(a, _, t.typeArguments);
	},
	183: function(t, a, _) {
		return S(a, t.assertsModifier) || S(a, t.parameterName) || S(a, t.type);
	},
	187: function(t, a, _) {
		return S(a, t.exprName) || ie(a, _, t.typeArguments);
	},
	188: function(t, a, _) {
		return ie(a, _, t.members);
	},
	189: function(t, a, _) {
		return S(a, t.elementType);
	},
	190: function(t, a, _) {
		return ie(a, _, t.elements);
	},
	193: rm,
	194: rm,
	195: function(t, a, _) {
		return S(a, t.checkType) || S(a, t.extendsType) || S(a, t.trueType) || S(a, t.falseType);
	},
	196: function(t, a, _) {
		return S(a, t.typeParameter);
	},
	206: function(t, a, _) {
		return S(a, t.argument) || S(a, t.attributes) || S(a, t.qualifier) || ie(a, _, t.typeArguments);
	},
	303: function(t, a, _) {
		return S(a, t.assertClause);
	},
	197: im,
	199: im,
	200: function(t, a, _) {
		return S(a, t.objectType) || S(a, t.indexType);
	},
	201: function(t, a, _) {
		return S(a, t.readonlyToken) || S(a, t.typeParameter) || S(a, t.nameType) || S(a, t.questionToken) || S(a, t.type) || ie(a, _, t.members);
	},
	202: function(t, a, _) {
		return S(a, t.literal);
	},
	203: function(t, a, _) {
		return S(a, t.dotDotDotToken) || S(a, t.name) || S(a, t.questionToken) || S(a, t.type);
	},
	207: am,
	208: am,
	210: function(t, a, _) {
		return ie(a, _, t.elements);
	},
	211: function(t, a, _) {
		return ie(a, _, t.properties);
	},
	212: function(t, a, _) {
		return S(a, t.expression) || S(a, t.questionDotToken) || S(a, t.name);
	},
	213: function(t, a, _) {
		return S(a, t.expression) || S(a, t.questionDotToken) || S(a, t.argumentExpression);
	},
	214: sm,
	215: sm,
	216: function(t, a, _) {
		return S(a, t.tag) || S(a, t.questionDotToken) || ie(a, _, t.typeArguments) || S(a, t.template);
	},
	217: function(t, a, _) {
		return S(a, t.type) || S(a, t.expression);
	},
	218: function(t, a, _) {
		return S(a, t.expression);
	},
	221: function(t, a, _) {
		return S(a, t.expression);
	},
	222: function(t, a, _) {
		return S(a, t.expression);
	},
	223: function(t, a, _) {
		return S(a, t.expression);
	},
	225: function(t, a, _) {
		return S(a, t.operand);
	},
	230: function(t, a, _) {
		return S(a, t.asteriskToken) || S(a, t.expression);
	},
	224: function(t, a, _) {
		return S(a, t.expression);
	},
	226: function(t, a, _) {
		return S(a, t.operand);
	},
	227: function(t, a, _) {
		return S(a, t.left) || S(a, t.operatorToken) || S(a, t.right);
	},
	235: function(t, a, _) {
		return S(a, t.expression) || S(a, t.type);
	},
	236: function(t, a, _) {
		return S(a, t.expression);
	},
	239: function(t, a, _) {
		return S(a, t.expression) || S(a, t.type);
	},
	237: function(t, a, _) {
		return S(a, t.name);
	},
	228: function(t, a, _) {
		return S(a, t.condition) || S(a, t.questionToken) || S(a, t.whenTrue) || S(a, t.colonToken) || S(a, t.whenFalse);
	},
	231: function(t, a, _) {
		return S(a, t.expression);
	},
	242: _m,
	269: _m,
	308: function(t, a, _) {
		return ie(a, _, t.statements) || S(a, t.endOfFileToken);
	},
	244: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.declarationList);
	},
	262: function(t, a, _) {
		return ie(a, _, t.declarations);
	},
	245: function(t, a, _) {
		return S(a, t.expression);
	},
	246: function(t, a, _) {
		return S(a, t.expression) || S(a, t.thenStatement) || S(a, t.elseStatement);
	},
	247: function(t, a, _) {
		return S(a, t.statement) || S(a, t.expression);
	},
	248: function(t, a, _) {
		return S(a, t.expression) || S(a, t.statement);
	},
	249: function(t, a, _) {
		return S(a, t.initializer) || S(a, t.condition) || S(a, t.incrementor) || S(a, t.statement);
	},
	250: function(t, a, _) {
		return S(a, t.initializer) || S(a, t.expression) || S(a, t.statement);
	},
	251: function(t, a, _) {
		return S(a, t.awaitModifier) || S(a, t.initializer) || S(a, t.expression) || S(a, t.statement);
	},
	252: om,
	253: om,
	254: function(t, a, _) {
		return S(a, t.expression);
	},
	255: function(t, a, _) {
		return S(a, t.expression) || S(a, t.statement);
	},
	256: function(t, a, _) {
		return S(a, t.expression) || S(a, t.caseBlock);
	},
	270: function(t, a, _) {
		return ie(a, _, t.clauses);
	},
	297: function(t, a, _) {
		return S(a, t.expression) || ie(a, _, t.statements);
	},
	298: function(t, a, _) {
		return ie(a, _, t.statements);
	},
	257: function(t, a, _) {
		return S(a, t.label) || S(a, t.statement);
	},
	258: function(t, a, _) {
		return S(a, t.expression);
	},
	259: function(t, a, _) {
		return S(a, t.tryBlock) || S(a, t.catchClause) || S(a, t.finallyBlock);
	},
	300: function(t, a, _) {
		return S(a, t.variableDeclaration) || S(a, t.block);
	},
	171: function(t, a, _) {
		return S(a, t.expression);
	},
	264: cm,
	232: cm,
	265: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || ie(a, _, t.typeParameters) || ie(a, _, t.heritageClauses) || ie(a, _, t.members);
	},
	266: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || ie(a, _, t.typeParameters) || S(a, t.type);
	},
	267: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || ie(a, _, t.members);
	},
	307: function(t, a, _) {
		return S(a, t.name) || S(a, t.initializer);
	},
	268: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || S(a, t.body);
	},
	272: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name) || S(a, t.moduleReference);
	},
	273: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.importClause) || S(a, t.moduleSpecifier) || S(a, t.attributes);
	},
	274: function(t, a, _) {
		return S(a, t.name) || S(a, t.namedBindings);
	},
	301: function(t, a, _) {
		return ie(a, _, t.elements);
	},
	302: function(t, a, _) {
		return S(a, t.name) || S(a, t.value);
	},
	271: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.name);
	},
	275: function(t, a, _) {
		return S(a, t.name);
	},
	281: function(t, a, _) {
		return S(a, t.name);
	},
	276: lm,
	280: lm,
	279: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.exportClause) || S(a, t.moduleSpecifier) || S(a, t.attributes);
	},
	277: um,
	282: um,
	278: function(t, a, _) {
		return ie(a, _, t.modifiers) || S(a, t.expression);
	},
	229: function(t, a, _) {
		return S(a, t.head) || ie(a, _, t.templateSpans);
	},
	240: function(t, a, _) {
		return S(a, t.expression) || S(a, t.literal);
	},
	204: function(t, a, _) {
		return S(a, t.head) || ie(a, _, t.templateSpans);
	},
	205: function(t, a, _) {
		return S(a, t.type) || S(a, t.literal);
	},
	168: function(t, a, _) {
		return S(a, t.expression);
	},
	299: function(t, a, _) {
		return ie(a, _, t.types);
	},
	234: function(t, a, _) {
		return S(a, t.expression) || ie(a, _, t.typeArguments);
	},
	284: function(t, a, _) {
		return S(a, t.expression);
	},
	283: function(t, a, _) {
		return ie(a, _, t.modifiers);
	},
	357: function(t, a, _) {
		return ie(a, _, t.elements);
	},
	285: function(t, a, _) {
		return S(a, t.openingElement) || ie(a, _, t.children) || S(a, t.closingElement);
	},
	289: function(t, a, _) {
		return S(a, t.openingFragment) || ie(a, _, t.children) || S(a, t.closingFragment);
	},
	286: pm,
	287: pm,
	293: function(t, a, _) {
		return ie(a, _, t.properties);
	},
	292: function(t, a, _) {
		return S(a, t.name) || S(a, t.initializer);
	},
	294: function(t, a, _) {
		return S(a, t.expression);
	},
	295: function(t, a, _) {
		return S(a, t.dotDotDotToken) || S(a, t.expression);
	},
	288: function(t, a, _) {
		return S(a, t.tagName);
	},
	296: function(t, a, _) {
		return S(a, t.namespace) || S(a, t.name);
	},
	191: Hi,
	192: Hi,
	310: Hi,
	316: Hi,
	315: Hi,
	317: Hi,
	319: Hi,
	318: function(t, a, _) {
		return ie(a, _, t.parameters) || S(a, t.type);
	},
	321: function(t, a, _) {
		return (typeof t.comment == "string" ? void 0 : ie(a, _, t.comment)) || ie(a, _, t.tags);
	},
	348: function(t, a, _) {
		return S(a, t.tagName) || S(a, t.name) || (typeof t.comment == "string" ? void 0 : ie(a, _, t.comment));
	},
	311: function(t, a, _) {
		return S(a, t.name);
	},
	312: function(t, a, _) {
		return S(a, t.left) || S(a, t.right);
	},
	342: fm,
	349: fm,
	331: function(t, a, _) {
		return S(a, t.tagName) || (typeof t.comment == "string" ? void 0 : ie(a, _, t.comment));
	},
	330: function(t, a, _) {
		return S(a, t.tagName) || S(a, t.class) || (typeof t.comment == "string" ? void 0 : ie(a, _, t.comment));
	},
	329: function(t, a, _) {
		return S(a, t.tagName) || S(a, t.class) || (typeof t.comment == "string" ? void 0 : ie(a, _, t.comment));
	},
	346: function(t, a, _) {
		return S(a, t.tagName) || S(a, t.constraint) || ie(a, _, t.typeParameters) || (typeof t.comment == "string" ? void 0 : ie(a, _, t.comment));
	},
	347: function(t, a, _) {
		return S(a, t.tagName) || (t.typeExpression && t.typeExpression.kind === 310 ? S(a, t.typeExpression) || S(a, t.fullName) || (typeof t.comment == "string" ? void 0 : ie(a, _, t.comment)) : S(a, t.fullName) || S(a, t.typeExpression) || (typeof t.comment == "string" ? void 0 : ie(a, _, t.comment)));
	},
	339: function(t, a, _) {
		return S(a, t.tagName) || S(a, t.fullName) || S(a, t.typeExpression) || (typeof t.comment == "string" ? void 0 : ie(a, _, t.comment));
	},
	343: Xi,
	345: Xi,
	344: Xi,
	341: Xi,
	351: Xi,
	350: Xi,
	340: Xi,
	324: function(t, a, _) {
		return jn(t.typeParameters, a) || jn(t.parameters, a) || S(a, t.type);
	},
	325: Cp,
	326: Cp,
	327: Cp,
	323: function(t, a, _) {
		return jn(t.jsDocPropertyTags, a);
	},
	328: ui,
	333: ui,
	334: ui,
	335: ui,
	336: ui,
	337: ui,
	332: ui,
	338: ui,
	352: O6,
	356: M6
};
function nm(e, t, a) {
	return ie(t, a, e.typeParameters) || ie(t, a, e.parameters) || S(t, e.type);
}
function rm(e, t, a) {
	return ie(t, a, e.types);
}
function im(e, t, a) {
	return S(t, e.type);
}
function am(e, t, a) {
	return ie(t, a, e.elements);
}
function sm(e, t, a) {
	return S(t, e.expression) || S(t, e.questionDotToken) || ie(t, a, e.typeArguments) || ie(t, a, e.arguments);
}
function _m(e, t, a) {
	return ie(t, a, e.statements);
}
function om(e, t, a) {
	return S(t, e.label);
}
function cm(e, t, a) {
	return ie(t, a, e.modifiers) || S(t, e.name) || ie(t, a, e.typeParameters) || ie(t, a, e.heritageClauses) || ie(t, a, e.members);
}
function lm(e, t, a) {
	return ie(t, a, e.elements);
}
function um(e, t, a) {
	return S(t, e.propertyName) || S(t, e.name);
}
function pm(e, t, a) {
	return S(t, e.tagName) || ie(t, a, e.typeArguments) || S(t, e.attributes);
}
function Hi(e, t, a) {
	return S(t, e.type);
}
function fm(e, t, a) {
	return S(t, e.tagName) || (e.isNameFirst ? S(t, e.name) || S(t, e.typeExpression) : S(t, e.typeExpression) || S(t, e.name)) || (typeof e.comment == "string" ? void 0 : ie(t, a, e.comment));
}
function Xi(e, t, a) {
	return S(t, e.tagName) || S(t, e.typeExpression) || (typeof e.comment == "string" ? void 0 : ie(t, a, e.comment));
}
function Cp(e, t, a) {
	return S(t, e.name);
}
function ui(e, t, a) {
	return S(t, e.tagName) || (typeof e.comment == "string" ? void 0 : ie(t, a, e.comment));
}
function O6(e, t, a) {
	return S(t, e.tagName) || S(t, e.importClause) || S(t, e.moduleSpecifier) || S(t, e.attributes) || (typeof e.comment == "string" ? void 0 : ie(t, a, e.comment));
}
function M6(e, t, a) {
	return S(t, e.expression);
}
function Xt(e, t, a) {
	if (e === void 0 || e.kind <= 166) return;
	let _ = I6[e.kind];
	return _ === void 0 ? void 0 : _(e, t, a);
}
function dm(e, t, a) {
	let _ = mm(e), f = [];
	for (; f.length < _.length;) f.push(e);
	for (; _.length !== 0;) {
		let h = _.pop(), T = f.pop();
		if ($r(h)) {
			if (a) {
				let k = a(h, T);
				if (k) {
					if (k === "skip") continue;
					return k;
				}
			}
			for (let k = h.length - 1; k >= 0; --k) _.push(h[k]), f.push(T);
		} else {
			let k = t(h, T);
			if (k) {
				if (k === "skip") continue;
				return k;
			}
			if (h.kind >= 167) for (let c of mm(h)) _.push(c), f.push(h);
		}
	}
}
function mm(e) {
	let t = [];
	return Xt(e, a, a), t;
	function a(_) {
		t.unshift(_);
	}
}
function ch(e) {
	e.externalModuleIndicator = A6(e);
}
function lh(e, t, a, _ = !1, f) {
	var h, T;
	(h = ll) == null || h.push(ll.Phase.Parse, "createSourceFile", { path: e }, !0), bd("beforeParse");
	let k, { languageVersion: c, setExternalModuleIndicator: W, impliedNodeFormat: y, jsDocParsingMode: G } = typeof a == "object" ? a : { languageVersion: a };
	if (c === 100) k = ta.parseSourceFile(e, t, c, void 0, _, 6, Va, G);
	else {
		let E = y === void 0 ? W : (D) => (D.impliedNodeFormat = y, (W || ch)(D));
		k = ta.parseSourceFile(e, t, c, void 0, _, f, E, G);
	}
	return bd("afterParse"), Oy("Parse", "beforeParse", "afterParse"), (T = ll) == null || T.pop(), k;
}
function uh(e) {
	return e.externalModuleIndicator !== void 0;
}
function L6(e, t, a, _ = !1) {
	let f = Sl.updateSourceFile(e, t, a, _);
	return f.flags |= e.flags & 12582912, f;
}
var ta;
((e) => {
	var t = sf(99, !0), a = 40960, _, f, h, T, k;
	function c(o) {
		return ar++, o;
	}
	var y = wf(11, {
		createBaseSourceFileNode: (o) => c(new k(o, 0, 0)),
		createBaseIdentifierNode: (o) => c(new h(o, 0, 0)),
		createBasePrivateIdentifierNode: (o) => c(new T(o, 0, 0)),
		createBaseTokenNode: (o) => c(new f(o, 0, 0)),
		createBaseNode: (o) => c(new _(o, 0, 0))
	}), { createNodeArray: G, createNumericLiteral: E, createStringLiteral: D, createLiteralLikeNode: R, createIdentifier: ue, createPrivateIdentifier: be, createToken: he, createArrayLiteralExpression: de, createObjectLiteralExpression: O, createPropertyAccessExpression: ae, createPropertyAccessChain: Oe, createElementAccessExpression: V, createElementAccessChain: oe, createCallExpression: Y, createCallChain: ft, createNewExpression: nr, createParenthesizedExpression: mn, createBlock: rr, createVariableStatement: hn, createExpressionStatement: Dn, createIfStatement: We, createWhileStatement: ir, createForStatement: Ir, createForOfStatement: Ot, createVariableDeclaration: Bn, createVariableDeclarationList: Pn } = y, Mt, ht, $e, qn, $t, ot, at, Bt, Lt, ct, ar, dt, yn, yt, _n, tt, qt = !0, tn = !1;
	function sr(o, p, m, g, b = !1, N, Q, _e = 0) {
		var ee;
		if (N = mb(o, N), N === 6) {
			let ce = hr(o, p, m, g, b);
			return convertToJson(ce, (ee = ce.statements[0]) == null ? void 0 : ee.expression, ce.parseDiagnostics, !1, void 0), ce.referencedFiles = vt, ce.typeReferenceDirectives = vt, ce.libReferenceDirectives = vt, ce.amdDependencies = vt, ce.hasNoDefaultLib = !1, ce.pragmas = ay, ce;
		}
		Fn(o, p, m, g, N, _e);
		let te = Or(m, b, N, Q || ch, _e);
		return zn(), te;
	}
	e.parseSourceFile = sr;
	function mr(o, p) {
		Fn("", o, p, void 0, 1, 0), B();
		let m = Ur(!0), g = u() === 1 && !at.length;
		return zn(), g ? m : void 0;
	}
	e.parseIsolatedEntityName = mr;
	function hr(o, p, m = 2, g, b = !1) {
		Fn(o, p, m, g, 6, 0), ht = tt, B();
		let N = M(), Q, _e;
		if (u() === 1) Q = At([], N, N), _e = Wt();
		else {
			let ce;
			for (; u() !== 1;) {
				let De;
				switch (u()) {
					case 23:
						De = _c();
						break;
					case 112:
					case 97:
					case 106:
						De = Wt();
						break;
					case 41:
						H(() => B() === 9 && B() !== 59) ? De = Wo() : De = Is();
						break;
					case 9:
					case 11: if (H(() => B() !== 59)) {
						De = Hn();
						break;
					}
					default:
						De = Is();
						break;
				}
				ce && $r(ce) ? ce.push(De) : ce ? ce = [ce, De] : (ce = De, u() !== 1 && Ee(A.Unexpected_token));
			}
			let Je = Dn($r(ce) ? P(de(ce), N) : q.checkDefined(ce));
			P(Je, N), Q = At([Je], N), _e = Yn(1, A.Unexpected_token);
		}
		let ee = se(o, 2, 6, !1, Q, _e, ht, Va);
		b && L(ee), ee.nodeCount = ar, ee.identifierCount = yn, ee.identifiers = dt, ee.parseDiagnostics = Yi(at, ee), Bt && (ee.jsDocDiagnostics = Yi(Bt, ee));
		let te = ee;
		return zn(), te;
	}
	e.parseJsonText = hr;
	function Fn(o, p, m, g, b, N) {
		switch (_ = Et.getNodeConstructor(), f = Et.getTokenConstructor(), h = Et.getIdentifierConstructor(), T = Et.getPrivateIdentifierConstructor(), k = Et.getSourceFileConstructor(), Mt = zy(o), $e = p, qn = m, Lt = g, $t = b, ot = Ud(b), at = [], yt = 0, dt = /* @__PURE__ */ new Map(), yn = 0, ar = 0, ht = 0, qt = !0, $t) {
			case 1:
			case 2:
				tt = 524288;
				break;
			case 6:
				tt = 134742016;
				break;
			default:
				tt = 0;
				break;
		}
		tn = !1, t.setText($e), t.setOnError(Zr), t.setScriptTarget(qn), t.setLanguageVariant(ot), t.setScriptKind($t), t.setJSDocParsingMode(N);
	}
	function zn() {
		t.clearCommentDirectives(), t.setText(""), t.setOnError(void 0), t.setScriptKind(0), t.setJSDocParsingMode(0), $e = void 0, qn = void 0, Lt = void 0, $t = void 0, ot = void 0, ht = 0, at = void 0, Bt = void 0, yt = 0, dt = void 0, _n = void 0, qt = !0;
	}
	function Or(o, p, m, g, b) {
		let N = R6(Mt);
		N && (tt |= 33554432), ht = tt, B();
		let Q = bn(0, Yt);
		q.assert(u() === 1);
		let _e = Ue(), ee = Ce(Wt(), _e), te = se(Mt, o, m, N, Q, ee, ht, g);
		return q6(te, $e), F6(te, ce), te.commentDirectives = t.getCommentDirectives(), te.nodeCount = ar, te.identifierCount = yn, te.identifiers = dt, te.parseDiagnostics = Yi(at, te), te.jsDocParsingMode = b, Bt && (te.jsDocDiagnostics = Yi(Bt, te)), p && L(te), te;
		function ce(je, Je, De) {
			at.push(Oa(Mt, $e, je, Je, De));
		}
	}
	let Vn = !1;
	function Ce(o, p) {
		if (!p) return o;
		q.assert(!o.jsDoc);
		let m = cy(u2(o, $e), (g) => el.parseJSDocComment(o, g.pos, g.end - g.pos));
		return m.length && (o.jsDoc = m), Vn && (Vn = !1, o.flags |= 536870912), o;
	}
	function yr(o) {
		let p = Lt, m = Sl.createSyntaxCursor(o);
		Lt = { currentNode: ce };
		let g = [], b = at;
		at = [];
		let N = 0, Q = ee(o.statements, 0);
		for (; Q !== -1;) {
			let je = o.statements[N], Je = o.statements[Q];
			En(g, o.statements, N, Q), N = te(o.statements, Q);
			let De = gp(b, (Nt) => Nt.start >= je.pos), Ht = De >= 0 ? gp(b, (Nt) => Nt.start >= Je.pos, De) : -1;
			De >= 0 && En(at, b, De, Ht >= 0 ? Ht : void 0), cn(() => {
				let Nt = tt;
				for (tt |= 65536, t.resetTokenState(Je.pos), B(); u() !== 1;) {
					let ur = t.getTokenFullStart(), pr = ns(0, Yt);
					if (g.push(pr), ur === t.getTokenFullStart() && B(), N >= 0) {
						let Mn = o.statements[N];
						if (pr.end === Mn.pos) break;
						pr.end > Mn.pos && (N = te(o.statements, N + 1));
					}
				}
				tt = Nt;
			}, 2), Q = N >= 0 ? ee(o.statements, N) : -1;
		}
		if (N >= 0) {
			let je = o.statements[N];
			En(g, o.statements, N);
			let Je = gp(b, (De) => De.start >= je.pos);
			Je >= 0 && En(at, b, Je);
		}
		return Lt = p, y.updateSourceFile(o, dn(G(g), o.statements));
		function _e(je) {
			return !(je.flags & 65536) && !!(je.transformFlags & 67108864);
		}
		function ee(je, Je) {
			for (let De = Je; De < je.length; De++) if (_e(je[De])) return De;
			return -1;
		}
		function te(je, Je) {
			for (let De = Je; De < je.length; De++) if (!_e(je[De])) return De;
			return -1;
		}
		function ce(je) {
			let Je = m.currentNode(je);
			return qt && Je && _e(Je) && Wp(Je), Je;
		}
	}
	function L(o) {
		Sb(o, !0);
	}
	e.fixupParentReferences = L;
	function se(o, p, m, g, b, N, Q, _e) {
		let ee = y.createSourceFile(b, N, Q);
		if (qd(ee, 0, $e.length), te(ee), !g && uh(ee) && ee.transformFlags & 67108864) {
			let ce = ee;
			ee = yr(ee), ce !== ee && te(ee);
		}
		return ee;
		function te(ce) {
			ce.text = $e, ce.bindDiagnostics = [], ce.bindSuggestionDiagnostics = void 0, ce.languageVersion = p, ce.fileName = o, ce.languageVariant = Ud(m), ce.isDeclarationFile = g, ce.scriptKind = m, _e(ce), ce.setExternalModuleIndicator = _e;
		}
	}
	function fe(o, p) {
		o ? tt |= p : tt &= ~p;
	}
	function Te(o) {
		fe(o, 8192);
	}
	function He(o) {
		fe(o, 16384);
	}
	function Qe(o) {
		fe(o, 32768);
	}
	function st(o) {
		fe(o, 65536);
	}
	function Ct(o, p) {
		let m = o & tt;
		if (m) {
			fe(!1, m);
			let g = p();
			return fe(!0, m), g;
		}
		return p();
	}
	function Tt(o, p) {
		let m = o & ~tt;
		if (m) {
			fe(!0, m);
			let g = p();
			return fe(!1, m), g;
		}
		return p();
	}
	function lt(o) {
		return Ct(8192, o);
	}
	function Mr(o) {
		return Tt(8192, o);
	}
	function gr(o) {
		return Ct(131072, o);
	}
	function Nn(o) {
		return Tt(131072, o);
	}
	function Wn(o) {
		return Tt(16384, o);
	}
	function wi(o) {
		return Tt(32768, o);
	}
	function U(o) {
		return Tt(65536, o);
	}
	function K(o) {
		return Ct(65536, o);
	}
	function Z(o) {
		return Tt(81920, o);
	}
	function xe(o) {
		return Ct(81920, o);
	}
	function Se(o) {
		return (tt & o) !== 0;
	}
	function we() {
		return Se(16384);
	}
	function me() {
		return Se(8192);
	}
	function Ve() {
		return Se(131072);
	}
	function Ze() {
		return Se(32768);
	}
	function Ye() {
		return Se(65536);
	}
	function Ee(o, ...p) {
		return rt(t.getTokenStart(), t.getTokenEnd(), o, ...p);
	}
	function gn(o, p, m, ...g) {
		let b = Ba(at), N;
		return (!b || o !== b.start) && (N = Oa(Mt, $e, o, p, m, ...g), at.push(N)), tn = !0, N;
	}
	function rt(o, p, m, ...g) {
		return gn(o, p - o, m, ...g);
	}
	function on(o, p, ...m) {
		rt(o.pos, o.end, p, ...m);
	}
	function Zr(o, p, m) {
		gn(t.getTokenEnd(), p, o, m);
	}
	function M() {
		return t.getTokenFullStart();
	}
	function Ue() {
		return t.hasPrecedingJSDocComment();
	}
	function u() {
		return ct;
	}
	function Ie() {
		return ct = t.scan();
	}
	function Me(o) {
		return B(), o();
	}
	function B() {
		return di(ct) && (t.hasUnicodeEscape() || t.hasExtendedUnicodeEscape()) && rt(t.getTokenStart(), t.getTokenEnd(), A.Keywords_cannot_contain_escape_characters), Ie();
	}
	function Be() {
		return ct = t.scanJsDocToken();
	}
	function nn(o) {
		return ct = t.scanJSDocCommentTextToken(o);
	}
	function ze() {
		return ct = t.reScanGreaterToken();
	}
	function Xe() {
		return ct = t.reScanSlashToken();
	}
	function Dt(o) {
		return ct = t.reScanTemplateToken(o);
	}
	function wt() {
		return ct = t.reScanLessThanToken();
	}
	function Pt() {
		return ct = t.reScanHashToken();
	}
	function Ft() {
		return ct = t.scanJsxIdentifier();
	}
	function Gn() {
		return ct = t.scanJsxToken();
	}
	function ki() {
		return ct = t.scanJsxAttributeValue();
	}
	function cn(o, p) {
		let m = ct, g = at.length, b = tn, N = tt, Q = p !== 0 ? t.lookAhead(o) : t.tryScan(o);
		return q.assert(N === tt), (!Q || p !== 0) && (ct = m, p !== 2 && (at.length = g), tn = b), Q;
	}
	function H(o) {
		return cn(o, 1);
	}
	function le(o) {
		return cn(o, 0);
	}
	function qe() {
		return u() === 80 ? !0 : u() > 118;
	}
	function ve() {
		return u() === 80 ? !0 : u() === 127 && we() || u() === 135 && Ye() ? !1 : u() > 118;
	}
	function J(o, p, m = !0) {
		return u() === o ? (m && B(), !0) : (p ? Ee(p) : Ee(A._0_expected, nt(o)), !1);
	}
	let mt = Object.keys(tf).filter((o) => o.length > 2);
	function xt(o) {
		if (F1(o)) {
			rt(Cr($e, o.template.pos), o.template.end, A.Module_declaration_names_may_only_use_or_quoted_strings);
			return;
		}
		let p = Ke(o) ? An(o) : void 0;
		if (!p || !cg(p, qn)) {
			Ee(A._0_expected, nt(27));
			return;
		}
		let m = Cr($e, o.pos);
		switch (p) {
			case "const":
			case "let":
			case "var":
				rt(m, o.end, A.Variable_declaration_not_allowed_at_this_location);
				return;
			case "declare": return;
			case "interface":
				Jt(A.Interface_name_cannot_be_0, A.Interface_must_be_given_a_name, 19);
				return;
			case "is":
				rt(m, t.getTokenStart(), A.A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods);
				return;
			case "module":
			case "namespace":
				Jt(A.Namespace_name_cannot_be_0, A.Namespace_must_be_given_a_name, 19);
				return;
			case "type":
				Jt(A.Type_alias_name_cannot_be_0, A.Type_alias_must_be_given_a_name, 64);
				return;
		}
		let g = t_(p, mt, bt) ?? ln(p);
		if (g) {
			rt(m, o.end, A.Unknown_keyword_or_identifier_Did_you_mean_0, g);
			return;
		}
		u() !== 0 && rt(m, o.end, A.Unexpected_keyword_or_identifier);
	}
	function Jt(o, p, m) {
		u() === m ? Ee(p) : Ee(o, t.getTokenValue());
	}
	function ln(o) {
		for (let p of mt) if (o.length > p.length + 2 && ml(o, p)) return `${p} ${o.slice(p.length)}`;
	}
	function ql(o, p, m) {
		if (u() === 60 && !t.hasPrecedingLineBreak()) {
			Ee(A.Decorators_must_precede_the_name_and_all_keywords_of_property_declarations);
			return;
		}
		if (u() === 21) {
			Ee(A.Cannot_start_a_function_call_in_a_type_annotation), B();
			return;
		}
		if (p && !_r()) {
			m ? Ee(A._0_expected, nt(27)) : Ee(A.Expected_for_property_initializer);
			return;
		}
		if (!oa()) {
			if (m) {
				Ee(A._0_expected, nt(27));
				return;
			}
			xt(o);
		}
	}
	function C_(o) {
		return u() === o ? (Be(), !0) : (q.assert(xp(o)), Ee(A._0_expected, nt(o)), !1);
	}
	function Lr(o, p, m, g) {
		if (u() === p) {
			B();
			return;
		}
		let b = Ee(A._0_expected, nt(p));
		m && b && sl(b, Oa(Mt, $e, g, 1, A.The_parser_expected_to_find_a_1_to_match_the_0_token_here, nt(o), nt(p)));
	}
	function Le(o) {
		return u() === o ? (B(), !0) : !1;
	}
	function pt(o) {
		if (u() === o) return Wt();
	}
	function Fl(o) {
		if (u() === o) return Vl();
	}
	function Yn(o, p, m) {
		return pt(o) || Gt(o, !1, p || A._0_expected, m || nt(o));
	}
	function zl(o) {
		return Fl(o) || (q.assert(xp(o)), Gt(o, !1, A._0_expected, nt(o)));
	}
	function Wt() {
		let o = M(), p = u();
		return B(), P(he(p), o);
	}
	function Vl() {
		let o = M(), p = u();
		return Be(), P(he(p), o);
	}
	function _r() {
		return u() === 27 ? !0 : u() === 20 || u() === 1 || t.hasPrecedingLineBreak();
	}
	function oa() {
		return _r() ? (u() === 27 && B(), !0) : !1;
	}
	function Qt() {
		return oa() || J(27);
	}
	function At(o, p, m, g) {
		let b = G(o, g);
		return yi(b, p, m ?? t.getTokenFullStart()), b;
	}
	function P(o, p, m) {
		return yi(o, p, m ?? t.getTokenFullStart()), tt && (o.flags |= tt), tn && (tn = !1, o.flags |= 262144), o;
	}
	function Gt(o, p, m, ...g) {
		p ? gn(t.getTokenFullStart(), 0, m, ...g) : m && Ee(m, ...g);
		let b = M();
		return P(o === 80 ? ue("", void 0) : Pd(o) ? y.createTemplateLiteralLikeNode(o, "", "", void 0) : o === 9 ? E("", void 0) : o === 11 ? D("", void 0) : o === 283 ? y.createMissingDeclaration() : he(o), b);
	}
	function Jr(o) {
		let p = dt.get(o);
		return p === void 0 && dt.set(o, p = o), p;
	}
	function or(o, p, m) {
		if (o) {
			yn++;
			let _e = t.hasPrecedingJSDocLeadingAsterisks() ? t.getTokenStart() : M(), ee = u(), te = Jr(t.getTokenValue()), ce = t.hasExtendedUnicodeEscape();
			return Ie(), P(ue(te, ee, ce), _e);
		}
		if (u() === 81) return Ee(m || A.Private_identifiers_are_not_allowed_outside_class_bodies), or(!0);
		if (u() === 0 && t.tryScan(() => t.reScanInvalidIdentifier() === 80)) return or(!0);
		yn++;
		let g = u() === 1, b = t.isReservedWord(), N = t.getTokenText(), Q = b ? A.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here : A.Identifier_expected;
		return Gt(80, g, p || Q, N);
	}
	function Ka(o) {
		return or(qe(), void 0, o);
	}
	function gt(o, p) {
		return or(ve(), o, p);
	}
	function jt(o) {
		return or(St(u()), o);
	}
	function ei() {
		return (t.hasUnicodeEscape() || t.hasExtendedUnicodeEscape()) && Ee(A.Unicode_escape_sequence_cannot_appear_here), or(St(u()));
	}
	function br() {
		return St(u()) || u() === 11 || u() === 9 || u() === 10;
	}
	function D_() {
		return St(u()) || u() === 11;
	}
	function Wl(o) {
		if (u() === 11 || u() === 9 || u() === 10) {
			let p = Hn();
			return p.text = Jr(p.text), p;
		}
		return o && u() === 23 ? Gl() : u() === 81 ? ca() : jt();
	}
	function jr() {
		return Wl(!0);
	}
	function Gl() {
		let o = M();
		J(23);
		let p = lt(kt);
		return J(24), P(y.createComputedPropertyName(p), o);
	}
	function ca() {
		let o = M(), p = be(Jr(t.getTokenValue()));
		return B(), P(p, o);
	}
	function ti(o) {
		return u() === o && le(P_);
	}
	function Za() {
		return B(), t.hasPrecedingLineBreak() ? !1 : cr();
	}
	function P_() {
		switch (u()) {
			case 87: return B() === 94;
			case 95: return B(), u() === 90 ? H(Ai) : u() === 156 ? H(Yl) : Ei();
			case 90: return Ai();
			case 126: return B(), cr();
			case 139:
			case 153: return B(), Hl();
			default: return Za();
		}
	}
	function Ei() {
		return u() === 60 || u() !== 42 && u() !== 130 && u() !== 19 && cr();
	}
	function Yl() {
		return B(), Ei();
	}
	function N_() {
		return Yr(u()) && le(P_);
	}
	function cr() {
		return u() === 23 || u() === 19 || u() === 42 || u() === 26 || br();
	}
	function Hl() {
		return u() === 23 || br();
	}
	function Ai() {
		return B(), u() === 86 || u() === 100 || u() === 120 || u() === 60 || u() === 128 && H(vc) || u() === 134 && H(Tc);
	}
	function la(o, p) {
		if (pa(o)) return !0;
		switch (o) {
			case 0:
			case 1:
			case 3: return !(u() === 27 && p) && xc();
			case 2: return u() === 84 || u() === 90;
			case 4: return H(_o);
			case 5: return H(Jc) || u() === 27 && !p;
			case 6: return u() === 23 || br();
			case 12: switch (u()) {
				case 23:
				case 42:
				case 26:
				case 25: return !0;
				default: return br();
			}
			case 18: return br();
			case 9: return u() === 23 || u() === 26 || br();
			case 24: return D_();
			case 7: return u() === 19 ? H(I_) : p ? ve() && !es() : xs() && !es();
			case 8: return Rs();
			case 10: return u() === 28 || u() === 26 || Rs();
			case 19: return u() === 103 || u() === 87 || ve();
			case 15: switch (u()) {
				case 28:
				case 25: return !0;
			}
			case 11: return u() === 26 || Tr();
			case 16: return ha(!1);
			case 17: return ha(!0);
			case 20:
			case 21: return u() === 28 || ai();
			case 22: return Vs();
			case 23: return u() === 161 && H(Cc) ? !1 : u() === 11 ? !0 : St(u());
			case 13: return St(u()) || u() === 19;
			case 14: return !0;
			case 25: return !0;
			case 26: return q.fail("ParsingContext.Count used as a context");
			default: q.assertNever(o, "Non-exhaustive case in 'isListElement'.");
		}
	}
	function I_() {
		if (q.assert(u() === 19), B() === 20) {
			let o = B();
			return o === 28 || o === 19 || o === 96 || o === 119;
		}
		return !0;
	}
	function Ci() {
		return B(), ve();
	}
	function Xl() {
		return B(), St(u());
	}
	function O_() {
		return B(), Vy(u());
	}
	function es() {
		return u() === 119 || u() === 96 ? H(M_) : !1;
	}
	function M_() {
		return B(), Tr();
	}
	function Di() {
		return B(), ai();
	}
	function ua(o) {
		if (u() === 1) return !0;
		switch (o) {
			case 1:
			case 2:
			case 4:
			case 5:
			case 6:
			case 12:
			case 9:
			case 23:
			case 24: return u() === 20;
			case 3: return u() === 20 || u() === 84 || u() === 90;
			case 7: return u() === 19 || u() === 96 || u() === 119;
			case 8: return ts();
			case 19: return u() === 32 || u() === 21 || u() === 19 || u() === 96 || u() === 119;
			case 11: return u() === 22 || u() === 27;
			case 15:
			case 21:
			case 10: return u() === 24;
			case 17:
			case 16:
			case 18: return u() === 22 || u() === 24;
			case 20: return u() !== 28;
			case 22: return u() === 19 || u() === 20;
			case 13: return u() === 32 || u() === 44;
			case 14: return u() === 30 && H(ap);
			default: return !1;
		}
	}
	function ts() {
		return !!(_r() || qo(u()) || u() === 39);
	}
	function L_() {
		q.assert(yt, "Missing parsing context");
		for (let o = 0; o < 26; o++) if (yt & 1 << o && (la(o, !0) || ua(o))) return !0;
		return !1;
	}
	function bn(o, p) {
		let m = yt;
		yt |= 1 << o;
		let g = [], b = M();
		for (; !ua(o);) {
			if (la(o, !1)) {
				g.push(ns(o, p));
				continue;
			}
			if (z_(o)) break;
		}
		return yt = m, At(g, b);
	}
	function ns(o, p) {
		let m = pa(o);
		return m ? J_(m) : p();
	}
	function pa(o, p) {
		var m;
		if (!Lt || !j_(o) || tn) return;
		let g = Lt.currentNode(p ?? t.getTokenFullStart());
		if (!(Zi(g) || j6(g) || u1(g) || (g.flags & 101441536) !== tt) && R_(g, o)) return bf(g) && (m = g.jsDoc) != null && m.jsDocCache && (g.jsDoc.jsDocCache = void 0), g;
	}
	function J_(o) {
		return t.resetTokenState(o.end), B(), o;
	}
	function j_(o) {
		switch (o) {
			case 5:
			case 2:
			case 0:
			case 1:
			case 3:
			case 6:
			case 4:
			case 8:
			case 17:
			case 16: return !0;
		}
		return !1;
	}
	function R_(o, p) {
		switch (p) {
			case 5: return rs(o);
			case 2: return U_(o);
			case 0:
			case 1:
			case 3: return is(o);
			case 6: return B_(o);
			case 4: return as(o);
			case 8: return q_(o);
			case 17:
			case 16: return F_(o);
		}
		return !1;
	}
	function rs(o) {
		if (o) switch (o.kind) {
			case 177:
			case 182:
			case 178:
			case 179:
			case 173:
			case 241: return !0;
			case 175:
				let p = o;
				return !(p.name.kind === 80 && p.name.escapedText === "constructor");
		}
		return !1;
	}
	function U_(o) {
		if (o) switch (o.kind) {
			case 297:
			case 298: return !0;
		}
		return !1;
	}
	function is(o) {
		if (o) switch (o.kind) {
			case 263:
			case 244:
			case 242:
			case 246:
			case 245:
			case 258:
			case 254:
			case 256:
			case 253:
			case 252:
			case 250:
			case 251:
			case 249:
			case 248:
			case 255:
			case 243:
			case 259:
			case 257:
			case 247:
			case 260:
			case 273:
			case 272:
			case 279:
			case 278:
			case 268:
			case 264:
			case 265:
			case 267:
			case 266: return !0;
		}
		return !1;
	}
	function B_(o) {
		return o.kind === 307;
	}
	function as(o) {
		if (o) switch (o.kind) {
			case 181:
			case 174:
			case 182:
			case 172:
			case 180: return !0;
		}
		return !1;
	}
	function q_(o) {
		return o.kind !== 261 ? !1 : o.initializer === void 0;
	}
	function F_(o) {
		return o.kind !== 170 ? !1 : o.initializer === void 0;
	}
	function z_(o) {
		return fa(o), L_() ? !0 : (B(), !1);
	}
	function fa(o) {
		switch (o) {
			case 0: return u() === 90 ? Ee(A._0_expected, nt(95)) : Ee(A.Declaration_or_statement_expected);
			case 1: return Ee(A.Declaration_or_statement_expected);
			case 2: return Ee(A.case_or_default_expected);
			case 3: return Ee(A.Statement_expected);
			case 18:
			case 4: return Ee(A.Property_or_signature_expected);
			case 5: return Ee(A.Unexpected_token_A_constructor_method_accessor_or_property_was_expected);
			case 6: return Ee(A.Enum_member_expected);
			case 7: return Ee(A.Expression_expected);
			case 8: return di(u()) ? Ee(A._0_is_not_allowed_as_a_variable_declaration_name, nt(u())) : Ee(A.Variable_declaration_expected);
			case 9: return Ee(A.Property_destructuring_pattern_expected);
			case 10: return Ee(A.Array_element_destructuring_pattern_expected);
			case 11: return Ee(A.Argument_expression_expected);
			case 12: return Ee(A.Property_assignment_expected);
			case 15: return Ee(A.Expression_or_comma_expected);
			case 17: return Ee(A.Parameter_declaration_expected);
			case 16: return di(u()) ? Ee(A._0_is_not_allowed_as_a_parameter_name, nt(u())) : Ee(A.Parameter_declaration_expected);
			case 19: return Ee(A.Type_parameter_declaration_expected);
			case 20: return Ee(A.Type_argument_expected);
			case 21: return Ee(A.Type_expected);
			case 22: return Ee(A.Unexpected_token_expected);
			case 23: return u() === 161 ? Ee(A._0_expected, "}") : Ee(A.Identifier_expected);
			case 13: return Ee(A.Identifier_expected);
			case 14: return Ee(A.Identifier_expected);
			case 24: return Ee(A.Identifier_or_string_literal_expected);
			case 25: return Ee(A.Identifier_expected);
			case 26: return q.fail("ParsingContext.Count used as a context");
			default: q.assertNever(o);
		}
	}
	function un(o, p, m) {
		let g = yt;
		yt |= 1 << o;
		let b = [], N = M(), Q = -1;
		for (;;) {
			if (la(o, !1)) {
				let _e = t.getTokenFullStart(), ee = ns(o, p);
				if (!ee) {
					yt = g;
					return;
				}
				if (b.push(ee), Q = t.getTokenStart(), Le(28)) continue;
				if (Q = -1, ua(o)) break;
				J(28, ss(o)), m && u() === 27 && !t.hasPrecedingLineBreak() && B(), _e === t.getTokenFullStart() && B();
				continue;
			}
			if (ua(o) || z_(o)) break;
		}
		return yt = g, At(b, N, void 0, Q >= 0);
	}
	function ss(o) {
		return o === 6 ? A.An_enum_member_name_must_be_followed_by_a_or : void 0;
	}
	function lr() {
		let o = At([], M());
		return o.isMissingList = !0, o;
	}
	function V_(o) {
		return !!o.isMissingList;
	}
	function Rr(o, p, m, g) {
		if (J(m)) {
			let b = un(o, p);
			return J(g), b;
		}
		return lr();
	}
	function Ur(o, p) {
		let m = M(), g = o ? jt(p) : gt(p);
		for (; Le(25) && u() !== 30;) g = P(y.createQualifiedName(g, ni(o, !1, !0)), m);
		return g;
	}
	function $l(o, p) {
		return P(y.createQualifiedName(o, p), o.pos);
	}
	function ni(o, p, m) {
		if (t.hasPrecedingLineBreak() && St(u()) && H(Ms)) return Gt(80, !0, A.Identifier_expected);
		if (u() === 81) {
			let g = ca();
			return p ? g : Gt(80, !0, A.Identifier_expected);
		}
		return o ? m ? jt() : ei() : gt();
	}
	function Ql(o) {
		let p = M(), m = [], g;
		do
			g = H_(o), m.push(g);
		while (g.literal.kind === 17);
		return At(m, p);
	}
	function da(o) {
		let p = M();
		return P(y.createTemplateExpression(Pi(o), Ql(o)), p);
	}
	function W_() {
		let o = M();
		return P(y.createTemplateLiteralType(Pi(!1), Kl()), o);
	}
	function Kl() {
		let o = M(), p = [], m;
		do
			m = G_(), p.push(m);
		while (m.literal.kind === 17);
		return At(p, o);
	}
	function G_() {
		let o = M();
		return P(y.createTemplateLiteralTypeSpan(_t(), Y_(!1)), o);
	}
	function Y_(o) {
		return u() === 20 ? (Dt(o), X_()) : Yn(18, A._0_expected, nt(20));
	}
	function H_(o) {
		let p = M();
		return P(y.createTemplateSpan(lt(kt), Y_(o)), p);
	}
	function Hn() {
		return ri(u());
	}
	function Pi(o) {
		!o && t.getTokenFlags() & 26656 && Dt(!1);
		let p = ri(u());
		return q.assert(p.kind === 16, "Template head has wrong token kind"), p;
	}
	function X_() {
		let o = ri(u());
		return q.assert(o.kind === 17 || o.kind === 18, "Template fragment has wrong token kind"), o;
	}
	function Zl(o) {
		let p = o === 15 || o === 18, m = t.getTokenText();
		return m.substring(1, m.length - (t.isUnterminated() ? 0 : p ? 1 : 2));
	}
	function ri(o) {
		let p = M(), m = Pd(o) ? y.createTemplateLiteralLikeNode(o, t.getTokenValue(), Zl(o), t.getTokenFlags() & 7176) : o === 9 ? E(t.getTokenValue(), t.getNumericLiteralFlags()) : o === 11 ? D(t.getTokenValue(), void 0, t.hasExtendedUnicodeEscape()) : Jg(o) ? R(o, t.getTokenValue()) : q.fail();
		return t.hasExtendedUnicodeEscape() && (m.hasExtendedUnicodeEscape = !0), t.isUnterminated() && (m.isUnterminated = !0), B(), P(m, p);
	}
	function ii() {
		return Ur(!0, A.Type_expected);
	}
	function $_() {
		if (!t.hasPrecedingLineBreak() && wt() === 30) return Rr(20, _t, 30, 32);
	}
	function ma() {
		let o = M();
		return P(y.createTypeReferenceNode(ii(), $_()), o);
	}
	function _s(o) {
		switch (o.kind) {
			case 184: return Zi(o.typeName);
			case 185:
			case 186: {
				let { parameters: p, type: m } = o;
				return V_(p) || _s(m);
			}
			case 197: return _s(o.type);
			default: return !1;
		}
	}
	function eu(o) {
		return B(), P(y.createTypePredicateNode(void 0, o, _t()), o.pos);
	}
	function os() {
		let o = M();
		return B(), P(y.createThisTypeNode(), o);
	}
	function tu() {
		let o = M();
		return B(), P(y.createJSDocAllType(), o);
	}
	function Q_() {
		let o = M();
		return B(), P(y.createJSDocNonNullableType(bs(), !1), o);
	}
	function nu() {
		let o = M();
		return B(), u() === 28 || u() === 20 || u() === 22 || u() === 32 || u() === 64 || u() === 52 ? P(y.createJSDocUnknownType(), o) : P(y.createJSDocNullableType(_t(), !1), o);
	}
	function K_() {
		let o = M(), p = Ue();
		if (le(Gc)) {
			let m = Xn(36), g = In(59, !1);
			return Ce(P(y.createJSDocFunctionType(m, g), o), p);
		}
		return P(y.createTypeReferenceNode(jt(), void 0), o);
	}
	function cs() {
		let o = M(), p;
		return (u() === 110 || u() === 105) && (p = jt(), J(59)), P(y.createParameterDeclaration(void 0, void 0, p, void 0, ls(), void 0), o);
	}
	function ls() {
		t.setSkipJsDocLeadingAsterisks(!0);
		let o = M();
		if (Le(144)) {
			let g = y.createJSDocNamepathType(void 0);
			e: for (;;) switch (u()) {
				case 20:
				case 1:
				case 28:
				case 5: break e;
				default: Be();
			}
			return t.setSkipJsDocLeadingAsterisks(!1), P(g, o);
		}
		let p = Le(26), m = ba();
		return t.setSkipJsDocLeadingAsterisks(!1), p && (m = P(y.createJSDocVariadicType(m), o)), u() === 64 ? (B(), P(y.createJSDocOptionalType(m), o)) : m;
	}
	function Z_() {
		let o = M();
		J(114);
		let p = Ur(!0), m = t.hasPrecedingLineBreak() ? void 0 : Ca();
		return P(y.createTypeQueryNode(p, m), o);
	}
	function eo() {
		let o = M(), p = On(!1, !0), m = gt(), g, b;
		Le(96) && (ai() || !Tr() ? g = _t() : b = Xo());
		let N = Le(64) ? _t() : void 0, Q = y.createTypeParameterDeclaration(p, m, g, N);
		return Q.expression = b, P(Q, o);
	}
	function pn() {
		if (u() === 30) return Rr(19, eo, 30, 32);
	}
	function ha(o) {
		return u() === 26 || Rs() || Yr(u()) || u() === 60 || ai(!o);
	}
	function to(o) {
		let p = si(A.Private_identifiers_cannot_be_used_as_parameters);
		return s2(p) === 0 && !Zt(o) && Yr(u()) && B(), p;
	}
	function no() {
		return qe() || u() === 23 || u() === 19;
	}
	function us(o) {
		return ps(o);
	}
	function ro(o) {
		return ps(o, !1);
	}
	function ps(o, p = !0) {
		let m = M(), g = Ue(), b = o ? U(() => On(!0)) : K(() => On(!0));
		if (u() === 110) {
			let ee = y.createParameterDeclaration(b, void 0, or(!0), void 0, vr(), void 0), te = Hp(b);
			return te && on(te, A.Neither_decorators_nor_modifiers_may_be_applied_to_this_parameters), Ce(P(ee, m), g);
		}
		let N = qt;
		qt = !1;
		let Q = pt(26);
		if (!p && !no()) return;
		let _e = Ce(P(y.createParameterDeclaration(b, Q, to(b), pt(58), vr(), xr()), m), g);
		return qt = N, _e;
	}
	function In(o, p) {
		if (io(o, p)) return gr(ba);
	}
	function io(o, p) {
		return o === 39 ? (J(o), !0) : Le(59) ? !0 : p && u() === 39 ? (Ee(A._0_expected, nt(59)), B(), !0) : !1;
	}
	function fs(o, p) {
		let m = we(), g = Ye();
		He(!!(o & 1)), st(!!(o & 2));
		let b = o & 32 ? un(17, cs) : un(16, () => p ? us(g) : ro(g));
		return He(m), st(g), b;
	}
	function Xn(o) {
		if (!J(21)) return lr();
		let p = fs(o, !0);
		return J(22), p;
	}
	function ya() {
		Le(28) || Qt();
	}
	function ao(o) {
		let p = M(), m = Ue();
		o === 181 && J(105);
		let g = pn(), b = Xn(4), N = In(59, !0);
		ya();
		return Ce(P(o === 180 ? y.createCallSignature(g, b, N) : y.createConstructSignature(g, b, N), p), m);
	}
	function Br() {
		return u() === 23 && H(ru);
	}
	function ru() {
		if (B(), u() === 26 || u() === 24) return !0;
		if (Yr(u())) {
			if (B(), ve()) return !0;
		} else if (ve()) B();
		else return !1;
		return u() === 59 || u() === 28 ? !0 : u() !== 58 ? !1 : (B(), u() === 59 || u() === 28 || u() === 24);
	}
	function ds(o, p, m) {
		let g = Rr(16, () => us(!1), 23, 24), b = vr();
		ya();
		return Ce(P(y.createIndexSignature(m, g, b), o), p);
	}
	function so(o, p, m) {
		let g = jr(), b = pt(58), N;
		if (u() === 21 || u() === 30) {
			let Q = pn(), _e = Xn(4), ee = In(59, !0);
			N = y.createMethodSignature(m, g, b, Q, _e, ee);
		} else {
			let Q = vr();
			N = y.createPropertySignature(m, g, b, Q), u() === 64 && (N.initializer = xr());
		}
		return ya(), Ce(P(N, o), p);
	}
	function _o() {
		if (u() === 21 || u() === 30 || u() === 139 || u() === 153) return !0;
		let o = !1;
		for (; Yr(u());) o = !0, B();
		return u() === 23 ? !0 : (br() && (o = !0, B()), o ? u() === 21 || u() === 30 || u() === 58 || u() === 59 || u() === 28 || _r() : !1);
	}
	function Ni() {
		if (u() === 21 || u() === 30) return ao(180);
		if (u() === 105 && H(oo)) return ao(181);
		let o = M(), p = Ue(), m = On(!1);
		return ti(139) ? _i(o, p, m, 178, 4) : ti(153) ? _i(o, p, m, 179, 4) : Br() ? ds(o, p, m) : so(o, p, m);
	}
	function oo() {
		return B(), u() === 21 || u() === 30;
	}
	function co() {
		return B() === 25;
	}
	function lo() {
		switch (B()) {
			case 21:
			case 30:
			case 25: return !0;
		}
		return !1;
	}
	function uo() {
		let o = M();
		return P(y.createTypeLiteralNode(po()), o);
	}
	function po() {
		let o;
		return J(19) ? (o = bn(4, Ni), J(20)) : o = lr(), o;
	}
	function fo() {
		return B(), u() === 40 || u() === 41 ? B() === 148 : (u() === 148 && B(), u() === 23 && Ci() && B() === 103);
	}
	function iu() {
		let o = M(), p = jt();
		J(103);
		let m = _t();
		return P(y.createTypeParameterDeclaration(void 0, p, m, void 0), o);
	}
	function mo() {
		let o = M();
		J(19);
		let p;
		(u() === 148 || u() === 40 || u() === 41) && (p = Wt(), p.kind !== 148 && J(148)), J(23);
		let m = iu(), g = Le(130) ? _t() : void 0;
		J(24);
		let b;
		(u() === 58 || u() === 40 || u() === 41) && (b = Wt(), b.kind !== 58 && J(58));
		let N = vr();
		Qt();
		let Q = bn(4, Ni);
		return J(20), P(y.createMappedTypeNode(p, m, g, b, N, Q), o);
	}
	function ho() {
		let o = M();
		if (Le(26)) return P(y.createRestTypeNode(_t()), o);
		let p = _t();
		if (th(p) && p.pos === p.type.pos) {
			let m = y.createOptionalTypeNode(p.type);
			return dn(m, p), m.flags = p.flags, m;
		}
		return p;
	}
	function ms() {
		return B() === 59 || u() === 58 && B() === 59;
	}
	function au() {
		return u() === 26 ? St(B()) && ms() : St(u()) && ms();
	}
	function yo() {
		if (H(au)) {
			let o = M(), p = Ue(), m = pt(26), g = jt(), b = pt(58);
			J(59);
			let N = ho();
			return Ce(P(y.createNamedTupleMember(m, g, b, N), o), p);
		}
		return ho();
	}
	function su() {
		let o = M();
		return P(y.createTupleTypeNode(Rr(21, yo, 23, 24)), o);
	}
	function go() {
		let o = M();
		J(21);
		let p = _t();
		return J(22), P(y.createParenthesizedType(p), o);
	}
	function _u() {
		let o;
		if (u() === 128) {
			let p = M();
			B();
			o = At([P(he(128), p)], p);
		}
		return o;
	}
	function hs() {
		let o = M(), p = Ue(), m = _u(), g = Le(105);
		q.assert(!m || g, "Per isStartOfFunctionOrConstructorType, a function type cannot have modifiers.");
		let b = pn(), N = Xn(4), Q = In(39, !1);
		return Ce(P(g ? y.createConstructorTypeNode(m, b, N, Q) : y.createFunctionTypeNode(b, N, Q), o), p);
	}
	function bo() {
		let o = Wt();
		return u() === 25 ? void 0 : o;
	}
	function ys(o) {
		let p = M();
		o && B();
		let m = u() === 112 || u() === 97 || u() === 106 ? Wt() : ri(u());
		return o && (m = P(y.createPrefixUnaryExpression(41, m), p)), P(y.createLiteralTypeNode(m), p);
	}
	function ou() {
		return B(), u() === 102;
	}
	function gs() {
		ht |= 4194304;
		let o = M(), p = Le(114);
		J(102), J(21);
		let m = _t(), g;
		if (Le(28)) {
			let Q = t.getTokenStart();
			J(19);
			let _e = u();
			if (_e === 118 || _e === 132 ? B() : Ee(A._0_expected, nt(118)), J(59), g = Ys(_e, !0), Le(28), !J(20)) {
				let ee = Ba(at);
				ee && ee.code === A._0_expected.code && sl(ee, Oa(Mt, $e, Q, 1, A.The_parser_expected_to_find_a_1_to_match_the_0_token_here, "{", "}"));
			}
		}
		J(22);
		let b = Le(25) ? ii() : void 0, N = $_();
		return P(y.createImportTypeNode(m, g, b, N, p), o);
	}
	function vo() {
		return B(), u() === 9 || u() === 10;
	}
	function bs() {
		switch (u()) {
			case 133:
			case 159:
			case 154:
			case 150:
			case 163:
			case 155:
			case 136:
			case 157:
			case 146:
			case 151: return le(bo) || ma();
			case 67: t.reScanAsteriskEqualsToken();
			case 42: return tu();
			case 61: t.reScanQuestionToken();
			case 58: return nu();
			case 100: return K_();
			case 54: return Q_();
			case 15:
			case 11:
			case 9:
			case 10:
			case 112:
			case 97:
			case 106: return ys();
			case 41: return H(vo) ? ys(!0) : ma();
			case 116: return Wt();
			case 110: {
				let o = os();
				return u() === 142 && !t.hasPrecedingLineBreak() ? eu(o) : o;
			}
			case 114: return H(ou) ? gs() : Z_();
			case 19: return H(fo) ? mo() : uo();
			case 23: return su();
			case 21: return go();
			case 102: return gs();
			case 131: return H(Ms) ? Po() : ma();
			case 16: return W_();
			default: return ma();
		}
	}
	function ai(o) {
		switch (u()) {
			case 133:
			case 159:
			case 154:
			case 150:
			case 163:
			case 136:
			case 148:
			case 155:
			case 158:
			case 116:
			case 157:
			case 106:
			case 110:
			case 114:
			case 146:
			case 19:
			case 23:
			case 30:
			case 52:
			case 51:
			case 105:
			case 11:
			case 9:
			case 10:
			case 112:
			case 97:
			case 151:
			case 42:
			case 58:
			case 54:
			case 26:
			case 140:
			case 102:
			case 131:
			case 15:
			case 16: return !0;
			case 100: return !o;
			case 41: return !o && H(vo);
			case 21: return !o && H(To);
			default: return ve();
		}
	}
	function To() {
		return B(), u() === 22 || ha(!1) || ai();
	}
	function xo() {
		let o = M(), p = bs();
		for (; !t.hasPrecedingLineBreak();) switch (u()) {
			case 54:
				B(), p = P(y.createJSDocNonNullableType(p, !0), o);
				break;
			case 58:
				if (H(Di)) return p;
				B(), p = P(y.createJSDocNullableType(p, !0), o);
				break;
			case 23:
				if (J(23), ai()) {
					let m = _t();
					J(24), p = P(y.createIndexedAccessTypeNode(p, m), o);
				} else J(24), p = P(y.createArrayTypeNode(p), o);
				break;
			default: return p;
		}
		return p;
	}
	function So(o) {
		let p = M();
		return J(o), P(y.createTypeOperatorNode(o, ko()), p);
	}
	function cu() {
		if (Le(96)) {
			let o = Nn(_t);
			if (Ve() || u() !== 58) return o;
		}
	}
	function wo() {
		let o = M(), p = gt(), m = le(cu);
		return P(y.createTypeParameterDeclaration(void 0, p, m), o);
	}
	function lu() {
		let o = M();
		return J(140), P(y.createInferTypeNode(wo()), o);
	}
	function ko() {
		let o = u();
		switch (o) {
			case 143:
			case 158:
			case 148: return So(o);
			case 140: return lu();
		}
		return gr(xo);
	}
	function ga(o) {
		if (Ts()) {
			let p = hs(), m;
			return Pf(p) ? m = o ? A.Function_type_notation_must_be_parenthesized_when_used_in_a_union_type : A.Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type : m = o ? A.Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type : A.Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type, on(p, m), p;
		}
	}
	function Eo(o, p, m) {
		let g = M(), b = o === 52, N = Le(o), Q = N && ga(b) || p();
		if (u() === o || N) {
			let _e = [Q];
			for (; Le(o);) _e.push(ga(b) || p());
			Q = P(m(At(_e, g)), g);
		}
		return Q;
	}
	function vs() {
		return Eo(51, ko, y.createIntersectionTypeNode);
	}
	function uu() {
		return Eo(52, vs, y.createUnionTypeNode);
	}
	function Ao() {
		return B(), u() === 105;
	}
	function Ts() {
		return u() === 30 || u() === 21 && H(Co) ? !0 : u() === 105 || u() === 128 && H(Ao);
	}
	function pu() {
		if (Yr(u()) && On(!1), ve() || u() === 110) return B(), !0;
		if (u() === 23 || u() === 19) {
			let o = at.length;
			return si(), o === at.length;
		}
		return !1;
	}
	function Co() {
		return B(), !!(u() === 22 || u() === 26 || pu() && (u() === 59 || u() === 28 || u() === 58 || u() === 64 || u() === 22 && (B(), u() === 39)));
	}
	function ba() {
		let o = M(), p = ve() && le(Do), m = _t();
		return p ? P(y.createTypePredicateNode(void 0, p, m), o) : m;
	}
	function Do() {
		let o = gt();
		if (u() === 142 && !t.hasPrecedingLineBreak()) return B(), o;
	}
	function Po() {
		let o = M(), p = Yn(131), m = u() === 110 ? os() : gt(), g = Le(142) ? _t() : void 0;
		return P(y.createTypePredicateNode(p, m, g), o);
	}
	function _t() {
		if (tt & 81920) return Ct(81920, _t);
		if (Ts()) return hs();
		let o = M(), p = uu();
		if (!Ve() && !t.hasPrecedingLineBreak() && Le(96)) {
			let m = Nn(_t);
			J(58);
			let g = gr(_t);
			J(59);
			let b = gr(_t);
			return P(y.createConditionalTypeNode(p, m, g, b), o);
		}
		return p;
	}
	function vr() {
		return Le(59) ? _t() : void 0;
	}
	function xs() {
		switch (u()) {
			case 110:
			case 108:
			case 106:
			case 112:
			case 97:
			case 9:
			case 10:
			case 11:
			case 15:
			case 16:
			case 21:
			case 23:
			case 19:
			case 100:
			case 86:
			case 105:
			case 44:
			case 69:
			case 80: return !0;
			case 102: return H(lo);
			default: return ve();
		}
	}
	function Tr() {
		if (xs()) return !0;
		switch (u()) {
			case 40:
			case 41:
			case 55:
			case 54:
			case 91:
			case 114:
			case 116:
			case 46:
			case 47:
			case 30:
			case 135:
			case 127:
			case 81:
			case 60: return !0;
			default: return Fo() ? !0 : ve();
		}
	}
	function No() {
		return u() !== 19 && u() !== 100 && u() !== 86 && u() !== 60 && Tr();
	}
	function kt() {
		let o = Ze();
		o && Qe(!1);
		let p = M(), m = zt(!0), g;
		for (; g = pt(28);) m = ks(m, g, zt(!0), p);
		return o && Qe(!0), m;
	}
	function xr() {
		return Le(64) ? zt(!0) : void 0;
	}
	function zt(o) {
		if (Io()) return Oo();
		let p = du(o) || Ro(o);
		if (p) return p;
		let m = M(), g = Ue(), b = Ii(0);
		return b.kind === 80 && u() === 39 ? Mo(m, b, o, g, void 0) : Fa(b) && b1(ze()) ? ks(b, Wt(), zt(o), m) : mu(b, m, o);
	}
	function Io() {
		return u() === 127 ? we() ? !0 : H(Ls) : !1;
	}
	function fu() {
		return B(), !t.hasPrecedingLineBreak() && ve();
	}
	function Oo() {
		let o = M();
		return B(), !t.hasPrecedingLineBreak() && (u() === 42 || Tr()) ? P(y.createYieldExpression(pt(42), zt(!0)), o) : P(y.createYieldExpression(void 0, void 0), o);
	}
	function Mo(o, p, m, g, b) {
		q.assert(u() === 39, "parseSimpleArrowFunctionExpression should only have been called if we had a =>");
		let N = y.createParameterDeclaration(void 0, void 0, p, void 0, void 0, void 0);
		P(N, p.pos);
		let Q = At([N], N.pos, N.end), _e = Yn(39), ee = Ss(!!b, m);
		return Ce(P(y.createArrowFunction(b, void 0, Q, void 0, _e, ee), o), g);
	}
	function du(o) {
		let p = Lo();
		if (p !== 0) return p === 1 ? Bo(!0, !0) : le(() => jo(o));
	}
	function Lo() {
		return u() === 21 || u() === 30 || u() === 134 ? H(Jo) : u() === 39 ? 1 : 0;
	}
	function Jo() {
		if (u() === 134 && (B(), t.hasPrecedingLineBreak() || u() !== 21 && u() !== 30)) return 0;
		let o = u(), p = B();
		if (o === 21) {
			if (p === 22) switch (B()) {
				case 39:
				case 59:
				case 19: return 1;
				default: return 0;
			}
			if (p === 23 || p === 19) return 2;
			if (p === 26) return 1;
			if (Yr(p) && p !== 134 && H(Ci)) return B() === 130 ? 0 : 1;
			if (!ve() && p !== 110) return 0;
			switch (B()) {
				case 59: return 1;
				case 58: return B(), u() === 59 || u() === 28 || u() === 64 || u() === 22 ? 1 : 0;
				case 28:
				case 64:
				case 22: return 2;
			}
			return 0;
		} else return q.assert(o === 30), !ve() && u() !== 87 ? 0 : ot === 1 ? H(() => {
			Le(87);
			let g = B();
			if (g === 96) switch (B()) {
				case 64:
				case 32:
				case 44: return !1;
				default: return !0;
			}
			else if (g === 28 || g === 64) return !0;
			return !1;
		}) ? 1 : 0 : 2;
	}
	function jo(o) {
		let p = t.getTokenStart();
		if (_n?.has(p)) return;
		let m = Bo(!1, o);
		return m || (_n || (_n = /* @__PURE__ */ new Set())).add(p), m;
	}
	function Ro(o) {
		if (u() === 134 && H(Uo) === 1) {
			let p = M(), m = Ue(), g = Uc();
			return Mo(p, Ii(0), o, m, g);
		}
	}
	function Uo() {
		if (u() === 134) {
			if (B(), t.hasPrecedingLineBreak() || u() === 39) return 0;
			let o = Ii(0);
			if (!t.hasPrecedingLineBreak() && o.kind === 80 && u() === 39) return 1;
		}
		return 0;
	}
	function Bo(o, p) {
		let m = M(), g = Ue(), b = Uc(), N = Zt(b, cl) ? 2 : 0, Q = pn(), _e;
		if (J(21)) {
			if (o) _e = fs(N, o);
			else {
				let ur = fs(N, o);
				if (!ur) return;
				_e = ur;
			}
			if (!J(22) && !o) return;
		} else {
			if (!o) return;
			_e = lr();
		}
		let ee = u() === 59, te = In(59, !1);
		if (te && !o && _s(te)) return;
		let ce = te;
		for (; ce?.kind === 197;) ce = ce.type;
		let je = ce && nh(ce);
		if (!o && u() !== 39 && (je || u() !== 19)) return;
		let Je = u(), De = Yn(39), Ht = Je === 39 || Je === 19 ? Ss(Zt(b, cl), p) : gt();
		if (!p && ee && u() !== 59) return;
		return Ce(P(y.createArrowFunction(b, Q, _e, te, De, Ht), m), g);
	}
	function Ss(o, p) {
		if (u() === 19) return wa(o ? 2 : 0);
		if (u() !== 27 && u() !== 100 && u() !== 86 && xc() && !No()) return wa(16 | (o ? 2 : 0));
		let m = we();
		He(!1);
		let g = qt;
		qt = !1;
		let b = o ? U(() => zt(p)) : K(() => zt(p));
		return qt = g, He(m), b;
	}
	function mu(o, p, m) {
		let g = pt(58);
		if (!g) return o;
		let b;
		return P(y.createConditionalExpression(o, g, Ct(a, () => zt(!1)), b = Yn(59), Rp(b) ? zt(m) : Gt(80, !1, A._0_expected, nt(59))), p);
	}
	function Ii(o) {
		let p = M();
		return ws(o, Xo(), p);
	}
	function qo(o) {
		return o === 103 || o === 165;
	}
	function ws(o, p, m) {
		for (;;) {
			ze();
			let g = Sp(u());
			if (!(u() === 43 ? g >= o : g > o) || u() === 103 && me()) break;
			if (u() === 130 || u() === 152) {
				if (t.hasPrecedingLineBreak()) break;
				{
					let N = u();
					B(), p = N === 152 ? zo(p, _t()) : Vo(p, _t());
				}
			} else p = ks(p, Wt(), Ii(g), m);
		}
		return p;
	}
	function Fo() {
		return me() && u() === 103 ? !1 : Sp(u()) > 0;
	}
	function zo(o, p) {
		return P(y.createSatisfiesExpression(o, p), o.pos);
	}
	function ks(o, p, m, g) {
		return P(y.createBinaryExpression(o, p, m), g);
	}
	function Vo(o, p) {
		return P(y.createAsExpression(o, p), o.pos);
	}
	function Wo() {
		let o = M();
		return P(y.createPrefixUnaryExpression(u(), Me(Sr)), o);
	}
	function Go() {
		let o = M();
		return P(y.createDeleteExpression(Me(Sr)), o);
	}
	function hu() {
		let o = M();
		return P(y.createTypeOfExpression(Me(Sr)), o);
	}
	function Yo() {
		let o = M();
		return P(y.createVoidExpression(Me(Sr)), o);
	}
	function yu() {
		return u() === 135 ? Ye() ? !0 : H(Ls) : !1;
	}
	function Ho() {
		let o = M();
		return P(y.createAwaitExpression(Me(Sr)), o);
	}
	function Xo() {
		if (gu()) {
			let m = M(), g = va();
			return u() === 43 ? ws(Sp(u()), g, m) : g;
		}
		let o = u(), p = Sr();
		if (u() === 43) {
			let m = Cr($e, p.pos), { end: g } = p;
			p.kind === 217 ? rt(m, g, A.A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses) : (q.assert(xp(o)), rt(m, g, A.An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses, nt(o)));
		}
		return p;
	}
	function Sr() {
		switch (u()) {
			case 40:
			case 41:
			case 55:
			case 54: return Wo();
			case 91: return Go();
			case 114: return hu();
			case 116: return Yo();
			case 30: return ot === 1 ? Mi(!0, void 0, void 0, !0) : ec();
			case 135: if (yu()) return Ho();
			default: return va();
		}
	}
	function gu() {
		switch (u()) {
			case 40:
			case 41:
			case 55:
			case 54:
			case 91:
			case 114:
			case 116:
			case 135: return !1;
			case 30: if (ot !== 1) return !1;
			default: return !0;
		}
	}
	function va() {
		if (u() === 46 || u() === 47) {
			let p = M();
			return P(y.createPrefixUnaryExpression(u(), Me(Oi)), p);
		} else if (ot === 1 && u() === 30 && H(O_)) return Mi(!0);
		let o = Oi();
		if (q.assert(Fa(o)), (u() === 46 || u() === 47) && !t.hasPrecedingLineBreak()) {
			let p = u();
			return B(), P(y.createPostfixUnaryExpression(o, p), o.pos);
		}
		return o;
	}
	function Oi() {
		let o = M(), p;
		return u() === 102 ? H(oo) ? (ht |= 4194304, p = Wt()) : H(co) ? (B(), B(), p = P(y.createMetaProperty(102, jt()), o), p.name.escapedText === "defer" ? (u() === 21 || u() === 30) && (ht |= 4194304) : ht |= 8388608) : p = Ta() : p = u() === 108 ? $o() : Ta(), Ps(o, p);
	}
	function Ta() {
		return rn(M(), Ns(), !0);
	}
	function $o() {
		let o = M(), p = Wt();
		if (u() === 30) {
			let m = M(), g = le(Sa);
			g !== void 0 && (rt(m, M(), A.super_may_not_use_type_arguments), vn() || (p = y.createExpressionWithTypeArguments(p, g)));
		}
		return u() === 21 || u() === 25 || u() === 23 ? p : (Yn(25, A.super_must_be_followed_by_an_argument_list_or_member_access), P(ae(p, ni(!0, !0, !0)), o));
	}
	function Mi(o, p, m, g = !1) {
		let b = M(), N = Tu(o), Q;
		if (N.kind === 287) {
			let _e = xa(N), ee, te = _e[_e.length - 1];
			if (te?.kind === 285 && !pi(te.openingElement.tagName, te.closingElement.tagName) && pi(N.tagName, te.closingElement.tagName)) {
				let ce = te.children.end, je = P(y.createJsxElement(te.openingElement, te.children, P(y.createJsxClosingElement(P(ue(""), ce, ce)), ce, ce)), te.openingElement.pos, ce);
				_e = At([..._e.slice(0, _e.length - 1), je], _e.pos, ce), ee = te.closingElement;
			} else ee = Zo(N, o), pi(N.tagName, ee.tagName) || (m && Fp(m) && pi(ee.tagName, m.tagName) ? on(N.tagName, A.JSX_element_0_has_no_corresponding_closing_tag, r_($e, N.tagName)) : on(ee.tagName, A.Expected_corresponding_JSX_closing_tag_for_0, r_($e, N.tagName)));
			Q = P(y.createJsxElement(N, _e, ee), b);
		} else N.kind === 290 ? Q = P(y.createJsxFragment(N, xa(N), ku(o)), b) : (q.assert(N.kind === 286), Q = N);
		if (!g && o && u() === 30) {
			let _e = typeof p > "u" ? Q.pos : p, ee = le(() => Mi(!0, _e));
			if (ee) {
				let te = Gt(28, !1);
				return qd(te, ee.pos, 0), rt(Cr($e, _e), ee.end, A.JSX_expressions_must_have_one_parent_element), P(y.createBinaryExpression(Q, te, ee), b);
			}
		}
		return Q;
	}
	function Es() {
		let o = M(), p = y.createJsxText(t.getTokenValue(), ct === 13);
		return ct = t.scanJsxToken(), P(p, o);
	}
	function bu(o, p) {
		switch (p) {
			case 1:
				if (n6(o)) on(o, A.JSX_fragment_has_no_corresponding_closing_tag);
				else {
					let m = o.tagName;
					rt(Math.min(Cr($e, m.pos), m.end), m.end, A.JSX_element_0_has_no_corresponding_closing_tag, r_($e, o.tagName));
				}
				return;
			case 31:
			case 7: return;
			case 12:
			case 13: return Es();
			case 19: return Qo(!1);
			case 30: return Mi(!1, void 0, o);
			default: return q.assertNever(p);
		}
	}
	function xa(o) {
		let p = [], m = M(), g = yt;
		for (yt |= 16384;;) {
			let b = bu(o, ct = t.reScanJsxToken());
			if (!b || (p.push(b), Fp(o) && b?.kind === 285 && !pi(b.openingElement.tagName, b.closingElement.tagName) && pi(o.tagName, b.closingElement.tagName))) break;
		}
		return yt = g, At(p, m);
	}
	function vu() {
		let o = M();
		return P(y.createJsxAttributes(bn(13, Ko)), o);
	}
	function Tu(o) {
		let p = M();
		if (J(30), u() === 32) return Gn(), P(y.createJsxOpeningFragment(), p);
		let m = As(), g = (tt & 524288) === 0 ? Ca() : void 0, b = vu(), N;
		return u() === 32 ? (Gn(), N = y.createJsxOpeningElement(m, g, b)) : (J(44), J(32, void 0, !1) && (o ? B() : Gn()), N = y.createJsxSelfClosingElement(m, g, b)), P(N, p);
	}
	function As() {
		let o = M(), p = xu();
		if (Q1(p)) return p;
		let m = p;
		for (; Le(25);) m = P(ae(m, ni(!0, !1, !1)), o);
		return m;
	}
	function xu() {
		let o = M();
		Ft();
		let p = u() === 110, m = ei();
		return Le(59) ? (Ft(), P(y.createJsxNamespacedName(m, ei()), o)) : p ? P(y.createToken(110), o) : m;
	}
	function Qo(o) {
		let p = M();
		if (!J(19)) return;
		let m, g;
		return u() !== 20 && (o || (m = pt(26)), g = kt()), o ? J(20) : J(20, void 0, !1) && Gn(), P(y.createJsxExpression(m, g), p);
	}
	function Ko() {
		if (u() === 19) return wu();
		let o = M();
		return P(y.createJsxAttribute(Su(), Cs()), o);
	}
	function Cs() {
		if (u() === 64) {
			if (ki() === 11) return Hn();
			if (u() === 19) return Qo(!0);
			if (u() === 30) return Mi(!0);
			Ee(A.or_JSX_element_expected);
		}
	}
	function Su() {
		let o = M();
		Ft();
		let p = ei();
		return Le(59) ? (Ft(), P(y.createJsxNamespacedName(p, ei()), o)) : p;
	}
	function wu() {
		let o = M();
		J(19), J(26);
		let p = kt();
		return J(20), P(y.createJsxSpreadAttribute(p), o);
	}
	function Zo(o, p) {
		let m = M();
		J(31);
		let g = As();
		return J(32, void 0, !1) && (p || !pi(o.tagName, g) ? B() : Gn()), P(y.createJsxClosingElement(g), m);
	}
	function ku(o) {
		let p = M();
		return J(31), J(32, A.Expected_corresponding_closing_tag_for_JSX_fragment, !1) && (o ? B() : Gn()), P(y.createJsxJsxClosingFragment(), p);
	}
	function ec() {
		q.assert(ot !== 1, "Type assertions should never be parsed in JSX; they should be parsed as comparisons or JSX elements/fragments.");
		let o = M();
		J(30);
		let p = _t();
		J(32);
		let m = Sr();
		return P(y.createTypeAssertion(p, m), o);
	}
	function Eu() {
		return B(), St(u()) || u() === 23 || vn();
	}
	function tc() {
		return u() === 29 && H(Eu);
	}
	function Ds(o) {
		if (o.flags & 64) return !0;
		if (fl(o)) {
			let p = o.expression;
			for (; fl(p) && !(p.flags & 64);) p = p.expression;
			if (p.flags & 64) {
				for (; fl(o);) o.flags |= 64, o = o.expression;
				return !0;
			}
		}
		return !1;
	}
	function nc(o, p, m) {
		let g = ni(!0, !0, !0), b = m || Ds(p), N = b ? Oe(p, m, g) : ae(p, g);
		if (b && gi(N.name) && on(N.name, A.An_optional_chain_cannot_contain_private_identifiers), G1(p) && p.typeArguments) rt(p.typeArguments.pos - 1, Cr($e, p.typeArguments.end) + 1, A.An_instantiation_expression_cannot_be_followed_by_a_property_access);
		return P(N, o);
	}
	function Au(o, p, m) {
		let g;
		if (u() === 24) g = Gt(80, !0, A.An_element_access_expression_should_take_an_argument);
		else {
			let N = lt(kt);
			Al(N) && (N.text = Jr(N.text)), g = N;
		}
		J(24);
		return P(m || Ds(p) ? oe(p, m, g) : V(p, g), o);
	}
	function rn(o, p, m) {
		for (;;) {
			let g, b = !1;
			if (m && tc() ? (g = Yn(29), b = St(u())) : b = Le(25), b) {
				p = nc(o, p, g);
				continue;
			}
			if ((g || !Ze()) && Le(23)) {
				p = Au(o, p, g);
				continue;
			}
			if (vn()) {
				p = !g && p.kind === 234 ? qr(o, p.expression, g, p.typeArguments) : qr(o, p, g, void 0);
				continue;
			}
			if (!g) {
				if (u() === 54 && !t.hasPrecedingLineBreak()) {
					B(), p = P(y.createNonNullExpression(p), o);
					continue;
				}
				let N = le(Sa);
				if (N) {
					p = P(y.createExpressionWithTypeArguments(p, N), o);
					continue;
				}
			}
			return p;
		}
	}
	function vn() {
		return u() === 15 || u() === 16;
	}
	function qr(o, p, m, g) {
		let b = y.createTaggedTemplateExpression(p, g, u() === 15 ? (Dt(!0), Hn()) : da(!0));
		return (m || p.flags & 64) && (b.flags |= 64), b.questionDotToken = m, P(b, o);
	}
	function Ps(o, p) {
		for (;;) {
			p = rn(o, p, !0);
			let m, g = pt(29);
			if (g && (m = le(Sa), vn())) {
				p = qr(o, p, g, m);
				continue;
			}
			if (m || u() === 21) {
				!g && p.kind === 234 && (m = p.typeArguments, p = p.expression);
				let b = rc();
				p = P(g || Ds(p) ? ft(p, g, m, b) : Y(p, m, b), o);
				continue;
			}
			if (g) {
				let b = Gt(80, !1, A.Identifier_expected);
				p = P(Oe(p, g, b), o);
			}
			break;
		}
		return p;
	}
	function rc() {
		J(21);
		let o = un(11, sc);
		return J(22), o;
	}
	function Sa() {
		if ((tt & 524288) !== 0 || wt() !== 30) return;
		B();
		let o = un(20, _t);
		if (ze() === 32) return B(), o && Cu() ? o : void 0;
	}
	function Cu() {
		switch (u()) {
			case 21:
			case 15:
			case 16: return !0;
			case 30:
			case 32:
			case 40:
			case 41: return !1;
		}
		return t.hasPrecedingLineBreak() || Fo() || !Tr();
	}
	function Ns() {
		switch (u()) {
			case 15: t.getTokenFlags() & 26656 && Dt(!1);
			case 9:
			case 10:
			case 11: return Hn();
			case 110:
			case 108:
			case 106:
			case 112:
			case 97: return Wt();
			case 21: return Du();
			case 23: return _c();
			case 19: return Is();
			case 134:
				if (!H(Tc)) break;
				return Os();
			case 60: return Xu();
			case 86: return $u();
			case 100: return Os();
			case 105: return cc();
			case 44:
			case 69:
				if (Xe() === 14) return Hn();
				break;
			case 16: return da(!1);
			case 81: return ca();
		}
		return gt(A.Expression_expected);
	}
	function Du() {
		let o = M(), p = Ue();
		J(21);
		let m = lt(kt);
		return J(22), Ce(P(mn(m), o), p);
	}
	function ic() {
		let o = M();
		J(26);
		let p = zt(!0);
		return P(y.createSpreadElement(p), o);
	}
	function ac() {
		return u() === 26 ? ic() : u() === 28 ? P(y.createOmittedExpression(), M()) : zt(!0);
	}
	function sc() {
		return Ct(a, ac);
	}
	function _c() {
		let o = M(), p = t.getTokenStart(), m = J(23), g = t.hasPrecedingLineBreak(), b = un(15, ac);
		return Lr(23, 24, m, p), P(de(b, g), o);
	}
	function oc() {
		let o = M(), p = Ue();
		if (pt(26)) {
			let ce = zt(!0);
			return Ce(P(y.createSpreadAssignment(ce), o), p);
		}
		let m = On(!0);
		if (ti(139)) return _i(o, p, m, 178, 0);
		if (ti(153)) return _i(o, p, m, 179, 0);
		let g = pt(42), b = ve(), N = jr(), Q = pt(58), _e = pt(54);
		if (g || u() === 21 || u() === 30) return Lc(o, p, m, g, N, Q, _e);
		let ee;
		if (b && u() !== 59) {
			let ce = pt(64), je = ce ? lt(() => zt(!0)) : void 0;
			ee = y.createShorthandPropertyAssignment(N, je), ee.equalsToken = ce;
		} else {
			J(59);
			let ce = lt(() => zt(!0));
			ee = y.createPropertyAssignment(N, ce);
		}
		return ee.modifiers = m, ee.questionToken = Q, ee.exclamationToken = _e, Ce(P(ee, o), p);
	}
	function Is() {
		let o = M(), p = t.getTokenStart(), m = J(19), g = t.hasPrecedingLineBreak(), b = un(12, oc, !0);
		return Lr(19, 20, m, p), P(O(b, g), o);
	}
	function Os() {
		let o = Ze();
		Qe(!1);
		let p = M(), m = Ue(), g = On(!1);
		J(100);
		let b = pt(42), N = b ? 1 : 0, Q = Zt(g, cl) ? 2 : 0, _e = N && Q ? Z(Li) : N ? Wn(Li) : Q ? U(Li) : Li(), ee = pn(), te = Xn(N | Q), ce = In(59, !1), je = wa(N | Q);
		Qe(o);
		return Ce(P(y.createFunctionExpression(g, b, _e, ee, te, ce, je), p), m);
	}
	function Li() {
		return qe() ? Ka() : void 0;
	}
	function cc() {
		let o = M();
		if (J(105), Le(25)) {
			let N = jt();
			return P(y.createMetaProperty(105, N), o);
		}
		let m = rn(M(), Ns(), !1), g;
		m.kind === 234 && (g = m.typeArguments, m = m.expression), u() === 29 && Ee(A.Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0, r_($e, m));
		let b = u() === 21 ? rc() : void 0;
		return P(nr(m, g, b), o);
	}
	function Fr(o, p) {
		let m = M(), g = Ue(), b = t.getTokenStart(), N = J(19, p);
		if (N || o) {
			let Q = t.hasPrecedingLineBreak(), _e = bn(1, Yt);
			Lr(19, 20, N, b);
			let ee = Ce(P(rr(_e, Q), m), g);
			return u() === 64 && (Ee(A.Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_destructuring_assignment_you_might_need_to_wrap_the_whole_assignment_in_parentheses), B()), ee;
		} else return Ce(P(rr(lr(), void 0), m), g);
	}
	function wa(o, p) {
		let m = we();
		He(!!(o & 1));
		let g = Ye();
		st(!!(o & 2));
		let b = qt;
		qt = !1;
		let N = Ze();
		N && Qe(!1);
		let Q = Fr(!!(o & 16), p);
		return N && Qe(!0), qt = b, He(m), st(g), Q;
	}
	function lc() {
		let o = M(), p = Ue();
		return J(27), Ce(P(y.createEmptyStatement(), o), p);
	}
	function Pu() {
		let o = M(), p = Ue();
		J(101);
		let m = t.getTokenStart(), g = J(21), b = lt(kt);
		Lr(21, 22, g, m);
		return Ce(P(We(b, Yt(), Le(93) ? Yt() : void 0), o), p);
	}
	function uc() {
		let o = M(), p = Ue();
		J(92);
		let m = Yt();
		J(117);
		let g = t.getTokenStart(), b = J(21), N = lt(kt);
		return Lr(21, 22, b, g), Le(27), Ce(P(y.createDoStatement(m, N), o), p);
	}
	function Nu() {
		let o = M(), p = Ue();
		J(117);
		let m = t.getTokenStart(), g = J(21), b = lt(kt);
		Lr(21, 22, g, m);
		return Ce(P(ir(b, Yt()), o), p);
	}
	function pc() {
		let o = M(), p = Ue();
		J(99);
		let m = pt(135);
		J(21);
		let g;
		u() !== 27 && (u() === 115 || u() === 121 || u() === 87 || u() === 160 && H(wc) || u() === 135 && H(Js) ? g = Ic(!0) : g = Mr(kt));
		let b;
		if (m ? J(165) : Le(165)) {
			let N = lt(() => zt(!0));
			J(22), b = Ot(m, g, N, Yt());
		} else if (Le(103)) {
			let N = lt(kt);
			J(22), b = y.createForInStatement(g, N, Yt());
		} else {
			J(27);
			let N = u() !== 27 && u() !== 22 ? lt(kt) : void 0;
			J(27);
			let Q = u() !== 22 ? lt(kt) : void 0;
			J(22), b = Ir(g, N, Q, Yt());
		}
		return Ce(P(b, o), p);
	}
	function fc(o) {
		let p = M(), m = Ue();
		J(o === 253 ? 83 : 88);
		let g = _r() ? void 0 : gt();
		Qt();
		return Ce(P(o === 253 ? y.createBreakStatement(g) : y.createContinueStatement(g), p), m);
	}
	function dc() {
		let o = M(), p = Ue();
		J(107);
		let m = _r() ? void 0 : lt(kt);
		return Qt(), Ce(P(y.createReturnStatement(m), o), p);
	}
	function Iu() {
		let o = M(), p = Ue();
		J(118);
		let m = t.getTokenStart(), g = J(21), b = lt(kt);
		Lr(21, 22, g, m);
		let N = Tt(67108864, Yt);
		return Ce(P(y.createWithStatement(b, N), o), p);
	}
	function mc() {
		let o = M(), p = Ue();
		J(84);
		let m = lt(kt);
		J(59);
		let g = bn(3, Yt);
		return Ce(P(y.createCaseClause(m, g), o), p);
	}
	function Ou() {
		let o = M();
		J(90), J(59);
		let p = bn(3, Yt);
		return P(y.createDefaultClause(p), o);
	}
	function Mu() {
		return u() === 84 ? mc() : Ou();
	}
	function hc() {
		let o = M();
		J(19);
		let p = bn(2, Mu);
		return J(20), P(y.createCaseBlock(p), o);
	}
	function Lu() {
		let o = M(), p = Ue();
		J(109), J(21);
		let m = lt(kt);
		J(22);
		let g = hc();
		return Ce(P(y.createSwitchStatement(m, g), o), p);
	}
	function yc() {
		let o = M(), p = Ue();
		J(111);
		let m = t.hasPrecedingLineBreak() ? void 0 : lt(kt);
		return m === void 0 && (yn++, m = P(ue(""), M())), oa() || xt(m), Ce(P(y.createThrowStatement(m), o), p);
	}
	function Ju() {
		let o = M(), p = Ue();
		J(113);
		let m = Fr(!1), g = u() === 85 ? gc() : void 0, b;
		return (!g || u() === 98) && (J(98, A.catch_or_finally_expected), b = Fr(!1)), Ce(P(y.createTryStatement(m, g, b), o), p);
	}
	function gc() {
		let o = M();
		J(85);
		let p;
		Le(21) ? (p = Ea(), J(22)) : p = void 0;
		let m = Fr(!1);
		return P(y.createCatchClause(p, m), o);
	}
	function ju() {
		let o = M(), p = Ue();
		return J(89), Qt(), Ce(P(y.createDebuggerStatement(), o), p);
	}
	function bc() {
		let o = M(), p = Ue(), m, g = u() === 21, b = lt(kt);
		return Ke(b) && Le(59) ? m = y.createLabeledStatement(b, Yt()) : (oa() || xt(b), m = Dn(b), g && (p = !1)), Ce(P(m, o), p);
	}
	function Ms() {
		return B(), St(u()) && !t.hasPrecedingLineBreak();
	}
	function vc() {
		return B(), u() === 86 && !t.hasPrecedingLineBreak();
	}
	function Tc() {
		return B(), u() === 100 && !t.hasPrecedingLineBreak();
	}
	function Ls() {
		return B(), (St(u()) || u() === 9 || u() === 10 || u() === 11) && !t.hasPrecedingLineBreak();
	}
	function Ru() {
		for (;;) switch (u()) {
			case 115:
			case 121:
			case 87:
			case 100:
			case 86:
			case 94: return !0;
			case 160: return kc();
			case 135: return js();
			case 120:
			case 156:
			case 166: return fu();
			case 144:
			case 145: return Fu();
			case 128:
			case 129:
			case 134:
			case 138:
			case 123:
			case 124:
			case 125:
			case 148:
				let o = u();
				if (B(), t.hasPrecedingLineBreak()) return !1;
				if (o === 138 && u() === 156) return !0;
				continue;
			case 162: return B(), u() === 19 || u() === 80 || u() === 95;
			case 102: return B(), u() === 166 || u() === 11 || u() === 42 || u() === 19 || St(u());
			case 95:
				let p = B();
				if (p === 156 && (p = H(B)), p === 64 || p === 42 || p === 19 || p === 90 || p === 130 || p === 60) return !0;
				continue;
			case 126:
				B();
				continue;
			default: return !1;
		}
	}
	function Ji() {
		return H(Ru);
	}
	function xc() {
		switch (u()) {
			case 60:
			case 27:
			case 19:
			case 115:
			case 121:
			case 160:
			case 100:
			case 86:
			case 94:
			case 101:
			case 92:
			case 117:
			case 99:
			case 88:
			case 83:
			case 107:
			case 118:
			case 109:
			case 111:
			case 113:
			case 89:
			case 85:
			case 98: return !0;
			case 102: return Ji() || H(lo);
			case 87:
			case 95: return Ji();
			case 134:
			case 138:
			case 120:
			case 144:
			case 145:
			case 156:
			case 162:
			case 166: return !0;
			case 129:
			case 125:
			case 123:
			case 124:
			case 126:
			case 148: return Ji() || !H(Ms);
			default: return Tr();
		}
	}
	function Sc() {
		return B(), qe() || u() === 19 || u() === 23;
	}
	function Uu() {
		return H(Sc);
	}
	function wc() {
		return ka(!0);
	}
	function Bu() {
		return B(), u() === 64 || u() === 27 || u() === 59;
	}
	function ka(o) {
		return B(), o && u() === 165 ? H(Bu) : (qe() || u() === 19) && !t.hasPrecedingLineBreak();
	}
	function kc() {
		return H(ka);
	}
	function Js(o) {
		return B() === 160 ? ka(o) : !1;
	}
	function js() {
		return H(Js);
	}
	function Yt() {
		switch (u()) {
			case 27: return lc();
			case 19: return Fr(!1);
			case 115: return Ui(M(), Ue(), void 0);
			case 121:
				if (Uu()) return Ui(M(), Ue(), void 0);
				break;
			case 135:
				if (js()) return Ui(M(), Ue(), void 0);
				break;
			case 160:
				if (kc()) return Ui(M(), Ue(), void 0);
				break;
			case 100: return Us(M(), Ue(), void 0);
			case 86: return Fs(M(), Ue(), void 0);
			case 101: return Pu();
			case 92: return uc();
			case 117: return Nu();
			case 99: return pc();
			case 88: return fc(252);
			case 83: return fc(253);
			case 107: return dc();
			case 118: return Iu();
			case 109: return Lu();
			case 111: return yc();
			case 113:
			case 85:
			case 98: return Ju();
			case 89: return ju();
			case 60: return ji();
			case 134:
			case 120:
			case 156:
			case 144:
			case 145:
			case 138:
			case 87:
			case 94:
			case 95:
			case 102:
			case 123:
			case 124:
			case 125:
			case 128:
			case 129:
			case 126:
			case 148:
			case 162:
				if (Ji()) return ji();
				break;
		}
		return bc();
	}
	function Ec(o) {
		return o.kind === 138;
	}
	function ji() {
		let o = M(), p = Ue(), m = On(!0);
		if (Zt(m, Ec)) {
			let b = qu(o);
			if (b) return b;
			for (let N of m) N.flags |= 33554432;
			return Tt(33554432, () => Ac(o, p, m));
		} else return Ac(o, p, m);
	}
	function qu(o) {
		return Tt(33554432, () => {
			let p = pa(yt, o);
			if (p) return J_(p);
		});
	}
	function Ac(o, p, m) {
		switch (u()) {
			case 115:
			case 121:
			case 87:
			case 160:
			case 135: return Ui(o, p, m);
			case 100: return Us(o, p, m);
			case 86: return Fs(o, p, m);
			case 120: return ep(o, p, m);
			case 156: return tp(o, p, m);
			case 94: return np(o, p, m);
			case 162:
			case 144:
			case 145: return rp(o, p, m);
			case 102: return Bi(o, p, m);
			case 95: switch (B(), u()) {
				case 90:
				case 64: return Kc(o, p, m);
				case 130: return sp(o, p, m);
				default: return Qc(o, p, m);
			}
			default:
				if (m) {
					let g = Gt(283, !0, A.Declaration_expected);
					return Bp(g, o), g.modifiers = m, g;
				}
				return;
		}
	}
	function Cc() {
		return B() === 11;
	}
	function Dc() {
		return B(), u() === 161 || u() === 64;
	}
	function Fu() {
		return B(), !t.hasPrecedingLineBreak() && (ve() || u() === 11);
	}
	function Ri(o, p) {
		if (u() !== 19) {
			if (o & 4) {
				ya();
				return;
			}
			if (_r()) {
				Qt();
				return;
			}
		}
		return wa(o, p);
	}
	function zu() {
		let o = M();
		if (u() === 28) return P(y.createOmittedExpression(), o);
		let p = pt(26), m = si(), g = xr();
		return P(y.createBindingElement(p, void 0, m, g), o);
	}
	function Pc() {
		let o = M(), p = pt(26), m = qe(), g = jr(), b;
		m && u() !== 59 ? (b = g, g = void 0) : (J(59), b = si());
		let N = xr();
		return P(y.createBindingElement(p, g, b, N), o);
	}
	function Vu() {
		let o = M();
		J(19);
		let p = lt(() => un(9, Pc));
		return J(20), P(y.createObjectBindingPattern(p), o);
	}
	function Nc() {
		let o = M();
		J(23);
		let p = lt(() => un(10, zu));
		return J(24), P(y.createArrayBindingPattern(p), o);
	}
	function Rs() {
		return u() === 19 || u() === 23 || u() === 81 || qe();
	}
	function si(o) {
		return u() === 23 ? Nc() : u() === 19 ? Vu() : Ka(o);
	}
	function Wu() {
		return Ea(!0);
	}
	function Ea(o) {
		let p = M(), m = Ue(), g = si(A.Private_identifiers_are_not_allowed_in_variable_declarations), b;
		o && g.kind === 80 && u() === 54 && !t.hasPrecedingLineBreak() && (b = Wt());
		let N = vr(), Q = qo(u()) ? void 0 : xr();
		return Ce(P(Bn(g, b, N, Q), p), m);
	}
	function Ic(o) {
		let p = M(), m = 0;
		switch (u()) {
			case 115: break;
			case 121:
				m |= 1;
				break;
			case 87:
				m |= 2;
				break;
			case 160:
				m |= 4;
				break;
			case 135:
				q.assert(js()), m |= 6, B();
				break;
			default: q.fail();
		}
		B();
		let g;
		if (u() === 165 && H(Oc)) g = lr();
		else {
			let b = me();
			Te(o), g = un(8, o ? Ea : Wu), Te(b);
		}
		return P(Pn(g, m), p);
	}
	function Oc() {
		return Ci() && B() === 22;
	}
	function Ui(o, p, m) {
		let g = Ic(!1);
		Qt();
		return Ce(P(hn(m, g), o), p);
	}
	function Us(o, p, m) {
		let g = Ye(), b = Jn(m);
		J(100);
		let N = pt(42), Q = b & 2048 ? Li() : Ka(), _e = N ? 1 : 0, ee = b & 1024 ? 2 : 0, te = pn();
		b & 32 && st(!0);
		let ce = Xn(_e | ee), je = In(59, !1), Je = Ri(_e | ee, A.or_expected);
		st(g);
		return Ce(P(y.createFunctionDeclaration(m, N, Q, te, ce, je, Je), o), p);
	}
	function Gu() {
		if (u() === 137) return J(137);
		if (u() === 11 && H(B) === 21) return le(() => {
			let o = Hn();
			return o.text === "constructor" ? o : void 0;
		});
	}
	function Mc(o, p, m) {
		return le(() => {
			if (Gu()) {
				let g = pn(), b = Xn(0), N = In(59, !1), Q = Ri(0, A.or_expected), _e = y.createConstructorDeclaration(m, b, Q);
				return _e.typeParameters = g, _e.type = N, Ce(P(_e, o), p);
			}
		});
	}
	function Lc(o, p, m, g, b, N, Q, _e) {
		let ee = g ? 1 : 0, te = Zt(m, cl) ? 2 : 0, ce = pn(), je = Xn(ee | te), Je = In(59, !1), De = Ri(ee | te, _e), Ht = y.createMethodDeclaration(m, g, b, N, ce, je, Je, De);
		return Ht.exclamationToken = Q, Ce(P(Ht, o), p);
	}
	function Aa(o, p, m, g, b) {
		let N = !b && !t.hasPrecedingLineBreak() ? pt(54) : void 0, Q = vr(), _e = Ct(90112, xr);
		ql(g, Q, _e);
		return Ce(P(y.createPropertyDeclaration(m, g, b || N, Q, _e), o), p);
	}
	function Bs(o, p, m) {
		let g = pt(42), b = jr(), N = pt(58);
		return g || u() === 21 || u() === 30 ? Lc(o, p, m, g, b, N, void 0, A.or_expected) : Aa(o, p, m, b, N);
	}
	function _i(o, p, m, g, b) {
		let N = jr(), Q = pn(), _e = Xn(0), ee = In(59, !1), te = Ri(b), ce = g === 178 ? y.createGetAccessorDeclaration(m, N, _e, ee, te) : y.createSetAccessorDeclaration(m, N, _e, te);
		return ce.typeParameters = Q, y_(ce) && (ce.type = ee), Ce(P(ce, o), p);
	}
	function Jc() {
		let o;
		if (u() === 60) return !0;
		for (; Yr(u());) {
			if (o = u(), Ug(o)) return !0;
			B();
		}
		if (u() === 42 || (br() && (o = u(), B()), u() === 23)) return !0;
		if (o !== void 0) {
			if (!di(o) || o === 153 || o === 139) return !0;
			switch (u()) {
				case 21:
				case 30:
				case 54:
				case 59:
				case 64:
				case 58: return !0;
				default: return _r();
			}
		}
		return !1;
	}
	function Yu(o, p, m) {
		Yn(126);
		let g = Hu(), b = Ce(P(y.createClassStaticBlockDeclaration(g), o), p);
		return b.modifiers = m, b;
	}
	function Hu() {
		let o = we(), p = Ye();
		He(!1), st(!0);
		let m = Fr(!1);
		return He(o), st(p), m;
	}
	function jc() {
		if (Ye() && u() === 135) {
			let o = M(), p = gt(A.Expression_expected);
			B();
			return Ps(o, rn(o, p, !0));
		}
		return Oi();
	}
	function Rc() {
		let o = M();
		if (!Le(60)) return;
		let p = wi(jc);
		return P(y.createDecorator(p), o);
	}
	function qs(o, p, m) {
		let g = M(), b = u();
		if (u() === 87 && p) {
			if (!le(Za)) return;
		} else {
			if (m && u() === 126 && H(Da)) return;
			if (o && u() === 126) return;
			if (!N_()) return;
		}
		return P(he(b), g);
	}
	function On(o, p, m) {
		let g = M(), b, N, Q, _e = !1, ee = !1, te = !1;
		if (o && u() === 60) for (; N = Rc();) b = wn(b, N);
		for (; Q = qs(_e, p, m);) Q.kind === 126 && (_e = !0), b = wn(b, Q), ee = !0;
		if (ee && o && u() === 60) for (; N = Rc();) b = wn(b, N), te = !0;
		if (te) for (; Q = qs(_e, p, m);) Q.kind === 126 && (_e = !0), b = wn(b, Q);
		return b && At(b, g);
	}
	function Uc() {
		let o;
		if (u() === 134) {
			let p = M();
			B();
			o = At([P(he(134), p)], p);
		}
		return o;
	}
	function Bc() {
		let o = M(), p = Ue();
		if (u() === 27) return B(), Ce(P(y.createSemicolonClassElement(), o), p);
		let m = On(!0, !0, !0);
		if (u() === 126 && H(Da)) return Yu(o, p, m);
		if (ti(139)) return _i(o, p, m, 178, 0);
		if (ti(153)) return _i(o, p, m, 179, 0);
		if (u() === 137 || u() === 11) {
			let g = Mc(o, p, m);
			if (g) return g;
		}
		if (Br()) return ds(o, p, m);
		if (St(u()) || u() === 11 || u() === 9 || u() === 10 || u() === 42 || u() === 23) if (Zt(m, Ec)) {
			for (let b of m) b.flags |= 33554432;
			return Tt(33554432, () => Bs(o, p, m));
		} else return Bs(o, p, m);
		if (m) return Aa(o, p, m, Gt(80, !0, A.Declaration_expected), void 0);
		return q.fail("Should not have attempted to parse class member declaration.");
	}
	function Xu() {
		let o = M(), p = Ue(), m = On(!0);
		if (u() === 86) return zs(o, p, m, 232);
		let g = Gt(283, !0, A.Expression_expected);
		return Bp(g, o), g.modifiers = m, g;
	}
	function $u() {
		return zs(M(), Ue(), void 0, 232);
	}
	function Fs(o, p, m) {
		return zs(o, p, m, 264);
	}
	function zs(o, p, m, g) {
		let b = Ye();
		J(86);
		let N = Qu(), Q = pn();
		Zt(m, Ub) && st(!0);
		let _e = Fc(), ee;
		J(19) ? (ee = zc(), J(20)) : ee = lr(), st(b);
		return Ce(P(g === 264 ? y.createClassDeclaration(m, N, Q, _e, ee) : y.createClassExpression(m, N, Q, _e, ee), o), p);
	}
	function Qu() {
		return qe() && !qc() ? or(qe()) : void 0;
	}
	function qc() {
		return u() === 119 && H(Xl);
	}
	function Fc() {
		if (Vs()) return bn(22, Ku);
	}
	function Ku() {
		let o = M(), p = u();
		q.assert(p === 96 || p === 119), B();
		let m = un(7, Zu);
		return P(y.createHeritageClause(p, m), o);
	}
	function Zu() {
		let o = M(), p = Oi();
		if (p.kind === 234) return p;
		let m = Ca();
		return P(y.createExpressionWithTypeArguments(p, m), o);
	}
	function Ca() {
		return u() === 30 ? Rr(20, _t, 30, 32) : void 0;
	}
	function Vs() {
		return u() === 96 || u() === 119;
	}
	function zc() {
		return bn(5, Bc);
	}
	function ep(o, p, m) {
		J(120);
		let g = gt(), b = pn(), N = Fc(), Q = po();
		return Ce(P(y.createInterfaceDeclaration(m, g, b, N, Q), o), p);
	}
	function tp(o, p, m) {
		J(156), t.hasPrecedingLineBreak() && Ee(A.Line_break_not_permitted_here);
		let g = gt(), b = pn();
		J(64);
		let N = u() === 141 && le(bo) || _t();
		Qt();
		return Ce(P(y.createTypeAliasDeclaration(m, g, b, N), o), p);
	}
	function Ws() {
		let o = M(), p = Ue(), m = jr(), g = lt(xr);
		return Ce(P(y.createEnumMember(m, g), o), p);
	}
	function np(o, p, m) {
		J(94);
		let g = gt(), b;
		J(19) ? (b = xe(() => un(6, Ws)), J(20)) : b = lr();
		return Ce(P(y.createEnumDeclaration(m, g, b), o), p);
	}
	function Gs() {
		let o = M(), p;
		return J(19) ? (p = bn(1, Yt), J(20)) : p = lr(), P(y.createModuleBlock(p), o);
	}
	function Vc(o, p, m, g) {
		let b = g & 32, N = g & 8 ? jt() : gt(), Q = Le(25) ? Vc(M(), !1, void 0, 8 | b) : Gs();
		return Ce(P(y.createModuleDeclaration(m, N, Q, g), o), p);
	}
	function Wc(o, p, m) {
		let g = 0, b;
		u() === 162 ? (b = gt(), g |= 2048) : (b = Hn(), b.text = Jr(b.text));
		let N;
		u() === 19 ? N = Gs() : Qt();
		return Ce(P(y.createModuleDeclaration(m, b, N, g), o), p);
	}
	function rp(o, p, m) {
		let g = 0;
		if (u() === 162) return Wc(o, p, m);
		if (Le(145)) g |= 32;
		else if (J(144), u() === 11) return Wc(o, p, m);
		return Vc(o, p, m, g);
	}
	function ip() {
		return u() === 149 && H(Gc);
	}
	function Gc() {
		return B() === 21;
	}
	function Da() {
		return B() === 19;
	}
	function ap() {
		return B() === 44;
	}
	function sp(o, p, m) {
		J(130), J(145);
		let g = gt();
		Qt();
		let b = y.createNamespaceExportDeclaration(g);
		return b.modifiers = m, Ce(P(b, o), p);
	}
	function Bi(o, p, m) {
		J(102);
		let g = t.getTokenFullStart(), b;
		ve() && (b = gt());
		let N;
		if (b?.escapedText === "type" && (u() !== 161 || ve() && H(Dc)) && (ve() || zr()) ? (N = 156, b = ve() ? gt() : void 0) : b?.escapedText === "defer" && (u() === 161 ? !H(Cc) : u() !== 28 && u() !== 64) && (N = 166, b = ve() ? gt() : void 0), b && !op() && N !== 166) return cp(o, p, m, b, N === 156);
		let Q = Yc(b, g, N, void 0), _e = Fi(), ee = Hc();
		Qt();
		return Ce(P(y.createImportDeclaration(m, Q, _e, ee), o), p);
	}
	function Yc(o, p, m, g = !1) {
		let b;
		return (o || u() === 42 || u() === 19) && (b = lp(o, p, m, g), J(161)), b;
	}
	function Hc() {
		let o = u();
		if ((o === 118 || o === 132) && !t.hasPrecedingLineBreak()) return Ys(o);
	}
	function _p() {
		let o = M(), p = St(u()) ? jt() : ri(11);
		J(59);
		let m = zt(!0);
		return P(y.createImportAttribute(p, m), o);
	}
	function Ys(o, p) {
		let m = M();
		p || J(o);
		let g = t.getTokenStart();
		if (J(19)) {
			let b = t.hasPrecedingLineBreak(), N = un(24, _p, !0);
			if (!J(20)) {
				let Q = Ba(at);
				Q && Q.code === A._0_expected.code && sl(Q, Oa(Mt, $e, g, 1, A.The_parser_expected_to_find_a_1_to_match_the_0_token_here, "{", "}"));
			}
			return P(y.createImportAttributes(N, b, o), m);
		} else {
			let b = At([], M(), void 0, !1);
			return P(y.createImportAttributes(b, !1, o), m);
		}
	}
	function zr() {
		return u() === 42 || u() === 19;
	}
	function op() {
		return u() === 28 || u() === 161;
	}
	function cp(o, p, m, g, b) {
		J(64);
		let N = qi();
		Qt();
		return Ce(P(y.createImportEqualsDeclaration(m, b, g, N), o), p);
	}
	function lp(o, p, m, g) {
		let b;
		return (!o || Le(28)) && (g && t.setSkipJsDocLeadingAsterisks(!0), u() === 42 ? b = pp() : b = Xc(276), g && t.setSkipJsDocLeadingAsterisks(!1)), P(y.createImportClause(m, o, b), p);
	}
	function qi() {
		return ip() ? up() : Ur(!1);
	}
	function up() {
		let o = M();
		J(149), J(21);
		let p = Fi();
		return J(22), P(y.createExternalModuleReference(p), o);
	}
	function Fi() {
		if (u() === 11) {
			let o = Hn();
			return o.text = Jr(o.text), o;
		} else return kt();
	}
	function pp() {
		let o = M();
		J(42), J(130);
		let p = gt();
		return P(y.createNamespaceImport(p), o);
	}
	function Hs() {
		return St(u()) || u() === 11;
	}
	function oi(o) {
		return u() === 11 ? Hn() : o();
	}
	function Xc(o) {
		let p = M();
		return P(o === 276 ? y.createNamedImports(Rr(23, fp, 19, 20)) : y.createNamedExports(Rr(23, ci, 19, 20)), p);
	}
	function ci() {
		let o = Ue();
		return Ce($c(282), o);
	}
	function fp() {
		return $c(277);
	}
	function $c(o) {
		let p = M(), m = di(u()) && !ve(), g = t.getTokenStart(), b = t.getTokenEnd(), N = !1, Q, _e = !0, ee = oi(jt);
		if (ee.kind === 80 && ee.escapedText === "type") if (u() === 130) {
			let je = jt();
			if (u() === 130) {
				let Je = jt();
				Hs() ? (N = !0, Q = je, ee = oi(ce), _e = !1) : (Q = ee, ee = Je, _e = !1);
			} else Hs() ? (Q = ee, _e = !1, ee = oi(ce)) : (N = !0, ee = je);
		} else Hs() && (N = !0, ee = oi(ce));
		_e && u() === 130 && (Q = ee, J(130), ee = oi(ce)), o === 277 && (ee.kind !== 80 ? (rt(Cr($e, ee.pos), ee.end, A.Identifier_expected), ee = yi(Gt(80, !1), ee.pos, ee.pos)) : m && rt(g, b, A.Identifier_expected));
		return P(o === 277 ? y.createImportSpecifier(N, Q, ee) : y.createExportSpecifier(N, Q, ee), p);
		function ce() {
			return m = di(u()) && !ve(), g = t.getTokenStart(), b = t.getTokenEnd(), jt();
		}
	}
	function dp(o) {
		return P(y.createNamespaceExport(oi(jt)), o);
	}
	function Qc(o, p, m) {
		let g = Ye();
		st(!0);
		let b, N, Q, _e = Le(156), ee = M();
		Le(42) ? (Le(130) && (b = dp(ee)), J(161), N = Fi()) : (b = Xc(280), (u() === 161 || u() === 11 && !t.hasPrecedingLineBreak()) && (J(161), N = Fi()));
		let te = u();
		N && (te === 118 || te === 132) && !t.hasPrecedingLineBreak() && (Q = Ys(te)), Qt(), st(g);
		return Ce(P(y.createExportDeclaration(m, _e, b, N, Q), o), p);
	}
	function Kc(o, p, m) {
		let g = Ye();
		st(!0);
		let b;
		Le(64) ? b = !0 : J(90);
		let N = zt(!0);
		Qt(), st(g);
		return Ce(P(y.createExportAssignment(m, b, N), o), p);
	}
	let Xs;
	((o) => {
		o[o.SourceElements = 0] = "SourceElements", o[o.BlockStatements = 1] = "BlockStatements", o[o.SwitchClauses = 2] = "SwitchClauses", o[o.SwitchClauseStatements = 3] = "SwitchClauseStatements", o[o.TypeMembers = 4] = "TypeMembers", o[o.ClassMembers = 5] = "ClassMembers", o[o.EnumMembers = 6] = "EnumMembers", o[o.HeritageClauseElement = 7] = "HeritageClauseElement", o[o.VariableDeclarations = 8] = "VariableDeclarations", o[o.ObjectBindingElements = 9] = "ObjectBindingElements", o[o.ArrayBindingElements = 10] = "ArrayBindingElements", o[o.ArgumentExpressions = 11] = "ArgumentExpressions", o[o.ObjectLiteralMembers = 12] = "ObjectLiteralMembers", o[o.JsxAttributes = 13] = "JsxAttributes", o[o.JsxChildren = 14] = "JsxChildren", o[o.ArrayLiteralMembers = 15] = "ArrayLiteralMembers", o[o.Parameters = 16] = "Parameters", o[o.JSDocParameters = 17] = "JSDocParameters", o[o.RestProperties = 18] = "RestProperties", o[o.TypeParameters = 19] = "TypeParameters", o[o.TypeArguments = 20] = "TypeArguments", o[o.TupleElementTypes = 21] = "TupleElementTypes", o[o.HeritageClauses = 22] = "HeritageClauses", o[o.ImportOrExportSpecifiers = 23] = "ImportOrExportSpecifiers", o[o.ImportAttributes = 24] = "ImportAttributes", o[o.JSDocComment = 25] = "JSDocComment", o[o.Count = 26] = "Count";
	})(Xs || (Xs = {}));
	let Zc;
	((o) => {
		o[o.False = 0] = "False", o[o.True = 1] = "True", o[o.Unknown = 2] = "Unknown";
	})(Zc || (Zc = {}));
	let el;
	((o) => {
		function p(te, ce, je) {
			Fn("file.js", te, 99, void 0, 1, 0), t.setText(te, ce, je), ct = t.scan();
			let Je = m(), De = se("file.js", 99, 1, !1, [], he(1), 0, Va), Ht = Yi(at, De);
			return Bt && (De.jsDocDiagnostics = Yi(Bt, De)), zn(), Je ? {
				jsDocTypeExpression: Je,
				diagnostics: Ht
			} : void 0;
		}
		o.parseJSDocTypeExpressionForTests = p;
		function m(te) {
			let ce = M(), je = (te ? Le : J)(19), Je = Tt(16777216, ls);
			(!te || je) && C_(20);
			let De = y.createJSDocTypeExpression(Je);
			return L(De), P(De, ce);
		}
		o.parseJSDocTypeExpression = m;
		function g() {
			let te = M(), ce = Le(19), je = M(), Je = Ur(!1);
			for (; u() === 81;) Pt(), Be(), Je = P(y.createJSDocMemberName(Je, gt()), je);
			ce && C_(20);
			let De = y.createJSDocNameReference(Je);
			return L(De), P(De, te);
		}
		o.parseJSDocNameReference = g;
		function b(te, ce, je) {
			Fn("", te, 99, void 0, 1, 0);
			let Je = Tt(16777216, () => ee(ce, je)), Ht = Yi(at, {
				languageVariant: 0,
				text: te
			});
			return zn(), Je ? {
				jsDoc: Je,
				diagnostics: Ht
			} : void 0;
		}
		o.parseIsolatedJSDocComment = b;
		function N(te, ce, je) {
			let Je = ct, De = at.length, Ht = tn, Nt = Tt(16777216, () => ee(ce, je));
			return Sf(Nt, te), tt & 524288 && (Bt || (Bt = []), En(Bt, at, De)), ct = Je, at.length = De, tn = Ht, Nt;
		}
		o.parseJSDocComment = N;
		let Q;
		((te) => {
			te[te.BeginningOfLine = 0] = "BeginningOfLine", te[te.SawAsterisk = 1] = "SawAsterisk", te[te.SavingComments = 2] = "SavingComments", te[te.SavingBackticks = 3] = "SavingBackticks";
		})(Q || (Q = {}));
		let _e;
		((te) => {
			te[te.Property = 1] = "Property", te[te.Parameter = 2] = "Parameter", te[te.CallbackParameter = 4] = "CallbackParameter";
		})(_e || (_e = {}));
		function ee(te = 0, ce) {
			let je = $e, Je = ce === void 0 ? je.length : te + ce;
			if (ce = Je - te, q.assert(te >= 0), q.assert(te <= Je), q.assert(Je <= je.length), !E6(je, te)) return;
			let De, Ht, Nt, ur, pr, Mn = [], Vr = [], Pe = yt;
			yt |= 1 << 25;
			let et = t.scanRange(te + 3, ce - 5, wr);
			return yt = Pe, et;
			function wr() {
				let I = 1, X, $ = te - (je.lastIndexOf(`
`, te) + 1) + 4;
				function ne(Re) {
					X || (X = $), Mn.push(Re), $ += Re.length;
				}
				for (Be(); Gi(5););
				Gi(4) && (I = 0, $ = 0);
				e: for (;;) {
					switch (u()) {
						case 60:
							mp(Mn), pr || (pr = M()), Fe(n($)), I = 0, X = void 0;
							break;
						case 4:
							Mn.push(t.getTokenText()), I = 0, $ = 0;
							break;
						case 42:
							let Re = t.getTokenText();
							I === 1 ? (I = 2, ne(Re)) : (q.assert(I === 0), I = 1, $ += Re.length);
							break;
						case 5:
							q.assert(I !== 2, "whitespace shouldn't come from the scanner while saving top-level comment text");
							let ut = t.getTokenText();
							X !== void 0 && $ + ut.length > X && Mn.push(ut.slice(X - $)), $ += ut.length;
							break;
						case 1: break e;
						case 82:
							I = 2, ne(t.getTokenValue());
							break;
						case 19:
							I = 2;
							let fn = t.getTokenFullStart(), Kt = l(t.getTokenEnd() - 1);
							if (Kt) {
								ur || zi(Mn), Vr.push(P(y.createJSDocText(Mn.join("")), ur ?? te, fn)), Vr.push(Kt), Mn = [], ur = t.getTokenEnd();
								break;
							}
						default:
							I = 2, ne(t.getTokenText());
							break;
					}
					I === 2 ? nn(!1) : Be();
				}
				let re = Mn.join("").trimEnd();
				Vr.length && re.length && Vr.push(P(y.createJSDocText(re), ur ?? te, pr)), Vr.length && De && q.assertIsDefined(pr, "having parsed tags implies that the end of the comment span should be set");
				let Ne = De && At(De, Ht, Nt);
				return P(y.createJSDocComment(Vr.length ? At(Vr, te, pr) : re.length ? re : void 0, Ne), te, Je);
			}
			function zi(I) {
				for (; I.length && (I[0] === `
` || I[0] === "\r");) I.shift();
			}
			function mp(I) {
				for (; I.length;) {
					let X = I[I.length - 1].trimEnd();
					if (X === "") I.pop();
					else if (X.length < I[I.length - 1].length) {
						I[I.length - 1] = X;
						break;
					} else break;
				}
			}
			function $n() {
				for (;;) {
					if (Be(), u() === 1) return !0;
					if (!(u() === 5 || u() === 4)) return !1;
				}
			}
			function Tn() {
				if (!((u() === 5 || u() === 4) && H($n))) for (; u() === 5 || u() === 4;) Be();
			}
			function j() {
				if ((u() === 5 || u() === 4) && H($n)) return "";
				let I = t.hasPrecedingLineBreak(), X = !1, $ = "";
				for (; I && u() === 42 || u() === 5 || u() === 4;) $ += t.getTokenText(), u() === 4 ? (I = !0, X = !0, $ = "") : u() === 42 && (I = !1), Be();
				return X ? $ : "";
			}
			function n(I) {
				q.assert(u() === 60);
				let X = t.getTokenStart();
				Be();
				let $ = li(void 0), ne = j(), re;
				switch ($.escapedText) {
					case "author":
						re = j0(X, $, I, ne);
						break;
					case "implements":
						re = U0(X, $, I, ne);
						break;
					case "augments":
					case "extends":
						re = B0(X, $, I, ne);
						break;
					case "class":
					case "constructor":
						re = Wi(X, y.createJSDocClassTag, $, I, ne);
						break;
					case "public":
						re = Wi(X, y.createJSDocPublicTag, $, I, ne);
						break;
					case "private":
						re = Wi(X, y.createJSDocPrivateTag, $, I, ne);
						break;
					case "protected":
						re = Wi(X, y.createJSDocProtectedTag, $, I, ne);
						break;
					case "readonly":
						re = Wi(X, y.createJSDocReadonlyTag, $, I, ne);
						break;
					case "override":
						re = Wi(X, y.createJSDocOverrideTag, $, I, ne);
						break;
					case "deprecated":
						Vn = !0, re = Wi(X, y.createJSDocDeprecatedTag, $, I, ne);
						break;
					case "this":
						re = fd(X, $, I, ne);
						break;
					case "enum":
						re = V0(X, $, I, ne);
						break;
					case "arg":
					case "argument":
					case "param": return Vi(X, $, 2, I);
					case "return":
					case "returns":
						re = M0(X, $, I, ne);
						break;
					case "template":
						re = md(X, $, I, ne);
						break;
					case "type":
						re = ud(X, $, I, ne);
						break;
					case "typedef":
						re = W0(X, $, I, ne);
						break;
					case "callback":
						re = Y0(X, $, I, ne);
						break;
					case "overload":
						re = H0(X, $, I, ne);
						break;
					case "satisfies":
						re = q0(X, $, I, ne);
						break;
					case "see":
						re = L0(X, $, I, ne);
						break;
					case "exception":
					case "throws":
						re = J0(X, $, I, ne);
						break;
					case "import":
						re = F0(X, $, I, ne);
						break;
					default:
						re = pe(X, $, I, ne);
						break;
				}
				return re;
			}
			function i(I, X, $, ne) {
				return ne || ($ += X - I), s($, ne.slice($));
			}
			function s(I, X) {
				let $ = M(), ne = [], re = [], Ne, Re = 0, ut;
				function fn(Qn) {
					ut || (ut = I), ne.push(Qn), I += Qn.length;
				}
				X !== void 0 && (X !== "" && fn(X), Re = 1);
				let an = u();
				e: for (;;) {
					switch (an) {
						case 4:
							Re = 0, ne.push(t.getTokenText()), I = 0;
							break;
						case 60:
							t.resetTokenState(t.getTokenEnd() - 1);
							break e;
						case 1: break e;
						case 5:
							q.assert(Re !== 2 && Re !== 3, "whitespace shouldn't come from the scanner while saving comment text");
							let Qn = t.getTokenText();
							ut !== void 0 && I + Qn.length > ut && (ne.push(Qn.slice(ut - I)), Re = 2), I += Qn.length;
							break;
						case 19:
							Re = 2;
							let tl = t.getTokenFullStart(), nl = l(t.getTokenEnd() - 1);
							nl ? (re.push(P(y.createJSDocText(ne.join("")), Ne ?? $, tl)), re.push(nl), ne = [], Ne = t.getTokenEnd()) : fn(t.getTokenText());
							break;
						case 62:
							Re === 3 ? Re = 2 : Re = 3, fn(t.getTokenText());
							break;
						case 82:
							Re !== 3 && (Re = 2), fn(t.getTokenValue());
							break;
						case 42: if (Re === 0) {
							Re = 1, I += 1;
							break;
						}
						default:
							Re !== 3 && (Re = 2), fn(t.getTokenText());
							break;
					}
					Re === 2 || Re === 3 ? an = nn(Re === 3) : an = Be();
				}
				zi(ne);
				let Kt = ne.join("").trimEnd();
				if (re.length) return Kt.length && re.push(P(y.createJSDocText(Kt), Ne ?? $)), At(re, $, t.getTokenEnd());
				if (Kt.length) return Kt;
			}
			function l(I) {
				let X = le(v);
				if (!X) return;
				Be(), Tn();
				let $ = d(), ne = [];
				for (; u() !== 20 && u() !== 4 && u() !== 1;) ne.push(t.getTokenText()), Be();
				return P((X === "link" ? y.createJSDocLink : X === "linkcode" ? y.createJSDocLinkCode : y.createJSDocLinkPlain)($, ne.join("")), I, t.getTokenEnd());
			}
			function d() {
				if (St(u())) {
					let I = M(), X = jt();
					for (; Le(25);) X = P(y.createQualifiedName(X, u() === 81 ? Gt(80, !1) : jt()), I);
					for (; u() === 81;) Pt(), Be(), X = P(y.createJSDocMemberName(X, gt()), I);
					return X;
				}
			}
			function v() {
				if (j(), u() === 19 && Be() === 60 && St(Be())) {
					let I = t.getTokenValue();
					if (F(I)) return I;
				}
			}
			function F(I) {
				return I === "link" || I === "linkcode" || I === "linkplain";
			}
			function pe(I, X, $, ne) {
				return P(y.createJSDocUnknownTag(X, i(I, M(), $, ne)), I);
			}
			function Fe(I) {
				I && (De ? De.push(I) : (De = [I], Ht = I.pos), Nt = I.end);
			}
			function It() {
				return j(), u() === 19 ? m() : void 0;
			}
			function fr() {
				let I = Gi(23);
				I && Tn();
				let X = Gi(62), $ = ey();
				return X && zl(62), I && (Tn(), pt(64) && kt(), J(24)), {
					name: $,
					isBracketed: I
				};
			}
			function xn(I) {
				switch (I.kind) {
					case 151: return !0;
					case 189: return xn(I.elementType);
					default: return Df(I) && Ke(I.typeName) && I.typeName.escapedText === "Object" && !I.typeArguments;
				}
			}
			function Vi(I, X, $, ne) {
				let re = It(), Ne = !re;
				j();
				let { name: Re, isBracketed: ut } = fr(), fn = j();
				Ne && !H(v) && (re = It());
				let an = i(I, M(), ne, fn), Kt = O0(re, Re, $, ne);
				Kt && (re = Kt, Ne = !0);
				return P($ === 1 ? y.createJSDocPropertyTag(X, Re, ut, re, Ne, an) : y.createJSDocParameterTag(X, Re, ut, re, Ne, an), I);
			}
			function O0(I, X, $, ne) {
				if (I && xn(I.type)) {
					let re = M(), Ne, Re;
					for (; Ne = le(() => yp($, ne, X));) Ne.kind === 342 || Ne.kind === 349 ? Re = wn(Re, Ne) : Ne.kind === 346 && on(Ne.tagName, A.A_JSDoc_template_tag_may_not_follow_a_typedef_callback_or_overload_tag);
					if (Re) {
						let ut = P(y.createJSDocTypeLiteral(Re, I.type.kind === 189), re);
						return P(y.createJSDocTypeExpression(ut), re);
					}
				}
			}
			function M0(I, X, $, ne) {
				Zt(De, f6) && rt(X.pos, t.getTokenStart(), A._0_tag_already_specified, l_(X.escapedText));
				let re = It();
				return P(y.createJSDocReturnTag(X, re, i(I, M(), $, ne)), I);
			}
			function ud(I, X, $, ne) {
				Zt(De, zf) && rt(X.pos, t.getTokenStart(), A._0_tag_already_specified, l_(X.escapedText));
				let re = m(!0), Ne = $ !== void 0 && ne !== void 0 ? i(I, M(), $, ne) : void 0;
				return P(y.createJSDocTypeTag(X, re, Ne), I);
			}
			function L0(I, X, $, ne) {
				let Ne = u() === 23 || H(() => Be() === 60 && St(Be()) && F(t.getTokenValue())) ? void 0 : g(), Re = $ !== void 0 && ne !== void 0 ? i(I, M(), $, ne) : void 0;
				return P(y.createJSDocSeeTag(X, Ne, Re), I);
			}
			function J0(I, X, $, ne) {
				let re = It(), Ne = i(I, M(), $, ne);
				return P(y.createJSDocThrowsTag(X, re, Ne), I);
			}
			function j0(I, X, $, ne) {
				let re = M(), Ne = R0(), Re = t.getTokenFullStart(), ut = i(I, Re, $, ne);
				ut || (Re = t.getTokenFullStart());
				let fn = typeof ut != "string" ? At(Yp([P(Ne, re, Re)], ut), re) : Ne.text + ut;
				return P(y.createJSDocAuthorTag(X, fn), I);
			}
			function R0() {
				let I = [], X = !1, $ = t.getToken();
				for (; $ !== 1 && $ !== 4;) {
					if ($ === 30) X = !0;
					else {
						if ($ === 60 && !X) break;
						if ($ === 32 && X) {
							I.push(t.getTokenText()), t.resetTokenState(t.getTokenEnd());
							break;
						}
					}
					I.push(t.getTokenText()), $ = Be();
				}
				return y.createJSDocText(I.join(""));
			}
			function U0(I, X, $, ne) {
				let re = pd();
				return P(y.createJSDocImplementsTag(X, re, i(I, M(), $, ne)), I);
			}
			function B0(I, X, $, ne) {
				let re = pd();
				return P(y.createJSDocAugmentsTag(X, re, i(I, M(), $, ne)), I);
			}
			function q0(I, X, $, ne) {
				let re = m(!1), Ne = $ !== void 0 && ne !== void 0 ? i(I, M(), $, ne) : void 0;
				return P(y.createJSDocSatisfiesTag(X, re, Ne), I);
			}
			function F0(I, X, $, ne) {
				let re = t.getTokenFullStart(), Ne;
				ve() && (Ne = gt());
				let Re = Yc(Ne, re, 156, !0), ut = Fi(), fn = Hc(), an = $ !== void 0 && ne !== void 0 ? i(I, M(), $, ne) : void 0;
				return P(y.createJSDocImportTag(X, Re, ut, fn, an), I);
			}
			function pd() {
				let I = Le(19), X = M(), $ = z0();
				t.setSkipJsDocLeadingAsterisks(!0);
				let ne = Ca();
				t.setSkipJsDocLeadingAsterisks(!1);
				let Ne = P(y.createExpressionWithTypeArguments($, ne), X);
				return I && (Tn(), J(20)), Ne;
			}
			function z0() {
				let I = M(), X = li();
				for (; Le(25);) {
					let $ = li();
					X = P(ae(X, $), I);
				}
				return X;
			}
			function Wi(I, X, $, ne, re) {
				return P(X($, i(I, M(), ne, re)), I);
			}
			function fd(I, X, $, ne) {
				let re = m(!0);
				return Tn(), P(y.createJSDocThisTag(X, re, i(I, M(), $, ne)), I);
			}
			function V0(I, X, $, ne) {
				let re = m(!0);
				return Tn(), P(y.createJSDocEnumTag(X, re, i(I, M(), $, ne)), I);
			}
			function W0(I, X, $, ne) {
				let re = It();
				j();
				let Ne = hp();
				Tn();
				let Re = s($), ut;
				if (!re || xn(re.type)) {
					let an, Kt, Qn, tl = !1;
					for (; (an = le(() => $0($))) && an.kind !== 346;) if (tl = !0, an.kind === 345) if (Kt) {
						let Pa = Ee(A.A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags);
						Pa && sl(Pa, Oa(Mt, $e, 0, 0, A.The_tag_was_first_specified_here));
						break;
					} else Kt = an;
					else Qn = wn(Qn, an);
					if (tl) {
						let Pa = re && re.type.kind === 189, nl = y.createJSDocTypeLiteral(Qn, Pa);
						re = Kt && Kt.typeExpression && !xn(Kt.typeExpression.type) ? Kt.typeExpression : P(nl, I), ut = re.end;
					}
				}
				ut = ut || Re !== void 0 ? M() : (Ne ?? re ?? X).end, Re || (Re = i(I, ut, $, ne));
				return P(y.createJSDocTypedefTag(X, re, Ne, Re), I, ut);
			}
			function hp(I) {
				let X = t.getTokenStart();
				if (!St(u())) return;
				let $ = li();
				if (Le(25)) {
					let ne = hp(!0);
					return P(y.createModuleDeclaration(void 0, $, ne, I ? 8 : void 0), X);
				}
				return I && ($.flags |= 4096), $;
			}
			function G0(I) {
				let X = M(), $, ne;
				for (; $ = le(() => yp(4, I));) {
					if ($.kind === 346) {
						on($.tagName, A.A_JSDoc_template_tag_may_not_follow_a_typedef_callback_or_overload_tag);
						break;
					}
					ne = wn(ne, $);
				}
				return At(ne || [], X);
			}
			function dd(I, X) {
				let $ = G0(X), ne = le(() => {
					if (Gi(60)) {
						let re = n(X);
						if (re && re.kind === 343) return re;
					}
				});
				return P(y.createJSDocSignature(void 0, $, ne), I);
			}
			function Y0(I, X, $, ne) {
				let re = hp();
				Tn();
				let Ne = s($), Re = dd(I, $);
				Ne || (Ne = i(I, M(), $, ne));
				let ut = Ne !== void 0 ? M() : Re.end;
				return P(y.createJSDocCallbackTag(X, Re, re, Ne), I, ut);
			}
			function H0(I, X, $, ne) {
				Tn();
				let re = s($), Ne = dd(I, $);
				re || (re = i(I, M(), $, ne));
				let Re = re !== void 0 ? M() : Ne.end;
				return P(y.createJSDocOverloadTag(X, Ne, re), I, Re);
			}
			function X0(I, X) {
				for (; !Ke(I) || !Ke(X);) if (!Ke(I) && !Ke(X) && I.right.escapedText === X.right.escapedText) I = I.left, X = X.left;
				else return !1;
				return I.escapedText === X.escapedText;
			}
			function $0(I) {
				return yp(1, I);
			}
			function yp(I, X, $) {
				let ne = !0, re = !1;
				for (;;) switch (Be()) {
					case 60:
						if (ne) {
							let Ne = Q0(I, X);
							return Ne && (Ne.kind === 342 || Ne.kind === 349) && $ && (Ke(Ne.name) || !X0($, Ne.name.left)) ? !1 : Ne;
						}
						re = !1;
						break;
					case 4:
						ne = !0, re = !1;
						break;
					case 42:
						re && (ne = !1), re = !0;
						break;
					case 80:
						ne = !1;
						break;
					case 1: return !1;
				}
			}
			function Q0(I, X) {
				q.assert(u() === 60);
				let $ = t.getTokenFullStart();
				Be();
				let ne = li(), re = j(), Ne;
				switch (ne.escapedText) {
					case "type": return I === 1 && ud($, ne);
					case "prop":
					case "property":
						Ne = 1;
						break;
					case "arg":
					case "argument":
					case "param":
						Ne = 6;
						break;
					case "template": return md($, ne, X, re);
					case "this": return fd($, ne, X, re);
					default: return !1;
				}
				return I & Ne ? Vi($, ne, I, X) : !1;
			}
			function K0() {
				let I = M(), X = Gi(23);
				X && Tn();
				let $ = On(!1, !0), ne = li(A.Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces), re;
				if (X && (Tn(), J(64), re = Tt(16777216, ls), J(24)), !Zi(ne)) return P(y.createTypeParameterDeclaration($, ne, void 0, re), I);
			}
			function Z0() {
				let I = M(), X = [];
				do {
					Tn();
					let $ = K0();
					$ !== void 0 && X.push($), j();
				} while (Gi(28));
				return At(X, I);
			}
			function md(I, X, $, ne) {
				let re = u() === 19 ? m() : void 0, Ne = Z0();
				return P(y.createJSDocTemplateTag(X, re, Ne, i(I, M(), $, ne)), I);
			}
			function Gi(I) {
				return u() === I ? (Be(), !0) : !1;
			}
			function ey() {
				let I = li();
				for (Le(23) && J(24); Le(25);) {
					let X = li();
					Le(23) && J(24), I = $l(I, X);
				}
				return I;
			}
			function li(I) {
				if (!St(u())) return Gt(80, !I, I || A.Identifier_expected);
				yn++;
				let X = t.getTokenStart(), $ = t.getTokenEnd(), ne = u(), Ne = P(ue(Jr(t.getTokenValue()), ne), X, $);
				return Be(), Ne;
			}
		}
	})(el = e.JSDocParser || (e.JSDocParser = {}));
})(ta || (ta = {}));
var hm = /* @__PURE__ */ new WeakSet();
function J6(e) {
	hm.has(e) && q.fail("Source file has already been incrementally parsed"), hm.add(e);
}
var ph = /* @__PURE__ */ new WeakSet();
function j6(e) {
	return ph.has(e);
}
function Wp(e) {
	ph.add(e);
}
var Sl;
((e) => {
	function t(D, R, ue, be) {
		if (be = be || q.shouldAssert(2), y(D, R, ue, be), dg(ue)) return D;
		if (D.statements.length === 0) return ta.parseSourceFile(D.fileName, R, D.languageVersion, void 0, !0, D.scriptKind, D.setExternalModuleIndicator, D.jsDocParsingMode);
		J6(D), ta.fixupParentReferences(D);
		let he = D.text, de = G(D), O = c(D, ue);
		y(D, R, O, be), q.assert(O.span.start <= ue.span.start), q.assert(kr(O.span) === kr(ue.span)), q.assert(kr(Qs(O)) === kr(Qs(ue)));
		let ae = Qs(O).length - O.span.length;
		k(D, O.span.start, kr(O.span), kr(Qs(O)), ae, he, R, be);
		let Oe = ta.parseSourceFile(D.fileName, R, D.languageVersion, de, !0, D.scriptKind, D.setExternalModuleIndicator, D.jsDocParsingMode);
		return Oe.commentDirectives = a(D.commentDirectives, Oe.commentDirectives, O.span.start, kr(O.span), ae, he, R, be), Oe.impliedNodeFormat = D.impliedNodeFormat, y6(D, Oe), Oe;
	}
	e.updateSourceFile = t;
	function a(D, R, ue, be, he, de, O, ae) {
		if (!D) return R;
		let Oe, V = !1;
		for (let Y of D) {
			let { range: ft, type: nr } = Y;
			if (ft.end < ue) Oe = wn(Oe, Y);
			else if (ft.pos > be) {
				oe();
				let mn = {
					range: {
						pos: ft.pos + he,
						end: ft.end + he
					},
					type: nr
				};
				Oe = wn(Oe, mn), ae && q.assert(de.substring(ft.pos, ft.end) === O.substring(mn.range.pos, mn.range.end));
			}
		}
		return oe(), Oe;
		function oe() {
			V || (V = !0, Oe ? R && Oe.push(...R) : Oe = R);
		}
	}
	function _(D, R, ue, be, he, de, O) {
		ue ? Oe(D) : ae(D);
		return;
		function ae(V) {
			let oe = "";
			if (O && f(V) && (oe = he.substring(V.pos, V.end)), Gd(V, R), yi(V, V.pos + be, V.end + be), O && f(V) && q.assert(oe === de.substring(V.pos, V.end)), Xt(V, ae, Oe), Ki(V)) for (let Y of V.jsDoc) ae(Y);
			T(V, O);
		}
		function Oe(V) {
			yi(V, V.pos + be, V.end + be);
			for (let oe of V) ae(oe);
		}
	}
	function f(D) {
		switch (D.kind) {
			case 11:
			case 9:
			case 80: return !0;
		}
		return !1;
	}
	function h(D, R, ue, be, he) {
		q.assert(D.end >= R, "Adjusting an element that was entirely before the change range"), q.assert(D.pos <= ue, "Adjusting an element that was entirely after the change range"), q.assert(D.pos <= D.end);
		let de = Math.min(D.pos, be), O = D.end >= ue ? D.end + he : Math.min(D.end, be);
		if (q.assert(de <= O), D.parent) {
			let ae = D.parent;
			q.assertGreaterThanOrEqual(de, ae.pos), q.assertLessThanOrEqual(O, ae.end);
		}
		yi(D, de, O);
	}
	function T(D, R) {
		if (R) {
			let ue = D.pos, be = (he) => {
				q.assert(he.pos >= ue), ue = he.end;
			};
			if (Ki(D)) for (let he of D.jsDoc) be(he);
			Xt(D, be), q.assert(ue <= D.end);
		}
	}
	function k(D, R, ue, be, he, de, O, ae) {
		Oe(D);
		return;
		function Oe(oe) {
			if (q.assert(oe.pos <= oe.end), oe.pos > ue) {
				_(oe, D, !1, he, de, O, ae);
				return;
			}
			let Y = oe.end;
			if (Y >= R) {
				if (Wp(oe), Gd(oe, D), h(oe, R, ue, be, he), Xt(oe, Oe, V), Ki(oe)) for (let ft of oe.jsDoc) Oe(ft);
				T(oe, ae);
				return;
			}
			q.assert(Y < R);
		}
		function V(oe) {
			if (q.assert(oe.pos <= oe.end), oe.pos > ue) {
				_(oe, D, !0, he, de, O, ae);
				return;
			}
			let Y = oe.end;
			if (Y >= R) {
				Wp(oe), h(oe, R, ue, be, he);
				for (let ft of oe) Oe(ft);
				return;
			}
			q.assert(Y < R);
		}
	}
	function c(D, R) {
		let be = R.span.start;
		for (let O = 0; be > 0 && O <= 1; O++) {
			let ae = W(D, be);
			q.assert(ae.pos <= be);
			let Oe = ae.pos;
			be = Math.max(0, Oe - 1);
		}
		return Ym(fg(be, kr(R.span)), R.newLength + (R.span.start - be));
	}
	function W(D, R) {
		let ue = D, be;
		if (Xt(D, de), be) {
			let O = he(be);
			O.pos > ue.pos && (ue = O);
		}
		return ue;
		function he(O) {
			for (;;) {
				let ae = K2(O);
				if (ae) O = ae;
				else return O;
			}
		}
		function de(O) {
			if (!Zi(O)) if (O.pos <= R) {
				if (O.pos >= ue.pos && (ue = O), R < O.end) return Xt(O, de), !0;
				q.assert(O.end <= R), be = O;
			} else return q.assert(O.pos > R), !0;
		}
	}
	function y(D, R, ue, be) {
		let he = D.text;
		if (ue && (q.assert(he.length - ue.span.length + ue.newLength === R.length), be || q.shouldAssert(3))) {
			let de = he.substr(0, ue.span.start), O = R.substr(0, ue.span.start);
			q.assert(de === O);
			let ae = he.substring(kr(ue.span), he.length), Oe = R.substring(kr(Qs(ue)), R.length);
			q.assert(ae === Oe);
		}
	}
	function G(D) {
		let R = D.statements, ue = 0;
		q.assert(ue < R.length);
		let be = R[ue], he = -1;
		return { currentNode(O) {
			return O !== he && (be && be.end === O && ue < R.length - 1 && (ue++, be = R[ue]), (!be || be.pos !== O) && de(O)), he = O, q.assert(!be || be.pos === O), be;
		} };
		function de(O) {
			R = void 0, ue = -1, be = void 0, Xt(D, ae, Oe);
			return;
			function ae(V) {
				return O >= V.pos && O < V.end ? (Xt(V, ae, Oe), !0) : !1;
			}
			function Oe(V) {
				if (O >= V.pos && O < V.end) for (let oe = 0; oe < V.length; oe++) {
					let Y = V[oe];
					if (Y) {
						if (Y.pos === O) return R = V, ue = oe, be = Y, !0;
						if (Y.pos < O && O < Y.end) return Xt(Y, ae, Oe), !0;
					}
				}
				return !1;
			}
		}
	}
	e.createSyntaxCursor = G;
	let E;
	((D) => {
		D[D.Value = -1] = "Value";
	})(E || (E = {}));
})(Sl || (Sl = {}));
function R6(e) {
	return U6(e) !== void 0;
}
function U6(e) {
	let t = Im(e, bb, !1);
	if (t) return t;
	if (jy(e, ".ts")) {
		let a = Nm(e), _ = a.lastIndexOf(".d.");
		if (_ >= 0) return a.substring(_);
	}
}
function B6(e, t, a, _) {
	if (e) {
		if (e === "import") return 99;
		if (e === "require") return 1;
		_(t, a - t, A.resolution_mode_should_be_either_require_or_import);
	}
}
function q6(e, t) {
	let a = [];
	for (let _ of Lp(t, 0) || vt) G6(a, _, t.substring(_.pos, _.end));
	e.pragmas = /* @__PURE__ */ new Map();
	for (let _ of a) {
		if (e.pragmas.has(_.name)) {
			let f = e.pragmas.get(_.name);
			f instanceof Array ? f.push(_.args) : e.pragmas.set(_.name, [f, _.args]);
			continue;
		}
		e.pragmas.set(_.name, _.args);
	}
}
function F6(e, t) {
	e.checkJsDirective = void 0, e.referencedFiles = [], e.typeReferenceDirectives = [], e.libReferenceDirectives = [], e.amdDependencies = [], e.hasNoDefaultLib = !1, e.pragmas.forEach((a, _) => {
		switch (_) {
			case "reference": {
				let f = e.referencedFiles, h = e.typeReferenceDirectives, T = e.libReferenceDirectives;
				jn(bp(a), (k) => {
					let { types: c, lib: W, path: y, ["resolution-mode"]: G, preserve: E } = k.arguments, D = E === "true" ? !0 : void 0;
					if (k.arguments["no-default-lib"] === "true") e.hasNoDefaultLib = !0;
					else if (c) {
						let R = B6(G, c.pos, c.end, t);
						h.push({
							pos: c.pos,
							end: c.end,
							fileName: c.value,
							...R ? { resolutionMode: R } : {},
							...D ? { preserve: D } : {}
						});
					} else W ? T.push({
						pos: W.pos,
						end: W.end,
						fileName: W.value,
						...D ? { preserve: D } : {}
					}) : y ? f.push({
						pos: y.pos,
						end: y.end,
						fileName: y.value,
						...D ? { preserve: D } : {}
					}) : t(k.range.pos, k.range.end - k.range.pos, A.Invalid_reference_directive_syntax);
				});
				break;
			}
			case "amd-dependency":
				e.amdDependencies = Pp(bp(a), (f) => ({
					name: f.arguments.name,
					path: f.arguments.path
				}));
				break;
			case "amd-module":
				if (a instanceof Array) for (let f of a) e.moduleName && t(f.range.pos, f.range.end - f.range.pos, A.An_AMD_module_cannot_have_multiple_name_assignments), e.moduleName = f.arguments.name;
				else e.moduleName = a.arguments.name;
				break;
			case "ts-nocheck":
			case "ts-check":
				jn(bp(a), (f) => {
					(!e.checkJsDirective || f.range.pos > e.checkJsDirective.pos) && (e.checkJsDirective = {
						enabled: _ === "ts-check",
						end: f.range.end,
						pos: f.range.pos
					});
				});
				break;
			case "jsx":
			case "jsxfrag":
			case "jsximportsource":
			case "jsxruntime": return;
			default: q.fail("Unhandled pragma kind");
		}
	});
}
var Dp = /* @__PURE__ */ new Map();
function z6(e) {
	if (Dp.has(e)) return Dp.get(e);
	let t = new RegExp(`(\\s${e}\\s*=\\s*)(?:(?:'([^']*)')|(?:"([^"]*)"))`, "im");
	return Dp.set(e, t), t;
}
var V6 = /^\/\/\/\s*<(\S+)\s.*?\/>/m, W6 = /^\/\/\/?\s*@([^\s:]+)((?:[^\S\r\n]|:).*)?$/m;
function G6(e, t, a) {
	let _ = t.kind === 2 && V6.exec(a);
	if (_) {
		let h = _[1].toLowerCase(), T = Pm[h];
		if (!T || !(T.kind & 1)) return;
		if (T.args) {
			let k = {};
			for (let c of T.args) {
				let y = z6(c.name).exec(a);
				if (!y && !c.optional) return;
				if (y) {
					let G = y[2] || y[3];
					if (c.captureSpan) {
						let E = t.pos + y.index + y[1].length + 1;
						k[c.name] = {
							value: G,
							pos: E,
							end: E + G.length
						};
					} else k[c.name] = G;
				}
			}
			e.push({
				name: h,
				args: {
					arguments: k,
					range: t
				}
			});
		} else e.push({
			name: h,
			args: {
				arguments: {},
				range: t
			}
		});
		return;
	}
	let f = t.kind === 2 && W6.exec(a);
	if (f) return ym(e, t, 2, f);
	if (t.kind === 3) {
		let h = /@(\S+)(\s+(?:\S.*)?)?$/gm, T;
		for (; T = h.exec(a);) ym(e, t, 4, T);
	}
}
function ym(e, t, a, _) {
	if (!_) return;
	let f = _[1].toLowerCase(), h = Pm[f];
	if (!h || !(h.kind & a)) return;
	let T = _[2], k = Y6(h, T);
	k !== "fail" && e.push({
		name: f,
		args: {
			arguments: k,
			range: t
		}
	});
}
function Y6(e, t) {
	if (!t) return {};
	if (!e.args) return {};
	let a = t.trim().split(/\s+/), _ = {};
	for (let f = 0; f < e.args.length; f++) {
		let h = e.args[f];
		if (!a[f] && !h.optional) return "fail";
		if (h.captureSpan) return q.fail("Capture spans not yet implemented for non-xml pragmas");
		_[h.name] = a[f];
	}
	return _;
}
function pi(e, t) {
	return e.kind !== t.kind ? !1 : e.kind === 80 ? e.escapedText === t.escapedText : e.kind === 110 ? !0 : e.kind === 296 ? e.namespace.escapedText === t.namespace.escapedText && e.name.escapedText === t.name.escapedText : e.name.escapedText === t.name.escapedText && pi(e.expression, t.expression);
}
var s_ = sf(g_.Latest, !0);
function fh(e, t, a, _) {
	let f = ff(e) ? new Gf(e, t, a) : e === 80 ? new mh(80, t, a) : e === 81 ? new hh(81, t, a) : new dh(e, t, a);
	return f.parent = _, f.flags = _.flags & 101441536, f;
}
var Gf = class {
	constructor(e, t, a) {
		this.pos = t, this.end = a, this.kind = e, this.id = 0, this.flags = 0, this.modifierFlagsCache = 0, this.transformFlags = 0, this.parent = void 0, this.original = void 0, this.emitNode = void 0;
	}
	assertHasRealPosition(e) {
		q.assert(!d_(this.pos) && !d_(this.end), e || "Node must have a real position for this operation");
	}
	getSourceFile() {
		return hi(this);
	}
	getStart(e, t) {
		return this.assertHasRealPosition(), bl(this, e, t);
	}
	getFullStart() {
		return this.assertHasRealPosition(), this.pos;
	}
	getEnd() {
		return this.assertHasRealPosition(), this.end;
	}
	getWidth(e) {
		return this.assertHasRealPosition(), this.getEnd() - this.getStart(e);
	}
	getFullWidth() {
		return this.assertHasRealPosition(), this.end - this.pos;
	}
	getLeadingTriviaWidth(e) {
		return this.assertHasRealPosition(), this.getStart(e) - this.pos;
	}
	getFullText(e) {
		return this.assertHasRealPosition(), (e || this.getSourceFile()).text.substring(this.pos, this.end);
	}
	getText(e) {
		return this.assertHasRealPosition(), e || (e = this.getSourceFile()), e.text.substring(this.getStart(e), this.getEnd());
	}
	getChildCount(e) {
		return this.getChildren(e).length;
	}
	getChildAt(e, t) {
		return this.getChildren(t)[e];
	}
	getChildren(e = hi(this)) {
		return this.assertHasRealPosition("Node without a real position cannot be scanned and thus has no token nodes - use forEachChild and collect the result if that's fine"), ah(this, e) ?? h6(this, e, H6(this, e));
	}
	getFirstToken(e) {
		this.assertHasRealPosition();
		let t = this.getChildren(e);
		if (!t.length) return;
		let a = bm(t, (_) => _.kind < 310 || _.kind > 352);
		return a.kind < 167 ? a : a.getFirstToken(e);
	}
	getLastToken(e) {
		this.assertHasRealPosition();
		let a = Ba(this.getChildren(e));
		if (a) return a.kind < 167 ? a : a.getLastToken(e);
	}
	forEachChild(e, t) {
		return Xt(this, e, t);
	}
};
function H6(e, t) {
	let a = [];
	if (e2(e)) return e.forEachChild((T) => {
		a.push(T);
	}), a;
	s_.setText((t || e.getSourceFile()).text);
	let _ = e.pos, f = (T) => {
		__(a, _, T.pos, e), a.push(T), _ = T.end;
	}, h = (T) => {
		__(a, _, T.pos, e), a.push(X6(T, e)), _ = T.end;
	};
	return jn(e.jsDoc, f), _ = e.pos, e.forEachChild(f, h), __(a, _, e.end, e), s_.setText(void 0), a;
}
function __(e, t, a, _) {
	for (s_.resetTokenState(t); t < a;) {
		let f = s_.scan(), h = s_.getTokenEnd();
		if (h <= a) {
			if (f === 80) {
				if (kb(_)) continue;
				q.fail(`Did not expect ${q.formatSyntaxKind(_.kind)} to have an Identifier in its trivia`);
			}
			e.push(fh(f, t, h, _));
		}
		if (t = h, f === 1) break;
	}
}
function X6(e, t) {
	let a = fh(353, e.pos, e.end, t), _ = [], f = e.pos;
	for (let h of e) __(_, f, h.pos, t), _.push(h), f = h.end;
	return __(_, f, e.end, t), a._children = _, a;
}
var Yf = class {
	constructor(e, t, a) {
		this.pos = t, this.end = a, this.kind = e, this.id = 0, this.flags = 0, this.transformFlags = 0, this.parent = void 0, this.emitNode = void 0;
	}
	getSourceFile() {
		return hi(this);
	}
	getStart(e, t) {
		return bl(this, e, t);
	}
	getFullStart() {
		return this.pos;
	}
	getEnd() {
		return this.end;
	}
	getWidth(e) {
		return this.getEnd() - this.getStart(e);
	}
	getFullWidth() {
		return this.end - this.pos;
	}
	getLeadingTriviaWidth(e) {
		return this.getStart(e) - this.pos;
	}
	getFullText(e) {
		return (e || this.getSourceFile()).text.substring(this.pos, this.end);
	}
	getText(e) {
		return e || (e = this.getSourceFile()), e.text.substring(this.getStart(e), this.getEnd());
	}
	getChildCount() {
		return this.getChildren().length;
	}
	getChildAt(e) {
		return this.getChildren()[e];
	}
	getChildren() {
		return this.kind === 1 && this.jsDoc || vt;
	}
	getFirstToken() {}
	getLastToken() {}
	forEachChild() {}
}, $6 = class {
	constructor(e, t) {
		this.flags = e, this.escapedName = t, this.declarations = void 0, this.valueDeclaration = void 0, this.id = 0, this.mergeId = 0, this.parent = void 0, this.members = void 0, this.exports = void 0, this.exportSymbol = void 0, this.constEnumOnlyModule = void 0, this.isReferenced = void 0, this.lastAssignmentPos = void 0, this.links = void 0;
	}
	getFlags() {
		return this.flags;
	}
	get name() {
		return Jp(this);
	}
	getEscapedName() {
		return this.escapedName;
	}
	getName() {
		return this.name;
	}
	getDeclarations() {
		return this.declarations;
	}
	getDocumentationComment(e) {
		if (!this.documentationComment) if (this.documentationComment = vt, !this.declarations && Id(this) && this.links.target && Id(this.links.target) && this.links.target.links.tupleLabelDeclaration) {
			let t = this.links.target.links.tupleLabelDeclaration;
			this.documentationComment = a_([t], e);
		} else this.documentationComment = a_(this.declarations, e);
		return this.documentationComment;
	}
	getContextualDocumentationComment(e, t) {
		if (e) {
			if (al(e) && (this.contextualGetAccessorDocumentationComment || (this.contextualGetAccessorDocumentationComment = vt, this.contextualGetAccessorDocumentationComment = a_(Hr(this.declarations, al), t)), e_(this.contextualGetAccessorDocumentationComment))) return this.contextualGetAccessorDocumentationComment;
			if (il(e) && (this.contextualSetAccessorDocumentationComment || (this.contextualSetAccessorDocumentationComment = vt, this.contextualSetAccessorDocumentationComment = a_(Hr(this.declarations, il), t)), e_(this.contextualSetAccessorDocumentationComment))) return this.contextualSetAccessorDocumentationComment;
		}
		return this.getDocumentationComment(t);
	}
	getJsDocTags(e) {
		return this.tags === void 0 && (this.tags = vt, this.tags = dl(this.declarations, e)), this.tags;
	}
	getContextualJsDocTags(e, t) {
		if (e) {
			if (al(e) && (this.contextualGetAccessorTags || (this.contextualGetAccessorTags = vt, this.contextualGetAccessorTags = dl(Hr(this.declarations, al), t)), e_(this.contextualGetAccessorTags))) return this.contextualGetAccessorTags;
			if (il(e) && (this.contextualSetAccessorTags || (this.contextualSetAccessorTags = vt, this.contextualSetAccessorTags = dl(Hr(this.declarations, il), t)), e_(this.contextualSetAccessorTags))) return this.contextualSetAccessorTags;
		}
		return this.getJsDocTags(t);
	}
}, dh = class extends Yf {
	constructor(e, t, a) {
		super(e, t, a);
	}
}, mh = class extends Yf {
	constructor(e, t, a) {
		super(e, t, a);
	}
	get text() {
		return An(this);
	}
}, hh = class extends Yf {
	constructor(e, t, a) {
		super(e, t, a);
	}
	get text() {
		return An(this);
	}
}, Q6 = class {
	constructor(e, t) {
		this.flags = t, this.checker = e;
	}
	getFlags() {
		return this.flags;
	}
	getSymbol() {
		return this.symbol;
	}
	getProperties() {
		return this.checker.getPropertiesOfType(this);
	}
	getProperty(e) {
		return this.checker.getPropertyOfType(this, e);
	}
	getApparentProperties() {
		return this.checker.getAugmentedPropertiesOfType(this);
	}
	getCallSignatures() {
		return this.checker.getSignaturesOfType(this, 0);
	}
	getConstructSignatures() {
		return this.checker.getSignaturesOfType(this, 1);
	}
	getStringIndexType() {
		return this.checker.getIndexTypeOfType(this, 0);
	}
	getNumberIndexType() {
		return this.checker.getIndexTypeOfType(this, 1);
	}
	getBaseTypes() {
		return this.isClassOrInterface() ? this.checker.getBaseTypes(this) : void 0;
	}
	isNullableType() {
		return this.checker.isNullableType(this);
	}
	getNonNullableType() {
		return this.checker.getNonNullableType(this);
	}
	getNonOptionalType() {
		return this.checker.getNonOptionalType(this);
	}
	getConstraint() {
		return this.checker.getBaseConstraintOfType(this);
	}
	getDefault() {
		return this.checker.getDefaultFromTypeParameter(this);
	}
	isUnion() {
		return !!(this.flags & 1048576);
	}
	isIntersection() {
		return !!(this.flags & 2097152);
	}
	isUnionOrIntersection() {
		return !!(this.flags & 3145728);
	}
	isLiteral() {
		return !!(this.flags & 2432);
	}
	isStringLiteral() {
		return !!(this.flags & 128);
	}
	isNumberLiteral() {
		return !!(this.flags & 256);
	}
	isTypeParameter() {
		return !!(this.flags & 262144);
	}
	isClassOrInterface() {
		return !!(kp(this) & 3);
	}
	isClass() {
		return !!(kp(this) & 1);
	}
	isIndexType() {
		return !!(this.flags & 4194304);
	}
	get typeArguments() {
		if (kp(this) & 4) return this.checker.getTypeArguments(this);
	}
}, K6 = class {
	constructor(e, t) {
		this.flags = t, this.checker = e;
	}
	getDeclaration() {
		return this.declaration;
	}
	getTypeParameters() {
		return this.typeParameters;
	}
	getParameters() {
		return this.parameters;
	}
	getReturnType() {
		return this.checker.getReturnTypeOfSignature(this);
	}
	getTypeParameterAtPosition(e) {
		let t = this.checker.getParameterType(this, e);
		if (t.isIndexType() && wb(t.type)) {
			let a = t.type.getConstraint();
			if (a) return this.checker.getIndexType(a);
		}
		return t;
	}
	getDocumentationComment() {
		return this.documentationComment || (this.documentationComment = a_(Ip(this.declaration), this.checker));
	}
	getJsDocTags() {
		return this.jsDocTags || (this.jsDocTags = dl(Ip(this.declaration), this.checker));
	}
};
function yh(e) {
	return Zm(e).some((t) => t.tagName.text === "inheritDoc" || t.tagName.text === "inheritdoc");
}
function dl(e, t) {
	if (!e) return vt;
	let a = ts_JsDoc_exports.getJsDocTagsFromDeclarations(e, t);
	if (t && (a.length === 0 || e.some(yh))) {
		let _ = /* @__PURE__ */ new Set();
		for (let f of e) {
			let h = gh(t, f, (T) => {
				var k;
				if (!_.has(T)) return _.add(T), f.kind === 178 || f.kind === 179 ? T.getContextualJsDocTags(f, t) : ((k = T.declarations) == null ? void 0 : k.length) === 1 ? T.getJsDocTags(t) : void 0;
			});
			h && (a = [...h, ...a]);
		}
	}
	return a;
}
function a_(e, t) {
	if (!e) return vt;
	let a = ts_JsDoc_exports.getJsDocCommentsFromDeclarations(e, t);
	if (t && (a.length === 0 || e.some(yh))) {
		let _ = /* @__PURE__ */ new Set();
		for (let f of e) {
			let h = gh(t, f, (T) => {
				if (!_.has(T)) return _.add(T), f.kind === 178 || f.kind === 179 ? T.getContextualDocumentationComment(f, t) : T.getDocumentationComment(t);
			});
			h && (a = a.length === 0 ? h.slice() : h.concat(lineBreakPart(), a));
		}
	}
	return a;
}
function gh(e, t, a) {
	var _;
	let f = ((_ = t.parent) == null ? void 0 : _.kind) === 177 ? t.parent.parent : t.parent;
	if (!f) return;
	let h = q2(t);
	return sy(I2(f), (T) => {
		let k = e.getTypeAtLocation(T), c = h && k.symbol ? e.getTypeOfSymbol(k.symbol) : k, W = e.getPropertyOfType(c, t.symbol.name);
		return W ? a(W) : void 0;
	});
}
var Z6 = class extends Gf {
	constructor(e, t, a) {
		super(e, t, a);
	}
	update(e, t) {
		return L6(this, e, t);
	}
	getLineAndCharacterOfPosition(e) {
		return Bm(this, e);
	}
	getLineStarts() {
		return Mp(this);
	}
	getPositionOfLineAndCharacter(e, t, a) {
		return rg(Mp(this), e, t, this.text, a);
	}
	getLineEndOfPosition(e) {
		let { line: t } = this.getLineAndCharacterOfPosition(e), a = this.getLineStarts(), _;
		t + 1 >= a.length && (_ = this.getEnd()), _ || (_ = a[t + 1] - 1);
		let f = this.getFullText();
		return f[_] === `
` && f[_ - 1] === "\r" ? _ - 1 : _;
	}
	getNamedDeclarations() {
		return this.namedDeclarations || (this.namedDeclarations = this.computeNamedDeclarations()), this.namedDeclarations;
	}
	computeNamedDeclarations() {
		let e = vy();
		return this.forEachChild(f), e;
		function t(h) {
			let T = _(h);
			T && e.add(T, h);
		}
		function a(h) {
			let T = e.get(h);
			return T || e.set(h, T = []), T;
		}
		function _(h) {
			let T = lf(h);
			return T && (kf(T) && dr(T.expression) ? T.expression.name.text : r1(T) ? getNameFromPropertyName(T) : void 0);
		}
		function f(h) {
			switch (h.kind) {
				case 263:
				case 219:
				case 175:
				case 174:
					let T = h, k = _(T);
					if (k) {
						let y = a(k), G = Ba(y);
						G && T.parent === G.parent && T.symbol === G.symbol ? T.body && !G.body && (y[y.length - 1] = T) : y.push(T);
					}
					Xt(h, f);
					break;
				case 264:
				case 232:
				case 265:
				case 266:
				case 267:
				case 268:
				case 272:
				case 282:
				case 277:
				case 274:
				case 275:
				case 178:
				case 179:
				case 188:
					t(h), Xt(h, f);
					break;
				case 170: if (!v_(h, 31)) break;
				case 261:
				case 209: {
					let y = h;
					if (Wg(y.name)) {
						Xt(y.name, f);
						break;
					}
					y.initializer && f(y.initializer);
				}
				case 307:
				case 173:
				case 172:
					t(h);
					break;
				case 279:
					let c = h;
					c.exportClause && ($1(c.exportClause) ? jn(c.exportClause.elements, f) : f(c.exportClause.name));
					break;
				case 273:
					let W = h.importClause;
					W && (W.name && t(W.name), W.namedBindings && (W.namedBindings.kind === 275 ? t(W.namedBindings) : jn(W.namedBindings.elements, f)));
					break;
				case 227: yf(h) !== 0 && t(h);
				default: Xt(h, f);
			}
		}
	}
}, ev = class {
	constructor(e, t, a) {
		this.fileName = e, this.text = t, this.skipTrivia = a || ((_) => _);
	}
	getLineAndCharacterOfPosition(e) {
		return Bm(this, e);
	}
};
function tv() {
	return {
		getNodeConstructor: () => Gf,
		getTokenConstructor: () => dh,
		getIdentifierConstructor: () => mh,
		getPrivateIdentifierConstructor: () => hh,
		getSourceFileConstructor: () => Z6,
		getSymbolConstructor: () => $6,
		getTypeConstructor: () => Q6,
		getSignatureConstructor: () => K6,
		getSourceMapSourceConstructor: () => ev
	};
}
_b(tv());
var Ml = new Proxy({}, { get: () => !0 });
var vh = Ml["4.8"];
function Rn(e, t = !1) {
	if (e != null) {
		if (vh) {
			if (t || Ol(e)) {
				let a = $m(e);
				return a ? [...a] : void 0;
			}
			return;
		}
		return e.modifiers?.filter((a) => !Cl(a));
	}
}
function xi(e, t = !1) {
	if (e != null) {
		if (vh) {
			if (t || Wf(e)) {
				let a = uf(e);
				return a ? [...a] : void 0;
			}
			return;
		}
		return e.decorators?.filter(Cl);
	}
}
var Th = {};
var Ll = new Proxy({}, { get: (e, t) => t });
var xh = Ll, Sh = Ll;
var C = xh, Rt = Sh;
var av = Ml["5.0"], ye = Ae, sv = new Set([
	ye.AmpersandAmpersandToken,
	ye.BarBarToken,
	ye.QuestionQuestionToken
]), _v = new Set([
	Ae.AmpersandAmpersandEqualsToken,
	Ae.AmpersandEqualsToken,
	Ae.AsteriskAsteriskEqualsToken,
	Ae.AsteriskEqualsToken,
	Ae.BarBarEqualsToken,
	Ae.BarEqualsToken,
	Ae.CaretEqualsToken,
	Ae.EqualsToken,
	Ae.GreaterThanGreaterThanEqualsToken,
	Ae.GreaterThanGreaterThanGreaterThanEqualsToken,
	Ae.LessThanLessThanEqualsToken,
	Ae.MinusEqualsToken,
	Ae.PercentEqualsToken,
	Ae.PlusEqualsToken,
	Ae.QuestionQuestionEqualsToken,
	Ae.SlashEqualsToken
]), ov = new Set([
	ye.AmpersandAmpersandToken,
	ye.AmpersandToken,
	ye.AsteriskAsteriskToken,
	ye.AsteriskToken,
	ye.BarBarToken,
	ye.BarToken,
	ye.CaretToken,
	ye.EqualsEqualsEqualsToken,
	ye.EqualsEqualsToken,
	ye.ExclamationEqualsEqualsToken,
	ye.ExclamationEqualsToken,
	ye.GreaterThanEqualsToken,
	ye.GreaterThanGreaterThanGreaterThanToken,
	ye.GreaterThanGreaterThanToken,
	ye.GreaterThanToken,
	ye.InKeyword,
	ye.InstanceOfKeyword,
	ye.LessThanEqualsToken,
	ye.LessThanLessThanToken,
	ye.LessThanToken,
	ye.MinusToken,
	ye.PercentToken,
	ye.PlusToken,
	ye.SlashToken
]);
function cv(e) {
	return _v.has(e.kind);
}
function lv(e) {
	return sv.has(e.kind);
}
function uv(e) {
	return ov.has(e.kind);
}
function Qr(e) {
	return nt(e);
}
function wh(e) {
	return e.kind !== ye.SemicolonClassElement;
}
function Ge(e, t) {
	return Rn(t)?.some((_) => _.kind === e) === !0;
}
function kh(e) {
	let t = Rn(e);
	return t == null ? null : t[t.length - 1] ?? null;
}
function Eh(e) {
	return e.kind === ye.CommaToken;
}
function pv(e) {
	return e.kind === ye.SingleLineCommentTrivia || e.kind === ye.MultiLineCommentTrivia;
}
function fv(e) {
	return e.kind === ye.JSDocComment;
}
function Ah(e) {
	if (cv(e)) return {
		type: C.AssignmentExpression,
		operator: Qr(e.kind)
	};
	if (lv(e)) return {
		type: C.LogicalExpression,
		operator: Qr(e.kind)
	};
	if (uv(e)) return {
		type: C.BinaryExpression,
		operator: Qr(e.kind)
	};
	throw new Error(`Unexpected binary operator ${nt(e.kind)}`);
}
function x_(e, t) {
	let a = t.getLineAndCharacterOfPosition(e);
	return {
		column: a.character,
		line: a.line + 1
	};
}
function Kr(e, t) {
	let [a, _] = e.map((f) => x_(f, t));
	return {
		end: _,
		start: a
	};
}
function Ch(e) {
	if (e.kind === Ae.Block) switch (e.parent.kind) {
		case Ae.Constructor:
		case Ae.GetAccessor:
		case Ae.SetAccessor:
		case Ae.ArrowFunction:
		case Ae.FunctionExpression:
		case Ae.FunctionDeclaration:
		case Ae.MethodDeclaration: return !0;
		default: return !1;
	}
	return !0;
}
function sa(e, t) {
	return [e.getStart(t), e.getEnd()];
}
function dv(e) {
	return e.kind >= ye.FirstToken && e.kind <= ye.LastToken;
}
function Dh(e) {
	return e.kind >= ye.JsxElement && e.kind <= ye.JsxAttribute;
}
function S_(e) {
	return e.flags & sn.Let ? "let" : (e.flags & sn.AwaitUsing) === sn.AwaitUsing ? "await using" : e.flags & sn.Const ? "const" : e.flags & sn.Using ? "using" : "var";
}
function Si(e) {
	let t = Rn(e);
	if (t != null) for (let a of t) switch (a.kind) {
		case ye.PublicKeyword: return "public";
		case ye.ProtectedKeyword: return "protected";
		case ye.PrivateKeyword: return "private";
		default: break;
	}
}
function er(e, t, a) {
	return _(t);
	function _(f) {
		return t1(f) && f.pos === e.end ? f : vv(f.getChildren(a), (h) => (h.pos <= e.pos && h.end > e.end || h.pos === e.end) && bv(h, a) ? _(h) : void 0);
	}
}
function mv(e, t) {
	let a = e;
	for (; a;) {
		if (t(a)) return a;
		a = a.parent;
	}
}
function hv(e) {
	return !!mv(e, Dh);
}
function Kf(e) {
	return Wr(0, e, /&(?:#\d+|#x[\da-fA-F]+|[0-9a-zA-Z]+);/g, (t) => {
		let a = t.slice(1, -1);
		if (a[0] === "#") {
			let _ = a[1] === "x" ? parseInt(a.slice(2), 16) : parseInt(a.slice(1), 10);
			return _ > 1114111 ? t : String.fromCodePoint(_);
		}
		return Th[a] || t;
	});
}
function _a(e) {
	return e.kind === ye.ComputedPropertyName;
}
function Zf(e) {
	return !!e.questionToken;
}
function ed(e) {
	return e.type === C.ChainExpression;
}
function Ph(e, t) {
	return ed(t) && e.expression.kind !== Ae.ParenthesizedExpression;
}
function yv(e) {
	if (e.kind === ye.NullKeyword) return Rt.Null;
	if (e.kind >= ye.FirstKeyword && e.kind <= ye.LastFutureReservedWord) return e.kind === ye.FalseKeyword || e.kind === ye.TrueKeyword ? Rt.Boolean : Rt.Keyword;
	if (e.kind >= ye.FirstPunctuation && e.kind <= ye.LastPunctuation) return Rt.Punctuator;
	if (e.kind >= ye.NoSubstitutionTemplateLiteral && e.kind <= ye.TemplateTail) return Rt.Template;
	switch (e.kind) {
		case ye.NumericLiteral:
		case ye.BigIntLiteral: return Rt.Numeric;
		case ye.PrivateIdentifier: return Rt.PrivateIdentifier;
		case ye.JsxText: return Rt.JSXText;
		case ye.StringLiteral: return e.parent.kind === ye.JsxAttribute || e.parent.kind === ye.JsxElement ? Rt.JSXText : Rt.String;
		case ye.RegularExpressionLiteral: return Rt.RegularExpression;
		case ye.Identifier:
		case ye.ConstructorKeyword:
		case ye.GetKeyword:
		case ye.SetKeyword:
		default:
	}
	if (e.kind === ye.Identifier) {
		if (Dh(e.parent)) return Rt.JSXIdentifier;
		if (e.parent.kind === ye.PropertyAccessExpression && hv(e)) return Rt.JSXIdentifier;
	}
	return Rt.Identifier;
}
function gv(e, t) {
	let a = e.kind === ye.JsxText ? e.getFullStart() : e.getStart(t), _ = e.getEnd(), f = t.text.slice(a, _), h = yv(e), T = [a, _], k = Kr(T, t);
	return h === Rt.RegularExpression ? {
		type: h,
		loc: k,
		range: T,
		regex: {
			flags: f.slice(f.lastIndexOf("/") + 1),
			pattern: f.slice(1, f.lastIndexOf("/"))
		},
		value: f
	} : h === Rt.PrivateIdentifier ? {
		type: h,
		loc: k,
		range: T,
		value: f.slice(1)
	} : {
		type: h,
		loc: k,
		range: T,
		value: f
	};
}
function Nh(e) {
	let t = [];
	function a(_) {
		pv(_) || fv(_) || (dv(_) && _.kind !== ye.EndOfFileToken ? t.push(gv(_, e)) : _.getChildren(e).forEach(a));
	}
	return a(e), t;
}
var Qf = class extends Error {
	fileName;
	location;
	constructor(t, a, _) {
		super(t), this.fileName = a, this.location = _, Object.defineProperty(this, "name", {
			configurable: !0,
			enumerable: !1,
			value: new.target.name
		});
	}
	get index() {
		return this.location.start.offset;
	}
	get lineNumber() {
		return this.location.start.line;
	}
	get column() {
		return this.location.start.column;
	}
};
function w_(e, t, a, _ = a) {
	let [f, h] = [a, _].map((T) => {
		let { character: k, line: c } = t.getLineAndCharacterOfPosition(T);
		return {
			column: k,
			line: c + 1,
			offset: T
		};
	});
	return new Qf(e, t.fileName, {
		end: h,
		start: f
	});
}
function bv(e, t) {
	return e.kind === ye.EndOfFileToken ? !!e.jsDoc : e.getWidth(t) !== 0;
}
function vv(e, t) {
	if (e !== void 0) for (let a = 0; a < e.length; a++) {
		let _ = t(e[a], a);
		if (_ !== void 0) return _;
	}
}
function Tv(e) {
	return (av ? cf(e) : e.originalKeywordKind) === ye.ThisKeyword;
}
function td(e) {
	return !!e && e.kind === ye.Identifier && Tv(e);
}
function Ih(e) {
	if (!td(e)) return !1;
	for (; A1(e.parent) && e.parent.left === e;) e = e.parent;
	return e.parent.kind === ye.TypeQuery;
}
function Jl(e) {
	switch (e.kind) {
		case ye.Identifier: return !0;
		case ye.PropertyAccessExpression:
		case ye.ElementAccessExpression: return !(e.flags & sn.OptionalChain);
		case ye.ParenthesizedExpression:
		case ye.TypeAssertionExpression:
		case ye.AsExpression:
		case ye.SatisfiesExpression:
		case ye.ExpressionWithTypeArguments:
		case ye.NonNullExpression: return Jl(e.expression);
		default: return !1;
	}
}
function Oh(e) {
	let t = Rn(e), a = e;
	for (; (!t || t.length === 0) && Ti(a.parent);) {
		let _ = Rn(a.parent);
		_?.length && (t = _), a = a.parent;
	}
	return t;
}
function Mh(e, t) {
	return t.text.slice(e.pos, e.end).trimStart() || "(Missing)";
}
var ge = Ae;
function xv(e) {
	return e == null ? !0 : e.pos === e.end && e.pos >= 0 && e.kind !== ge.EndOfFileToken;
}
function Lh(e) {
	return !xv(e);
}
function Sv(e) {
	return Ge(ge.AbstractKeyword, e);
}
function wv(e) {
	if (e.parameters.length && !Il(e)) {
		let t = e.parameters[0];
		if (kv(t)) return t;
	}
	return null;
}
function kv(e) {
	return td(e.name);
}
function Ev(e) {
	return of(e.parent, mf);
}
function Av(e) {
	switch (e.kind) {
		case ge.ClassDeclaration: return !0;
		case ge.ClassExpression: return !0;
		case ge.PropertyDeclaration: {
			let { parent: t } = e;
			return !!(Ga(t) || ra(t) && !Sv(e));
		}
		case ge.GetAccessor:
		case ge.SetAccessor:
		case ge.MethodDeclaration: {
			let { parent: t } = e;
			return !!e.body && (Ga(t) || ra(t));
		}
		case ge.Parameter: {
			let { parent: t } = e, a = t.parent;
			return !!t && "body" in t && !!t.body && (t.kind === ge.Constructor || t.kind === ge.MethodDeclaration || t.kind === ge.SetAccessor) && wv(t) !== e && !!a && a.kind === ge.ClassDeclaration;
		}
	}
	return !1;
}
function Cv(e) {
	return !!("illegalDecorators" in e && e.illegalDecorators?.length);
}
function Ut(e, t) {
	let a = e.getSourceFile();
	throw w_(t, a, e.getStart(a), e.getEnd());
}
function Jh(e) {
	Cv(e) && Ut(e.illegalDecorators[0], "Decorators are not valid here.");
	for (let t of xi(e, !0) ?? []) Av(e) || (h_(e) && !Lh(e.body) ? Ut(t, "A decorator can only decorate a method implementation, not an overload.") : Ut(t, "Decorators are not valid here."));
	for (let t of Rn(e, !0) ?? []) {
		if (t.kind !== ge.ReadonlyKeyword && ((e.kind === ge.PropertySignature || e.kind === ge.MethodSignature) && Ut(t, `'${nt(t.kind)}' modifier cannot appear on a type member`), e.kind === ge.IndexSignature && (t.kind !== ge.StaticKeyword || !ra(e.parent)) && Ut(t, `'${nt(t.kind)}' modifier cannot appear on an index signature`)), t.kind !== ge.InKeyword && t.kind !== ge.OutKeyword && t.kind !== ge.ConstKeyword && e.kind === ge.TypeParameter && Ut(t, `'${nt(t.kind)}' modifier cannot appear on a type parameter`), (t.kind === ge.InKeyword || t.kind === ge.OutKeyword) && (e.kind !== ge.TypeParameter || !(T_(e.parent) || ra(e.parent) || Nl(e.parent))) && Ut(t, `'${nt(t.kind)}' modifier can only appear on a type parameter of a class, interface or type alias`), t.kind === ge.ReadonlyKeyword && e.kind !== ge.PropertyDeclaration && e.kind !== ge.PropertySignature && e.kind !== ge.IndexSignature && e.kind !== ge.Parameter && Ut(t, "'readonly' modifier can only appear on a property declaration or index signature."), t.kind === ge.DeclareKeyword && ra(e.parent) && !Wa(e) && Ut(t, `'${nt(t.kind)}' modifier cannot appear on class elements of this kind.`), t.kind === ge.DeclareKeyword && Xa(e)) {
			let a = S_(e.declarationList);
			(a === "using" || a === "await using") && Ut(t, `'declare' modifier cannot appear on a '${a}' declaration.`);
		}
		if (t.kind === ge.AbstractKeyword && e.kind !== ge.ClassDeclaration && e.kind !== ge.ConstructorType && e.kind !== ge.MethodDeclaration && e.kind !== ge.PropertyDeclaration && e.kind !== ge.GetAccessor && e.kind !== ge.SetAccessor && Ut(t, `'${nt(t.kind)}' modifier can only appear on a class, method, or property declaration.`), (t.kind === ge.StaticKeyword || t.kind === ge.PublicKeyword || t.kind === ge.ProtectedKeyword || t.kind === ge.PrivateKeyword) && (e.parent.kind === ge.ModuleBlock || e.parent.kind === ge.SourceFile) && Ut(t, `'${nt(t.kind)}' modifier cannot appear on a module or namespace element.`), t.kind === ge.AccessorKeyword && e.kind !== ge.PropertyDeclaration && Ut(t, "'accessor' modifier can only appear on a property declaration."), t.kind === ge.AsyncKeyword && e.kind !== ge.MethodDeclaration && e.kind !== ge.FunctionDeclaration && e.kind !== ge.FunctionExpression && e.kind !== ge.ArrowFunction && Ut(t, "'async' modifier cannot be used here."), e.kind === ge.Parameter && (t.kind === ge.StaticKeyword || t.kind === ge.ExportKeyword || t.kind === ge.DeclareKeyword || t.kind === ge.AsyncKeyword) && Ut(t, `'${nt(t.kind)}' modifier cannot appear on a parameter.`), t.kind === ge.PublicKeyword || t.kind === ge.ProtectedKeyword || t.kind === ge.PrivateKeyword) for (let a of Rn(e) ?? []) a !== t && (a.kind === ge.PublicKeyword || a.kind === ge.ProtectedKeyword || a.kind === ge.PrivateKeyword) && Ut(a, "Accessibility modifier already seen.");
		if (e.kind === ge.Parameter && (t.kind === ge.PublicKeyword || t.kind === ge.PrivateKeyword || t.kind === ge.ProtectedKeyword || t.kind === ge.ReadonlyKeyword || t.kind === ge.OverrideKeyword)) {
			let a = Ev(e);
			a?.kind === ge.Constructor && Lh(a.body) || Ut(t, "A parameter property is only allowed in a constructor implementation.");
			let _ = e;
			_.dotDotDotToken && Ut(t, "A parameter property cannot be a rest parameter."), (_.name.kind === ge.ArrayBindingPattern || _.name.kind === ge.ObjectBindingPattern) && Ut(t, "A parameter property may not be declared using a binding pattern.");
		}
		t.kind !== ge.AsyncKeyword && e.kind === ge.MethodDeclaration && e.parent.kind === ge.ObjectLiteralExpression && Ut(t, `'${nt(t.kind)}' modifier cannot be used here.`);
	}
}
var x = Ae;
function nd(e) {
	return w_("message" in e && e.message || e.messageText, e.file, e.start);
}
function Pv(e) {
	return dr(e) && Ke(e.name) && jh(e.expression);
}
function jh(e) {
	return e.kind === x.Identifier || Pv(e);
}
var Rl = class {
	allowPattern = !1;
	ast;
	esTreeNodeToTSNodeMap = /* @__PURE__ */ new WeakMap();
	options;
	tsNodeToESTreeNodeMap = /* @__PURE__ */ new WeakMap();
	constructor(t, a) {
		this.ast = t, this.options = { ...a };
	}
	#r(t, a) {
		let _ = a === Ae.ForInStatement ? "for...in" : "for...of";
		if (H1(t)) {
			t.declarations.length !== 1 && this.#e(t, `Only a single variable declaration is allowed in a '${_}' statement.`);
			let f = t.declarations[0];
			f.initializer ? this.#e(f, `The variable declaration of a '${_}' statement cannot have an initializer.`) : f.type && this.#e(f, `The variable declaration of a '${_}' statement cannot have a type annotation.`), a === Ae.ForInStatement && t.flags & sn.Using && this.#e(t, "The left-hand side of a 'for...in' statement cannot be a 'using' declaration.");
		} else !Jl(t) && t.kind !== Ae.ObjectLiteralExpression && t.kind !== Ae.ArrayLiteralExpression && this.#e(t, `The left-hand side of a '${_}' statement must be a variable or a property access.`);
	}
	#i(t) {
		this.options.allowInvalidAST || Jh(t);
	}
	#e(t, a) {
		if (this.options.allowInvalidAST) return;
		let _, f;
		throw Array.isArray(t) ? [_, f] = t : typeof t == "number" ? _ = f = t : (_ = t.getStart(this.ast), f = t.getEnd()), w_(a, this.ast, _, f);
	}
	#t(t, a, _, f = !1) {
		let h = f;
		return Object.defineProperty(t, a, {
			configurable: !0,
			get: this.options.suppressDeprecatedPropertyWarnings ? () => t[_] : () => (h || ((void 0)(`The '${a}' property is deprecated on ${t.type} nodes. Use '${_}' instead. See https://typescript-eslint.io/troubleshooting/faqs/general#the-key-property-is-deprecated-on-type-nodes-use-key-instead-warnings.`, "DeprecationWarning"), h = !0), t[_]),
			set(T) {
				Object.defineProperty(t, a, {
					enumerable: !0,
					value: T,
					writable: !0
				});
			}
		}), t;
	}
	#n(t, a, _, f) {
		let h = !1;
		return Object.defineProperty(t, a, {
			configurable: !0,
			get: this.options.suppressDeprecatedPropertyWarnings ? () => f : () => {
				if (!h) {
					let T = `The '${a}' property is deprecated on ${t.type} nodes.`;
					_ && (T += ` Use ${_} instead.`), T += " See https://typescript-eslint.io/troubleshooting/faqs/general#the-key-property-is-deprecated-on-type-nodes-use-key-instead-warnings.", (void 0)(T, "DeprecationWarning"), h = !0;
				}
				return f;
			},
			set(T) {
				Object.defineProperty(t, a, {
					enumerable: !0,
					value: T,
					writable: !0
				});
			}
		}), t;
	}
	assertModuleSpecifier(t, a) {
		!a && t.moduleSpecifier == null && this.#e(t, "Module specifier must be a string literal."), t.moduleSpecifier && t.moduleSpecifier?.kind !== x.StringLiteral && this.#e(t.moduleSpecifier, "Module specifier must be a string literal.");
	}
	convertBindingNameWithTypeAnnotation(t, a, _) {
		let f = this.convertPattern(t);
		return a && (f.typeAnnotation = this.convertTypeAnnotation(a, _), this.fixParentLocation(f, f.typeAnnotation.range)), f;
	}
	convertBodyExpressions(t, a) {
		let _ = Ch(a);
		return t.map((f) => {
			let h = this.convertChild(f);
			if (_) {
				if (h?.expression && Pl(f) && vi(f.expression)) return h.directive = h.expression.raw.slice(1, -1), h;
				_ = !1;
			}
			return h;
		}).filter((f) => f);
	}
	convertChainExpression(t, a) {
		let { child: _, isOptional: f } = t.type === C.MemberExpression ? {
			child: t.object,
			isOptional: t.optional
		} : t.type === C.CallExpression ? {
			child: t.callee,
			isOptional: t.optional
		} : {
			child: t.expression,
			isOptional: !1
		}, h = Ph(a, _);
		if (!h && !f) return t;
		if (h && ed(_)) {
			let T = _.expression;
			t.type === C.MemberExpression ? t.object = T : t.type === C.CallExpression ? t.callee = T : t.expression = T;
		}
		return this.createNode(a, {
			type: C.ChainExpression,
			expression: t
		});
	}
	convertChild(t, a) {
		return this.converter(t, a, !1);
	}
	convertChildren(t, a) {
		return t.map((_) => this.converter(_, a, !1));
	}
	convertPattern(t, a) {
		return this.converter(t, a, !0);
	}
	convertTypeAnnotation(t, a) {
		let _ = a?.kind === x.FunctionType || a?.kind === x.ConstructorType ? 2 : 1, h = [t.getFullStart() - _, t.end], T = Kr(h, this.ast);
		return {
			type: C.TSTypeAnnotation,
			loc: T,
			range: h,
			typeAnnotation: this.convertChild(t)
		};
	}
	convertTypeArgumentsToTypeParameterInstantiation(t, a) {
		let _ = er(t, this.ast, this.ast), f = [t.pos - 1, _.end];
		return t.length === 0 && this.#e(f, "Type argument list cannot be empty."), this.createNode(a, {
			type: C.TSTypeParameterInstantiation,
			range: f,
			params: this.convertChildren(t)
		});
	}
	convertTSTypeParametersToTypeParametersDeclaration(t) {
		let a = er(t, this.ast, this.ast), _ = [t.pos - 1, a.end];
		return t.length === 0 && this.#e(_, "Type parameter list cannot be empty."), {
			type: C.TSTypeParameterDeclaration,
			loc: Kr(_, this.ast),
			range: _,
			params: this.convertChildren(t)
		};
	}
	convertParameters(t) {
		return t?.length ? t.map((a) => {
			let _ = this.convertChild(a);
			return _.decorators = this.convertChildren(xi(a) ?? []), _;
		}) : [];
	}
	converter(t, a, _) {
		if (!t) return null;
		this.#i(t);
		let f = this.allowPattern;
		_ != null && (this.allowPattern = _);
		let h = this.convertNode(t, a ?? t.parent);
		return this.registerTSNodeInNodeMap(t, h), this.allowPattern = f, h;
	}
	convertImportAttributes(t) {
		let a = t.attributes ?? t.assertClause;
		return this.convertChildren(a?.elements ?? []);
	}
	convertJSXIdentifier(t) {
		let a = this.createNode(t, {
			type: C.JSXIdentifier,
			name: t.getText()
		});
		return this.registerTSNodeInNodeMap(t, a), a;
	}
	convertJSXNamespaceOrIdentifier(t) {
		if (t.kind === Ae.JsxNamespacedName) {
			let f = this.createNode(t, {
				type: C.JSXNamespacedName,
				name: this.createNode(t.name, {
					type: C.JSXIdentifier,
					name: t.name.text
				}),
				namespace: this.createNode(t.namespace, {
					type: C.JSXIdentifier,
					name: t.namespace.text
				})
			});
			return this.registerTSNodeInNodeMap(t, f), f;
		}
		let a = t.getText(), _ = a.indexOf(":");
		if (_ > 0) {
			let f = sa(t, this.ast), h = this.createNode(t, {
				type: C.JSXNamespacedName,
				range: f,
				name: this.createNode(t, {
					type: C.JSXIdentifier,
					range: [f[0] + _ + 1, f[1]],
					name: a.slice(_ + 1)
				}),
				namespace: this.createNode(t, {
					type: C.JSXIdentifier,
					range: [f[0], f[0] + _],
					name: a.slice(0, _)
				})
			});
			return this.registerTSNodeInNodeMap(t, h), h;
		}
		return this.convertJSXIdentifier(t);
	}
	convertJSXTagName(t, a) {
		let _;
		switch (t.kind) {
			case x.PropertyAccessExpression:
				t.name.kind === x.PrivateIdentifier && this.#e(t.name, "Non-private identifier expected."), _ = this.createNode(t, {
					type: C.JSXMemberExpression,
					object: this.convertJSXTagName(t.expression, a),
					property: this.convertJSXIdentifier(t.name)
				});
				break;
			case x.ThisKeyword:
			case x.Identifier:
			default: return this.convertJSXNamespaceOrIdentifier(t);
		}
		return this.registerTSNodeInNodeMap(t, _), _;
	}
	convertMethodSignature(t) {
		return this.createNode(t, {
			type: C.TSMethodSignature,
			accessibility: Si(t),
			computed: _a(t.name),
			key: this.convertChild(t.name),
			kind: (() => {
				switch (t.kind) {
					case x.GetAccessor: return "get";
					case x.SetAccessor: return "set";
					case x.MethodSignature: return "method";
				}
			})(),
			optional: Zf(t),
			params: this.convertParameters(t.parameters),
			readonly: Ge(x.ReadonlyKeyword, t),
			returnType: t.type && this.convertTypeAnnotation(t.type, t),
			static: Ge(x.StaticKeyword, t),
			typeParameters: t.typeParameters && this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters)
		});
	}
	fixParentLocation(t, a) {
		a[0] < t.range[0] && (t.range[0] = a[0], t.loc.start = x_(t.range[0], this.ast)), a[1] > t.range[1] && (t.range[1] = a[1], t.loc.end = x_(t.range[1], this.ast));
	}
	convertNode(t, a) {
		switch (t.kind) {
			case x.SourceFile: return this.createNode(t, {
				type: C.Program,
				range: [t.getStart(this.ast), t.endOfFileToken.end],
				body: this.convertBodyExpressions(t.statements, t),
				comments: void 0,
				sourceType: t.externalModuleIndicator ? "module" : "script",
				tokens: void 0
			});
			case x.Block: return this.createNode(t, {
				type: C.BlockStatement,
				body: this.convertBodyExpressions(t.statements, t)
			});
			case x.Identifier: return Ih(t) ? this.createNode(t, { type: C.ThisExpression }) : this.createNode(t, {
				type: C.Identifier,
				decorators: [],
				name: t.text,
				optional: !1,
				typeAnnotation: void 0
			});
			case x.PrivateIdentifier: return this.createNode(t, {
				type: C.PrivateIdentifier,
				name: t.text.slice(1)
			});
			case x.WithStatement: return this.createNode(t, {
				type: C.WithStatement,
				body: this.convertChild(t.statement),
				object: this.convertChild(t.expression)
			});
			case x.ReturnStatement: return this.createNode(t, {
				type: C.ReturnStatement,
				argument: this.convertChild(t.expression)
			});
			case x.LabeledStatement: return this.createNode(t, {
				type: C.LabeledStatement,
				body: this.convertChild(t.statement),
				label: this.convertChild(t.label)
			});
			case x.ContinueStatement: return this.createNode(t, {
				type: C.ContinueStatement,
				label: this.convertChild(t.label)
			});
			case x.BreakStatement: return this.createNode(t, {
				type: C.BreakStatement,
				label: this.convertChild(t.label)
			});
			case x.IfStatement: return this.createNode(t, {
				type: C.IfStatement,
				alternate: this.convertChild(t.elseStatement),
				consequent: this.convertChild(t.thenStatement),
				test: this.convertChild(t.expression)
			});
			case x.SwitchStatement: return t.caseBlock.clauses.filter((_) => _.kind === x.DefaultClause).length > 1 && this.#e(t, "A 'default' clause cannot appear more than once in a 'switch' statement."), this.createNode(t, {
				type: C.SwitchStatement,
				cases: this.convertChildren(t.caseBlock.clauses),
				discriminant: this.convertChild(t.expression)
			});
			case x.CaseClause:
			case x.DefaultClause: return this.createNode(t, {
				type: C.SwitchCase,
				consequent: this.convertChildren(t.statements),
				test: t.kind === x.CaseClause ? this.convertChild(t.expression) : null
			});
			case x.ThrowStatement: return t.expression.end === t.expression.pos && this.#e(t, "A throw statement must throw an expression."), this.createNode(t, {
				type: C.ThrowStatement,
				argument: this.convertChild(t.expression)
			});
			case x.TryStatement: return this.createNode(t, {
				type: C.TryStatement,
				block: this.convertChild(t.tryBlock),
				finalizer: this.convertChild(t.finallyBlock),
				handler: this.convertChild(t.catchClause)
			});
			case x.CatchClause: return t.variableDeclaration?.initializer && this.#e(t.variableDeclaration.initializer, "Catch clause variable cannot have an initializer."), this.createNode(t, {
				type: C.CatchClause,
				body: this.convertChild(t.block),
				param: t.variableDeclaration ? this.convertBindingNameWithTypeAnnotation(t.variableDeclaration.name, t.variableDeclaration.type) : null
			});
			case x.WhileStatement: return this.createNode(t, {
				type: C.WhileStatement,
				body: this.convertChild(t.statement),
				test: this.convertChild(t.expression)
			});
			case x.DoStatement: return this.createNode(t, {
				type: C.DoWhileStatement,
				body: this.convertChild(t.statement),
				test: this.convertChild(t.expression)
			});
			case x.ForStatement: return this.createNode(t, {
				type: C.ForStatement,
				body: this.convertChild(t.statement),
				init: this.convertChild(t.initializer),
				test: this.convertChild(t.condition),
				update: this.convertChild(t.incrementor)
			});
			case x.ForInStatement: return this.#r(t.initializer, t.kind), this.createNode(t, {
				type: C.ForInStatement,
				body: this.convertChild(t.statement),
				left: this.convertPattern(t.initializer),
				right: this.convertChild(t.expression)
			});
			case x.ForOfStatement: return this.#r(t.initializer, t.kind), this.createNode(t, {
				type: C.ForOfStatement,
				await: !!(t.awaitModifier && t.awaitModifier.kind === x.AwaitKeyword),
				body: this.convertChild(t.statement),
				left: this.convertPattern(t.initializer),
				right: this.convertChild(t.expression)
			});
			case x.FunctionDeclaration: {
				let _ = Ge(x.DeclareKeyword, t), f = Ge(x.AsyncKeyword, t), h = !!t.asteriskToken;
				_ ? t.body ? this.#e(t, "An implementation cannot be declared in ambient contexts.") : f ? this.#e(t, "'async' modifier cannot be used in an ambient context.") : h && this.#e(t, "Generators are not allowed in an ambient context.") : !t.body && h && this.#e(t, "A function signature cannot be declared as a generator.");
				let T = this.createNode(t, {
					type: t.body ? C.FunctionDeclaration : C.TSDeclareFunction,
					async: f,
					body: this.convertChild(t.body) || void 0,
					declare: _,
					expression: !1,
					generator: h,
					id: this.convertChild(t.name),
					params: this.convertParameters(t.parameters),
					returnType: t.type && this.convertTypeAnnotation(t.type, t),
					typeParameters: t.typeParameters && this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters)
				});
				return this.fixExports(t, T);
			}
			case x.VariableDeclaration: {
				let _ = !!t.exclamationToken, f = this.convertChild(t.initializer), h = this.convertBindingNameWithTypeAnnotation(t.name, t.type, t);
				return _ && (f ? this.#e(t, "Declarations with initializers cannot also have definite assignment assertions.") : (h.type !== C.Identifier || !h.typeAnnotation) && this.#e(t, "Declarations with definite assignment assertions must also have type annotations.")), this.createNode(t, {
					type: C.VariableDeclarator,
					definite: _,
					id: h,
					init: f
				});
			}
			case x.VariableStatement: {
				let _ = this.createNode(t, {
					type: C.VariableDeclaration,
					declarations: this.convertChildren(t.declarationList.declarations),
					declare: Ge(x.DeclareKeyword, t),
					kind: S_(t.declarationList)
				});
				return _.declarations.length || this.#e(t, "A variable declaration list must have at least one variable declarator."), (_.kind === "using" || _.kind === "await using") && t.declarationList.declarations.forEach((f, h) => {
					_.declarations[h].init ?? this.#e(f, `'${_.kind}' declarations must be initialized.`), _.declarations[h].id.type !== C.Identifier && this.#e(f.name, `'${_.kind}' declarations may not have binding patterns.`);
				}), (_.declare || [
					"await using",
					"const",
					"using"
				].includes(_.kind)) && t.declarationList.declarations.forEach((f, h) => {
					_.declarations[h].definite && this.#e(f, "A definite assignment assertion '!' is not permitted in this context.");
				}), _.declare && t.declarationList.declarations.forEach((f, h) => {
					_.declarations[h].init && (["let", "var"].includes(_.kind) || _.declarations[h].id.typeAnnotation) && this.#e(f, "Initializers are not permitted in ambient contexts.");
				}), this.fixExports(t, _);
			}
			case x.VariableDeclarationList: {
				let _ = this.createNode(t, {
					type: C.VariableDeclaration,
					declarations: this.convertChildren(t.declarations),
					declare: !1,
					kind: S_(t)
				});
				return (_.kind === "using" || _.kind === "await using") && t.declarations.forEach((f, h) => {
					_.declarations[h].init != null && this.#e(f, `'${_.kind}' declarations may not be initialized in for statement.`), _.declarations[h].id.type !== C.Identifier && this.#e(f.name, `'${_.kind}' declarations may not have binding patterns.`);
				}), _;
			}
			case x.ExpressionStatement: return this.createNode(t, {
				type: C.ExpressionStatement,
				directive: void 0,
				expression: this.convertChild(t.expression)
			});
			case x.ThisKeyword: return this.createNode(t, { type: C.ThisExpression });
			case x.ArrayLiteralExpression: return this.allowPattern ? this.createNode(t, {
				type: C.ArrayPattern,
				decorators: [],
				elements: t.elements.map((_) => this.convertPattern(_)),
				optional: !1,
				typeAnnotation: void 0
			}) : this.createNode(t, {
				type: C.ArrayExpression,
				elements: this.convertChildren(t.elements)
			});
			case x.ObjectLiteralExpression: {
				if (this.allowPattern) return this.createNode(t, {
					type: C.ObjectPattern,
					decorators: [],
					optional: !1,
					properties: t.properties.map((f) => this.convertPattern(f)),
					typeAnnotation: void 0
				});
				let _ = [];
				for (let f of t.properties) (f.kind === x.GetAccessor || f.kind === x.SetAccessor || f.kind === x.MethodDeclaration) && !f.body && this.#e(f.end - 1, "'{' expected."), _.push(this.convertChild(f));
				return this.createNode(t, {
					type: C.ObjectExpression,
					properties: _
				});
			}
			case x.PropertyAssignment: {
				let { exclamationToken: _, questionToken: f } = t;
				return f && this.#e(f, "A property assignment cannot have a question token."), _ && this.#e(_, "A property assignment cannot have an exclamation token."), this.createNode(t, {
					type: C.Property,
					computed: _a(t.name),
					key: this.convertChild(t.name),
					kind: "init",
					method: !1,
					optional: !1,
					shorthand: !1,
					value: this.converter(t.initializer, t, this.allowPattern)
				});
			}
			case x.ShorthandPropertyAssignment: {
				let { exclamationToken: _, modifiers: f, questionToken: h } = t;
				return f && this.#e(f[0], "A shorthand property assignment cannot have modifiers."), h && this.#e(h, "A shorthand property assignment cannot have a question token."), _ && this.#e(_, "A shorthand property assignment cannot have an exclamation token."), t.objectAssignmentInitializer ? this.createNode(t, {
					type: C.Property,
					computed: !1,
					key: this.convertChild(t.name),
					kind: "init",
					method: !1,
					optional: !1,
					shorthand: !0,
					value: this.createNode(t, {
						type: C.AssignmentPattern,
						decorators: [],
						left: this.convertPattern(t.name),
						optional: !1,
						right: this.convertChild(t.objectAssignmentInitializer),
						typeAnnotation: void 0
					})
				}) : this.createNode(t, {
					type: C.Property,
					computed: !1,
					key: this.convertChild(t.name),
					kind: "init",
					method: !1,
					optional: !1,
					shorthand: !0,
					value: this.convertChild(t.name)
				});
			}
			case x.ComputedPropertyName: return this.convertChild(t.expression);
			case x.PropertyDeclaration: {
				let _ = Ge(x.AbstractKeyword, t);
				_ && t.initializer && this.#e(t.initializer, "Abstract property cannot have an initializer."), t.name.kind === x.StringLiteral && t.name.text === "constructor" && this.#e(t.name, "Classes may not have a field named 'constructor'.");
				let h = Ge(x.AccessorKeyword, t) ? _ ? C.TSAbstractAccessorProperty : C.AccessorProperty : _ ? C.TSAbstractPropertyDefinition : C.PropertyDefinition, T = this.convertChild(t.name);
				return this.createNode(t, {
					type: h,
					accessibility: Si(t),
					computed: _a(t.name),
					declare: Ge(x.DeclareKeyword, t),
					decorators: this.convertChildren(xi(t) ?? []),
					definite: !!t.exclamationToken,
					key: T,
					optional: (T.type === C.Literal || t.name.kind === x.Identifier || t.name.kind === x.ComputedPropertyName || t.name.kind === x.PrivateIdentifier) && !!t.questionToken,
					override: Ge(x.OverrideKeyword, t),
					readonly: Ge(x.ReadonlyKeyword, t),
					static: Ge(x.StaticKeyword, t),
					typeAnnotation: t.type && this.convertTypeAnnotation(t.type, t),
					value: _ ? null : this.convertChild(t.initializer)
				});
			}
			case x.GetAccessor:
			case x.SetAccessor: if (t.parent.kind === x.InterfaceDeclaration || t.parent.kind === x.TypeLiteral) return this.convertMethodSignature(t);
			case x.MethodDeclaration: {
				let _ = Ge(x.AbstractKeyword, t);
				_ && t.body && this.#e(t.name, t.kind === x.GetAccessor || t.kind === x.SetAccessor ? "An abstract accessor cannot have an implementation." : `Method '${Mh(t.name, this.ast)}' cannot have an implementation because it is marked abstract.`);
				let f = this.createNode(t, {
					type: t.body ? C.FunctionExpression : C.TSEmptyBodyFunctionExpression,
					range: [t.parameters.pos - 1, t.end],
					async: Ge(x.AsyncKeyword, t),
					body: this.convertChild(t.body),
					declare: !1,
					expression: !1,
					generator: !!t.asteriskToken,
					id: null,
					params: [],
					returnType: t.type && this.convertTypeAnnotation(t.type, t),
					typeParameters: t.typeParameters && this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters)
				});
				f.typeParameters && this.fixParentLocation(f, f.typeParameters.range);
				let h;
				if (a.kind === x.ObjectLiteralExpression) f.params = this.convertChildren(t.parameters), h = this.createNode(t, {
					type: C.Property,
					computed: _a(t.name),
					key: this.convertChild(t.name),
					kind: "init",
					method: t.kind === x.MethodDeclaration,
					optional: !!t.questionToken,
					shorthand: !1,
					value: f
				});
				else {
					f.params = this.convertParameters(t.parameters);
					let T = _ ? C.TSAbstractMethodDefinition : C.MethodDefinition;
					h = this.createNode(t, {
						type: T,
						accessibility: Si(t),
						computed: _a(t.name),
						decorators: this.convertChildren(xi(t) ?? []),
						key: this.convertChild(t.name),
						kind: "method",
						optional: !!t.questionToken,
						override: Ge(x.OverrideKeyword, t),
						static: Ge(x.StaticKeyword, t),
						value: f
					});
				}
				return t.kind === x.GetAccessor ? h.kind = "get" : t.kind === x.SetAccessor ? h.kind = "set" : !h.static && t.name.kind === x.StringLiteral && t.name.text === "constructor" && h.type !== C.Property && (h.kind = "constructor"), h;
			}
			case x.Constructor: {
				let _ = kh(t), f = (_ && er(_, t, this.ast)) ?? t.getFirstToken(), h = this.createNode(t, {
					type: t.body ? C.FunctionExpression : C.TSEmptyBodyFunctionExpression,
					range: [t.parameters.pos - 1, t.end],
					async: !1,
					body: this.convertChild(t.body),
					declare: !1,
					expression: !1,
					generator: !1,
					id: null,
					params: this.convertParameters(t.parameters),
					returnType: t.type && this.convertTypeAnnotation(t.type, t),
					typeParameters: t.typeParameters && this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters)
				});
				h.typeParameters && this.fixParentLocation(h, h.typeParameters.range);
				let T = f.kind === x.StringLiteral ? this.createNode(f, {
					type: C.Literal,
					raw: f.getText(),
					value: "constructor"
				}) : this.createNode(t, {
					type: C.Identifier,
					range: [f.getStart(this.ast), f.end],
					decorators: [],
					name: "constructor",
					optional: !1,
					typeAnnotation: void 0
				}), k = Ge(x.StaticKeyword, t);
				return this.createNode(t, {
					type: Ge(x.AbstractKeyword, t) ? C.TSAbstractMethodDefinition : C.MethodDefinition,
					accessibility: Si(t),
					computed: !1,
					decorators: [],
					key: T,
					kind: k ? "method" : "constructor",
					optional: !1,
					override: !1,
					static: k,
					value: h
				});
			}
			case x.FunctionExpression: return this.createNode(t, {
				type: C.FunctionExpression,
				async: Ge(x.AsyncKeyword, t),
				body: this.convertChild(t.body),
				declare: !1,
				expression: !1,
				generator: !!t.asteriskToken,
				id: this.convertChild(t.name),
				params: this.convertParameters(t.parameters),
				returnType: t.type && this.convertTypeAnnotation(t.type, t),
				typeParameters: t.typeParameters && this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters)
			});
			case x.SuperKeyword: return this.createNode(t, { type: C.Super });
			case x.ArrayBindingPattern: return this.createNode(t, {
				type: C.ArrayPattern,
				decorators: [],
				elements: t.elements.map((_) => this.convertPattern(_)),
				optional: !1,
				typeAnnotation: void 0
			});
			case x.OmittedExpression: return null;
			case x.ObjectBindingPattern: return this.createNode(t, {
				type: C.ObjectPattern,
				decorators: [],
				optional: !1,
				properties: t.elements.map((_) => this.convertPattern(_)),
				typeAnnotation: void 0
			});
			case x.BindingElement: {
				if (a.kind === x.ArrayBindingPattern) {
					let f = this.convertChild(t.name, a);
					return t.initializer ? this.createNode(t, {
						type: C.AssignmentPattern,
						decorators: [],
						left: f,
						optional: !1,
						right: this.convertChild(t.initializer),
						typeAnnotation: void 0
					}) : t.dotDotDotToken ? this.createNode(t, {
						type: C.RestElement,
						argument: f,
						decorators: [],
						optional: !1,
						typeAnnotation: void 0,
						value: void 0
					}) : f;
				}
				let _;
				return t.dotDotDotToken ? _ = this.createNode(t, {
					type: C.RestElement,
					argument: this.convertChild(t.propertyName ?? t.name),
					decorators: [],
					optional: !1,
					typeAnnotation: void 0,
					value: void 0
				}) : _ = this.createNode(t, {
					type: C.Property,
					computed: !!(t.propertyName && t.propertyName.kind === x.ComputedPropertyName),
					key: this.convertChild(t.propertyName ?? t.name),
					kind: "init",
					method: !1,
					optional: !1,
					shorthand: !t.propertyName,
					value: this.convertChild(t.name)
				}), t.initializer && (_.value = this.createNode(t, {
					type: C.AssignmentPattern,
					range: [t.name.getStart(this.ast), t.initializer.end],
					decorators: [],
					left: this.convertChild(t.name),
					optional: !1,
					right: this.convertChild(t.initializer),
					typeAnnotation: void 0
				})), _;
			}
			case x.ArrowFunction: return this.createNode(t, {
				type: C.ArrowFunctionExpression,
				async: Ge(x.AsyncKeyword, t),
				body: this.convertChild(t.body),
				expression: t.body.kind !== x.Block,
				generator: !1,
				id: null,
				params: this.convertParameters(t.parameters),
				returnType: t.type && this.convertTypeAnnotation(t.type, t),
				typeParameters: t.typeParameters && this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters)
			});
			case x.YieldExpression: return this.createNode(t, {
				type: C.YieldExpression,
				argument: this.convertChild(t.expression),
				delegate: !!t.asteriskToken
			});
			case x.AwaitExpression: return this.createNode(t, {
				type: C.AwaitExpression,
				argument: this.convertChild(t.expression)
			});
			case x.NoSubstitutionTemplateLiteral: return this.createNode(t, {
				type: C.TemplateLiteral,
				expressions: [],
				quasis: [this.createNode(t, {
					type: C.TemplateElement,
					tail: !0,
					value: {
						cooked: t.text,
						raw: this.ast.text.slice(t.getStart(this.ast) + 1, t.end - 1)
					}
				})]
			});
			case x.TemplateExpression: {
				let _ = this.createNode(t, {
					type: C.TemplateLiteral,
					expressions: [],
					quasis: [this.convertChild(t.head)]
				});
				return t.templateSpans.forEach((f) => {
					_.expressions.push(this.convertChild(f.expression)), _.quasis.push(this.convertChild(f.literal));
				}), _;
			}
			case x.TaggedTemplateExpression: return t.tag.flags & sn.OptionalChain && this.#e(t, "Tagged template expressions are not permitted in an optional chain."), this.createNode(t, {
				type: C.TaggedTemplateExpression,
				quasi: this.convertChild(t.template),
				tag: this.convertChild(t.tag),
				typeArguments: t.typeArguments && this.convertTypeArgumentsToTypeParameterInstantiation(t.typeArguments, t)
			});
			case x.TemplateHead:
			case x.TemplateMiddle:
			case x.TemplateTail: {
				let _ = t.kind === x.TemplateTail;
				return this.createNode(t, {
					type: C.TemplateElement,
					tail: _,
					value: {
						cooked: t.text,
						raw: this.ast.text.slice(t.getStart(this.ast) + 1, t.end - (_ ? 1 : 2))
					}
				});
			}
			case x.SpreadAssignment:
			case x.SpreadElement: return this.allowPattern ? this.createNode(t, {
				type: C.RestElement,
				argument: this.convertPattern(t.expression),
				decorators: [],
				optional: !1,
				typeAnnotation: void 0,
				value: void 0
			}) : this.createNode(t, {
				type: C.SpreadElement,
				argument: this.convertChild(t.expression)
			});
			case x.Parameter: {
				let _, f;
				return t.dotDotDotToken ? _ = f = this.createNode(t, {
					type: C.RestElement,
					argument: this.convertChild(t.name),
					decorators: [],
					optional: !1,
					typeAnnotation: void 0,
					value: void 0
				}) : t.initializer ? (_ = this.convertChild(t.name), f = this.createNode(t, {
					type: C.AssignmentPattern,
					range: [t.name.getStart(this.ast), t.initializer.end],
					decorators: [],
					left: _,
					optional: !1,
					right: this.convertChild(t.initializer),
					typeAnnotation: void 0
				}), Rn(t) && (f.range[0] = _.range[0], f.loc = Kr(f.range, this.ast))) : _ = f = this.convertChild(t.name, a), t.type && (_.typeAnnotation = this.convertTypeAnnotation(t.type, t), this.fixParentLocation(_, _.typeAnnotation.range)), t.questionToken && (t.questionToken.end > _.range[1] && (_.range[1] = t.questionToken.end, _.loc.end = x_(_.range[1], this.ast)), _.optional = !0), Rn(t) ? this.createNode(t, {
					type: C.TSParameterProperty,
					accessibility: Si(t),
					decorators: [],
					override: Ge(x.OverrideKeyword, t),
					parameter: f,
					readonly: Ge(x.ReadonlyKeyword, t),
					static: Ge(x.StaticKeyword, t)
				}) : f;
			}
			case x.ClassDeclaration: !t.name && (!Ge(Ae.ExportKeyword, t) || !Ge(Ae.DefaultKeyword, t)) && this.#e(t, "A class declaration without the 'default' modifier must have a name.");
			case x.ClassExpression: {
				let _ = t.heritageClauses ?? [], f = t.kind === x.ClassDeclaration ? C.ClassDeclaration : C.ClassExpression, h, T;
				for (let c of _) {
					let { token: W, types: y } = c;
					y.length === 0 && this.#e(c, `'${nt(W)}' list cannot be empty.`), W === x.ExtendsKeyword ? (h && this.#e(c, "'extends' clause already seen."), T && this.#e(c, "'extends' clause must precede 'implements' clause."), y.length > 1 && this.#e(y[1], "Classes can only extend a single class."), h ?? (h = c)) : W === x.ImplementsKeyword && (T && this.#e(c, "'implements' clause already seen."), T ?? (T = c));
				}
				let k = this.createNode(t, {
					type: f,
					abstract: Ge(x.AbstractKeyword, t),
					body: this.createNode(t, {
						type: C.ClassBody,
						range: [t.members.pos - 1, t.end],
						body: this.convertChildren(t.members.filter(wh))
					}),
					declare: Ge(x.DeclareKeyword, t),
					decorators: this.convertChildren(xi(t) ?? []),
					id: this.convertChild(t.name),
					implements: this.convertChildren(T?.types ?? []),
					superClass: h?.types[0] ? this.convertChild(h.types[0].expression) : null,
					superTypeArguments: void 0,
					typeParameters: t.typeParameters && this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters)
				});
				return h?.types[0]?.typeArguments && (k.superTypeArguments = this.convertTypeArgumentsToTypeParameterInstantiation(h.types[0].typeArguments, h.types[0])), this.fixExports(t, k);
			}
			case x.ModuleBlock: return this.createNode(t, {
				type: C.TSModuleBlock,
				body: this.convertBodyExpressions(t.statements, t)
			});
			case x.ImportDeclaration: {
				this.assertModuleSpecifier(t, !1);
				let _ = this.createNode(t, this.#t({
					type: C.ImportDeclaration,
					attributes: this.convertImportAttributes(t),
					importKind: "value",
					source: this.convertChild(t.moduleSpecifier),
					specifiers: []
				}, "assertions", "attributes", !0));
				if (t.importClause && (t.importClause.isTypeOnly && (_.importKind = "type"), t.importClause.name && _.specifiers.push(this.convertChild(t.importClause)), t.importClause.namedBindings)) switch (t.importClause.namedBindings.kind) {
					case x.NamespaceImport:
						_.specifiers.push(this.convertChild(t.importClause.namedBindings));
						break;
					case x.NamedImports:
						_.specifiers.push(...this.convertChildren(t.importClause.namedBindings.elements));
						break;
				}
				return _;
			}
			case x.NamespaceImport: return this.createNode(t, {
				type: C.ImportNamespaceSpecifier,
				local: this.convertChild(t.name)
			});
			case x.ImportSpecifier: return this.createNode(t, {
				type: C.ImportSpecifier,
				imported: this.convertChild(t.propertyName ?? t.name),
				importKind: t.isTypeOnly ? "type" : "value",
				local: this.convertChild(t.name)
			});
			case x.ImportClause: {
				let _ = this.convertChild(t.name);
				return this.createNode(t, {
					type: C.ImportDefaultSpecifier,
					range: _.range,
					local: _
				});
			}
			case x.ExportDeclaration: return t.exportClause?.kind === x.NamedExports ? (this.assertModuleSpecifier(t, !0), this.createNode(t, this.#t({
				type: C.ExportNamedDeclaration,
				attributes: this.convertImportAttributes(t),
				declaration: null,
				exportKind: t.isTypeOnly ? "type" : "value",
				source: this.convertChild(t.moduleSpecifier),
				specifiers: this.convertChildren(t.exportClause.elements, t)
			}, "assertions", "attributes", !0))) : (this.assertModuleSpecifier(t, !1), this.createNode(t, this.#t({
				type: C.ExportAllDeclaration,
				attributes: this.convertImportAttributes(t),
				exported: t.exportClause?.kind === x.NamespaceExport ? this.convertChild(t.exportClause.name) : null,
				exportKind: t.isTypeOnly ? "type" : "value",
				source: this.convertChild(t.moduleSpecifier)
			}, "assertions", "attributes", !0)));
			case x.ExportSpecifier: {
				let _ = t.propertyName ?? t.name;
				return _.kind === x.StringLiteral && a.kind === x.ExportDeclaration && a.moduleSpecifier?.kind !== x.StringLiteral && this.#e(_, "A string literal cannot be used as a local exported binding without `from`."), this.createNode(t, {
					type: C.ExportSpecifier,
					exported: this.convertChild(t.name),
					exportKind: t.isTypeOnly ? "type" : "value",
					local: this.convertChild(_)
				});
			}
			case x.ExportAssignment: return t.isExportEquals ? this.createNode(t, {
				type: C.TSExportAssignment,
				expression: this.convertChild(t.expression)
			}) : this.createNode(t, {
				type: C.ExportDefaultDeclaration,
				declaration: this.convertChild(t.expression),
				exportKind: "value"
			});
			case x.PrefixUnaryExpression:
			case x.PostfixUnaryExpression: {
				let _ = Qr(t.operator);
				return _ === "++" || _ === "--" ? (Jl(t.operand) || this.#e(t.operand, "Invalid left-hand side expression in unary operation"), this.createNode(t, {
					type: C.UpdateExpression,
					argument: this.convertChild(t.operand),
					operator: _,
					prefix: t.kind === x.PrefixUnaryExpression
				})) : this.createNode(t, {
					type: C.UnaryExpression,
					argument: this.convertChild(t.operand),
					operator: _,
					prefix: t.kind === x.PrefixUnaryExpression
				});
			}
			case x.DeleteExpression: return this.createNode(t, {
				type: C.UnaryExpression,
				argument: this.convertChild(t.expression),
				operator: "delete",
				prefix: !0
			});
			case x.VoidExpression: return this.createNode(t, {
				type: C.UnaryExpression,
				argument: this.convertChild(t.expression),
				operator: "void",
				prefix: !0
			});
			case x.TypeOfExpression: return this.createNode(t, {
				type: C.UnaryExpression,
				argument: this.convertChild(t.expression),
				operator: "typeof",
				prefix: !0
			});
			case x.TypeOperator: return this.createNode(t, {
				type: C.TSTypeOperator,
				operator: Qr(t.operator),
				typeAnnotation: this.convertChild(t.type)
			});
			case x.BinaryExpression: {
				if (t.operatorToken.kind !== x.InKeyword && t.left.kind === x.PrivateIdentifier ? this.#e(t.left, "Private identifiers cannot appear on the right-hand-side of an 'in' expression.") : t.right.kind === x.PrivateIdentifier && this.#e(t.right, "Private identifiers are only allowed on the left-hand-side of an 'in' expression."), Eh(t.operatorToken)) {
					let f = this.createNode(t, {
						type: C.SequenceExpression,
						expressions: []
					}), h = this.convertChild(t.left);
					return h.type === C.SequenceExpression && t.left.kind !== x.ParenthesizedExpression ? f.expressions.push(...h.expressions) : f.expressions.push(h), f.expressions.push(this.convertChild(t.right)), f;
				}
				let _ = Ah(t.operatorToken);
				return this.allowPattern && _.type === C.AssignmentExpression ? this.createNode(t, {
					type: C.AssignmentPattern,
					decorators: [],
					left: this.convertPattern(t.left, t),
					optional: !1,
					right: this.convertChild(t.right),
					typeAnnotation: void 0
				}) : this.createNode(t, {
					..._,
					left: this.converter(t.left, t, _.type === C.AssignmentExpression),
					right: this.convertChild(t.right)
				});
			}
			case x.PropertyAccessExpression: {
				let _ = this.convertChild(t.expression), f = this.convertChild(t.name), T = this.createNode(t, {
					type: C.MemberExpression,
					computed: !1,
					object: _,
					optional: t.questionDotToken != null,
					property: f
				});
				return this.convertChainExpression(T, t);
			}
			case x.ElementAccessExpression: {
				let _ = this.convertChild(t.expression), f = this.convertChild(t.argumentExpression), T = this.createNode(t, {
					type: C.MemberExpression,
					computed: !0,
					object: _,
					optional: t.questionDotToken != null,
					property: f
				});
				return this.convertChainExpression(T, t);
			}
			case x.CallExpression: {
				if (t.expression.kind === x.ImportKeyword) return t.arguments.length !== 1 && t.arguments.length !== 2 && this.#e(t.arguments[2] ?? t, "Dynamic import requires exactly one or two arguments."), this.createNode(t, this.#t({
					type: C.ImportExpression,
					options: t.arguments[1] ? this.convertChild(t.arguments[1]) : null,
					source: this.convertChild(t.arguments[0])
				}, "attributes", "options", !0));
				let _ = this.convertChild(t.expression), f = this.convertChildren(t.arguments), h = t.typeArguments && this.convertTypeArgumentsToTypeParameterInstantiation(t.typeArguments, t), T = this.createNode(t, {
					type: C.CallExpression,
					arguments: f,
					callee: _,
					optional: t.questionDotToken != null,
					typeArguments: h
				});
				return this.convertChainExpression(T, t);
			}
			case x.NewExpression: {
				let _ = t.typeArguments && this.convertTypeArgumentsToTypeParameterInstantiation(t.typeArguments, t);
				return this.createNode(t, {
					type: C.NewExpression,
					arguments: this.convertChildren(t.arguments ?? []),
					callee: this.convertChild(t.expression),
					typeArguments: _
				});
			}
			case x.ConditionalExpression: return this.createNode(t, {
				type: C.ConditionalExpression,
				alternate: this.convertChild(t.whenFalse),
				consequent: this.convertChild(t.whenTrue),
				test: this.convertChild(t.condition)
			});
			case x.MetaProperty: return this.createNode(t, {
				type: C.MetaProperty,
				meta: this.createNode(t.getFirstToken(), {
					type: C.Identifier,
					decorators: [],
					name: Qr(t.keywordToken),
					optional: !1,
					typeAnnotation: void 0
				}),
				property: this.convertChild(t.name)
			});
			case x.Decorator: return this.createNode(t, {
				type: C.Decorator,
				expression: this.convertChild(t.expression)
			});
			case x.StringLiteral: return this.createNode(t, {
				type: C.Literal,
				raw: t.getText(),
				value: a.kind === x.JsxAttribute ? Kf(t.text) : t.text
			});
			case x.NumericLiteral: return this.createNode(t, {
				type: C.Literal,
				raw: t.getText(),
				value: Number(t.text)
			});
			case x.BigIntLiteral: {
				let _ = sa(t, this.ast), f = this.ast.text.slice(_[0], _[1]), h = Wr(0, f.slice(0, -1), "_", ""), T = typeof BigInt < "u" ? BigInt(h) : null;
				return this.createNode(t, {
					type: C.Literal,
					range: _,
					bigint: T == null ? h : String(T),
					raw: f,
					value: T
				});
			}
			case x.RegularExpressionLiteral: {
				let _ = t.text.slice(1, t.text.lastIndexOf("/")), f = t.text.slice(t.text.lastIndexOf("/") + 1), h = null;
				try {
					h = new RegExp(_, f);
				} catch {}
				return this.createNode(t, {
					type: C.Literal,
					raw: t.text,
					regex: {
						flags: f,
						pattern: _
					},
					value: h
				});
			}
			case x.TrueKeyword: return this.createNode(t, {
				type: C.Literal,
				raw: "true",
				value: !0
			});
			case x.FalseKeyword: return this.createNode(t, {
				type: C.Literal,
				raw: "false",
				value: !1
			});
			case x.NullKeyword: return this.createNode(t, {
				type: C.Literal,
				raw: "null",
				value: null
			});
			case x.EmptyStatement: return this.createNode(t, { type: C.EmptyStatement });
			case x.DebuggerStatement: return this.createNode(t, { type: C.DebuggerStatement });
			case x.JsxElement: return this.createNode(t, {
				type: C.JSXElement,
				children: this.convertChildren(t.children),
				closingElement: this.convertChild(t.closingElement),
				openingElement: this.convertChild(t.openingElement)
			});
			case x.JsxFragment: return this.createNode(t, {
				type: C.JSXFragment,
				children: this.convertChildren(t.children),
				closingFragment: this.convertChild(t.closingFragment),
				openingFragment: this.convertChild(t.openingFragment)
			});
			case x.JsxSelfClosingElement: return this.createNode(t, {
				type: C.JSXElement,
				children: [],
				closingElement: null,
				openingElement: this.createNode(t, {
					type: C.JSXOpeningElement,
					range: sa(t, this.ast),
					attributes: this.convertChildren(t.attributes.properties),
					name: this.convertJSXTagName(t.tagName, t),
					selfClosing: !0,
					typeArguments: t.typeArguments ? this.convertTypeArgumentsToTypeParameterInstantiation(t.typeArguments, t) : void 0
				})
			});
			case x.JsxOpeningElement: return this.createNode(t, {
				type: C.JSXOpeningElement,
				attributes: this.convertChildren(t.attributes.properties),
				name: this.convertJSXTagName(t.tagName, t),
				selfClosing: !1,
				typeArguments: t.typeArguments && this.convertTypeArgumentsToTypeParameterInstantiation(t.typeArguments, t)
			});
			case x.JsxClosingElement: return this.createNode(t, {
				type: C.JSXClosingElement,
				name: this.convertJSXTagName(t.tagName, t)
			});
			case x.JsxOpeningFragment: return this.createNode(t, { type: C.JSXOpeningFragment });
			case x.JsxClosingFragment: return this.createNode(t, { type: C.JSXClosingFragment });
			case x.JsxExpression: {
				let _ = t.expression ? this.convertChild(t.expression) : this.createNode(t, {
					type: C.JSXEmptyExpression,
					range: [t.getStart(this.ast) + 1, t.getEnd() - 1]
				});
				return t.dotDotDotToken ? this.createNode(t, {
					type: C.JSXSpreadChild,
					expression: _
				}) : this.createNode(t, {
					type: C.JSXExpressionContainer,
					expression: _
				});
			}
			case x.JsxAttribute: return this.createNode(t, {
				type: C.JSXAttribute,
				name: this.convertJSXNamespaceOrIdentifier(t.name),
				value: this.convertChild(t.initializer)
			});
			case x.JsxText: {
				let _ = t.getFullStart(), f = t.getEnd(), h = this.ast.text.slice(_, f);
				return this.createNode(t, {
					type: C.JSXText,
					range: [_, f],
					raw: h,
					value: Kf(h)
				});
			}
			case x.JsxSpreadAttribute: return this.createNode(t, {
				type: C.JSXSpreadAttribute,
				argument: this.convertChild(t.expression)
			});
			case x.QualifiedName: return this.createNode(t, {
				type: C.TSQualifiedName,
				left: this.convertChild(t.left),
				right: this.convertChild(t.right)
			});
			case x.TypeReference: return this.createNode(t, {
				type: C.TSTypeReference,
				typeArguments: t.typeArguments && this.convertTypeArgumentsToTypeParameterInstantiation(t.typeArguments, t),
				typeName: this.convertChild(t.typeName)
			});
			case x.TypeParameter: return this.createNode(t, {
				type: C.TSTypeParameter,
				const: Ge(x.ConstKeyword, t),
				constraint: t.constraint && this.convertChild(t.constraint),
				default: t.default ? this.convertChild(t.default) : void 0,
				in: Ge(x.InKeyword, t),
				name: this.convertChild(t.name),
				out: Ge(x.OutKeyword, t)
			});
			case x.ThisType: return this.createNode(t, { type: C.TSThisType });
			case x.AnyKeyword:
			case x.BigIntKeyword:
			case x.BooleanKeyword:
			case x.NeverKeyword:
			case x.NumberKeyword:
			case x.ObjectKeyword:
			case x.StringKeyword:
			case x.SymbolKeyword:
			case x.UnknownKeyword:
			case x.VoidKeyword:
			case x.UndefinedKeyword:
			case x.IntrinsicKeyword: return this.createNode(t, { type: C[`TS${x[t.kind]}`] });
			case x.NonNullExpression: {
				let _ = this.createNode(t, {
					type: C.TSNonNullExpression,
					expression: this.convertChild(t.expression)
				});
				return this.convertChainExpression(_, t);
			}
			case x.TypeLiteral: return this.createNode(t, {
				type: C.TSTypeLiteral,
				members: this.convertChildren(t.members)
			});
			case x.ArrayType: return this.createNode(t, {
				type: C.TSArrayType,
				elementType: this.convertChild(t.elementType)
			});
			case x.IndexedAccessType: return this.createNode(t, {
				type: C.TSIndexedAccessType,
				indexType: this.convertChild(t.indexType),
				objectType: this.convertChild(t.objectType)
			});
			case x.ConditionalType: return this.createNode(t, {
				type: C.TSConditionalType,
				checkType: this.convertChild(t.checkType),
				extendsType: this.convertChild(t.extendsType),
				falseType: this.convertChild(t.falseType),
				trueType: this.convertChild(t.trueType)
			});
			case x.TypeQuery: return this.createNode(t, {
				type: C.TSTypeQuery,
				exprName: this.convertChild(t.exprName),
				typeArguments: t.typeArguments && this.convertTypeArgumentsToTypeParameterInstantiation(t.typeArguments, t)
			});
			case x.MappedType: return t.members && t.members.length > 0 && this.#e(t.members[0], "A mapped type may not declare properties or methods."), this.createNode(t, this.#n({
				type: C.TSMappedType,
				constraint: this.convertChild(t.typeParameter.constraint),
				key: this.convertChild(t.typeParameter.name),
				nameType: this.convertChild(t.nameType) ?? null,
				optional: t.questionToken ? t.questionToken.kind === x.QuestionToken || Qr(t.questionToken.kind) : !1,
				readonly: t.readonlyToken ? t.readonlyToken.kind === x.ReadonlyKeyword || Qr(t.readonlyToken.kind) : void 0,
				typeAnnotation: t.type && this.convertChild(t.type)
			}, "typeParameter", "'constraint' and 'key'", this.convertChild(t.typeParameter)));
			case x.ParenthesizedExpression: return this.convertChild(t.expression, a);
			case x.TypeAliasDeclaration: {
				let _ = this.createNode(t, {
					type: C.TSTypeAliasDeclaration,
					declare: Ge(x.DeclareKeyword, t),
					id: this.convertChild(t.name),
					typeAnnotation: this.convertChild(t.type),
					typeParameters: t.typeParameters && this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters)
				});
				return this.fixExports(t, _);
			}
			case x.MethodSignature: return this.convertMethodSignature(t);
			case x.PropertySignature: {
				let { initializer: _ } = t;
				return _ && this.#e(_, "A property signature cannot have an initializer."), this.createNode(t, {
					type: C.TSPropertySignature,
					accessibility: Si(t),
					computed: _a(t.name),
					key: this.convertChild(t.name),
					optional: Zf(t),
					readonly: Ge(x.ReadonlyKeyword, t),
					static: Ge(x.StaticKeyword, t),
					typeAnnotation: t.type && this.convertTypeAnnotation(t.type, t)
				});
			}
			case x.IndexSignature: return this.createNode(t, {
				type: C.TSIndexSignature,
				accessibility: Si(t),
				parameters: this.convertChildren(t.parameters),
				readonly: Ge(x.ReadonlyKeyword, t),
				static: Ge(x.StaticKeyword, t),
				typeAnnotation: t.type && this.convertTypeAnnotation(t.type, t)
			});
			case x.ConstructorType: return this.createNode(t, {
				type: C.TSConstructorType,
				abstract: Ge(x.AbstractKeyword, t),
				params: this.convertParameters(t.parameters),
				returnType: t.type && this.convertTypeAnnotation(t.type, t),
				typeParameters: t.typeParameters && this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters)
			});
			case x.FunctionType: {
				let { modifiers: _ } = t;
				_ && this.#e(_[0], "A function type cannot have modifiers.");
			}
			case x.ConstructSignature:
			case x.CallSignature: {
				let _ = t.kind === x.ConstructSignature ? C.TSConstructSignatureDeclaration : t.kind === x.CallSignature ? C.TSCallSignatureDeclaration : C.TSFunctionType;
				return this.createNode(t, {
					type: _,
					params: this.convertParameters(t.parameters),
					returnType: t.type && this.convertTypeAnnotation(t.type, t),
					typeParameters: t.typeParameters && this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters)
				});
			}
			case x.ExpressionWithTypeArguments: {
				let _ = a.kind, f = _ === x.InterfaceDeclaration ? C.TSInterfaceHeritage : _ === x.HeritageClause ? C.TSClassImplements : C.TSInstantiationExpression;
				return this.createNode(t, {
					type: f,
					expression: this.convertChild(t.expression),
					typeArguments: t.typeArguments && this.convertTypeArgumentsToTypeParameterInstantiation(t.typeArguments, t)
				});
			}
			case x.InterfaceDeclaration: {
				let _ = t.heritageClauses ?? [], f = [], h = !1;
				for (let k of _) {
					k.token !== x.ExtendsKeyword && this.#e(k, k.token === x.ImplementsKeyword ? "Interface declaration cannot have 'implements' clause." : "Unexpected token."), h && this.#e(k, "'extends' clause already seen."), h = !0;
					for (let c of k.types) (!jh(c.expression) || e1(c.expression)) && this.#e(c, "Interface declaration can only extend an identifier/qualified name with optional type arguments."), f.push(this.convertChild(c, t));
				}
				let T = this.createNode(t, {
					type: C.TSInterfaceDeclaration,
					body: this.createNode(t, {
						type: C.TSInterfaceBody,
						range: [t.members.pos - 1, t.end],
						body: this.convertChildren(t.members)
					}),
					declare: Ge(x.DeclareKeyword, t),
					extends: f,
					id: this.convertChild(t.name),
					typeParameters: t.typeParameters && this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters)
				});
				return this.fixExports(t, T);
			}
			case x.TypePredicate: {
				let _ = this.createNode(t, {
					type: C.TSTypePredicate,
					asserts: t.assertsModifier != null,
					parameterName: this.convertChild(t.parameterName),
					typeAnnotation: null
				});
				return t.type && (_.typeAnnotation = this.convertTypeAnnotation(t.type, t), _.typeAnnotation.loc = _.typeAnnotation.typeAnnotation.loc, _.typeAnnotation.range = _.typeAnnotation.typeAnnotation.range), _;
			}
			case x.ImportType: {
				let _ = sa(t, this.ast);
				if (t.isTypeOf) _[0] = er(t.getFirstToken(), t, this.ast).getStart(this.ast);
				let f = null;
				if (t.attributes) {
					let c = this.createNode(t.attributes, {
						type: C.ObjectExpression,
						properties: t.attributes.elements.map((be) => this.createNode(be, {
							type: C.Property,
							computed: !1,
							key: this.convertChild(be.name),
							kind: "init",
							method: !1,
							optional: !1,
							shorthand: !1,
							value: this.convertChild(be.value)
						}))
					}), y = er(er(t.argument, t, this.ast), t, this.ast), G = er(t.attributes, t, this.ast), E = G.kind === Ae.CommaToken ? er(G, t, this.ast) : G, D = er(y, t, this.ast), R = sa(D, this.ast), ue = D.kind === Ae.AssertKeyword ? "assert" : "with";
					f = this.createNode(t, {
						type: C.ObjectExpression,
						range: [y.getStart(this.ast), E.end],
						properties: [this.createNode(t, {
							type: C.Property,
							range: [R[0], t.attributes.end],
							computed: !1,
							key: this.createNode(t, {
								type: C.Identifier,
								range: R,
								decorators: [],
								name: ue,
								optional: !1,
								typeAnnotation: void 0
							}),
							kind: "init",
							method: !1,
							optional: !1,
							shorthand: !1,
							value: c
						})]
					});
				}
				let h = this.convertChild(t.argument), T = h.literal, k = this.createNode(t, this.#n({
					type: C.TSImportType,
					range: _,
					options: f,
					qualifier: this.convertChild(t.qualifier),
					source: T,
					typeArguments: t.typeArguments ? this.convertTypeArgumentsToTypeParameterInstantiation(t.typeArguments, t) : null
				}, "argument", "source", h));
				return t.isTypeOf ? this.createNode(t, {
					type: C.TSTypeQuery,
					exprName: k,
					typeArguments: void 0
				}) : k;
			}
			case x.EnumDeclaration: {
				let _ = this.convertChildren(t.members), f = this.createNode(t, this.#n({
					type: C.TSEnumDeclaration,
					body: this.createNode(t, {
						type: C.TSEnumBody,
						range: [t.members.pos - 1, t.end],
						members: _
					}),
					const: Ge(x.ConstKeyword, t),
					declare: Ge(x.DeclareKeyword, t),
					id: this.convertChild(t.name)
				}, "members", "'body.members'", this.convertChildren(t.members)));
				return this.fixExports(t, f);
			}
			case x.EnumMember: {
				let _ = t.name.kind === Ae.ComputedPropertyName;
				return _ && this.#e(t.name, "Computed property names are not allowed in enums."), (t.name.kind === x.NumericLiteral || t.name.kind === x.BigIntLiteral) && this.#e(t.name, "An enum member cannot have a numeric name."), this.createNode(t, this.#n({
					type: C.TSEnumMember,
					id: this.convertChild(t.name),
					initializer: t.initializer && this.convertChild(t.initializer)
				}, "computed", void 0, _));
			}
			case x.ModuleDeclaration: {
				let _ = Ge(x.DeclareKeyword, t), f = this.createNode(t, {
					type: C.TSModuleDeclaration,
					...(() => {
						if (t.flags & sn.GlobalAugmentation) {
							let T = this.convertChild(t.name), k = this.convertChild(t.body);
							return (k == null || k.type === C.TSModuleDeclaration) && this.#e(t.body ?? t, "Expected a valid module body"), T.type !== C.Identifier && this.#e(t.name, "global module augmentation must have an Identifier id"), {
								body: k,
								declare: !1,
								global: !1,
								id: T,
								kind: "global"
							};
						}
						if (vi(t.name)) {
							let T = this.convertChild(t.body);
							return {
								kind: "module",
								...T != null ? { body: T } : {},
								declare: !1,
								global: !1,
								id: this.convertChild(t.name)
							};
						}
						t.body ?? this.#e(t, "Expected a module body"), t.name.kind !== Ae.Identifier && this.#e(t.name, "`namespace`s must have an Identifier id");
						let h = this.createNode(t.name, {
							type: C.Identifier,
							range: [t.name.getStart(this.ast), t.name.getEnd()],
							decorators: [],
							name: t.name.text,
							optional: !1,
							typeAnnotation: void 0
						});
						for (; t.body && Ti(t.body) && t.body.name;) {
							t = t.body, _ || (_ = Ge(x.DeclareKeyword, t));
							let T = t.name, k = this.createNode(T, {
								type: C.Identifier,
								range: [T.getStart(this.ast), T.getEnd()],
								decorators: [],
								name: T.text,
								optional: !1,
								typeAnnotation: void 0
							});
							h = this.createNode(T, {
								type: C.TSQualifiedName,
								range: [h.range[0], k.range[1]],
								left: h,
								right: k
							});
						}
						return {
							body: this.convertChild(t.body),
							declare: !1,
							global: !1,
							id: h,
							kind: t.flags & sn.Namespace ? "namespace" : "module"
						};
					})()
				});
				return f.declare = _, t.flags & sn.GlobalAugmentation && (f.global = !0), this.fixExports(t, f);
			}
			case x.ParenthesizedType: return this.convertChild(t.type);
			case x.UnionType: return this.createNode(t, {
				type: C.TSUnionType,
				types: this.convertChildren(t.types)
			});
			case x.IntersectionType: return this.createNode(t, {
				type: C.TSIntersectionType,
				types: this.convertChildren(t.types)
			});
			case x.AsExpression: return this.createNode(t, {
				type: C.TSAsExpression,
				expression: this.convertChild(t.expression),
				typeAnnotation: this.convertChild(t.type)
			});
			case x.InferType: return this.createNode(t, {
				type: C.TSInferType,
				typeParameter: this.convertChild(t.typeParameter)
			});
			case x.LiteralType: return t.literal.kind === x.NullKeyword ? this.createNode(t.literal, { type: C.TSNullKeyword }) : this.createNode(t, {
				type: C.TSLiteralType,
				literal: this.convertChild(t.literal)
			});
			case x.TypeAssertionExpression: return this.createNode(t, {
				type: C.TSTypeAssertion,
				expression: this.convertChild(t.expression),
				typeAnnotation: this.convertChild(t.type)
			});
			case x.ImportEqualsDeclaration: return this.fixExports(t, this.createNode(t, {
				type: C.TSImportEqualsDeclaration,
				id: this.convertChild(t.name),
				importKind: t.isTypeOnly ? "type" : "value",
				moduleReference: this.convertChild(t.moduleReference)
			}));
			case x.ExternalModuleReference: return t.expression.kind !== x.StringLiteral && this.#e(t.expression, "String literal expected."), this.createNode(t, {
				type: C.TSExternalModuleReference,
				expression: this.convertChild(t.expression)
			});
			case x.NamespaceExportDeclaration: return this.createNode(t, {
				type: C.TSNamespaceExportDeclaration,
				id: this.convertChild(t.name)
			});
			case x.AbstractKeyword: return this.createNode(t, { type: C.TSAbstractKeyword });
			case x.TupleType: {
				let _ = this.convertChildren(t.elements);
				return this.createNode(t, {
					type: C.TSTupleType,
					elementTypes: _
				});
			}
			case x.NamedTupleMember: {
				let _ = this.createNode(t, {
					type: C.TSNamedTupleMember,
					elementType: this.convertChild(t.type, t),
					label: this.convertChild(t.name, t),
					optional: t.questionToken != null
				});
				return t.dotDotDotToken ? (_.range[0] = _.label.range[0], _.loc.start = _.label.loc.start, this.createNode(t, {
					type: C.TSRestType,
					typeAnnotation: _
				})) : _;
			}
			case x.OptionalType: return this.createNode(t, {
				type: C.TSOptionalType,
				typeAnnotation: this.convertChild(t.type)
			});
			case x.RestType: return this.createNode(t, {
				type: C.TSRestType,
				typeAnnotation: this.convertChild(t.type)
			});
			case x.TemplateLiteralType: {
				let _ = this.createNode(t, {
					type: C.TSTemplateLiteralType,
					quasis: [this.convertChild(t.head)],
					types: []
				});
				return t.templateSpans.forEach((f) => {
					_.types.push(this.convertChild(f.type)), _.quasis.push(this.convertChild(f.literal));
				}), _;
			}
			case x.ClassStaticBlockDeclaration: return this.createNode(t, {
				type: C.StaticBlock,
				body: this.convertBodyExpressions(t.body.statements, t)
			});
			case x.AssertEntry:
			case x.ImportAttribute: return this.createNode(t, {
				type: C.ImportAttribute,
				key: this.convertChild(t.name),
				value: this.convertChild(t.value)
			});
			case x.SatisfiesExpression: return this.createNode(t, {
				type: C.TSSatisfiesExpression,
				expression: this.convertChild(t.expression),
				typeAnnotation: this.convertChild(t.type)
			});
			default: return this.deeplyCopy(t);
		}
	}
	createNode(t, a) {
		let _ = a;
		return _.range ?? (_.range = sa(t, this.ast)), _.loc ?? (_.loc = Kr(_.range, this.ast)), _ && this.options.shouldPreserveNodeMaps && this.esTreeNodeToTSNodeMap.set(_, t), _;
	}
	convertProgram() {
		return this.converter(this.ast);
	}
	deeplyCopy(t) {
		t.kind === Ae.JSDocFunctionType && this.#e(t, "JSDoc types can only be used inside documentation comments.");
		let a = `TS${x[t.kind]}`;
		if (this.options.errorOnUnknownASTType && !C[a]) throw new Error(`Unknown AST_NODE_TYPE: "${a}"`);
		let _ = this.createNode(t, { type: a });
		"type" in t && (_.typeAnnotation = t.type && "kind" in t.type && i1(t.type) ? this.convertTypeAnnotation(t.type, t) : null), "typeArguments" in t && (_.typeArguments = t.typeArguments && "pos" in t.typeArguments ? this.convertTypeArgumentsToTypeParameterInstantiation(t.typeArguments, t) : null), "typeParameters" in t && (_.typeParameters = t.typeParameters && "pos" in t.typeParameters ? this.convertTSTypeParametersToTypeParametersDeclaration(t.typeParameters) : null);
		let f = xi(t);
		f?.length && (_.decorators = this.convertChildren(f));
		let h = new Set([
			"_children",
			"decorators",
			"end",
			"flags",
			"heritageClauses",
			"illegalDecorators",
			"jsDoc",
			"kind",
			"locals",
			"localSymbol",
			"modifierFlagsCache",
			"modifiers",
			"nextContainer",
			"parent",
			"pos",
			"symbol",
			"transformFlags",
			"type",
			"typeArguments",
			"typeParameters"
		]);
		return Object.entries(t).filter(([T]) => !h.has(T)).forEach(([T, k]) => {
			Array.isArray(k) ? _[T] = this.convertChildren(k) : k && typeof k == "object" && k.kind ? _[T] = this.convertChild(k) : _[T] = k;
		}), _;
	}
	fixExports(t, a) {
		let f = Ti(t) && !vi(t.name) ? Oh(t) : Rn(t);
		if (f?.[0].kind === x.ExportKeyword) {
			this.registerTSNodeInNodeMap(t, a);
			let h = f[0], T = f[1], k = T?.kind === x.DefaultKeyword, c = k ? er(T, this.ast, this.ast) : er(h, this.ast, this.ast);
			if (a.range[0] = c.getStart(this.ast), a.loc = Kr(a.range, this.ast), k) return this.createNode(t, {
				type: C.ExportDefaultDeclaration,
				range: [h.getStart(this.ast), a.range[1]],
				declaration: a,
				exportKind: "value"
			});
			let W = a.type === C.TSInterfaceDeclaration || a.type === C.TSTypeAliasDeclaration, y = "declare" in a && a.declare;
			return this.createNode(t, this.#t({
				type: C.ExportNamedDeclaration,
				range: [h.getStart(this.ast), a.range[1]],
				attributes: [],
				declaration: a,
				exportKind: W || y ? "type" : "value",
				source: null,
				specifiers: []
			}, "assertions", "attributes", !0));
		}
		return a;
	}
	getASTMaps() {
		return {
			esTreeNodeToTSNodeMap: this.esTreeNodeToTSNodeMap,
			tsNodeToESTreeNodeMap: this.tsNodeToESTreeNodeMap
		};
	}
	registerTSNodeInNodeMap(t, a) {
		a && this.options.shouldPreserveNodeMaps && !this.tsNodeToESTreeNodeMap.has(t) && this.tsNodeToESTreeNodeMap.set(t, a);
	}
};
function Nv(e, t, a = e.getSourceFile()) {
	let _ = [];
	for (;;) {
		if (df(e.kind)) t(e);
		else {
			let f = e.getChildren(a);
			if (f.length === 1) {
				e = f[0];
				continue;
			}
			for (let h = f.length - 1; h >= 0; --h) _.push(f[h]);
		}
		if (_.length === 0) break;
		e = _.pop();
	}
}
function Uh(e, t, a = e.getSourceFile()) {
	let _ = a.text, f = a.languageVariant !== wl.JSX;
	return Nv(e, (T) => {
		if (T.pos !== T.end && (T.kind !== Ae.JsxText && Vm(_, T.pos === 0 ? (af(_) ?? "").length : T.pos, h), f || Iv(T))) return Wm(_, T.end, h);
	}, a);
	function h(T, k, c) {
		t(_, {
			end: k,
			kind: c,
			pos: T
		});
	}
}
function Iv(e) {
	switch (e.kind) {
		case Ae.CloseBraceToken: return e.parent.kind !== Ae.JsxExpression || !rd(e.parent.parent);
		case Ae.GreaterThanToken: switch (e.parent.kind) {
			case Ae.JsxClosingElement:
			case Ae.JsxClosingFragment: return !rd(e.parent.parent.parent);
			case Ae.JsxOpeningElement: return e.end !== e.parent.end;
			case Ae.JsxOpeningFragment: return !1;
			case Ae.JsxSelfClosingElement: return e.end !== e.parent.end || !rd(e.parent.parent);
		}
	}
	return !0;
}
function rd(e) {
	return e.kind === Ae.JsxElement || e.kind === Ae.JsxFragment;
}
var [rx, ix] = gm.split(".").map((e) => Number.parseInt(e, 10));
en.Intrinsic ?? en.Any | en.Unknown | en.String | en.Number | en.BigInt | en.Boolean | en.BooleanLiteral | en.ESSymbol | en.Void | en.Undefined | en.Null | en.Never | en.NonPrimitive;
function Bh(e, t) {
	let a = [];
	return Uh(e, (_, f) => {
		let h = f.kind === Ae.SingleLineCommentTrivia ? Rt.Line : Rt.Block, T = [f.pos, f.end], k = Kr(T, e), c = T[0] + 2, W = f.kind === Ae.SingleLineCommentTrivia ? T[1] : T[1] - 2;
		a.push({
			type: h,
			loc: k,
			range: T,
			value: t.slice(c, W)
		});
	}, e), a;
}
var qh = () => {};
function Fh(e, t, a) {
	let { parseDiagnostics: _ } = e;
	if (_.length) throw nd(_[0]);
	let f = new Rl(e, {
		allowInvalidAST: t.allowInvalidAST,
		errorOnUnknownASTType: t.errorOnUnknownASTType,
		shouldPreserveNodeMaps: a,
		suppressDeprecatedPropertyWarnings: t.suppressDeprecatedPropertyWarnings
	}), h = f.convertProgram();
	return (!t.range || !t.loc) && qh(h, { enter: (k) => {
		t.range || delete k.range, t.loc || delete k.loc;
	} }), t.tokens && (h.tokens = Nh(e)), t.comment && (h.comments = Bh(e, t.codeFullText)), {
		astMaps: f.getASTMaps(),
		estree: h
	};
}
function Ul(e) {
	if (typeof e != "object" || e == null) return !1;
	let t = e;
	return t.kind === Ae.SourceFile && typeof t.getFullText == "function";
}
var Uv = function(e) {
	return e && e.__esModule ? e : { default: e };
};
var Bv = Uv({ extname: (e) => "." + e.split(".").pop() });
function Vh(e, t) {
	switch (Bv.default.extname(e).toLowerCase()) {
		case Cn.Cjs:
		case Cn.Js:
		case Cn.Mjs: return Pr.JS;
		case Cn.Cts:
		case Cn.Mts:
		case Cn.Ts: return Pr.TS;
		case Cn.Json: return Pr.JSON;
		case Cn.Jsx: return Pr.JSX;
		case Cn.Tsx: return Pr.TSX;
		default: return t ? Pr.TSX : Pr.TS;
	}
}
var zv = (0, { default: Na }.default)("typescript-eslint:typescript-estree:create-program:createSourceFile");
function Wh(e) {
	return zv("Getting AST without type information in %s mode for: %s", e.jsx ? "TSX" : "TS", e.filePath), Ul(e.code) ? e.code : lh(e.filePath, e.codeFullText, {
		jsDocParsingMode: e.jsDocParsingMode,
		languageVersion: g_.Latest,
		setExternalModuleIndicator: e.setExternalModuleIndicator
	}, !0, Vh(e.filePath, e.jsx));
}
var Gh = (e) => e;
var Yh = () => {};
var Hh = class {};
var $h = () => !1;
var Qh = () => {};
var n4 = function(e) {
	return e && e.__esModule ? e : { default: e };
};
var r4 = {}, id = { default: Na }, i4 = n4({ extname: (e) => "." + e.split(".").pop() }), a4 = (0, id.default)("typescript-eslint:typescript-estree:parseSettings:createParseSettings"), s4, Kh = null, k_ = {
	ParseAll: Ya?.ParseAll,
	ParseForTypeErrors: Ya?.ParseForTypeErrors,
	ParseForTypeInfo: Ya?.ParseForTypeInfo,
	ParseNone: Ya?.ParseNone
};
function Zh(e, t = {}) {
	let a = _4(e), _ = $h(t), f = void 0, h = typeof t.loggerFn == "function", T = Gh(typeof t.filePath == "string" && t.filePath !== "<input>" ? t.filePath : o4(t.jsx), f), k = i4.default.extname(T).toLowerCase(), c = (() => {
		switch (t.jsDocParsingMode) {
			case "all": return k_.ParseAll;
			case "none": return k_.ParseNone;
			case "type-info": return k_.ParseForTypeInfo;
			default: return k_.ParseAll;
		}
	})(), W = {
		loc: t.loc === !0,
		range: t.range === !0,
		allowInvalidAST: t.allowInvalidAST === !0,
		code: e,
		codeFullText: a,
		comment: t.comment === !0,
		comments: [],
		debugLevel: t.debugLevel === !0 ? new Set(["typescript-eslint"]) : Array.isArray(t.debugLevel) ? new Set(t.debugLevel) : /* @__PURE__ */ new Set(),
		errorOnTypeScriptSyntacticAndSemanticIssues: !1,
		errorOnUnknownASTType: t.errorOnUnknownASTType === !0,
		extraFileExtensions: Array.isArray(t.extraFileExtensions) && t.extraFileExtensions.every((y) => typeof y == "string") ? t.extraFileExtensions : [],
		filePath: T,
		jsDocParsingMode: c,
		jsx: t.jsx === !0,
		log: typeof t.loggerFn == "function" ? t.loggerFn : t.loggerFn === !1 ? () => {} : console.log,
		preserveNodeMaps: t.preserveNodeMaps !== !1,
		programs: Array.isArray(t.programs) ? t.programs : null,
		projects: /* @__PURE__ */ new Map(),
		projectService: t.projectService || t.project && t.projectService !== !1 && (void 0).env.TYPESCRIPT_ESLINT_PROJECT_SERVICE === "true" ? c4(t.projectService, {
			jsDocParsingMode: c,
			tsconfigRootDir: f
		}) : void 0,
		setExternalModuleIndicator: t.sourceType === "module" || t.sourceType == null && k === Cn.Mjs || t.sourceType == null && k === Cn.Mts ? (y) => {
			y.externalModuleIndicator = !0;
		} : void 0,
		singleRun: _,
		suppressDeprecatedPropertyWarnings: t.suppressDeprecatedPropertyWarnings ?? !0,
		tokens: t.tokens === !0 ? [] : null,
		tsconfigMatchCache: s4 ?? (s4 = new Hh(_ ? "Infinity" : t.cacheLifetime?.glob ?? void 0)),
		tsconfigRootDir: f
	};
	if (W.projectService && t.project && (void 0).env.TYPESCRIPT_ESLINT_IGNORE_PROJECT_AND_PROJECT_SERVICE_ERROR !== "true") throw new Error("Enabling \"project\" does nothing when \"projectService\" is enabled. You can remove the \"project\" setting.");
	if (W.debugLevel.size > 0) {
		let y = [];
		W.debugLevel.has("typescript-eslint") && y.push("typescript-eslint:*"), (W.debugLevel.has("eslint") || id.default.enabled("eslint:*,-eslint:code-path")) && y.push("eslint:*,-eslint:code-path"), id.default.enable(y.join(","));
	}
	if (Array.isArray(t.programs)) {
		if (!t.programs.length) throw new Error("You have set parserOptions.programs to an empty array. This will cause all files to not be found in existing programs. Either provide one or more existing TypeScript Program instances in the array, or remove the parserOptions.programs setting.");
		a4("parserOptions.programs was provided, so parserOptions.project will be ignored.");
	}
	return !W.programs && !W.projectService && (W.projects = /* @__PURE__ */ new Map()), t.jsDocParsingMode == null && W.projects.size === 0 && W.programs == null && W.projectService == null && (W.jsDocParsingMode = k_.ParseNone), Qh(W, h), W;
}
function _4(e) {
	return Ul(e) ? e.getFullText(e) : typeof e == "string" ? e : String(e);
}
function o4(e) {
	return e ? "estree.tsx" : "estree.ts";
}
function c4(e, t) {
	let a = typeof e == "object" ? e : {};
	return Yh(a.allowDefaultProject), Kh ?? (Kh = (0, r4.createProjectService)({
		options: a,
		...t
	})), Kh;
}
(0, { default: Na }.default)("typescript-eslint:typescript-estree:parser");
function e0(e, t) {
	let { ast: a } = d4(e, t, !1);
	return a;
}
function d4(e, t, a) {
	let _ = Zh(e, t);
	if (t?.errorOnTypeScriptSyntacticAndSemanticIssues) throw new Error("\"errorOnTypeScriptSyntacticAndSemanticIssues\" is only supported for parseAndGenerateServices()");
	let { astMaps: h, estree: T } = Fh(Wh(_), _, a);
	return {
		ast: T,
		esTreeNodeToTSNodeMap: h.esTreeNodeToTSNodeMap,
		tsNodeToESTreeNodeMap: h.tsNodeToESTreeNodeMap
	};
}
function m4(e, t) {
	let a = /* @__PURE__ */ new SyntaxError(e + " (" + t.loc.start.line + ":" + t.loc.start.column + ")");
	return Object.assign(a, t);
}
var t0 = m4;
function n0(e) {
	let t = [];
	for (let a of e) try {
		return a();
	} catch (_) {
		t.push(_);
	}
	throw Object.assign(/* @__PURE__ */ new Error("All combinations failed"), { errors: t });
}
var h4 = Array.prototype.findLast ?? function(e) {
	for (let t = this.length - 1; t >= 0; t--) {
		let a = this[t];
		if (e(a, t, this)) return a;
	}
}, r0 = Ia("findLast", function() {
	if (Array.isArray(this)) return h4;
});
function g4(e) {
	return this[e < 0 ? this.length + e : e];
}
var i0 = Ia("at", function() {
	if (Array.isArray(this) || typeof this == "string") return g4;
});
function tr(e) {
	let t = e.range?.[0] ?? e.start, a = (e.declaration?.decorators ?? e.decorators)?.[0];
	return a ? Math.min(tr(a), t) : t;
}
function Un(e) {
	return e.range?.[1] ?? e.end;
}
function v4(e) {
	let t = new Set(e);
	return (a) => t.has(a?.type);
}
var $a = v4;
var Qa = $a([
	"Block",
	"CommentBlock",
	"MultiLine"
]);
var a0 = $a([
	"Line",
	"CommentLine",
	"SingleLine",
	"HashbangComment",
	"HTMLOpen",
	"HTMLClose",
	"Hashbang",
	"InterpreterDirective"
]);
var ad = /* @__PURE__ */ new WeakMap();
function S4(e) {
	return ad.has(e) || ad.set(e, Qa(e) && e.value[0] === "*" && /@(?:type|satisfies)\b/u.test(e.value)), ad.get(e);
}
var s0 = S4;
function w4(e) {
	if (!Qa(e)) return !1;
	let t = `*${e.value}*`.split(`
`);
	return t.length > 1 && t.every((a) => a.trimStart()[0] === "*");
}
var sd = /* @__PURE__ */ new WeakMap();
function k4(e) {
	return sd.has(e) || sd.set(e, w4(e)), sd.get(e);
}
var _d = k4;
function E4(e) {
	if (e.length < 2) return;
	let t;
	for (let a = e.length - 1; a >= 0; a--) {
		let _ = e[a];
		if (t && Un(_) === tr(t) && _d(_) && _d(t) && (e.splice(a + 1, 1), _.value += "*//*" + t.value, _.range = [tr(_), Un(t)]), !a0(_) && !Qa(_)) throw new TypeError(`Unknown comment type: "${_.type}".`);
		t = _;
	}
}
var _0 = E4;
function A4(e) {
	return e !== null && typeof e == "object";
}
var o0 = A4;
var E_ = null;
function A_(e) {
	if (E_ !== null && typeof E_.property) {
		let t = E_;
		return E_ = A_.prototype = null, t;
	}
	return E_ = A_.prototype = e ?? Object.create(null), new A_();
}
var C4 = 10;
for (let e = 0; e <= C4; e++) A_();
function od(e) {
	return A_(e);
}
function D4(e, t = "type") {
	od(e);
	function a(_) {
		let f = _[t], h = e[f];
		if (!Array.isArray(h)) throw Object.assign(/* @__PURE__ */ new Error(`Missing visitor keys for '${f}'.`), { node: _ });
		return h;
	}
	return a;
}
var c0 = D4;
var w = [
	[
		"decorators",
		"key",
		"typeAnnotation",
		"value"
	],
	[],
	["elementType"],
	["expression"],
	["expression", "typeAnnotation"],
	["left", "right"],
	["argument"],
	["directives", "body"],
	["label"],
	[
		"callee",
		"typeArguments",
		"arguments"
	],
	["body"],
	[
		"decorators",
		"id",
		"typeParameters",
		"superClass",
		"superTypeArguments",
		"mixins",
		"implements",
		"body",
		"superTypeParameters"
	],
	["id", "typeParameters"],
	[
		"decorators",
		"key",
		"typeParameters",
		"params",
		"returnType",
		"body"
	],
	[
		"decorators",
		"variance",
		"key",
		"typeAnnotation",
		"value"
	],
	["name", "typeAnnotation"],
	[
		"test",
		"consequent",
		"alternate"
	],
	[
		"checkType",
		"extendsType",
		"trueType",
		"falseType"
	],
	["value"],
	["id", "body"],
	[
		"declaration",
		"specifiers",
		"source",
		"attributes"
	],
	["id"],
	[
		"id",
		"typeParameters",
		"extends",
		"body"
	],
	["typeAnnotation"],
	[
		"id",
		"typeParameters",
		"right"
	],
	["body", "test"],
	["members"],
	["id", "init"],
	["exported"],
	[
		"left",
		"right",
		"body"
	],
	[
		"id",
		"typeParameters",
		"params",
		"predicate",
		"returnType",
		"body"
	],
	[
		"id",
		"params",
		"body",
		"typeParameters",
		"returnType"
	],
	["key", "value"],
	["local"],
	["objectType", "indexType"],
	["typeParameter"],
	["types"],
	["node"],
	["object", "property"],
	["argument", "cases"],
	[
		"pattern",
		"body",
		"guard"
	],
	["literal"],
	[
		"decorators",
		"key",
		"value"
	],
	["expressions"],
	["qualification", "id"],
	[
		"decorators",
		"key",
		"typeAnnotation"
	],
	[
		"typeParameters",
		"params",
		"returnType"
	],
	["expression", "typeArguments"],
	["params"],
	["parameterName", "typeAnnotation"]
];
var u0 = c0({
	AccessorProperty: w[0],
	AnyTypeAnnotation: w[1],
	ArgumentPlaceholder: w[1],
	ArrayExpression: ["elements"],
	ArrayPattern: [
		"elements",
		"typeAnnotation",
		"decorators"
	],
	ArrayTypeAnnotation: w[2],
	ArrowFunctionExpression: [
		"typeParameters",
		"params",
		"predicate",
		"returnType",
		"body"
	],
	AsConstExpression: w[3],
	AsExpression: w[4],
	AssignmentExpression: w[5],
	AssignmentPattern: [
		"left",
		"right",
		"decorators",
		"typeAnnotation"
	],
	AwaitExpression: w[6],
	BigIntLiteral: w[1],
	BigIntLiteralTypeAnnotation: w[1],
	BigIntTypeAnnotation: w[1],
	BinaryExpression: w[5],
	BindExpression: ["object", "callee"],
	BlockStatement: w[7],
	BooleanLiteral: w[1],
	BooleanLiteralTypeAnnotation: w[1],
	BooleanTypeAnnotation: w[1],
	BreakStatement: w[8],
	CallExpression: w[9],
	CatchClause: ["param", "body"],
	ChainExpression: w[3],
	ClassAccessorProperty: w[0],
	ClassBody: w[10],
	ClassDeclaration: w[11],
	ClassExpression: w[11],
	ClassImplements: w[12],
	ClassMethod: w[13],
	ClassPrivateMethod: w[13],
	ClassPrivateProperty: w[14],
	ClassProperty: w[14],
	ComponentDeclaration: [
		"id",
		"params",
		"body",
		"typeParameters",
		"rendersType"
	],
	ComponentParameter: ["name", "local"],
	ComponentTypeAnnotation: [
		"params",
		"rest",
		"typeParameters",
		"rendersType"
	],
	ComponentTypeParameter: w[15],
	ConditionalExpression: w[16],
	ConditionalTypeAnnotation: w[17],
	ContinueStatement: w[8],
	DebuggerStatement: w[1],
	DeclareClass: [
		"id",
		"typeParameters",
		"extends",
		"mixins",
		"implements",
		"body"
	],
	DeclareComponent: [
		"id",
		"params",
		"rest",
		"typeParameters",
		"rendersType"
	],
	DeclaredPredicate: w[18],
	DeclareEnum: w[19],
	DeclareExportAllDeclaration: ["source", "attributes"],
	DeclareExportDeclaration: w[20],
	DeclareFunction: ["id", "predicate"],
	DeclareHook: w[21],
	DeclareInterface: w[22],
	DeclareModule: w[19],
	DeclareModuleExports: w[23],
	DeclareNamespace: w[19],
	DeclareOpaqueType: [
		"id",
		"typeParameters",
		"supertype",
		"lowerBound",
		"upperBound"
	],
	DeclareTypeAlias: w[24],
	DeclareVariable: w[21],
	Decorator: w[3],
	Directive: w[18],
	DirectiveLiteral: w[1],
	DoExpression: w[10],
	DoWhileStatement: w[25],
	EmptyStatement: w[1],
	EmptyTypeAnnotation: w[1],
	EnumBigIntBody: w[26],
	EnumBigIntMember: w[27],
	EnumBooleanBody: w[26],
	EnumBooleanMember: w[27],
	EnumDeclaration: w[19],
	EnumDefaultedMember: w[21],
	EnumNumberBody: w[26],
	EnumNumberMember: w[27],
	EnumStringBody: w[26],
	EnumStringMember: w[27],
	EnumSymbolBody: w[26],
	ExistsTypeAnnotation: w[1],
	ExperimentalRestProperty: w[6],
	ExperimentalSpreadProperty: w[6],
	ExportAllDeclaration: [
		"source",
		"attributes",
		"exported"
	],
	ExportDefaultDeclaration: ["declaration"],
	ExportDefaultSpecifier: w[28],
	ExportNamedDeclaration: w[20],
	ExportNamespaceSpecifier: w[28],
	ExportSpecifier: ["local", "exported"],
	ExpressionStatement: w[3],
	File: ["program"],
	ForInStatement: w[29],
	ForOfStatement: w[29],
	ForStatement: [
		"init",
		"test",
		"update",
		"body"
	],
	FunctionDeclaration: w[30],
	FunctionExpression: w[30],
	FunctionTypeAnnotation: [
		"typeParameters",
		"this",
		"params",
		"rest",
		"returnType"
	],
	FunctionTypeParam: w[15],
	GenericTypeAnnotation: w[12],
	HookDeclaration: w[31],
	HookTypeAnnotation: [
		"params",
		"returnType",
		"rest",
		"typeParameters"
	],
	Identifier: ["typeAnnotation", "decorators"],
	IfStatement: w[16],
	ImportAttribute: w[32],
	ImportDeclaration: [
		"specifiers",
		"source",
		"attributes"
	],
	ImportDefaultSpecifier: w[33],
	ImportExpression: ["source", "options"],
	ImportNamespaceSpecifier: w[33],
	ImportSpecifier: ["imported", "local"],
	IndexedAccessType: w[34],
	InferredPredicate: w[1],
	InferTypeAnnotation: w[35],
	InterfaceDeclaration: w[22],
	InterfaceExtends: w[12],
	InterfaceTypeAnnotation: ["extends", "body"],
	InterpreterDirective: w[1],
	IntersectionTypeAnnotation: w[36],
	JsExpressionRoot: w[37],
	JsonRoot: w[37],
	JSXAttribute: ["name", "value"],
	JSXClosingElement: ["name"],
	JSXClosingFragment: w[1],
	JSXElement: [
		"openingElement",
		"children",
		"closingElement"
	],
	JSXEmptyExpression: w[1],
	JSXExpressionContainer: w[3],
	JSXFragment: [
		"openingFragment",
		"children",
		"closingFragment"
	],
	JSXIdentifier: w[1],
	JSXMemberExpression: w[38],
	JSXNamespacedName: ["namespace", "name"],
	JSXOpeningElement: [
		"name",
		"typeArguments",
		"attributes"
	],
	JSXOpeningFragment: w[1],
	JSXSpreadAttribute: w[6],
	JSXSpreadChild: w[3],
	JSXText: w[1],
	KeyofTypeAnnotation: w[6],
	LabeledStatement: ["label", "body"],
	Literal: w[1],
	LogicalExpression: w[5],
	MatchArrayPattern: ["elements", "rest"],
	MatchAsPattern: ["pattern", "target"],
	MatchBindingPattern: w[21],
	MatchExpression: w[39],
	MatchExpressionCase: w[40],
	MatchIdentifierPattern: w[21],
	MatchLiteralPattern: w[41],
	MatchMemberPattern: ["base", "property"],
	MatchObjectPattern: ["properties", "rest"],
	MatchObjectPatternProperty: ["key", "pattern"],
	MatchOrPattern: ["patterns"],
	MatchRestPattern: w[6],
	MatchStatement: w[39],
	MatchStatementCase: w[40],
	MatchUnaryPattern: w[6],
	MatchWildcardPattern: w[1],
	MemberExpression: w[38],
	MetaProperty: ["meta", "property"],
	MethodDefinition: w[42],
	MixedTypeAnnotation: w[1],
	ModuleExpression: w[10],
	NeverTypeAnnotation: w[1],
	NewExpression: w[9],
	NGChainedExpression: w[43],
	NGEmptyExpression: w[1],
	NGMicrosyntax: w[10],
	NGMicrosyntaxAs: ["key", "alias"],
	NGMicrosyntaxExpression: ["expression", "alias"],
	NGMicrosyntaxKey: w[1],
	NGMicrosyntaxKeyedExpression: ["key", "expression"],
	NGMicrosyntaxLet: w[32],
	NGPipeExpression: [
		"left",
		"right",
		"arguments"
	],
	NGRoot: w[37],
	NullableTypeAnnotation: w[23],
	NullLiteral: w[1],
	NullLiteralTypeAnnotation: w[1],
	NumberLiteralTypeAnnotation: w[1],
	NumberTypeAnnotation: w[1],
	NumericLiteral: w[1],
	ObjectExpression: ["properties"],
	ObjectMethod: w[13],
	ObjectPattern: [
		"decorators",
		"properties",
		"typeAnnotation"
	],
	ObjectProperty: w[42],
	ObjectTypeAnnotation: [
		"properties",
		"indexers",
		"callProperties",
		"internalSlots"
	],
	ObjectTypeCallProperty: w[18],
	ObjectTypeIndexer: [
		"variance",
		"id",
		"key",
		"value"
	],
	ObjectTypeInternalSlot: ["id", "value"],
	ObjectTypeMappedTypeProperty: [
		"keyTparam",
		"propType",
		"sourceType",
		"variance"
	],
	ObjectTypeProperty: [
		"key",
		"value",
		"variance"
	],
	ObjectTypeSpreadProperty: w[6],
	OpaqueType: [
		"id",
		"typeParameters",
		"supertype",
		"impltype",
		"lowerBound",
		"upperBound"
	],
	OptionalCallExpression: w[9],
	OptionalIndexedAccessType: w[34],
	OptionalMemberExpression: w[38],
	ParenthesizedExpression: w[3],
	PipelineBareFunction: ["callee"],
	PipelinePrimaryTopicReference: w[1],
	PipelineTopicExpression: w[3],
	Placeholder: w[1],
	PrivateIdentifier: w[1],
	PrivateName: w[21],
	Program: w[7],
	Property: w[32],
	PropertyDefinition: w[14],
	QualifiedTypeIdentifier: w[44],
	QualifiedTypeofIdentifier: w[44],
	RegExpLiteral: w[1],
	RestElement: [
		"argument",
		"typeAnnotation",
		"decorators"
	],
	ReturnStatement: w[6],
	SatisfiesExpression: w[4],
	SequenceExpression: w[43],
	SpreadElement: w[6],
	StaticBlock: w[10],
	StringLiteral: w[1],
	StringLiteralTypeAnnotation: w[1],
	StringTypeAnnotation: w[1],
	Super: w[1],
	SwitchCase: ["test", "consequent"],
	SwitchStatement: ["discriminant", "cases"],
	SymbolTypeAnnotation: w[1],
	TaggedTemplateExpression: [
		"tag",
		"typeArguments",
		"quasi"
	],
	TemplateElement: w[1],
	TemplateLiteral: ["quasis", "expressions"],
	ThisExpression: w[1],
	ThisTypeAnnotation: w[1],
	ThrowStatement: w[6],
	TopicReference: w[1],
	TryStatement: [
		"block",
		"handler",
		"finalizer"
	],
	TSAbstractAccessorProperty: w[45],
	TSAbstractKeyword: w[1],
	TSAbstractMethodDefinition: w[32],
	TSAbstractPropertyDefinition: w[45],
	TSAnyKeyword: w[1],
	TSArrayType: w[2],
	TSAsExpression: w[4],
	TSAsyncKeyword: w[1],
	TSBigIntKeyword: w[1],
	TSBooleanKeyword: w[1],
	TSCallSignatureDeclaration: w[46],
	TSClassImplements: w[47],
	TSConditionalType: w[17],
	TSConstructorType: w[46],
	TSConstructSignatureDeclaration: w[46],
	TSDeclareFunction: w[31],
	TSDeclareKeyword: w[1],
	TSDeclareMethod: [
		"decorators",
		"key",
		"typeParameters",
		"params",
		"returnType"
	],
	TSEmptyBodyFunctionExpression: [
		"id",
		"typeParameters",
		"params",
		"returnType"
	],
	TSEnumBody: w[26],
	TSEnumDeclaration: w[19],
	TSEnumMember: ["id", "initializer"],
	TSExportAssignment: w[3],
	TSExportKeyword: w[1],
	TSExternalModuleReference: w[3],
	TSFunctionType: w[46],
	TSImportEqualsDeclaration: ["id", "moduleReference"],
	TSImportType: [
		"options",
		"qualifier",
		"typeArguments",
		"source"
	],
	TSIndexedAccessType: w[34],
	TSIndexSignature: ["parameters", "typeAnnotation"],
	TSInferType: w[35],
	TSInstantiationExpression: w[47],
	TSInterfaceBody: w[10],
	TSInterfaceDeclaration: w[22],
	TSInterfaceHeritage: w[47],
	TSIntersectionType: w[36],
	TSIntrinsicKeyword: w[1],
	TSJSDocAllType: w[1],
	TSJSDocNonNullableType: w[23],
	TSJSDocNullableType: w[23],
	TSJSDocUnknownType: w[1],
	TSLiteralType: w[41],
	TSMappedType: [
		"key",
		"constraint",
		"nameType",
		"typeAnnotation"
	],
	TSMethodSignature: [
		"key",
		"typeParameters",
		"params",
		"returnType"
	],
	TSModuleBlock: w[10],
	TSModuleDeclaration: w[19],
	TSNamedTupleMember: ["label", "elementType"],
	TSNamespaceExportDeclaration: w[21],
	TSNeverKeyword: w[1],
	TSNonNullExpression: w[3],
	TSNullKeyword: w[1],
	TSNumberKeyword: w[1],
	TSObjectKeyword: w[1],
	TSOptionalType: w[23],
	TSParameterProperty: ["parameter", "decorators"],
	TSParenthesizedType: w[23],
	TSPrivateKeyword: w[1],
	TSPropertySignature: ["key", "typeAnnotation"],
	TSProtectedKeyword: w[1],
	TSPublicKeyword: w[1],
	TSQualifiedName: w[5],
	TSReadonlyKeyword: w[1],
	TSRestType: w[23],
	TSSatisfiesExpression: w[4],
	TSStaticKeyword: w[1],
	TSStringKeyword: w[1],
	TSSymbolKeyword: w[1],
	TSTemplateLiteralType: ["quasis", "types"],
	TSThisType: w[1],
	TSTupleType: ["elementTypes"],
	TSTypeAliasDeclaration: [
		"id",
		"typeParameters",
		"typeAnnotation"
	],
	TSTypeAnnotation: w[23],
	TSTypeAssertion: w[4],
	TSTypeLiteral: w[26],
	TSTypeOperator: w[23],
	TSTypeParameter: [
		"name",
		"constraint",
		"default"
	],
	TSTypeParameterDeclaration: w[48],
	TSTypeParameterInstantiation: w[48],
	TSTypePredicate: w[49],
	TSTypeQuery: ["exprName", "typeArguments"],
	TSTypeReference: ["typeName", "typeArguments"],
	TSUndefinedKeyword: w[1],
	TSUnionType: w[36],
	TSUnknownKeyword: w[1],
	TSVoidKeyword: w[1],
	TupleTypeAnnotation: ["types", "elementTypes"],
	TupleTypeLabeledElement: [
		"label",
		"elementType",
		"variance"
	],
	TupleTypeSpreadElement: ["label", "typeAnnotation"],
	TypeAlias: w[24],
	TypeAnnotation: w[23],
	TypeCastExpression: w[4],
	TypeofTypeAnnotation: ["argument", "typeArguments"],
	TypeOperator: w[23],
	TypeParameter: [
		"bound",
		"default",
		"variance"
	],
	TypeParameterDeclaration: w[48],
	TypeParameterInstantiation: w[48],
	TypePredicate: w[49],
	UnaryExpression: w[6],
	UndefinedTypeAnnotation: w[1],
	UnionTypeAnnotation: w[36],
	UnknownTypeAnnotation: w[1],
	UpdateExpression: w[6],
	V8IntrinsicIdentifier: w[1],
	VariableDeclaration: ["declarations"],
	VariableDeclarator: w[27],
	Variance: w[1],
	VoidPattern: w[1],
	VoidTypeAnnotation: w[1],
	WhileStatement: w[25],
	WithStatement: ["object", "body"],
	YieldExpression: w[6]
});
function Bl(e, t) {
	if (!o0(e)) return e;
	if (Array.isArray(e)) {
		for (let _ = 0; _ < e.length; _++) e[_] = Bl(e[_], t);
		return e;
	}
	if (t.onEnter) {
		let _ = t.onEnter(e) ?? e;
		if (_ !== e) return Bl(_, t);
		e = _;
	}
	let a = u0(e);
	for (let _ = 0; _ < a.length; _++) e[a[_]] = Bl(e[a[_]], t);
	return t.onLeave && (e = t.onLeave(e) || e), e;
}
var p0 = Bl;
$a([
	"RegExpLiteral",
	"BigIntLiteral",
	"NumericLiteral",
	"StringLiteral",
	"DirectiveLiteral",
	"Literal",
	"JSXText",
	"TemplateElement",
	"StringLiteralTypeAnnotation",
	"NumberLiteralTypeAnnotation",
	"BigIntLiteralTypeAnnotation"
]);
function N4(e, t) {
	let { parser: a, text: _ } = t, { comments: f } = e, h = a === "oxc" && t.oxcAstType === "ts";
	_0(f);
	let T = e.type === "File" ? e.program : e;
	T.interpreter && (f.unshift(T.interpreter), delete T.interpreter), h && e.hashbang && (f.unshift(e.hashbang), delete e.hashbang), e.type === "Program" && (e.range = [0, _.length]);
	let k;
	return e = p0(e, {
		onEnter(c) {
			switch (c.type) {
				case "ParenthesizedExpression": {
					let { expression: W } = c, y = tr(c);
					if (W.type === "TypeCastExpression") return W.range = [y, Un(c)], W;
					let G = !1;
					if (!h) {
						if (!k) {
							k = [];
							for (let D of f) s0(D) && k.push(Un(D));
						}
						let E = r0(0, k, (D) => D <= y);
						G = E && _.slice(E, y).trim().length === 0;
					}
					return G ? void 0 : (W.extra = {
						...W.extra,
						parenthesized: !0
					}, W);
				}
				case "TemplateLiteral":
					if (c.expressions.length !== c.quasis.length - 1) throw new Error("Malformed template literal.");
					break;
				case "TemplateElement":
					if (a === "flow" || a === "hermes" || a === "espree" || a === "typescript" || h) c.range = [tr(c) + 1, Un(c) - (c.tail ? 1 : 2)];
					break;
				case "VariableDeclaration": {
					let W = i0(0, c.declarations, -1);
					W?.init && _[Un(W)] !== ";" && (c.range = [tr(c), Un(W)]);
					break;
				}
				case "TSParenthesizedType": return c.typeAnnotation;
				case "TopicReference":
					e.extra = {
						...e.extra,
						__isUsingHackPipeline: !0
					};
					break;
				case "TSUnionType":
				case "TSIntersectionType":
					if (c.types.length === 1) return c.types[0];
					break;
				case "ImportExpression":
					a === "hermes" && c.attributes && !c.options && (c.options = c.attributes);
					break;
			}
		},
		onLeave(c) {
			switch (c.type) {
				case "LogicalExpression":
					if (f0(c)) return cd(c);
					break;
				case "TSImportType":
					!c.source && c.argument.type === "TSLiteralType" && (c.source = c.argument.literal, delete c.argument);
					break;
			}
		}
	}), e;
}
function f0(e) {
	return e.type === "LogicalExpression" && e.right.type === "LogicalExpression" && e.operator === e.right.operator;
}
function cd(e) {
	return f0(e) ? cd({
		type: "LogicalExpression",
		operator: e.operator,
		left: cd({
			type: "LogicalExpression",
			operator: e.operator,
			left: e.left,
			right: e.right.left,
			range: [tr(e.left), Un(e.right.left)]
		}),
		right: e.right.right,
		range: [tr(e), Un(e)]
	}) : e;
}
var d0 = N4;
var I4 = /\*\/$/, O4 = /^\/\*\*?/, M4 = /^\s*(\/\*\*?(.|\r?\n)*?\*\/)/, L4 = /(^|\s+)\/\/([^\n\r]*)/g, m0 = /^(\r?\n)+/, J4 = /(?:^|\r?\n) *(@[^\n\r]*?) *\r?\n *(?![^\n\r@]*\/\/[^]*)([^\s@][^\n\r@]+?) *\r?\n/g, h0 = /(?:^|\r?\n) *@(\S+) *([^\n\r]*)/g, j4 = /(\r?\n|^) *\* ?/g, R4 = [];
function y0(e) {
	let t = e.match(M4);
	return t ? t[0].trimStart() : "";
}
function g0(e) {
	e = Wr(0, e.replace(O4, "").replace(I4, ""), j4, "$1");
	let a = "";
	for (; a !== e;) a = e, e = Wr(0, e, J4, `
$1 $2
`);
	e = e.replace(m0, "").trimEnd();
	let _ = Object.create(null), f = Wr(0, e, h0, "").replace(m0, "").trimEnd(), h;
	for (; h = h0.exec(e);) {
		let T = Wr(0, h[2], L4, "");
		if (typeof _[h[1]] == "string" || Array.isArray(_[h[1]])) {
			let k = _[h[1]];
			_[h[1]] = [
				...R4,
				...Array.isArray(k) ? k : [k],
				T
			];
		} else _[h[1]] = T;
	}
	return {
		comments: f,
		pragmas: _
	};
}
var b0 = ["noformat", "noprettier"], v0 = ["format", "prettier"];
function U4(e) {
	if (!e.startsWith("#!")) return "";
	let t = e.indexOf(`
`);
	return t === -1 ? e : e.slice(0, t);
}
var T0 = U4;
function x0(e) {
	let t = T0(e);
	t && (e = e.slice(t.length + 1));
	let { pragmas: _, comments: f } = g0(y0(e));
	return {
		shebang: t,
		text: e,
		pragmas: _,
		comments: f
	};
}
function S0(e) {
	let { pragmas: t } = x0(e);
	return v0.some((a) => Object.prototype.hasOwnProperty.call(t, a));
}
function w0(e) {
	let { pragmas: t } = x0(e);
	return b0.some((a) => Object.prototype.hasOwnProperty.call(t, a));
}
function B4(e) {
	return e = typeof e == "function" ? { parse: e } : e, {
		astFormat: "estree",
		hasPragma: S0,
		hasIgnorePragma: w0,
		locStart: tr,
		locEnd: Un,
		...e
	};
}
var k0 = B4;
var E0 = /^[^"'`]*<\/|^[^/]{2}.*\/>/mu;
function q4(e) {
	return e.charAt(0) === "#" && e.charAt(1) === "!" ? "//" + e.slice(2) : e;
}
var A0 = q4;
var C0 = "module";
var D0 = "commonjs", P0 = [C0, D0];
function N0(e) {
	if (typeof e == "string") {
		if (e = e.toLowerCase(), /\.(?:mjs|mts)$/iu.test(e)) return C0;
		if (/\.(?:cjs|cts)$/iu.test(e)) return D0;
	}
}
var F4 = {
	loc: !0,
	range: !0,
	comment: !0,
	tokens: !1,
	loggerFn: !1,
	project: !1,
	jsDocParsingMode: "none",
	suppressDeprecatedPropertyWarnings: !0
};
function z4(e) {
	let { message: t, location: a } = e;
	if (!a) return e;
	let { start: _, end: f } = a;
	return t0(t, {
		loc: {
			start: {
				line: _.line,
				column: _.column + 1
			},
			end: {
				line: f.line,
				column: f.column + 1
			}
		},
		cause: e
	});
}
var V4 = (e) => e && /\.(?:js|mjs|cjs|jsx|ts|mts|cts|tsx)$/iu.test(e);
function W4(e, t) {
	let a = [{
		...F4,
		filePath: t
	}], _ = N0(t);
	if (_ ? a = a.map((h) => ({
		...h,
		sourceType: _
	})) : a = P0.flatMap((h) => a.map((T) => ({
		...T,
		sourceType: h
	}))), V4(t)) return a;
	let f = E0.test(e);
	return [f, !f].flatMap((h) => a.map((T) => ({
		...T,
		jsx: h
	})));
}
function G4(e, t) {
	let a = t?.filepath;
	typeof a != "string" && (a = void 0);
	let _ = A0(e), f = W4(e, a), h;
	try {
		h = n0(f.map((T) => () => e0(_, T)));
	} catch ({ errors: [T] }) {
		throw z4(T);
	}
	return d0(h, {
		parser: "typescript",
		text: e
	});
}
var Y4 = k0(G4);
//#endregion
export { I0 as default, ld as parsers };
